﻿

""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: GGDM30_FCFieldsFeaAsFC.py                                        **
 **  Copyright (c) March 2017 by Leidos                                                      **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides a schema-like definition for the data model:             **
 **                 GGDM 3.0 Composite                                    **
 **
 **    A python dictionary structure is used to define the schema fields for this data model
 **    allowing for the look up and retrieval of default value information, assigned feature code
 **    and identification of whether an attribute applies to a feature within a feature class.
 **
 **    This information is specific to the data model listed above.
 **
 **    The information held within this definition consists of:
 **    1) interval_fields: are special case fields that do not have the standard default value
 **    2) feature class lists
 **    3) fields in the feature class, and for each field, the data type and list of feature codes
 **       on which the field is 'allowed'
 **    4) fields that are enumerated values also get a list of the allowed values for that field
 **    5) summary domain values is a listing of the domain value numeric and textual value that may be
 **       useful for lookup or documentation purposes
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                                                        **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2017 / Annette Janett Filer (Annette.J.Filer@leidos.com) Original version                                                     **               **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""

def GGDM30AddSchemaInfoFeaturesAsFCTables(field_information):
    field_information['GGDM 3.0']['interval_fields'] = {'AQTC','AYRC','BPWHAC','BPWHBC','BPWSAC','BPWSBC','BWVCAC','BWVCBC','DMBC','DPAC','GSGCHC','GSGCLC','PFHC','PWAC','RMWC','SDCC','SDSC','SGCC','SNDC','TSCC','VAVC','WDAC','WRCC','WWRC','ZI015_GCUC','ZI026_CTUC'}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S'] = {}
    field_information['GGDM 3.0']['AERIAL_P'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S'] = {}
    field_information['GGDM 3.0']['ANCHOR_P'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S'] = {}
    field_information['GGDM 3.0']['APRON_S'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S'] = {}
    field_information['GGDM 3.0']['AQUIFER_S'] = {}
    field_information['GGDM 3.0']['ARCADE_C'] = {}
    field_information['GGDM 3.0']['ARCADE_S'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S'] = {}
    field_information['GGDM 3.0']['BARN_P'] = {}
    field_information['GGDM 3.0']['BARN_S'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C'] = {}
    field_information['GGDM 3.0']['BEACH_S'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P'] = {}
    field_information['GGDM 3.0']['BERTH_P'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S'] = {}
    field_information['GGDM 3.0']['BOG_S'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P'] = {}
    field_information['GGDM 3.0']['BRIDGE_C'] = {}
    field_information['GGDM 3.0']['BRIDGE_P'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S'] = {}
    field_information['GGDM 3.0']['BRIDGE_S'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P'] = {}
    field_information['GGDM 3.0']['BRUSH_S'] = {}
    field_information['GGDM 3.0']['BUILDING_P'] = {}
    field_information['GGDM 3.0']['BUILDING_S'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S'] = {}
    field_information['GGDM 3.0']['BUOY_P'] = {}
    field_information['GGDM 3.0']['CABLE_C'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C'] = {}
    field_information['GGDM 3.0']['CAIRN_P'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P'] = {}
    field_information['GGDM 3.0']['CAMP_P'] = {}
    field_information['GGDM 3.0']['CAMP_S'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S'] = {}
    field_information['GGDM 3.0']['CANE_S'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S'] = {}
    field_information['GGDM 3.0']['CASTLE_P'] = {}
    field_information['GGDM 3.0']['CASTLE_S'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P'] = {}
    field_information['GGDM 3.0']['CEMETERY_P'] = {}
    field_information['GGDM 3.0']['CEMETERY_S'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S'] = {}
    field_information['GGDM 3.0']['CISTERN_P'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S'] = {}
    field_information['GGDM 3.0']['CODE_LIST_T'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S'] = {}
    field_information['GGDM 3.0']['COURTYARD_S'] = {}
    field_information['GGDM 3.0']['CRANE_P'] = {}
    field_information['GGDM 3.0']['CRANE_S'] = {}
    field_information['GGDM 3.0']['CRATER_P'] = {}
    field_information['GGDM 3.0']['CRATER_S'] = {}
    field_information['GGDM 3.0']['CREVASSE_C'] = {}
    field_information['GGDM 3.0']['CREVASSE_S'] = {}
    field_information['GGDM 3.0']['CREVICE_C'] = {}
    field_information['GGDM 3.0']['CREVICE_S'] = {}
    field_information['GGDM 3.0']['CRIB_P'] = {}
    field_information['GGDM 3.0']['CRIB_S'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S'] = {}
    field_information['GGDM 3.0']['CROSSING_P'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S'] = {}
    field_information['GGDM 3.0']['CULVERT_C'] = {}
    field_information['GGDM 3.0']['CULVERT_P'] = {}
    field_information['GGDM 3.0']['CUT_C'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C'] = {}
    field_information['GGDM 3.0']['DAM_C'] = {}
    field_information['GGDM 3.0']['DAM_P'] = {}
    field_information['GGDM 3.0']['DAM_S'] = {}
    field_information['GGDM 3.0']['DATASET_S'] = {}
    field_information['GGDM 3.0']['DATASET_T'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C'] = {}
    field_information['GGDM 3.0']['DESERT_S'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S'] = {}
    field_information['GGDM 3.0']['DITCH_C'] = {}
    field_information['GGDM 3.0']['DITCH_S'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T'] = {}
    field_information['GGDM 3.0']['ESKER_C'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S'] = {}
    field_information['GGDM 3.0']['FACILITY_P'] = {}
    field_information['GGDM 3.0']['FACILITY_S'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S'] = {}
    field_information['GGDM 3.0']['FENCE_C'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S'] = {}
    field_information['GGDM 3.0']['FORD_C'] = {}
    field_information['GGDM 3.0']['FORD_P'] = {}
    field_information['GGDM 3.0']['FORD_S'] = {}
    field_information['GGDM 3.0']['FORESHORE_S'] = {}
    field_information['GGDM 3.0']['FOREST_C'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S'] = {}
    field_information['GGDM 3.0']['FOREST_S'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S'] = {}
    field_information['GGDM 3.0']['GANTRY_C'] = {}
    field_information['GGDM 3.0']['GANTRY_P'] = {}
    field_information['GGDM 3.0']['GATE_C'] = {}
    field_information['GGDM 3.0']['GATE_P'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S'] = {}
    field_information['GGDM 3.0']['GLACIER_S'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S'] = {}
    field_information['GGDM 3.0']['GROVE_P'] = {}
    field_information['GGDM 3.0']['GROVE_S'] = {}
    field_information['GGDM 3.0']['HARBOUR_S'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C'] = {}
    field_information['GGDM 3.0']['HELIPAD_P'] = {}
    field_information['GGDM 3.0']['HELIPAD_S'] = {}
    field_information['GGDM 3.0']['HELIPORT_P'] = {}
    field_information['GGDM 3.0']['HELIPORT_S'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S'] = {}
    field_information['GGDM 3.0']['HOPPER_P'] = {}
    field_information['GGDM 3.0']['HULK_P'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S'] = {}
    field_information['GGDM 3.0']['HUT_P'] = {}
    field_information['GGDM 3.0']['HUT_S'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C'] = {}
    field_information['GGDM 3.0']['ISLAND_P'] = {}
    field_information['GGDM 3.0']['ISLAND_S'] = {}
    field_information['GGDM 3.0']['LAGOON_S'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S'] = {}
    field_information['GGDM 3.0']['LOCK_C'] = {}
    field_information['GGDM 3.0']['LOCK_P'] = {}
    field_information['GGDM 3.0']['LOCK_S'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P'] = {}
    field_information['GGDM 3.0']['MARSH_S'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S'] = {}
    field_information['GGDM 3.0']['MOAT_C'] = {}
    field_information['GGDM 3.0']['MOAT_S'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P'] = {}
    field_information['GGDM 3.0']['MORAINE_S'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S'] = {}
    field_information['GGDM 3.0']['OASIS_P'] = {}
    field_information['GGDM 3.0']['OASIS_S'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S'] = {}
    field_information['GGDM 3.0']['ORCHARD_P'] = {}
    field_information['GGDM 3.0']['ORCHARD_S'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S'] = {}
    field_information['GGDM 3.0']['PARK_S'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S'] = {}
    field_information['GGDM 3.0']['PIPELINE_C'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S'] = {}
    field_information['GGDM 3.0']['PORT_P'] = {}
    field_information['GGDM 3.0']['PORT_S'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S'] = {}
    field_information['GGDM 3.0']['PUMP_P'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S'] = {}
    field_information['GGDM 3.0']['PYLON_P'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P'] = {}
    field_information['GGDM 3.0']['RACETRACK_C'] = {}
    field_information['GGDM 3.0']['RACETRACK_S'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S'] = {}
    field_information['GGDM 3.0']['RAILWAY_C'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S'] = {}
    field_information['GGDM 3.0']['RAMP_C'] = {}
    field_information['GGDM 3.0']['RAMP_S'] = {}
    field_information['GGDM 3.0']['RAPIDS_C'] = {}
    field_information['GGDM 3.0']['RAPIDS_P'] = {}
    field_information['GGDM 3.0']['RAPIDS_S'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S'] = {}
    field_information['GGDM 3.0']['REEF_C'] = {}
    field_information['GGDM 3.0']['REEF_S'] = {}
    field_information['GGDM 3.0']['RESTRICTION_INFO_T'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S'] = {}
    field_information['GGDM 3.0']['RIG_P'] = {}
    field_information['GGDM 3.0']['RIG_S'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S'] = {}
    field_information['GGDM 3.0']['RIVER_C'] = {}
    field_information['GGDM 3.0']['RIVER_S'] = {}
    field_information['GGDM 3.0']['ROAD_C'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P'] = {}
    field_information['GGDM 3.0']['ROAD_S'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S'] = {}
    field_information['GGDM 3.0']['RUINS_P'] = {}
    field_information['GGDM 3.0']['RUINS_S'] = {}
    field_information['GGDM 3.0']['RUNWAY_S'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S'] = {}
    field_information['GGDM 3.0']['SABKHA_S'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C'] = {}
    field_information['GGDM 3.0']['SHED_P'] = {}
    field_information['GGDM 3.0']['SHED_S'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S'] = {}
    field_information['GGDM 3.0']['SHORELINE_C'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P'] = {}
    field_information['GGDM 3.0']['SNAG_P'] = {}
    field_information['GGDM 3.0']['SNAG_S'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S'] = {}
    field_information['GGDM 3.0']['SOUNDING_P'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P'] = {}
    field_information['GGDM 3.0']['STABLE_P'] = {}
    field_information['GGDM 3.0']['STABLE_S'] = {}
    field_information['GGDM 3.0']['STADIUM_P'] = {}
    field_information['GGDM 3.0']['STADIUM_S'] = {}
    field_information['GGDM 3.0']['STAIR_C'] = {}
    field_information['GGDM 3.0']['STAIR_S'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C'] = {}
    field_information['GGDM 3.0']['STOPWAY_S'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P'] = {}
    field_information['GGDM 3.0']['SWAMP_S'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P'] = {}
    field_information['GGDM 3.0']['THICKET_S'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S'] = {}
    field_information['GGDM 3.0']['TOMB_P'] = {}
    field_information['GGDM 3.0']['TOMB_S'] = {}
    field_information['GGDM 3.0']['TOWER_P'] = {}
    field_information['GGDM 3.0']['TOWER_S'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S'] = {}
    field_information['GGDM 3.0']['TRAIL_C'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S'] = {}
    field_information['GGDM 3.0']['TREE_P'] = {}
    field_information['GGDM 3.0']['TUNDRA_S'] = {}
    field_information['GGDM 3.0']['TUNNEL_C'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P'] = {}
    field_information['GGDM 3.0']['TUNNEL_S'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S'] = {}
    field_information['GGDM 3.0']['VINEYARD_P'] = {}
    field_information['GGDM 3.0']['VINEYARD_S'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C'] = {}
    field_information['GGDM 3.0']['VOLCANO_P'] = {}
    field_information['GGDM 3.0']['VOLCANO_S'] = {}
    field_information['GGDM 3.0']['WALL_C'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S'] = {}
    field_information['GGDM 3.0']['WATERFALL_C'] = {}
    field_information['GGDM 3.0']['WATERFALL_P'] = {}
    field_information['GGDM 3.0']['WATERWORK_P'] = {}
    field_information['GGDM 3.0']['WATERWORK_S'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P'] = {}
    field_information['GGDM 3.0']['WINDMILL_P'] = {}
    field_information['GGDM 3.0']['WINDMILL_S'] = {}
    field_information['GGDM 3.0']['WRECK_P'] = {}
    field_information['GGDM 3.0']['WRECK_S'] = {}
    field_information['GGDM 3.0']['ZOO_P'] = {}
    field_information['GGDM 3.0']['ZOO_S'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CODE_LIST_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues'] = {}


    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['BEN'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['BST'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['BST'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['BST']['FA000']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['CAA'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['CAA']['FA000']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['DSP'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['DSP']['FA000']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['F_CODE'] = ('CONSTRAINED_STRING',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['FA003_BAL'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['FA003_BAL'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['FA003_BAL']['FA000']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['FUFI'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['FURL'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['GDBV'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['GDBV']['FA000']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['LSP'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['LSP'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['LSP']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['LZN'] = ('Real',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['MGL'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['MGL2'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL2'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL2']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['MGL3'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL3'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['MGL3']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['OTH'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['RPC'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['RPC'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['RPC']['FA000']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['UFI'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI001_SDV'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI001_SRT'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT']['FA000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI002_UFI'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI004_RCG'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_FNAA'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_FNAB'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_GNTA'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTA'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTA']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_GNTB'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTB'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTB']['FA000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_NFNA'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI005_NFNB'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI006_MEM'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI020_FI2A'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI020_FI2B'] = ('String',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI020_GE4'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI020_GE4A'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI020_GE4B'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI026_CTUC'] = ('Enumeration',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC']['FA000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI026_CTUL'] = ('integer',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI026_CTUU'] = ('integer',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI031S_URI'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZI039S_UFI'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZSAX_RS0'] = ('CodeList',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZSAX_RX0'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZSAX_RX3'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_BOUNDARY_C']['ZSAX_RX4'] = ('StructuredText',('FA000'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ARA'] = ('Real',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['BEN'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['CAA'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['CAA']['FA003']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['FUFI'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['FURL'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['GDBV'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['GDBV']['FA003']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['OTH'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['PPL'] = ('Integer',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['UFI'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI001_SDV'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI001_SRT'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI001_SRT']['FA003']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI002_UFI'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI004_RCG'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI004_RCG']['FA003']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI005_FNA'] = ('String',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI005_GNT'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI005_GNT']['FA003']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI005_NFN'] = ('String',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI006_MEM'] = ('String',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI020_GE4'] = ('CodeList',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI026_CTUC'] = ('Enumeration',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA003']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI026_CTUL'] = ('integer',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI026_CTUU'] = ('integer',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI031S_URI'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZI039S_UFI'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZSAX_RS0'] = ('CodeList',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZSAX_RX0'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZSAX_RX3'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['ADMINISTRATIVE_SUBDIVISION_S']['ZSAX_RX4'] = ('StructuredText',('FA003'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ARA'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['BEN'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['CNCP'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['COS'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['COS']['AB040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['FUFI'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['FURL'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['GDBV'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['GDBV']['AB040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['LMC'] = ('Boolean',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['LZN'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['OTH'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['PCF'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['PCF']['AB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['UFI'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['VLM'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['WID'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI001_SDV'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI001_SRT'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI001_SRT']['AB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI002_UFI'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI004_RCG'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI004_RCG']['AB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI005_FNA'] = ('String',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI005_GNT'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI005_GNT']['AB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI005_NFN'] = ('String',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI006_MEM'] = ('String',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI020_GE4'] = ('CodeList',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_ASE'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_CFR'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_CLO'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_CYN'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_FMR'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_FRR'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_HAR'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_MGN'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_PHW'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_SCC'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI024_SCC']['AB040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_SUL'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_TDS'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_TEP'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_TUR'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_WAC'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI024_WTNO'] = ('Real',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI026_CTUC'] = ('Enumeration',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERATION_BASIN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI026_CTUL'] = ('integer',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI026_CTUU'] = ('integer',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI031S_URI'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZI039S_UFI'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZSAX_RS0'] = ('CodeList',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZSAX_RX0'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZSAX_RX3'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERATION_BASIN_S']['ZSAX_RX4'] = ('StructuredText',('AB040'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ADR'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['AOO'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ARA'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['BEN'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['CAA'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['CAA']['AT012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['CNCP'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['COS'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['COS']['AT012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['FFN'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['FFN2'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['FFN3'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['FUFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['FURL'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['GDBV'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['GDBV']['AT012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['HGT'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['LMC'] = ('Boolean',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['LZN'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['OTH'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['PCF'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['WID'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI001_SDV'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI001_SRT'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI001_SRT']['AT012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI002_UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI004_RCG'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI004_RCG']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI005_FNA'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI005_GNT'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI005_GNT']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI005_NFN'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI006_MEM'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI020_GE4'] = ('CodeList',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI026_CTUC'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AT012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI026_CTUL'] = ('integer',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI026_CTUU'] = ('integer',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI031S_URI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZI039S_UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZSAX_RS0'] = ('CodeList',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZSAX_RX0'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZSAX_RX3'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZSAX_RX4'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_P']['ZVH'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ADR'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['AOO'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ARA'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['BEN'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['CAA'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['CAA']['AT012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['CNCP'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['COS'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['COS']['AT012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['FFN'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['FFN2'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['FFN3'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['FUFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['FURL'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['GDBV'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['GDBV']['AT012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['HGT'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['LMC'] = ('Boolean',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['LZN'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['OTH'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['PCF'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['WID'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI001_SDV'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI001_SRT'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI001_SRT']['AT012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI002_UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI004_RCG'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI004_RCG']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI005_FNA'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI005_GNT'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI005_GNT']['AT012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI005_NFN'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI006_MEM'] = ('String',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI020_GE4'] = ('CodeList',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI026_CTUC'] = ('Enumeration',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERIAL_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AT012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI026_CTUL'] = ('integer',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI026_CTUU'] = ('integer',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI031S_URI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZI039S_UFI'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZSAX_RS0'] = ('CodeList',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZSAX_RX0'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZSAX_RX3'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZSAX_RX4'] = ('StructuredText',('AT012'))
    field_information['GGDM 3.0']['AERIAL_FARM_S']['ZVH'] = ('Real',('AT012'))
    field_information['GGDM 3.0']['AERIAL_P']['AOO'] = ('Real',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['AWP'] = ('Boolean',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['BEN'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['CAA'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['CAA']['AT011']  = (-999999,3,5,7,17,999)
    field_information['GGDM 3.0']['AERIAL_P']['CNCP'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['COS'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['COS']['AT011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AERIAL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['FUFI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['FURL'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['GDBV'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['GDBV']['AT011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERIAL_P']['HEI'] = ('Real',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['HGT'] = ('Real',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['LMC'] = ('Boolean',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['OTH'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['PCF'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['PCF']['AT011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERIAL_P']['RAC'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['RAC'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['RAC']['AT011']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['AERIAL_P']['SPT'] = ('Boolean',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['UFI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['VOI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI001_SDV'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI001_SRT'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI001_SRT']['AT011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERIAL_P']['ZI002_UFI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI004_RCG'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI004_RCG']['AT011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERIAL_P']['ZI005_FNA'] = ('String',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI005_GNT'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI005_GNT']['AT011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERIAL_P']['ZI005_NFN'] = ('String',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI006_MEM'] = ('String',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI018_WIT'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI018_WIT']['AT011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERIAL_P']['ZI020_GE4'] = ('CodeList',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI026_CTUC'] = ('Enumeration',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERIAL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AT011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERIAL_P']['ZI026_CTUL'] = ('integer',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI026_CTUU'] = ('integer',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI031S_URI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZI039S_UFI'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZSAX_RS0'] = ('CodeList',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZSAX_RX0'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZSAX_RX3'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZSAX_RX4'] = ('StructuredText',('AT011'))
    field_information['GGDM 3.0']['AERIAL_P']['ZVH'] = ('Real',('AT011'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ARA'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ART'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ART'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ART']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ASO'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ASO'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ASO']['GA033']  = (-999999,1,2,3,4,6,7,8,10,11,12,13,14,15,16,17)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['AWP'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['BEN'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['CMS'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['CMS'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['CMS']['GA033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['DIA'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['DIR'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['DIR'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['DIR']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['FUFI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['FURL'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['GA032_NSX'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['GDBV'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['GDBV']['GA033']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['LOC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['LOC']['GA033']  = (-999999,44,45)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['LZN'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['MCA'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['MCC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['MCC2'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC2']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['MCC3'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['MCC3']['GA033']  = (-999999,2,21,51,64,107,120,131,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['OTH'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['PCF'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['PCF']['GA033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['PRM'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['PWR'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['RAC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['RAC'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['RAC']['GA033']  = (-999999,1,3,4,6,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['RSI'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['RSI'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['RSI']['GA033']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['SPT'] = ('Boolean',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['SRL'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['SRL']['GA033']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['UFI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['VOI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['WID'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI001_SDV'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI001_SRT'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT']['GA033']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI002_UFI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI004_RCG'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG']['GA033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI005_FNA'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI005_GNT'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT']['GA033']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI005_NFN'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI006_MEM'] = ('String',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI020_GE4'] = ('CodeList',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI026_CTUC'] = ('Enumeration',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['GA033']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI026_CTUL'] = ('integer',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI026_CTUU'] = ('integer',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI031S_URI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZI039S_UFI'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZSAX_RS0'] = ('CodeList',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZSAX_RX0'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZSAX_RX3'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZSAX_RX4'] = ('StructuredText',('GA033'))
    field_information['GGDM 3.0']['AERO_RADIO_NAV_INSTALLATION_P']['ZVH'] = ('Real',('GA033'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['BEN'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['CAA'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['CAA']['GB013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['CHA'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['CHA'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['CHA']['GB013']  = (-999999,1,4,5,6,8,11,12,13,14,15,16,17,28,29,44,45,46,47,48,49,50,51,57,58,59,60)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['CNCP'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['COC'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['COC']['GB013']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['COL'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['COS'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['COS']['GB013']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['FUFI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['FURL'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['GB001_AID'] = ('String',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['GDBV'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['GDBV']['GB013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['HGT'] = ('Real',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['LCN'] = ('Integer',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['OTH'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['PCF'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['PCF']['GB013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['PER'] = ('Real',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['UFI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['VIS'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['VIS2'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS2'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS2']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['VIS3'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS3'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['VIS3']['GB013']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['VOI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI001_SDV'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI001_SRT'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI001_SRT']['GB013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI002_UFI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI004_RCG'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI004_RCG']['GB013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI005_FNA'] = ('String',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI005_GNT'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI005_GNT']['GB013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI005_NFN'] = ('String',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI006_MEM'] = ('String',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI020_GE4'] = ('CodeList',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI026_CTUC'] = ('Enumeration',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI026_CTUL'] = ('integer',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI026_CTUU'] = ('integer',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI031S_URI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZI039S_UFI'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZSAX_RS0'] = ('CodeList',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZSAX_RX0'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZSAX_RX3'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZSAX_RX4'] = ('StructuredText',('GB013'))
    field_information['GGDM 3.0']['AERODROME_BEACON_P']['ZVH'] = ('Real',('GB013'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ADR'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['AOO'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ARA'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ATB'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['AWP'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['BEN'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['CAA'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['CAA']['GB230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['CNCP'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['COS'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['COS']['GB230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['FFN'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['FFN2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['FFN3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['FUFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['FURL'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['GDBV'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['GDBV']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['HGT'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['HTP'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['LMC'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['LZN'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['OTH'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['PCF'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['SSR'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['SSR2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['SSR3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['VCM'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['VCM2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['VCM3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['VOI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['WID'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI001_SDV'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI001_SRT'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI001_SRT']['GB230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI002_UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI004_RCG'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI004_RCG']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI005_FNA'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI005_GNT'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI005_GNT']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI005_NFN'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI006_MEM'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI020_GE4'] = ('CodeList',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI026_CTUC'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI026_CTUL'] = ('integer',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI026_CTUU'] = ('integer',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI031S_URI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZI039S_UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZSAX_RS0'] = ('CodeList',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZSAX_RX0'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZSAX_RX3'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZSAX_RX4'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_P']['ZVH'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ADR'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['AOO'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ARA'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ATB'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['AWP'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['BEN'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['CAA'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['CAA']['GB230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['CNCP'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['COS'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['COS']['GB230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['FFN'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['FFN2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['FFN3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['FUFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['FURL'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['GDBV'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['GDBV']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['HGT'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['HTP'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['LMC'] = ('Boolean',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['LZN'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['OTH'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['PCF'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['SSR'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['SSR2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['SSR3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['VCM'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['VCM2'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['VCM3'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['VOI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['WID'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI001_SDV'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI001_SRT'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI001_SRT']['GB230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI002_UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI004_RCG'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI004_RCG']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI005_FNA'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI005_GNT'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI005_GNT']['GB230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI005_NFN'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI006_MEM'] = ('String',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI020_GE4'] = ('CodeList',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI026_CTUC'] = ('Enumeration',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI026_CTUL'] = ('integer',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI026_CTUU'] = ('integer',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI031S_URI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZI039S_UFI'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZSAX_RS0'] = ('CodeList',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZSAX_RX0'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZSAX_RX3'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZSAX_RX4'] = ('StructuredText',('GB230'))
    field_information['GGDM 3.0']['AIRCRAFT_HANGAR_S']['ZVH'] = ('Real',('GB230'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ADR'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['AOO'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ARA'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['BEN'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['CNCP'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['COS'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['COS']['AK164']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['FUFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['FURL'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['GDBV'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['GDBV']['AK164']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['HGT'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['LMC'] = ('Boolean',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['LZN'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['OTH'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['PCF'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['WID'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI001_SDV'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI001_SRT'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI001_SRT']['AK164']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI002_UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI004_RCG'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI004_RCG']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI005_FNA'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI005_GNT'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI005_GNT']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI005_NFN'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI006_MEM'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI020_GE4'] = ('CodeList',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI026_CTUC'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK164']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI026_CTUL'] = ('integer',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI026_CTUU'] = ('integer',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI031S_URI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZI039S_UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZSAX_RS0'] = ('CodeList',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZSAX_RX0'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZSAX_RX3'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZSAX_RX4'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_P']['ZVH'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ADR'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['AOO'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ARA'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['BEN'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['CNCP'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['COS'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['COS']['AK164']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['FUFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['FURL'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['GDBV'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['GDBV']['AK164']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['HGT'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['LMC'] = ('Boolean',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['LZN'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['OTH'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['PCF'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['WID'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI001_SDV'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI001_SRT'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK164']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI002_UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI004_RCG'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI005_FNA'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI005_GNT'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK164']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI005_NFN'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI006_MEM'] = ('String',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI020_GE4'] = ('CodeList',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI026_CTUC'] = ('Enumeration',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK164']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI026_CTUL'] = ('integer',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI026_CTUU'] = ('integer',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI031S_URI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZI039S_UFI'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZSAX_RS0'] = ('CodeList',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZSAX_RX0'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZSAX_RX3'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZSAX_RX4'] = ('StructuredText',('AK164'))
    field_information['GGDM 3.0']['AMPHITHEATRE_S']['ZVH'] = ('Real',('AK164'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['AOO'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ARA'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['AWP'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['BEN'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['CAA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['CNCP'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['COS'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['F_CODE'] = ('CONSTRAINED_STRING',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['FUFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['FURL'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['GDBV'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['HGT'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['LMC'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['LZN'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['OTH'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['PCF'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['VOI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['WID'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI001_SDV'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI001_SRT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI002_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI004_RCG'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI005_FNA'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI005_GNT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI005_NFN'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI006_MEM'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI020_GE4'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI026_CTUC'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI026_CTUL'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI026_CTUU'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI031S_URI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZI039S_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZSAX_RS0'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZSAX_RX0'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZSAX_RX3'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZSAX_RX4'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_C']['ZVH'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['AOO'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ARA'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['AWP'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['BEN'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['CAA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['CNCP'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['COS'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['FUFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['FURL'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['GDBV'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['HGT'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['LMC'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['LZN'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['OTH'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['PCF'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['VOI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['WID'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI001_SDV'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI001_SRT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI002_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI004_RCG'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI005_FNA'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI005_GNT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI005_NFN'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI006_MEM'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI020_GE4'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI026_CTUC'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI026_CTUL'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI026_CTUU'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI031S_URI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZI039S_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZSAX_RS0'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZSAX_RX0'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZSAX_RX3'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZSAX_RX4'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_P']['ZVH'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['AMA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['AMA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['AOO'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ARA'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['AWP'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['BEN'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['CAA'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['CAA']['AK020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['CNCP'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['COS'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['COS']['AK020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['FUFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['FURL'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['GDBV'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['GDBV']['AK020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['HGT'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['LMC'] = ('Boolean',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['LZN'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['OTH'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['PCF'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['VOI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['WID'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI001_SDV'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI001_SRT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI001_SRT']['AK020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI002_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI004_RCG'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI004_RCG']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI005_FNA'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI005_GNT'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI005_GNT']['AK020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI005_NFN'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI006_MEM'] = ('String',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI020_GE4'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI026_CTUC'] = ('Enumeration',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI026_CTUL'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI026_CTUU'] = ('integer',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI031S_URI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZI039S_UFI'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZSAX_RS0'] = ('CodeList',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZSAX_RX0'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZSAX_RX3'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZSAX_RX4'] = ('StructuredText',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_ATTRACTION_S']['ZVH'] = ('Real',('AK020'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ADR'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['AOO'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ARA'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['BEN'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['CAA'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['CAA']['AK030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['CNCP'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['COS'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['COS']['AK030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['FFN'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['FFN2'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['FFN3'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['FUFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['FURL'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['GDBV'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['GDBV']['AK030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['HGT'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['LMC'] = ('Boolean',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['LZN'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['OTH'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['PCF'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['WID'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI001_SDV'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI001_SRT'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI001_SRT']['AK030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI002_UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI004_RCG'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI004_RCG']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI005_FNA'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI005_GNT'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI005_GNT']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI005_NFN'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI006_MEM'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI020_GE4'] = ('CodeList',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI026_CTUC'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI026_CTUL'] = ('integer',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI026_CTUU'] = ('integer',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI031S_URI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZI039S_UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZSAX_RS0'] = ('CodeList',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZSAX_RX0'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZSAX_RX3'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZSAX_RX4'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_P']['ZVH'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ADR'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['AOO'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ARA'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['BEN'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['CAA'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['CAA']['AK030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['CNCP'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['COS'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['COS']['AK030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['FFN'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['FFN2'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['FFN3'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,594,643,780,863,890,891,894,895,900,905,906,907,909,912,915,921,922,923,930,970,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['FUFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['FURL'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['GDBV'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['GDBV']['AK030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['HGT'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['LMC'] = ('Boolean',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['LZN'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['OTH'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['PCF'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['WID'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI001_SDV'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI001_SRT'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI001_SRT']['AK030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI002_UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI004_RCG'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI004_RCG']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI005_FNA'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI005_GNT'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI005_GNT']['AK030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI005_NFN'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI006_MEM'] = ('String',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI020_GE4'] = ('CodeList',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI026_CTUC'] = ('Enumeration',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI026_CTUL'] = ('integer',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI026_CTUU'] = ('integer',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI031S_URI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZI039S_UFI'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZSAX_RS0'] = ('CodeList',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZSAX_RX0'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZSAX_RX3'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZSAX_RX4'] = ('StructuredText',('AK030'))
    field_information['GGDM 3.0']['AMUSEMENT_PARK_S']['ZVH'] = ('Real',('AK030'))
    field_information['GGDM 3.0']['ANCHOR_P']['BEN'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['CNCP'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['COS'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['COS']['BB019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ANCHOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['FUFI'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['FURL'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['GDBV'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['GDBV']['BB019']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANCHOR_P']['OTH'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['PCF'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['PCF']['BB019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ANCHOR_P']['UFI'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI001_SDV'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI001_SRT'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI001_SRT']['BB019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANCHOR_P']['ZI002_UFI'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI004_RCG'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI004_RCG']['BB019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANCHOR_P']['ZI005_FNA'] = ('String',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI005_GNT'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI005_GNT']['BB019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANCHOR_P']['ZI005_NFN'] = ('String',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI006_MEM'] = ('String',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI020_GE4'] = ('CodeList',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI026_CTUC'] = ('Enumeration',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANCHOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANCHOR_P']['ZI026_CTUL'] = ('integer',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI026_CTUU'] = ('integer',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI031S_URI'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZI039S_UFI'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZSAX_RS0'] = ('CodeList',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZSAX_RX0'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZSAX_RX3'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHOR_P']['ZSAX_RX4'] = ('StructuredText',('BB019'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ACH'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ACH'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ACH']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['ANCHORAGE_P']['ARA'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['BEN'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['CNCP'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['COS'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['COS']['BB010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['ANCHORAGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['FUFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['FURL'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['GDBV'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['GDBV']['BB010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANCHORAGE_P']['HDP'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['OTH'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['PCF'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['PCF']['BB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ANCHORAGE_P']['UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI001_SDV'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI001_SRT'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI001_SRT']['BB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI002_UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI004_RCG'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI004_RCG']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI005_FNA'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI005_GNT'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI005_GNT']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI005_NFN'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI006_MEM'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI020_GE4'] = ('CodeList',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI026_CTUC'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI026_CTUL'] = ('integer',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI026_CTUU'] = ('integer',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI031S_URI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZI039S_UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZSAX_RS0'] = ('CodeList',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZSAX_RX0'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZSAX_RX3'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_P']['ZSAX_RX4'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ACH'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ACH'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ACH']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['ANCHORAGE_S']['ARA'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['BEN'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['CNCP'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['COS'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['COS']['BB010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['ANCHORAGE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['FUFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['FURL'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['GDBV'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['GDBV']['BB010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANCHORAGE_S']['HDP'] = ('Real',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['OTH'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['PCF'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['PCF']['BB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ANCHORAGE_S']['UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI001_SDV'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI001_SRT'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI001_SRT']['BB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI002_UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI004_RCG'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI004_RCG']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI005_FNA'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI005_GNT'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI005_GNT']['BB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI005_NFN'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI006_MEM'] = ('String',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI020_GE4'] = ('CodeList',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI026_CTUC'] = ('Enumeration',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANCHORAGE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI026_CTUL'] = ('integer',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI026_CTUU'] = ('integer',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI031S_URI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZI039S_UFI'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZSAX_RS0'] = ('CodeList',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZSAX_RX0'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZSAX_RX3'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANCHORAGE_S']['ZSAX_RX4'] = ('StructuredText',('BB010'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['BEN'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['F_CODE'] = ('CONSTRAINED_STRING',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['FUFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['FURL'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['GDBV'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['OTH'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI001_SDV'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI001_SRT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI002_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI004_RCG'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_FNA'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_FNA2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_FNA3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNR'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNR2'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNR3'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNT2'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_GNT3'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_NFN'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_NFN2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI005_NFN3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI006_MEM'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI015_GCUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI015_GCUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI015_GCUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI020_GE4'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI026_CTUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI026_CTUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI026_CTUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI031S_URI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZI039S_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZSAX_RS0'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZSAX_RX0'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZSAX_RX3'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_C']['ZSAX_RX4'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['BEN'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['FUFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['FURL'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['GDBV'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['OTH'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI001_SDV'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI001_SRT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI002_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI004_RCG'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_FNA'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_FNA2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_FNA3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNR'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNR2'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNR3'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNT2'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_GNT3'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_NFN'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_NFN2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI005_NFN3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI006_MEM'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI015_GCUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI015_GCUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI015_GCUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI020_GE4'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI026_CTUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI026_CTUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI026_CTUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI031S_URI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZI039S_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZSAX_RS0'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZSAX_RX0'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZSAX_RX3'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_P']['ZSAX_RX4'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['BEN'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['FUFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['FURL'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['GDBV'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['GDBV']['ZD045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['OTH'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI001_SDV'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI001_SRT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT']['ZD045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI002_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI004_RCG'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_FNA'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_FNA2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_FNA3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNR'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNR2'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNR3'] = ('Integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNT'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNT2'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_GNT3'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3']['ZD045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_NFN'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_NFN2'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI005_NFN3'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI006_MEM'] = ('String',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI015_GCUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI015_GCUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI015_GCUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI015_GCUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI020_GE4'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI026_CTUC'] = ('Enumeration',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZD045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI026_CTUL'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI026_CTUU'] = ('integer',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI031S_URI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZI039S_UFI'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZSAX_RS0'] = ('CodeList',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZSAX_RX0'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZSAX_RX3'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANNOTATED_LOCATION_S']['ZSAX_RX4'] = ('StructuredText',('ZD045'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ARA'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['BEN'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['CAA'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['CAA']['AL121']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['CNCP'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['COS'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['COS']['AL121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['FUFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['FURL'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['GDBV'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['GDBV']['AL121']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['HGT'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['LMC'] = ('Boolean',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['LZN'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['OTH'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['PCF'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['PCF']['AL121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['VCM'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['VCM2'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM2']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['VCM3'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['VCM3']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['WID'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['YSU'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['YSU']['AL121']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI001_SDV'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI001_SRT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI002_UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI004_RCG'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI005_FNA'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI005_GNT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI005_NFN'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI006_MEM'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI020_GE4'] = ('CodeList',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI026_CTUL'] = ('integer',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI026_CTUU'] = ('integer',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI031S_URI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZSAX_RS0'] = ('CodeList',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ARA'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['BEN'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['CAA'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['CAA']['AL121']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['CNCP'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['COS'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['COS']['AL121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['FUFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['FURL'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['GDBV'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['GDBV']['AL121']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['HGT'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['LMC'] = ('Boolean',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['LZN'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['OTH'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['PCF'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['PCF']['AL121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['VCM'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['VCM2'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM2']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['VCM3'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['VCM3']['AL121']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['WID'] = ('Real',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['YSU'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['YSU']['AL121']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI001_SDV'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI001_SRT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI002_UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI004_RCG'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI005_FNA'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI005_GNT'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI005_NFN'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI006_MEM'] = ('String',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI020_GE4'] = ('CodeList',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI026_CTUL'] = ('integer',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI026_CTUU'] = ('integer',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI031S_URI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZSAX_RS0'] = ('CodeList',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['ANTI_AIRCRAFT_ARTILLERY_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AL121'))
    field_information['GGDM 3.0']['APRON_S']['APU'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['APRON_S']['APU2'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU2'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['APRON_S']['APU3'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU3'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APU3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['APRON_S']['APY'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APY'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['APY']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['APRON_S']['ARA'] = ('Real',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['AXS'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['AXS']['GB015']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['APRON_S']['BEN'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['CNCP'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['COS'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['COS']['GB015']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['APRON_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['FUFI'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['FURL'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['GDBV'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['GDBV']['GB015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['APRON_S']['LZN'] = ('Real',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['OTH'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['PCF'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['PCF']['GB015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['APRON_S']['UFI'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['WID'] = ('Real',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI001_SDV'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI001_SRT'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI001_SRT']['GB015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['APRON_S']['ZI002_UFI'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI004_RCG'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI004_RCG']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['APRON_S']['ZI005_FNA'] = ('String',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI005_GNT'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI005_GNT']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['APRON_S']['ZI005_NFN'] = ('String',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI006_MEM'] = ('String',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASP'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASP2'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASP3'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASP3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASU'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASU2'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASU3'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASU3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_ASX'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_ASX']['GB015']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['APRON_S']['ZI019_SFS'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI019_SFS']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['APRON_S']['ZI020_GE4'] = ('CodeList',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI026_CTUC'] = ('Enumeration',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['APRON_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['APRON_S']['ZI026_CTUL'] = ('integer',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI026_CTUU'] = ('integer',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI031S_URI'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZI039S_UFI'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZSAX_RS0'] = ('CodeList',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZSAX_RX0'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZSAX_RX3'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZSAX_RX4'] = ('StructuredText',('GB015'))
    field_information['GGDM 3.0']['APRON_S']['ZVH'] = ('Real',('GB015'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ARA'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['BEN'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['DTN'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['FLO'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['FUFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['FURL'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['GDBV'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['GDBV']['BD061']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['LZN'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['OTH'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['VSP'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['VSP2'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP2']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['VSP3'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['VSP3']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['WID'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI001_SDV'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI001_SRT'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI001_SRT']['BD061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI002_UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI004_RCG'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI004_RCG']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI005_FNA'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI005_GNT'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI005_GNT']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI005_NFN'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI006_MEM'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI020_GE4'] = ('CodeList',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI026_CTUC'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI026_CTUL'] = ('integer',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI026_CTUU'] = ('integer',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI031S_URI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZI039S_UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZSAX_RS0'] = ('CodeList',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZSAX_RX0'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZSAX_RX3'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_P']['ZSAX_RX4'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ARA'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['BEN'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['DTN'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['FLO'] = ('Boolean',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['FUFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['FURL'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['GDBV'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['GDBV']['BD061']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['LZN'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['OTH'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['VSP'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['VSP2'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP2']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['VSP3'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['VSP3']['BD061']  = (-999999,17,19,22,28,29,30,31,35,36,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['WID'] = ('Real',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI001_SDV'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI001_SRT'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI001_SRT']['BD061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI002_UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI004_RCG'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI004_RCG']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI005_FNA'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI005_GNT'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI005_GNT']['BD061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI005_NFN'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI006_MEM'] = ('String',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI020_GE4'] = ('CodeList',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI026_CTUC'] = ('Enumeration',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI026_CTUL'] = ('integer',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI026_CTUU'] = ('integer',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI031S_URI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZI039S_UFI'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZSAX_RS0'] = ('CodeList',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZSAX_RX0'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZSAX_RX3'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUATIC_VEGETATION_S']['ZSAX_RX4'] = ('StructuredText',('BD061'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ARA'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ATC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ATC']['NM010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BEN'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCAC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['BWVCAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCAL'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCAU'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCBC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['BWVCBC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCBL'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['BWVCBU'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['CAA'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['CAA']['NM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['CDA'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['CDL'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['CNCP'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['COS'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['COS']['NM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['CWT'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['DEV'] = ('Integer',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['DMF'] = ('Integer',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['DOXY'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['FRZ'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['FUFI'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['FURL'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['GDBV'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['GDBV']['NM010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['LMC'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['MWD'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['OTH'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['PCF'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['PCF']['NM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['PWAC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['PWAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['PWAL'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['PWAU'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['RLE'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['RLE']['NM010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['SBB'] = ('Boolean',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['UFI'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['WDAC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['WDAC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['WDAL'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['WDAU'] = ('real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['WVA'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI001_SDV'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI001_SRT'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI002_UFI'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI004_RCG'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_FNA'] = ('String',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_FNA2'] = ('String',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_GNT'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_GNT2'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_NFN'] = ('String',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI005_NFN2'] = ('String',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI006_MEM'] = ('String',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI020_GE4'] = ('CodeList',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_ASE'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_AWO'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_AWOI'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_AWOX'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_CFR'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_CLO'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_CYN'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_FMR'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_FRR'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_HAR'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_HYP'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_MGN'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_PHW'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_SCC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_SUL'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_TDS'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_TEP'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_TUR'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WAC'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WPAC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WPAC']['NM010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WTNO'] = ('Real',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WUR'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI026_CTUL'] = ('integer',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI026_CTUU'] = ('integer',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI031S_URI'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZSAX_RS0'] = ('CodeList',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ARA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ATC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BEN'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_AWBA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_AWBB'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_IBOA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_IBOB'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_SHDA'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_SHDB'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_SLTA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_SLTB'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_WBHA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BH141_WBHB'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWHBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BPWSBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['BWVCBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['CAA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['CDA'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['CDL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['CNCP'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['COS'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['COS']['BH010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AQUEDUCT_C']['CWT'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['DEV'] = ('Integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['DOXY'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['DZP'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['FRZ'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['FUFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['FURL'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['GDBV'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['GDBV']['BH010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['HGT'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['LEA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['LMC'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['LUN'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['LZN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['MWD'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['OTH'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['PCF'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_C']['PWAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['PWAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['PWAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['PWAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['RLE'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['AQUEDUCT_C']['SBB'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WD3'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WDAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['WDAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['WDAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WDAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WDH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WDL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WID'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WVA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WVH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['WVL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI001_SDV'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI001_SRT'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI001_SRT']['BH010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI002_UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI004_RCG'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI004_RCG']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_FNA'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_FNA2'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_GNT'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI005_GNT']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_GNT2'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI005_GNT2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_NFN'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI005_NFN2'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI006_MEM'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI020_GE4'] = ('CodeList',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_ASE'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_AWO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_AWOI'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_AWOX'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_CFR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_CLO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_CYN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_FMR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_FRR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_HAR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_HYP'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_MGN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_PHW'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_SCC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_SQN'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_SQN']['BH010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_SUL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_TDS'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_TEP'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_TUR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WAC'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WPAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WPAC']['BH010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WTNO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WUR'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WUR2'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WUR3'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR3']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_WUR4'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_WUR4']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI024_YWQ'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI026_CTUC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI026_CTUL'] = ('integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI026_CTUU'] = ('integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI031S_URI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZI039S_UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZSAX_RS0'] = ('CodeList',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZSAX_RX0'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZSAX_RX3'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZSAX_RX4'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_C']['ZVH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ARA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ATC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ATC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BEN'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_AWBA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_AWBB'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_IBOA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_IBOB'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_SHDA'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_SHDB'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_SLTA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_SLTB'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_WBHA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BH141_WBHB'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWHBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BPWSBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCBC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCBL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['BWVCBU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['CAA'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['CDA'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['CDL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['CNCP'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['COS'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['COS']['BH010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['AQUEDUCT_S']['CWT'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['DEV'] = ('Integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['DOXY'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['DZP'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['FRZ'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['FUFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['FURL'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['GDBV'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['GDBV']['BH010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['HGT'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['LEA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['LMC'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['LUN'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['LZN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['MWD'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['OTH'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['PCF'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['AQUEDUCT_S']['PWAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['PWAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['PWAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['PWAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['RLE'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['AQUEDUCT_S']['SBB'] = ('Boolean',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WD3'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WDAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['WDAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['WDAL'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WDAU'] = ('real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WDH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WDL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WID'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WVA'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WVH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['WVL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI001_SDV'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI001_SRT'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI001_SRT']['BH010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI002_UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI004_RCG'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI004_RCG']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_FNA'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_FNA2'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_GNT'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI005_GNT']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_GNT2'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_NFN'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI005_NFN2'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI006_MEM'] = ('String',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI020_GE4'] = ('CodeList',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_ASE'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_AWO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_AWOI'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_AWOX'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_CFR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_CLO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_CYN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_FMR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_FRR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_HAR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_HYP'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_MGN'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_PHW'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_SCC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_SQN'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_SQN']['BH010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_SUL'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_TDS'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_TEP'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_TUR'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WAC'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WPAC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WPAC']['BH010']  = (-999999,100,101,102,103)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WTNO'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WUR'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WUR2'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WUR3'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_WUR4'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI024_YWQ'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI026_CTUC'] = ('Enumeration',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUEDUCT_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI026_CTUL'] = ('integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI026_CTUU'] = ('integer',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI031S_URI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZI039S_UFI'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZSAX_RS0'] = ('CodeList',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZSAX_RX0'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZSAX_RX3'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZSAX_RX4'] = ('StructuredText',('BH010'))
    field_information['GGDM 3.0']['AQUEDUCT_S']['ZVH'] = ('Real',('BH010'))
    field_information['GGDM 3.0']['AQUIFER_S']['AQN'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['AQO'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQO2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO2'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQO3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO3'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQO3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQP'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQP2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP2'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQP3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP3'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQP3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['AQUIFER_S']['AQTC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQTC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AQTC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['AQTL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['AQTU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ARA'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['AYRC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AYRC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['AYRC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['AYRL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['AYRU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['BEN'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['CAA'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['CAA']['BH116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['AQUIFER_S']['CNF'] = ('Boolean',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['DPAC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['DPAC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['DPAC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['DPAL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['DPAU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['FUFI'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['FURL'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['GDBV'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['GDBV']['BH116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['AQUIFER_S']['GWS'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['GWS'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['GWS']['BH116']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['AQUIFER_S']['GWTR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['HYCD'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['LZN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['OTH'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['SWCP'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['UFI'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['WID'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['WRCC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['WRCC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['WRCC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['WRCL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['WRCU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['WWRC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['WWRC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['WWRC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['WWRL'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['WWRU'] = ('real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI001_SDV'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI001_SRT'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI001_SRT']['BH116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI002_UFI'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI004_RCG'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI004_RCG']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_FNA'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_FNA2'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_FNA3'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_GNT'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_GNT2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_GNT3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_NFN'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_NFN2'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI005_NFN3'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI006_MEM'] = ('String',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI020_GE4'] = ('CodeList',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_ASE'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_CFR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_CLO'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_CYN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_FMR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_FRR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_HAR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_MGN'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_PHW'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_SCC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_SCC']['BH116']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_SUL'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_TDS'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_TEP'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_TUR'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WAC'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WTNO'] = ('Real',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WUR'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WUR2'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WUR3'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_WUR4'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI024_YWQ'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI026_CTUC'] = ('Enumeration',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['AQUIFER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['AQUIFER_S']['ZI026_CTUL'] = ('integer',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI026_CTUU'] = ('integer',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI031S_URI'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZI039S_UFI'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZSAX_RS0'] = ('CodeList',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZSAX_RX0'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZSAX_RX3'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['AQUIFER_S']['ZSAX_RX4'] = ('StructuredText',('BH116'))
    field_information['GGDM 3.0']['ARCADE_C']['AOO'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ARA'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['BEN'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['CAA'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['CAA']['AQ151']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ARCADE_C']['CNCP'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['COS'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['COS']['AQ151']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ARCADE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['FUFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['FURL'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['GDBV'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['GDBV']['AQ151']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ARCADE_C']['HGT'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['LMC'] = ('Boolean',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['LZN'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['OTH'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['PCF'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ARCADE_C']['UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['WID'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI001_SDV'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI001_SRT'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ151']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ARCADE_C']['ZI002_UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI004_RCG'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ARCADE_C']['ZI005_FNA'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI005_GNT'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ARCADE_C']['ZI005_NFN'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI006_MEM'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI020_GE4'] = ('CodeList',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI026_CTUC'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ARCADE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ151']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ARCADE_C']['ZI026_CTUL'] = ('integer',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI026_CTUU'] = ('integer',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI031S_URI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZI039S_UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZSAX_RS0'] = ('CodeList',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZSAX_RX0'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZSAX_RX3'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZSAX_RX4'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_C']['ZVH'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['AOO'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ARA'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['BEN'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['CAA'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['CAA']['AQ151']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ARCADE_S']['CNCP'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['COS'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['COS']['AQ151']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ARCADE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['FUFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['FURL'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['GDBV'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['GDBV']['AQ151']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ARCADE_S']['HGT'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['LMC'] = ('Boolean',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['LZN'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['OTH'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['PCF'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ARCADE_S']['UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['WID'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI001_SDV'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI001_SRT'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ151']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ARCADE_S']['ZI002_UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI004_RCG'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ARCADE_S']['ZI005_FNA'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI005_GNT'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ151']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ARCADE_S']['ZI005_NFN'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI006_MEM'] = ('String',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI020_GE4'] = ('CodeList',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI026_CTUC'] = ('Enumeration',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ARCADE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ151']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ARCADE_S']['ZI026_CTUL'] = ('integer',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI026_CTUU'] = ('integer',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI031S_URI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZI039S_UFI'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZSAX_RS0'] = ('CodeList',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZSAX_RX0'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZSAX_RX3'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZSAX_RX4'] = ('StructuredText',('AQ151'))
    field_information['GGDM 3.0']['ARCADE_S']['ZVH'] = ('Real',('AQ151'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['AOO'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ARA'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['AWP'] = ('Boolean',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['BEN'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['FUFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['FURL'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['GDBV'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['GDBV']['AL012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['HGT'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['LMC'] = ('Boolean',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['LZN'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['OTH'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['PCF'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['VOI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['WID'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI001_SDV'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI001_SRT'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI002_UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI004_RCG'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI005_FNA'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI005_GNT'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI005_NFN'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI006_MEM'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI020_GE4'] = ('CodeList',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI026_CTUL'] = ('integer',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI026_CTUU'] = ('integer',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI031S_URI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZSAX_RS0'] = ('CodeList',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_P']['ZVH'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['AOO'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ARA'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['AWP'] = ('Boolean',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['BEN'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['FUFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['FURL'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['GDBV'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['GDBV']['AL012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['HGT'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['LMC'] = ('Boolean',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['LZN'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['OTH'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['PCF'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['VOI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['WID'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI001_SDV'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI001_SRT'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI002_UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI004_RCG'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI005_FNA'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI005_GNT'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI005_NFN'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI006_MEM'] = ('String',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI020_GE4'] = ('CodeList',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI026_CTUL'] = ('integer',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI026_CTUU'] = ('integer',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI031S_URI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZSAX_RS0'] = ('CodeList',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AL012'))
    field_information['GGDM 3.0']['ARCHAEOLOGICAL_SITE_S']['ZVH'] = ('Real',('AL012'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ARA'] = ('Real',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['BEN'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['F_CODE'] = ('CONSTRAINED_STRING',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['FUFI'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['FURL'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['GDBV'] = ('Enumeration',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['GDBV']['DA005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['LMC'] = ('Boolean',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['LZN'] = ('Real',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['OTH'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['UFI'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['WID'] = ('Real',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI001_SDV'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI001_SRT'] = ('Enumeration',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI001_SRT']['DA005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI002_UFI'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI004_RCG'] = ('Enumeration',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI004_RCG']['DA005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI005_FNA'] = ('String',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI005_GNT'] = ('Enumeration',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI005_GNT']['DA005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI005_NFN'] = ('String',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI006_MEM'] = ('String',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI020_GE4'] = ('CodeList',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI026_CTUC'] = ('Enumeration',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['EnumeratedIndexValues']['ZI026_CTUC']['DA005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI026_CTUL'] = ('integer',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI026_CTUU'] = ('integer',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI031S_URI'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZI039S_UFI'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZSAX_RS0'] = ('CodeList',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZSAX_RX0'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZSAX_RX3'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASPHALT_LAKE_S']['ZSAX_RX4'] = ('StructuredText',('DA005'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ADR'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['AOO'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ARA'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['AWP'] = ('Boolean',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['BEN'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['CAA'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['CAA']['AL142']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['CNCP'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['COS'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['COS']['AL142']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['FFN'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['FFN2'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['FFN3'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['FUFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['FURL'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['GDBV'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['GDBV']['AL142']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['HGT'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['LMC'] = ('Boolean',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['LZN'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['OTH'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['PCF'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['SSR'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['SSR2'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['SSR3'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['TEL'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['TEL'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['VOI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['WID'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI001_SDV'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI001_SRT'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI001_SRT']['AL142']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI002_UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI004_RCG'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI004_RCG']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI005_FNA'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI005_GNT'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI005_GNT']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI005_NFN'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI006_MEM'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI020_GE4'] = ('CodeList',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI026_CTUC'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL142']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI026_CTUL'] = ('integer',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI026_CTUU'] = ('integer',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI031S_URI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZI039S_UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZSAX_RS0'] = ('CodeList',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZSAX_RX0'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZSAX_RX3'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZSAX_RX4'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_P']['ZVH'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ADR'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['AOO'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ARA'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['AWP'] = ('Boolean',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['BEN'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['CAA'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['CAA']['AL142']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['CNCP'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['COS'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['COS']['AL142']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['FFN'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['FFN2'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['FFN3'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['FUFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['FURL'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['GDBV'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['GDBV']['AL142']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['HGT'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['LMC'] = ('Boolean',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['LZN'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['OTH'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['PCF'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['SSR'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['SSR2'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['SSR3'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['TEL'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['TEL'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['VOI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['WID'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI001_SDV'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI001_SRT'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI001_SRT']['AL142']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI002_UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI004_RCG'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI004_RCG']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI005_FNA'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI005_GNT'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI005_GNT']['AL142']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI005_NFN'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI006_MEM'] = ('String',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI020_GE4'] = ('CodeList',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI026_CTUC'] = ('Enumeration',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL142']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI026_CTUL'] = ('integer',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI026_CTUU'] = ('integer',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI031S_URI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZI039S_UFI'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZSAX_RS0'] = ('CodeList',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZSAX_RX0'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZSAX_RX3'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZSAX_RX4'] = ('StructuredText',('AL142'))
    field_information['GGDM 3.0']['ASTRONOMICAL_OBSERVATORY_S']['ZVH'] = ('Real',('AL142'))
    field_information['GGDM 3.0']['BARN_P']['ADR'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['AOO'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ARA'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['BEN'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['BNF'] = ('Integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['CAA'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BARN_P']['CNCP'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['COS'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['COS']['AJ085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BARN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['FFN'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_P']['FFN2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_P']['FFN3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_P']['FUFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['FURL'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['GDBV'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['GDBV']['AJ085']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BARN_P']['HGT'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['LMC'] = ('Boolean',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['LZN'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['OTH'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['PCF'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BARN_P']['SSR'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_P']['SSR2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_P']['SSR3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_P']['UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['VCM'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_P']['VCM2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_P']['VCM3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_P']['WID'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI001_SDV'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI001_SRT'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BARN_P']['ZI002_UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI004_RCG'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BARN_P']['ZI005_FNA'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI005_GNT'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BARN_P']['ZI005_NFN'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI006_MEM'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI020_GE4'] = ('CodeList',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI026_CTUC'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BARN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BARN_P']['ZI026_CTUL'] = ('integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI026_CTUU'] = ('integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI031S_URI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZI039S_UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZSAX_RS0'] = ('CodeList',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZSAX_RX0'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZSAX_RX3'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZSAX_RX4'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_P']['ZVH'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ADR'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['AOO'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ARA'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['BEN'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['BNF'] = ('Integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['CAA'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BARN_S']['CNCP'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['COS'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['COS']['AJ085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BARN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['FFN'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_S']['FFN2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_S']['FFN3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['GGDM 3.0']['BARN_S']['FUFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['FURL'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['GDBV'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['GDBV']['AJ085']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BARN_S']['HGT'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['LMC'] = ('Boolean',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['LZN'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['OTH'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['PCF'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BARN_S']['SSR'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_S']['SSR2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_S']['SSR3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BARN_S']['UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['VCM'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_S']['VCM2'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_S']['VCM3'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['BARN_S']['WID'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI001_SDV'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI001_SRT'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BARN_S']['ZI002_UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI004_RCG'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BARN_S']['ZI005_FNA'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI005_GNT'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BARN_S']['ZI005_NFN'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI006_MEM'] = ('String',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI020_GE4'] = ('CodeList',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI026_CTUC'] = ('Enumeration',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BARN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BARN_S']['ZI026_CTUL'] = ('integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI026_CTUU'] = ('integer',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI031S_URI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZI039S_UFI'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZSAX_RS0'] = ('CodeList',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZSAX_RX0'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZSAX_RX3'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZSAX_RX4'] = ('StructuredText',('AJ085'))
    field_information['GGDM 3.0']['BARN_S']['ZVH'] = ('Real',('AJ085'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['AOO'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['BEN'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['BGT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['BGT'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['CNCP'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['COS'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['COS']['BI045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BASIN_GATE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['FUFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['FURL'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['GDBV'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['GDBV']['BI045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['HDP'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['HEI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['HGT'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['LMC'] = ('Boolean',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['LZN'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['MCC'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['MCC2'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['MCC3'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['OTH'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['PCF'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BASIN_GATE_C']['THI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI001_SDV'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI001_SRT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI001_SRT']['BI045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI002_UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI004_RCG'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI004_RCG']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI006_MEM'] = ('String',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI020_GE4'] = ('CodeList',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI026_CTUC'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI026_CTUL'] = ('integer',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI026_CTUU'] = ('integer',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI031S_URI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZI039S_UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZSAX_RS0'] = ('CodeList',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZSAX_RX0'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZSAX_RX3'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZSAX_RX4'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_C']['ZVH'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['AOO'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['BEN'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['BGT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['BGT'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['CNCP'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['COS'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['COS']['BI045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BASIN_GATE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['FUFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['FURL'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['GDBV'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['GDBV']['BI045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['HDP'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['HEI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['HGT'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['LMC'] = ('Boolean',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['LZN'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['MCC'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['MCC2'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['MCC3'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['OTH'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['PCF'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BASIN_GATE_P']['THI'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI001_SDV'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI001_SRT'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI001_SRT']['BI045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI002_UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI004_RCG'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI004_RCG']['BI045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI006_MEM'] = ('String',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI020_GE4'] = ('CodeList',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI026_CTUC'] = ('Enumeration',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BASIN_GATE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI026_CTUL'] = ('integer',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI026_CTUU'] = ('integer',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI031S_URI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZI039S_UFI'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZSAX_RS0'] = ('CodeList',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZSAX_RX0'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZSAX_RX3'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZSAX_RX4'] = ('StructuredText',('BI045'))
    field_information['GGDM 3.0']['BASIN_GATE_P']['ZVH'] = ('Real',('BI045'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['AZC'] = ('Boolean',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['BEN'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['CNCP'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['COS'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['COS']['BB150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['FUFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['FURL'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['GDBV'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['GDBV']['BB150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['OTH'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['PCF'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['PCF']['BB150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI001_SDV'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI001_SRT'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['BB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI002_UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI004_RCG'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI006_MEM'] = ('String',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI020_GE4'] = ('CodeList',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI026_CTUC'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI026_CTUL'] = ('integer',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI026_CTUU'] = ('integer',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI031S_URI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZI039S_UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZSAX_RS0'] = ('CodeList',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZSAX_RX0'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZSAX_RX3'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_P']['ZSAX_RX4'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['AZC'] = ('Boolean',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['BEN'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['CNCP'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['COS'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['COS']['BB150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['FUFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['FURL'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['GDBV'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['GDBV']['BB150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['OTH'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['PCF'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['PCF']['BB150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI001_SDV'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI001_SRT'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['BB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI002_UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI004_RCG'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['BB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI006_MEM'] = ('String',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI020_GE4'] = ('CodeList',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI026_CTUC'] = ('Enumeration',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI026_CTUL'] = ('integer',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI026_CTUU'] = ('integer',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI031S_URI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZI039S_UFI'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZSAX_RS0'] = ('CodeList',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZSAX_RX0'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZSAX_RX3'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_LANDING_SITE_S']['ZSAX_RX4'] = ('StructuredText',('BB150'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['BEN'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['FUFI'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['FURL'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['GDBV'] = ('Enumeration',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['GDBV']['BE050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['OTH'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['UFI'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI001_SDV'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI001_SRT'] = ('Enumeration',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI001_SRT']['BE050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI002_UFI'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI004_RCG'] = ('Enumeration',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI004_RCG']['BE050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI006_MEM'] = ('String',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI020_GE4'] = ('CodeList',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI026_CTUC'] = ('Enumeration',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BE050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI026_CTUL'] = ('integer',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI026_CTUU'] = ('integer',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI031S_URI'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZI039S_UFI'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZSAX_RS0'] = ('CodeList',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZSAX_RX0'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZSAX_RX3'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_PROFILE_C']['ZSAX_RX4'] = ('StructuredText',('BE050'))
    field_information['GGDM 3.0']['BEACH_S']['BEN'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['F_CODE'] = ('CONSTRAINED_STRING',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['FUFI'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['FURL'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['GDBV'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['GDBV']['BA050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_MCC1'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_MCC1']['BA050']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_MCC2'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_MCC2']['BA050']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_PSC1'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_PSC1']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_PSC2'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_PSC2']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_SCO1'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_SCO1']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BEACH_S']['MBC_SCO2'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['MBC_SCO2']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BEACH_S']['OTH'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['STP'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['STP'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['STP']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['BEACH_S']['SWC'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['SWC'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['SWC']['BA050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['BEACH_S']['UFI'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI001_SDV'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI001_SRT'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI001_SRT']['BA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BEACH_S']['ZI002_UFI'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI004_RCG'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI004_RCG']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BEACH_S']['ZI005_FNA'] = ('String',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI005_GNT'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI005_GNT']['BA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BEACH_S']['ZI005_NFN'] = ('String',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI006_MEM'] = ('String',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI020_GE4'] = ('CodeList',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI026_CTUC'] = ('Enumeration',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BEACH_S']['EnumeratedIndexValues']['ZI026_CTUC']['BA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BEACH_S']['ZI026_CTUL'] = ('integer',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI026_CTUU'] = ('integer',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI031S_URI'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZI039S_UFI'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZSAX_RS0'] = ('CodeList',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZSAX_RX0'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZSAX_RX3'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BEACH_S']['ZSAX_RX4'] = ('StructuredText',('BA050'))
    field_information['GGDM 3.0']['BENCHMARK_P']['BEN'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['CPA'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['CPA'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['CPA']['ZB020']  = (-999999,1,2,3,5)
    field_information['GGDM 3.0']['BENCHMARK_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['FUFI'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['FURL'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['GDBV'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['GDBV']['ZB020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BENCHMARK_P']['OTH'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['PCF'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['PCF']['ZB020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BENCHMARK_P']['UFI'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI001_SDV'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI001_SRT'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI001_SRT']['ZB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI002_UFI'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI004_RCG'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI004_RCG']['ZB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI005_FNA'] = ('String',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI005_GNT'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI005_GNT']['ZB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI005_NFN'] = ('String',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI006_MEM'] = ('String',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI020_GE4'] = ('CodeList',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI026_CTUC'] = ('Enumeration',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BENCHMARK_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI026_CTUL'] = ('integer',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI026_CTUU'] = ('integer',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI031S_URI'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZI039S_UFI'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZSAX_RS0'] = ('CodeList',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZSAX_RX0'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZSAX_RX3'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZSAX_RX4'] = ('StructuredText',('ZB020'))
    field_information['GGDM 3.0']['BENCHMARK_P']['ZVH'] = ('Real',('ZB020'))
    field_information['GGDM 3.0']['BERTH_P']['BEN'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['BER'] = ('String',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['CNCP'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['COS'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['COS']['BB020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['BERTH_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['FUFI'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['FURL'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['GDBV'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['GDBV']['BB020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BERTH_P']['OTH'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['PCF'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['PCF']['BB020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BERTH_P']['UFI'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI001_SDV'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI001_SRT'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI001_SRT']['BB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BERTH_P']['ZI002_UFI'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI004_RCG'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI004_RCG']['BB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BERTH_P']['ZI006_MEM'] = ('String',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI020_GE4'] = ('CodeList',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI026_CTUC'] = ('Enumeration',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BERTH_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BERTH_P']['ZI026_CTUL'] = ('integer',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI026_CTUU'] = ('integer',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI031S_URI'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZI039S_UFI'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZSAX_RS0'] = ('CodeList',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZSAX_RX0'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZSAX_RX3'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BERTH_P']['ZSAX_RX4'] = ('StructuredText',('BB020'))
    field_information['GGDM 3.0']['BILLBOARD_P']['AOO'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ARA'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['AWP'] = ('Boolean',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['BEN'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['CAA'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['CAA']['AG050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['CNCP'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['COS'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['COS']['AG050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BILLBOARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['FFN'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['FFN2'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN2']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['FFN3'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['FFN3']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['FUFI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['FURL'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['GDBV'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['GDBV']['AG050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['HEI'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['HGT'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['LMC'] = ('Boolean',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['LZN'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['OTH'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['PCF'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['PCF']['AG050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BILLBOARD_P']['UFI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['VOI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI001_SDV'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI001_SRT'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI001_SRT']['AG050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI002_UFI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI004_RCG'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI004_RCG']['AG050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI005_FNA'] = ('String',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI005_GNT'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI005_GNT']['AG050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI005_NFN'] = ('String',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI006_MEM'] = ('String',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI020_GE4'] = ('CodeList',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI026_CTUC'] = ('Enumeration',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BILLBOARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['AG050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI026_CTUL'] = ('integer',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI026_CTUU'] = ('integer',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI031S_URI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZI039S_UFI'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZSAX_RS0'] = ('CodeList',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZSAX_RX0'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZSAX_RX3'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZSAX_RX4'] = ('StructuredText',('AG050'))
    field_information['GGDM 3.0']['BILLBOARD_P']['ZVH'] = ('Real',('AG050'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['AOO'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ARA'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['AWP'] = ('Boolean',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['BEN'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['CAA'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['CAA']['AC010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['CNCP'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['COS'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['COS']['AC010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['FUFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['FURL'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['GDBV'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['GDBV']['AC010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['HGT'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['LMC'] = ('Boolean',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['LZN'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['OTH'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['PCF'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['VOI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['WID'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI001_SDV'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI001_SRT'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI001_SRT']['AC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI002_UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI004_RCG'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI004_RCG']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI005_FNA'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI005_GNT'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI005_GNT']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI005_NFN'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI006_MEM'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI020_GE4'] = ('CodeList',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI026_CTUC'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI026_CTUL'] = ('integer',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI026_CTUU'] = ('integer',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI031S_URI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZI039S_UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZSAX_RS0'] = ('CodeList',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZSAX_RX0'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZSAX_RX3'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZSAX_RX4'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_P']['ZVH'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['AOO'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ARA'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['AWP'] = ('Boolean',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['BEN'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['CAA'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['CAA']['AC010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['CNCP'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['COS'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['COS']['AC010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['FUFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['FURL'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['GDBV'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['GDBV']['AC010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['HGT'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['LMC'] = ('Boolean',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['LZN'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['OTH'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['PCF'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['VOI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['WID'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI001_SDV'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI001_SRT'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI001_SRT']['AC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI002_UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI004_RCG'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI004_RCG']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI005_FNA'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI005_GNT'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI005_GNT']['AC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI005_NFN'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI006_MEM'] = ('String',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI020_GE4'] = ('CodeList',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI026_CTUC'] = ('Enumeration',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI026_CTUL'] = ('integer',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI026_CTUU'] = ('integer',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI031S_URI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZI039S_UFI'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZSAX_RS0'] = ('CodeList',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZSAX_RX0'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZSAX_RX3'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZSAX_RX4'] = ('StructuredText',('AC010'))
    field_information['GGDM 3.0']['BLAST_FURNACE_S']['ZVH'] = ('Real',('AC010'))
    field_information['GGDM 3.0']['BOG_S']['ARA'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['BEN'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['BMC'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['BOG_S']['BMC2'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC2']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['BOG_S']['BMC3'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BMC3']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['BOG_S']['BOC'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BOC'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['BOC']['BH015']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['BOG_S']['CAA'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['CAA']['BH015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BOG_S']['DZP'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['FUFI'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['FURL'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['GDBV'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['GDBV']['BH015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOG_S']['LZN'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['OTH'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['UFI'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['VTI'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['WID'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI001_SDV'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI001_SRT'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI001_SRT']['BH015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOG_S']['ZI002_UFI'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI004_RCG'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI004_RCG']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOG_S']['ZI005_FNA'] = ('String',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI005_GNT'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI005_GNT']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOG_S']['ZI005_NFN'] = ('String',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI006_MEM'] = ('String',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI020_GE4'] = ('CodeList',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_ASE'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_CFR'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_CLO'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_CYN'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_FMR'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_FRR'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_HAR'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_MGN'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_PHW'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_SCC'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_SCC']['BH015']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['BOG_S']['ZI024_SUL'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_TDS'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_TEP'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_TUR'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_WAC'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_WTNO'] = ('Real',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI024_WUR'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_WUR']['BH015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['BOG_S']['ZI024_YWQ'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH015']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['BOG_S']['ZI026_CTUC'] = ('Enumeration',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOG_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOG_S']['ZI026_CTUL'] = ('integer',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI026_CTUU'] = ('integer',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI031S_URI'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZI039S_UFI'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZSAX_RS0'] = ('CodeList',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZSAX_RX0'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZSAX_RX3'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOG_S']['ZSAX_RX4'] = ('StructuredText',('BH015'))
    field_information['GGDM 3.0']['BOREHOLE_P']['BEN'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['CNCP'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['COS'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['COS']['AA045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BOREHOLE_P']['DZP'] = ('Real',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['FUFI'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['FURL'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['GDBV'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['GDBV']['AA045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOREHOLE_P']['LMC'] = ('Boolean',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['OTH'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['PCF'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['PCF']['AA045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BOREHOLE_P']['RIP'] = ('Boolean',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['UFI'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI001_SDV'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI001_SRT'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI001_SRT']['AA045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI002_UFI'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI004_RCG'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI004_RCG']['AA045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI005_FNA'] = ('String',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI005_GNT'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI005_GNT']['AA045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI005_NFN'] = ('String',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI006_MEM'] = ('String',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI020_GE4'] = ('CodeList',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI026_CTUC'] = ('Enumeration',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOREHOLE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI026_CTUL'] = ('integer',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI026_CTUU'] = ('integer',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI031S_URI'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZI039S_UFI'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZSAX_RS0'] = ('CodeList',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZSAX_RX0'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZSAX_RX3'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZSAX_RX4'] = ('StructuredText',('AA045'))
    field_information['GGDM 3.0']['BOREHOLE_P']['ZVH'] = ('Real',('AA045'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ADR'] = ('String',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ARA'] = ('Real',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['BEN'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['FUFI'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['FURL'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['GDBV'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['GDBV']['EA031']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['LMC'] = ('Boolean',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['LZN'] = ('Real',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['OTH'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['TRE'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['TRE']['EA031']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['UFI'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['WID'] = ('Real',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI001_SDV'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI001_SRT'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI001_SRT']['EA031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI002_UFI'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI004_RCG'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI004_RCG']['EA031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI005_FNA'] = ('String',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI005_GNT'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI005_GNT']['EA031']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI005_NFN'] = ('String',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI006_MEM'] = ('String',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI020_GE4'] = ('CodeList',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI026_CTUC'] = ('Enumeration',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI026_CTUL'] = ('integer',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI026_CTUU'] = ('integer',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI031S_URI'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZI039S_UFI'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZSAX_RS0'] = ('CodeList',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZSAX_RX0'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZSAX_RX3'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZSAX_RX4'] = ('StructuredText',('EA031'))
    field_information['GGDM 3.0']['BOTANIC_GARDEN_S']['ZVH'] = ('Real',('EA031'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ARA'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['BEN'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['FUFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['FURL'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['GDBV'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['GDBV']['BF010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['LZN'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_MCC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_MCC1']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_MCC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_MCC2']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_PSC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_PSC1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_PSC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_PSC2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_SCO1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_SCO1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['MBC_SCO2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['MBC_SCO2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['OTH'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['VEG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['VEG']['BF010']  = (-999999,61,62,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['WID'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI001_SDV'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI001_SRT'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI001_SRT']['BF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI002_UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI004_RCG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI004_RCG']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI005_FNA'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI005_GNT'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI005_GNT']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI005_NFN'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI006_MEM'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI020_GE4'] = ('CodeList',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI026_CTUC'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI026_CTUL'] = ('integer',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI026_CTUU'] = ('integer',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI031S_URI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZI039S_UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZSAX_RS0'] = ('CodeList',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZSAX_RX0'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZSAX_RX3'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_P']['ZSAX_RX4'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ARA'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['BEN'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['F_CODE'] = ('CONSTRAINED_STRING',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['FUFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['FURL'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['GDBV'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['GDBV']['BF010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['LZN'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_MCC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_MCC1']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_MCC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_MCC2']['BF010']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_PSC1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_PSC1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_PSC2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_PSC2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_SCO1'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_SCO1']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['MBC_SCO2'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['MBC_SCO2']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['OTH'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['VEG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['VEG']['BF010']  = (-999999,61,62,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['WID'] = ('Real',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI001_SDV'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI001_SRT'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI001_SRT']['BF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI002_UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI004_RCG'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI004_RCG']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI005_FNA'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI005_GNT'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI005_GNT']['BF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI005_NFN'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI006_MEM'] = ('String',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI020_GE4'] = ('CodeList',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI026_CTUC'] = ('Enumeration',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC']['BF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI026_CTUL'] = ('integer',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI026_CTUU'] = ('integer',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI031S_URI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZI039S_UFI'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZSAX_RS0'] = ('CodeList',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZSAX_RX0'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZSAX_RX3'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOTTOM_CHARACTER_REGION_S']['ZSAX_RX4'] = ('StructuredText',('BF010'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['BEN'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['CNCP'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['COS'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['COS']['ZB030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['FUFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['FURL'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['GDBV'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['GDBV']['ZB030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['LZN'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['MCC'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['MCC2'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC2']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['MCC3'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['MCC3']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['OTH'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['PCF'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['PCF']['ZB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['WID'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI001_SDV'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI001_SRT'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI001_SRT']['ZB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI002_UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI004_RCG'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI004_RCG']['ZB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI005_FNA'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI005_GNT'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI005_GNT']['ZB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI005_NFN'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI006_MEM'] = ('String',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI020_GE4'] = ('CodeList',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI026_CTUC'] = ('Enumeration',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI026_CTUL'] = ('integer',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI026_CTUU'] = ('integer',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI031S_URI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZI039S_UFI'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZSAX_RS0'] = ('CodeList',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZSAX_RX0'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZSAX_RX3'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZSAX_RX4'] = ('StructuredText',('ZB030'))
    field_information['GGDM 3.0']['BOUNDARY_MONUMENT_P']['ZVH'] = ('Real',('ZB030'))
    field_information['GGDM 3.0']['BRIDGE_C']['AOO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ARA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['AWP'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['BCC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BRIDGE_C']['BEN'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['BOT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_C']['BRN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['BSC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_C']['BSC2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_C']['BSC3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_C']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['CAA'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_C']['CNCP'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['COS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_C']['DZC'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['FUFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['FURL'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['GDBV'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_C']['HCA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['HGT'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LC1'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LC2'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LC3'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LC4'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LMC'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['LZN'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['OHC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['OTH'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['PCF'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_C']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['TRS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_C']['TRS2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_C']['TRS3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_C']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['VCM'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_C']['VCM2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_C']['VCM3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_C']['VCO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['BRIDGE_C']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['VOI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['WID'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI001_SDV'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI001_SRT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_C']['ZI002_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI004_RCG'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_C']['ZI005_FNA'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI005_GNT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_C']['ZI005_NFN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI006_MEM'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI020_GE4'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI026_CTUC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_C']['ZI026_CTUL'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI026_CTUU'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI031S_URI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZI039S_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZSAX_RS0'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZSAX_RX0'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZSAX_RX3'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZSAX_RX4'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_C']['ZVH'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['AOO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ARA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['AWP'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['BCC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BRIDGE_P']['BEN'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['BOT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_P']['BRN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['BSC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_P']['BSC2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_P']['BSC3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_P']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['CAA'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_P']['CNCP'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['COS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_P']['DZC'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['FUFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['FURL'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['GDBV'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_P']['HCA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['HGT'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LC1'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LC2'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LC3'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LC4'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LMC'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['LZN'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['OHC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['OTH'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['PCF'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_P']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['TRS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_P']['TRS2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_P']['TRS3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_P']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['VCM'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_P']['VCM2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_P']['VCM3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_P']['VCO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['BRIDGE_P']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['VOI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['WID'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI001_SDV'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI001_SRT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_P']['ZI002_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI004_RCG'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_P']['ZI005_FNA'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI005_GNT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_P']['ZI005_NFN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI006_MEM'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI020_GE4'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI026_CTUC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_P']['ZI026_CTUL'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI026_CTUU'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI031S_URI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZI039S_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZSAX_RS0'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZSAX_RX0'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZSAX_RX3'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZSAX_RX4'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_P']['ZVH'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ARA'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['BEN'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['FUFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['FURL'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['GDBV'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['HGT'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['LMC'] = ('Boolean',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['LZN'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['OTH'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['PCF'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['WID'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI001_SDV'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI001_SRT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI002_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI004_RCG'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI005_FNA'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI005_GNT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI005_NFN'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI006_MEM'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI020_GE4'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI026_CTUC'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI026_CTUL'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI026_CTUU'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI031S_URI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZI039S_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZSAX_RS0'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZSAX_RX0'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZSAX_RX3'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZSAX_RX4'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_C']['ZVH'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ARA'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['BEN'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['FUFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['FURL'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['GDBV'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['HGT'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['LMC'] = ('Boolean',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['LZN'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['OTH'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['PCF'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['WID'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI001_SDV'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI001_SRT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI002_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI004_RCG'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI005_FNA'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI005_GNT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI005_NFN'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI006_MEM'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI020_GE4'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI026_CTUC'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI026_CTUL'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI026_CTUU'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI031S_URI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZI039S_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZSAX_RS0'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZSAX_RX0'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZSAX_RX3'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZSAX_RX4'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_P']['ZVH'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ARA'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['BEN'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['FUFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['FURL'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['GDBV'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['GDBV']['AQ056']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['HGT'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['LMC'] = ('Boolean',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['LZN'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['OTH'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['PCF'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['WID'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI001_SDV'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI001_SRT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI002_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI004_RCG'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI005_FNA'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI005_GNT'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ056']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI005_NFN'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI006_MEM'] = ('String',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI020_GE4'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI026_CTUC'] = ('Enumeration',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI026_CTUL'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI026_CTUU'] = ('integer',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI031S_URI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZI039S_UFI'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZSAX_RS0'] = ('CodeList',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZSAX_RX0'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZSAX_RX3'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZSAX_RX4'] = ('StructuredText',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_PIER_S']['ZVH'] = ('Real',('AQ056'))
    field_information['GGDM 3.0']['BRIDGE_S']['AOO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ARA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['AWP'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['BCC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BRIDGE_S']['BEN'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['BOT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_S']['BRN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['BSC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_S']['BSC2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_S']['BSC3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_S']['BSM'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['CAA'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_S']['CNCP'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['COS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['COS']['AQ040']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_S']['DZC'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['FUFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['FURL'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['GDBV'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['GDBV']['AQ040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_S']['HCA'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['HGT'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LC1'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LC2'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LC3'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LC4'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LMC'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['LZN'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['NOS'] = ('Integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['OHC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['OTH'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['PCF'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_S']['RFD'] = ('Boolean',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['TRS'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_S']['TRS2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_S']['TRS3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['GGDM 3.0']['BRIDGE_S']['UBC'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['VCM'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_S']['VCM2'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_S']['VCM3'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_S']['VCO'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['VCS'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['VCS_VCD'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCS_VCD'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['VCS_VCD']['AQ040']  = (-999999,7,9,10,15,24,28,30,999)
    field_information['GGDM 3.0']['BRIDGE_S']['VCS_VCR'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['VOI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['WID'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI001_SDV'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI001_SRT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_S']['ZI002_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI004_RCG'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_S']['ZI005_FNA'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI005_GNT'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_S']['ZI005_NFN'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI006_MEM'] = ('String',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI020_GE4'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI026_CTUC'] = ('Enumeration',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_S']['ZI026_CTUL'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI026_CTUU'] = ('integer',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI031S_URI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZI039S_UFI'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZSAX_RS0'] = ('CodeList',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZSAX_RX0'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZSAX_RX3'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZSAX_RX4'] = ('StructuredText',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_S']['ZVH'] = ('Real',('AQ040'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['AOO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ARA'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BEN'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BOT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BRN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BSC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BSC2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['BSC3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['CNCP'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['COS'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['FUFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['FURL'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['GDBV'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['HGT'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['LC1'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['LC2'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['LC3'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['LC4'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['LZN'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['OHC'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['OTH'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['PCF'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['VCM'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['VCM2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['VCM3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['VCO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['WID'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI001_SDV'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI001_SRT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI002_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI004_RCG'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI005_FNA'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI005_GNT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI005_NFN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI006_MEM'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI020_GE4'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI026_CTUC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI026_CTUL'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI026_CTUU'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI031S_URI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZI039S_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZSAX_RS0'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZSAX_RX0'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZSAX_RX3'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZSAX_RX4'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_C']['ZVH'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['AOO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ARA'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BEN'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BOT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BRN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BSC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BSC2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['BSC3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['CNCP'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['COS'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['FUFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['FURL'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['GDBV'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['HGT'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['LC1'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['LC2'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['LC3'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['LC4'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['LZN'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['OHC'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['OTH'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['PCF'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['VCM'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['VCM2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['VCM3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['VCO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['WID'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI001_SDV'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI001_SRT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI002_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI004_RCG'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI005_FNA'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI005_GNT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI005_NFN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI006_MEM'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI020_GE4'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI026_CTUC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI026_CTUL'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI026_CTUU'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI031S_URI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZI039S_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZSAX_RS0'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZSAX_RX0'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZSAX_RX3'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZSAX_RX4'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_P']['ZVH'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['AOO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ARA'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BEN'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BOT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BOT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BRN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BSC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BSC2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['BSC3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['CNCP'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['COS'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['COS']['AQ045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['FUFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['FURL'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['GDBV'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['GDBV']['AQ045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['HGT'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['LC1'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['LC2'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['LC3'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['LC4'] = ('Integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['LZN'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['OHC'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['OTH'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['PCF'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['VCM'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['VCM2'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['VCM3'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['VCO'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['WID'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI001_SDV'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI001_SRT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI002_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI004_RCG'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI005_FNA'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI005_GNT'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI005_NFN'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI006_MEM'] = ('String',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI020_GE4'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI026_CTUC'] = ('Enumeration',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI026_CTUL'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI026_CTUU'] = ('integer',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI031S_URI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZI039S_UFI'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZSAX_RS0'] = ('CodeList',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZSAX_RX0'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZSAX_RX3'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZSAX_RX4'] = ('StructuredText',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SPAN_S']['ZVH'] = ('Real',('AQ045'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['AOO'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ARA'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['AWP'] = ('Boolean',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['BEN'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['BRN'] = ('String',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['BSC'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['BSC']['AQ050']  = (-999999,1,2,3,5,6,7,8,9,12,15,16,19,22,26,27,28,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['FUFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['FURL'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['GDBV'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['GDBV']['AQ050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['HEI'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['HGT'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['LMC'] = ('Boolean',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['LZN'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['OTH'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['PCF'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['VOI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['WID'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI001_SDV'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI001_SRT'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI002_UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI004_RCG'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI006_MEM'] = ('String',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI020_GE4'] = ('CodeList',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI026_CTUC'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI026_CTUL'] = ('integer',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI026_CTUU'] = ('integer',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI031S_URI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZI039S_UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZSAX_RS0'] = ('CodeList',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZSAX_RX0'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZSAX_RX3'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZSAX_RX4'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_C']['ZVH'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['AOO'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ARA'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['AWP'] = ('Boolean',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['BEN'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['BRN'] = ('String',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['BSC'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['BSC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['BSC']['AQ050']  = (-999999,1,2,3,5,6,7,8,9,12,15,16,19,22,26,27,28,31,32,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['FUFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['FURL'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['GDBV'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AQ050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['HEI'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['HGT'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['LMC'] = ('Boolean',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['LZN'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['OTH'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['PCF'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['VOI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['WID'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI006_MEM'] = ('String',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI026_CTUL'] = ('integer',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI026_CTUU'] = ('integer',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_SUPERSTRUCTURE_S']['ZVH'] = ('Real',('AQ050'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['AOO'] = ('Real',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['AWP'] = ('Boolean',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['BEN'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['BRN'] = ('String',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['FUFI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['FURL'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['GDBV'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['GDBV']['AQ055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['HGT'] = ('Real',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['LMC'] = ('Boolean',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['LZN'] = ('Real',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['OTH'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['PCF'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['PCF']['AQ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['PYM'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['PYM']['AQ055']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['UFI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['VOI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['WID'] = ('Real',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI001_SDV'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI001_SRT'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI002_UFI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI004_RCG'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI006_MEM'] = ('String',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI020_GE4'] = ('CodeList',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI026_CTUC'] = ('Enumeration',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI026_CTUL'] = ('integer',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI026_CTUU'] = ('integer',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI031S_URI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZI039S_UFI'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZSAX_RS0'] = ('CodeList',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZSAX_RX0'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZSAX_RX3'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZSAX_RX4'] = ('StructuredText',('AQ055'))
    field_information['GGDM 3.0']['BRIDGE_TOWER_P']['ZVH'] = ('Real',('AQ055'))
    field_information['GGDM 3.0']['BRUSH_S']['AOO'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ARA'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['BEN'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['F_CODE'] = ('CONSTRAINED_STRING',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['FUFI'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['FURL'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['GDBV'] = ('Enumeration',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['GDBV']['EB070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BRUSH_S']['HGT'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['LMC'] = ('Boolean',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['LZN'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['OTH'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['PVH'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['TRE'] = ('Enumeration',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['TRE']['EB070']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BRUSH_S']['UFI'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['WID'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI001_SDV'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI001_SRT'] = ('Enumeration',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI001_SRT']['EB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BRUSH_S']['ZI002_UFI'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI004_RCG'] = ('Enumeration',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI004_RCG']['EB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BRUSH_S']['ZI006_MEM'] = ('String',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI020_GE4'] = ('CodeList',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI026_CTUC'] = ('Enumeration',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BRUSH_S']['EnumeratedIndexValues']['ZI026_CTUC']['EB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BRUSH_S']['ZI026_CTUL'] = ('integer',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI026_CTUU'] = ('integer',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI031S_URI'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZI039S_UFI'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZSAX_RS0'] = ('CodeList',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZSAX_RX0'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZSAX_RX3'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZSAX_RX4'] = ('StructuredText',('EB070'))
    field_information['GGDM 3.0']['BRUSH_S']['ZVH'] = ('Real',('EB070'))
    field_information['GGDM 3.0']['BUILDING_P']['ADR'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['AOO'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ARA'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ATB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['AWP'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['BEN'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['BNF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['CAA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BUILDING_P']['CNCP'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['COS'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['COS']['AL013']  = (-999999,1,2,3,4,6,8,9,13,14)
    field_information['GGDM 3.0']['BUILDING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['FFN'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_P']['FFN2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_P']['FFN3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_P']['FUFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['FURL'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['GDBV'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['GDBV']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_P']['HGT'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['HSC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['HST'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_P']['HST2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_P']['HST3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_P']['LMC'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['LZN'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['MEL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MEL'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MEL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['BUILDING_P']['MFB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['MFY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MFY'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MFY']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,999)
    field_information['GGDM 3.0']['BUILDING_P']['MKSZ'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MKSZ'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['MKSZ']['AL013']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['BUILDING_P']['MUB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['NOR'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['OTH'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['PCF'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILDING_P']['RLE'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['RLE']['AL013']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BUILDING_P']['SSR'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_P']['SSR2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_P']['SSR3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_P']['STAF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['VCM'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_P']['VCM2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_P']['VCM3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_P']['VEC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['VOI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['WID'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['WPST'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['WTYP'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['WTYP']['AL013']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI001_SDV'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI001_SRT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI001_SRT']['AL013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI002_UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI004_RCG'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI004_RCG']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_FNA'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_FNA2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_FNA3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_GNT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_GNT2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_GNT3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_NFN'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_NFN2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI005_NFN3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI006_MEM'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PBY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PBY2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PBY3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PPO'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PPO2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PPO3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PRW'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PRW2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI014_PRW3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI018_WIT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI020_GE4'] = ('CodeList',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI026_CTUC'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILDING_P']['ZI026_CTUL'] = ('integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI026_CTUU'] = ('integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI031S_URI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['BUILDING_P']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['BUILDING_P']['ZI039S_UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZSAX_RS0'] = ('CodeList',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZSAX_RX0'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZSAX_RX3'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZSAX_RX4'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_P']['ZVH'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ADR'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['AOO'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ARA'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ATB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['AWP'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['BEN'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['BNF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['CAA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BUILDING_S']['CNCP'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['COS'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['COS']['AL013']  = (-999999,1,2,3,4,6,8,9,13,14)
    field_information['GGDM 3.0']['BUILDING_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['FFN'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_S']['FFN2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_S']['FFN3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['BUILDING_S']['FUFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['FURL'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['GDBV'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['GDBV']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_S']['HGT'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['HSC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['HST'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_S']['HST2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_S']['HST3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['BUILDING_S']['LMC'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['LZN'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['MEL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MEL'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MEL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['BUILDING_S']['MFB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['MFY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MFY'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MFY']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,999)
    field_information['GGDM 3.0']['BUILDING_S']['MKSZ'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MKSZ'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['MKSZ']['AL013']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['BUILDING_S']['MUB'] = ('Boolean',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['NOR'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['OTH'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['PCF'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILDING_S']['RLE'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['RLE']['AL013']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BUILDING_S']['SSR'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_S']['SSR2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_S']['SSR3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['BUILDING_S']['STAF'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['VCM'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_S']['VCM2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_S']['VCM3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_S']['VEC'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['VOI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['WID'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['WPST'] = ('Integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['WTYP'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['WTYP']['AL013']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI001_SDV'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI001_SRT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI001_SRT']['AL013']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI002_UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI004_RCG'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI004_RCG']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_FNA'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_FNA2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_FNA3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_GNT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_GNT2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_GNT3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_NFN'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_NFN2'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI005_NFN3'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI006_MEM'] = ('String',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PBY'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PBY2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PBY3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PPO'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PPO2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PPO3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PRW'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PRW2'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI014_PRW3'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI018_WIT'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI020_GE4'] = ('CodeList',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI026_CTUC'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL013']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILDING_S']['ZI026_CTUL'] = ('integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI026_CTUU'] = ('integer',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI031S_URI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['BUILDING_S']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['BUILDING_S']['ZI039S_UFI'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZSAX_RS0'] = ('CodeList',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZSAX_RX0'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZSAX_RX3'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZSAX_RX4'] = ('StructuredText',('AL013'))
    field_information['GGDM 3.0']['BUILDING_S']['ZVH'] = ('Real',('AL013'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['AOO'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ARA'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['AWP'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['BEN'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['CNCP'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['COS'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['FUFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['FURL'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['GDBV'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['HEI'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['HGT'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['LMC'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['LZN'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['OTH'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['PCF'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['VOI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['WID'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI001_SDV'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI001_SRT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI002_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI004_RCG'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI005_FNA'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI005_GNT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI005_NFN'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI006_MEM'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI018_WIT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI020_GE4'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI026_CTUC'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI026_CTUL'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI026_CTUU'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI031S_URI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZI039S_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZSAX_RS0'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZSAX_RX0'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZSAX_RX3'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZSAX_RX4'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_C']['ZVH'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['AOO'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ARA'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['AWP'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['BEN'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['CNCP'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['COS'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['FUFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['FURL'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['GDBV'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['HEI'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['HGT'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['LMC'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['LZN'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['OTH'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['PCF'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['VOI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['WID'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI005_FNA'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI005_GNT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI005_NFN'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI006_MEM'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI018_WIT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI020_GE4'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI026_CTUL'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI026_CTUU'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_P']['ZVH'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['AOO'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ARA'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['AWP'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['BEN'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['BSU'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['BSU'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['CNCP'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['COS'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['COS']['AL018']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['FUFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['FURL'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['GDBV'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['HEI'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['HGT'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['LMC'] = ('Boolean',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['LZN'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['OTH'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['PCF'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['VOI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['WID'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL018']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI005_FNA'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI005_GNT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI005_NFN'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI006_MEM'] = ('String',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI018_WIT'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI018_WIT']['AL018']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL018']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI026_CTUL'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI026_CTUU'] = ('integer',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AL018'))
    field_information['GGDM 3.0']['BUILDING_SUPERSTRUCTURE_S']['ZVH'] = ('Real',('AL018'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['AOO'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ARA'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['BAC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['BAC'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['BEN'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['BNF'] = ('Integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['CAA'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['CNCP'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['COS'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['COS']['AL020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['DNE'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['DNE'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['DNE']['AL020']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['FFN'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['FFN2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['FFN3'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['FUFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['FURL'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['GDBV'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['GDBV']['AL020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['HGT'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['LZN'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['OTH'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['PCF'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['WID'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['WPI'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI001_SDV'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI001_SRT'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI001_SRT']['AL020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI002_UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI004_RCG'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI004_RCG']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_FNA'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_GNT'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI005_GNT']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_GNT2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI005_GNT2']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_NFN'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI006_MEM'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI020_GE4'] = ('CodeList',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI026_CTUC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI026_CTUL'] = ('integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI026_CTUU'] = ('integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI031S_URI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZI039S_UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZSAX_RS0'] = ('CodeList',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZSAX_RX0'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZSAX_RX3'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZSAX_RX4'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_P']['ZVH'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['AOO'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ARA'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['BAC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['BAC'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['BEN'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['BNF'] = ('Integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['CAA'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['CNCP'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['COS'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['COS']['AL020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['DNE'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['DNE'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['DNE']['AL020']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['FFN'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['FFN2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['FFN3'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['FUFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['FURL'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['GDBV'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['GDBV']['AL020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['HGT'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['LZN'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['OTH'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['PCF'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['WID'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['WPI'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI001_SDV'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI001_SRT'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['AL020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI002_UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI004_RCG'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_FNA'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_GNT'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_GNT2'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI005_GNT2']['AL020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_NFN'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI006_MEM'] = ('String',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI020_GE4'] = ('CodeList',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI026_CTUC'] = ('Enumeration',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI026_CTUL'] = ('integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI026_CTUU'] = ('integer',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI031S_URI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZI039S_UFI'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZSAX_RS0'] = ('CodeList',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZSAX_RX0'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZSAX_RX3'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZSAX_RX4'] = ('StructuredText',('AL020'))
    field_information['GGDM 3.0']['BUILT_UP_AREA_S']['ZVH'] = ('Real',('AL020'))
    field_information['GGDM 3.0']['BUOY_P']['BC034_BRF'] = ('Integer',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC034_BRF2'] = ('Integer',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC034_MRT'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BUOY_P']['BC034_MRT2'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT2']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BUOY_P']['BC034_MRT3'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC034_MRT3']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BUOY_P']['BC040_COL'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC040_EOL'] = ('Real',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC040_LVN'] = ('Integer',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC040_MLR'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BC101_SST'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BC101_SST']['BC020']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['BUOY_P']['BEN'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['BUS'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BUS'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BUS']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['BUOY_P']['BUT'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BUT'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['BUT']['BC020']  = (-999999,3,4,6,7,10,11,15,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,39,81,82,84,85,86,87,88,89,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119,120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,149,150,999)
    field_information['GGDM 3.0']['BUOY_P']['CNCP'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['COS'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['COS']['BC020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['BUOY_P']['CSS'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['CSS'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['CSS']['BC020']  = (-999999,1,4,5,6,999)
    field_information['GGDM 3.0']['BUOY_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['FUFI'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['FURL'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['GDBV'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['GDBV']['BC020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['BUOY_P']['NMC'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['BUOY_P']['NMC2'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC2'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC2']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['BUOY_P']['NMC3'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC3'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['NMC3']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['BUOY_P']['OTH'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['PCF'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['PCF']['BC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['BUOY_P']['REF'] = ('Boolean',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['TZP'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['TZP'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['TZP']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['BUOY_P']['UFI'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI001_SDV'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI001_SRT'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI001_SRT']['BC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['BUOY_P']['ZI002_UFI'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI004_RCG'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI004_RCG']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['BUOY_P']['ZI005_FNA'] = ('String',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI005_GNT'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI005_GNT']['BC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['BUOY_P']['ZI005_NFN'] = ('String',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI006_MEM'] = ('String',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI020_GE4'] = ('CodeList',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI026_CTUC'] = ('Enumeration',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['BUOY_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['BUOY_P']['ZI026_CTUL'] = ('integer',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI026_CTUU'] = ('integer',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI031S_URI'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZI039S_UFI'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZSAX_RS0'] = ('CodeList',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZSAX_RX0'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZSAX_RX3'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['BUOY_P']['ZSAX_RX4'] = ('StructuredText',('BC020'))
    field_information['GGDM 3.0']['CABLE_C']['AWP'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['BEN'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['CAA'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAA']['AT005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CABLE_C']['CAB'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['CABLE_C']['CAB2'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB2'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB2']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['CABLE_C']['CAB3'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB3'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['CAB3']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['CABLE_C']['CNCP'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['COS'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['COS']['AT005']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['CABLE_C']['CST'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['DZP'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['FLO'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['FUFI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['FURL'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['GDBV'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['GDBV']['AT005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CABLE_C']['HGT'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['KVA'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['LEA'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['LMC'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['LOC'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['LOC']['AT005']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['CABLE_C']['LZN'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['NPL'] = ('Integer',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['OHC'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['OTH'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['OWO'] = ('Boolean',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['PCF'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['PCF']['AT005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CABLE_C']['PFH'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['TST'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['TST'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['TST']['AT005']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CABLE_C']['UFI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['VCO'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['VOI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI001_SDV'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI001_SRT'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI001_SRT']['AT005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CABLE_C']['ZI002_UFI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI004_RCG'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI004_RCG']['AT005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CABLE_C']['ZI005_FNA'] = ('String',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI005_GNT'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI005_GNT']['AT005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CABLE_C']['ZI005_NFN'] = ('String',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI006_MEM'] = ('String',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI020_GE4'] = ('CodeList',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI025_HDP'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI025_WLE'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI025_WLE']['AT005']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['CABLE_C']['ZI026_CTUC'] = ('Enumeration',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CABLE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AT005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CABLE_C']['ZI026_CTUL'] = ('integer',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI026_CTUU'] = ('integer',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI031S_URI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZI039S_UFI'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZSAX_RS0'] = ('CodeList',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZSAX_RX0'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZSAX_RX3'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZSAX_RX4'] = ('StructuredText',('AT005'))
    field_information['GGDM 3.0']['CABLE_C']['ZVH'] = ('Real',('AT005'))
    field_information['GGDM 3.0']['CABLEWAY_C']['AWP'] = ('Boolean',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['BEN'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['CAT'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['CAT'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['CAT']['AT041']  = (-999999,2,3,5,6,7,8,9,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['CNCP'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['COS'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['COS']['AT041']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['CABLEWAY_C']['F_CODE'] = ('CONSTRAINED_STRING',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['FFN'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['FFN2'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN2']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['FFN3'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['FFN3']['AT041']  = (-999999,99,480,921,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['FUFI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['FURL'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['GDBV'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['GDBV']['AT041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['HGT'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['LMC'] = ('Boolean',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['LZN'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['OTH'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['OWO'] = ('Boolean',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['PCF'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['PCF']['AT041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CABLEWAY_C']['PFH'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['TST'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['TST'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['TST']['AT041']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['UFI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['VCO'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['VOI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['WID'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI001_SDV'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI001_SRT'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI001_SRT']['AT041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI002_UFI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI004_RCG'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI004_RCG']['AT041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI005_FNA'] = ('String',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI005_GNT'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI005_GNT']['AT041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI005_NFN'] = ('String',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI006_MEM'] = ('String',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI020_GE4'] = ('CodeList',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI026_CTUC'] = ('Enumeration',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CABLEWAY_C']['EnumeratedIndexValues']['ZI026_CTUC']['AT041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI026_CTUL'] = ('integer',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI026_CTUU'] = ('integer',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI031S_URI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZI039S_UFI'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZSAX_RS0'] = ('CodeList',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZSAX_RX0'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZSAX_RX3'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZSAX_RX4'] = ('StructuredText',('AT041'))
    field_information['GGDM 3.0']['CABLEWAY_C']['ZVH'] = ('Real',('AT041'))
    field_information['GGDM 3.0']['CAIRN_P']['BEN'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['FUFI'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['FURL'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['GDBV'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['GDBV']['AL025']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAIRN_P']['HGT'] = ('Real',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['LMC'] = ('Boolean',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['LZN'] = ('Real',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['OTH'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['PCF'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['PCF']['AL025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAIRN_P']['UFI'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['WID'] = ('Real',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI001_SDV'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI001_SRT'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI001_SRT']['AL025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAIRN_P']['ZI002_UFI'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI004_RCG'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI004_RCG']['AL025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAIRN_P']['ZI005_FNA'] = ('String',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI005_GNT'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI005_GNT']['AL025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAIRN_P']['ZI005_NFN'] = ('String',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI006_MEM'] = ('String',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI020_GE4'] = ('CodeList',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI026_CTUC'] = ('Enumeration',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAIRN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAIRN_P']['ZI026_CTUL'] = ('integer',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI026_CTUU'] = ('integer',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI031S_URI'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZI039S_UFI'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZSAX_RS0'] = ('CodeList',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZSAX_RX0'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZSAX_RX3'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZSAX_RX4'] = ('StructuredText',('AL025'))
    field_information['GGDM 3.0']['CAIRN_P']['ZVH'] = ('Real',('AL025'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['BEN'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['DF1'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['DF2'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['DF3'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['DF4'] = ('Integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['FUFI'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['FURL'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['GDBV'] = ('Enumeration',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['GDBV']['BB050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['OTH'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['UFI'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI001_SDV'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI001_SRT'] = ('Enumeration',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['BB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI002_UFI'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI004_RCG'] = ('Enumeration',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['BB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI005_FNA'] = ('String',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI005_GNT'] = ('Enumeration',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['BB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI005_NFN'] = ('String',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI006_MEM'] = ('String',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI020_GE4'] = ('CodeList',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI026_CTUC'] = ('Enumeration',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI026_CTUL'] = ('integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI026_CTUU'] = ('integer',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI031S_URI'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZI039S_UFI'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZSAX_RS0'] = ('CodeList',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZSAX_RX0'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZSAX_RX3'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CALLING_IN_POINT_P']['ZSAX_RX4'] = ('StructuredText',('BB050'))
    field_information['GGDM 3.0']['CAMP_P']['ADR'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ARA'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['BEN'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['CAA'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAMP_P']['CNCP'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['COS'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['COS']['AI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAMP_P']['F_CODE'] = ('CONSTRAINED_STRING',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['FFN'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_P']['FFN2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_P']['FFN3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_P']['FUFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['FURL'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['GDBV'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['GDBV']['AI030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAMP_P']['HGT'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['LMC'] = ('Boolean',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['LZN'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['OTH'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['PCF'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAMP_P']['STL'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_P']['STL2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL2'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_P']['STL3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL3'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_P']['UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['WID'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI001_SDV'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI001_SRT'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI001_SRT']['AI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAMP_P']['ZI002_UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI004_RCG'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI004_RCG']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAMP_P']['ZI005_FNA'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI005_GNT'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI005_GNT']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAMP_P']['ZI005_NFN'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI006_MEM'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI020_GE4'] = ('CodeList',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI026_CTUC'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAMP_P']['EnumeratedIndexValues']['ZI026_CTUC']['AI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAMP_P']['ZI026_CTUL'] = ('integer',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI026_CTUU'] = ('integer',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI031S_URI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZI039S_UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZSAX_RS0'] = ('CodeList',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZSAX_RX0'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZSAX_RX3'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZSAX_RX4'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_P']['ZVH'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ADR'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ARA'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['BEN'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['CAA'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAMP_S']['CNCP'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['COS'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['COS']['AI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAMP_S']['F_CODE'] = ('CONSTRAINED_STRING',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['FFN'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_S']['FFN2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_S']['FFN3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,835,881,883,999)
    field_information['GGDM 3.0']['CAMP_S']['FUFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['FURL'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['GDBV'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['GDBV']['AI030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAMP_S']['HGT'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['LMC'] = ('Boolean',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['LZN'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['OTH'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['PCF'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAMP_S']['STL'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_S']['STL2'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL2'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_S']['STL3'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL3'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CAMP_S']['UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['WID'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI001_SDV'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI001_SRT'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI001_SRT']['AI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAMP_S']['ZI002_UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI004_RCG'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI004_RCG']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAMP_S']['ZI005_FNA'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI005_GNT'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI005_GNT']['AI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAMP_S']['ZI005_NFN'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI006_MEM'] = ('String',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI020_GE4'] = ('CodeList',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI026_CTUC'] = ('Enumeration',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAMP_S']['EnumeratedIndexValues']['ZI026_CTUC']['AI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAMP_S']['ZI026_CTUL'] = ('integer',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI026_CTUU'] = ('integer',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI031S_URI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZI039S_UFI'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZSAX_RS0'] = ('CodeList',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZSAX_RX0'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZSAX_RX3'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZSAX_RX4'] = ('StructuredText',('AI030'))
    field_information['GGDM 3.0']['CAMP_S']['ZVH'] = ('Real',('AI030'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ARA'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['BEN'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['CNCP'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['COS'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['COS']['AK060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAMP_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['FUFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['FURL'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['GDBV'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['GDBV']['AK060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAMP_SITE_P']['LMC'] = ('Boolean',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['LZN'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['OTH'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['PCF'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAMP_SITE_P']['UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['WID'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI001_SDV'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI001_SRT'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AK060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI002_UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI004_RCG'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI005_FNA'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI005_GNT'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI005_NFN'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI006_MEM'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI020_GE4'] = ('CodeList',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI026_CTUL'] = ('integer',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI026_CTUU'] = ('integer',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI031S_URI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZSAX_RS0'] = ('CodeList',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ARA'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['BEN'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['CNCP'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['COS'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['COS']['AK060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAMP_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['FUFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['FURL'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['GDBV'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['GDBV']['AK060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAMP_SITE_S']['LMC'] = ('Boolean',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['LZN'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['OTH'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['PCF'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAMP_SITE_S']['UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['WID'] = ('Real',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI001_SDV'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI001_SRT'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI002_UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI004_RCG'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI005_FNA'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI005_GNT'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI005_NFN'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI006_MEM'] = ('String',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI020_GE4'] = ('CodeList',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAMP_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI026_CTUL'] = ('integer',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI026_CTUU'] = ('integer',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI031S_URI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZSAX_RS0'] = ('CodeList',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CAMP_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AK060'))
    field_information['GGDM 3.0']['CANE_S']['ARA'] = ('Real',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['BEN'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['FUFI'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['FURL'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['GDBV'] = ('Enumeration',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['GDBV']['EC010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CANE_S']['HGT'] = ('Real',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['LZN'] = ('Real',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['OTH'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['UFI'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['VTI'] = ('Real',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['WID'] = ('Real',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI001_SDV'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI001_SRT'] = ('Enumeration',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI001_SRT']['EC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CANE_S']['ZI002_UFI'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI004_RCG'] = ('Enumeration',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI004_RCG']['EC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CANE_S']['ZI005_FNA'] = ('String',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI005_GNT'] = ('Enumeration',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI005_GNT']['EC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CANE_S']['ZI005_NFN'] = ('String',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI006_MEM'] = ('String',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI020_GE4'] = ('CodeList',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI026_CTUC'] = ('Enumeration',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CANE_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CANE_S']['ZI026_CTUL'] = ('integer',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI026_CTUU'] = ('integer',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI031S_URI'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZI039S_UFI'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZSAX_RS0'] = ('CodeList',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZSAX_RX0'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZSAX_RX3'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANE_S']['ZSAX_RX4'] = ('StructuredText',('EC010'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ADR'] = ('String',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ARA'] = ('Real',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['BEN'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['CAA'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['CAA']['SU004']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['FUFI'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['FURL'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['GDBV'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['GDBV']['SU004']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['LZN'] = ('Real',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['OTH'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['PCF'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['PCF']['SU004']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['UFI'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['WID'] = ('Real',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI001_SDV'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI001_SRT'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['SU004']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI002_UFI'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI004_RCG'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['SU004']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI005_FNA'] = ('String',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI005_GNT'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['SU004']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI005_NFN'] = ('String',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI006_MEM'] = ('String',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI020_GE4'] = ('CodeList',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI026_CTUC'] = ('Enumeration',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['SU004']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI026_CTUL'] = ('integer',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI026_CTUU'] = ('integer',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI031S_URI'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZI039S_UFI'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZSAX_RS0'] = ('CodeList',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZSAX_RX0'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZSAX_RX3'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CANTONMENT_AREA_S']['ZSAX_RX4'] = ('StructuredText',('SU004'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ADR'] = ('String',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['AOO'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ARA'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['BEN'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['CAA'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['CAA']['AI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['CNCP'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['COS'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['COS']['AI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['FFN'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['FFN2'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN2']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['FFN3'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['FFN3']['AI020']  = (-999999,382,466,470,476,563,570,572,921,930,961,970,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['FUFI'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['FURL'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['GDBV'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['GDBV']['AI020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['HGT'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['LMC'] = ('Boolean',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['LZN'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['OTH'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['PCF'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['PCF']['AI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['UFI'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['WID'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI001_SDV'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI001_SRT'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI001_SRT']['AI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI002_UFI'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI004_RCG'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI004_RCG']['AI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI005_FNA'] = ('String',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI005_GNT'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI005_GNT']['AI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI005_NFN'] = ('String',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI006_MEM'] = ('String',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI020_GE4'] = ('CodeList',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI026_CTUC'] = ('Enumeration',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI026_CTUL'] = ('integer',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI026_CTUU'] = ('integer',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI031S_URI'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZI039S_UFI'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZSAX_RS0'] = ('CodeList',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZSAX_RX0'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZSAX_RX3'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZSAX_RX4'] = ('StructuredText',('AI020'))
    field_information['GGDM 3.0']['CARAVAN_PARK_S']['ZVH'] = ('Real',('AI020'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ARA'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['BEN'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['CIW'] = ('Boolean',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['CNCP'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['COS'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['COS']['AP010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CART_TRACK_C']['CWT'] = ('Boolean',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['DEV'] = ('Integer',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['FUFI'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['FURL'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['GDBV'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['GDBV']['AP010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['LOC'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['LOC']['AP010']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['CART_TRACK_C']['LZN'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['OTH'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['PCF'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['PCF']['AP010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CART_TRACK_C']['PSN'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['PTG'] = ('Boolean',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['RLE'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['RLE']['AP010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CART_TRACK_C']['RTN'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['RTN2'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['RTN3'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['SBB'] = ('Boolean',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['SPD'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['SPM'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['THR'] = ('Boolean',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['TRS'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['TRS2'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS2']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['TRS3'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['TRS3']['AP010']  = (-999999,3,4,6,11,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['UFI'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['WID'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI001_SDV'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI001_SRT'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI001_SRT']['AP010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI002_UFI'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI004_RCG'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI004_RCG']['AP010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI005_FNA'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI005_GNT'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI005_GNT']['AP010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI005_NFN'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI006_MEM'] = ('String',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI016_WD1'] = ('Real',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI016_WTC'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI016_WTC']['AP010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI020_GE4'] = ('CodeList',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI026_CTUC'] = ('Enumeration',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CART_TRACK_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI026_CTUL'] = ('integer',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI026_CTUU'] = ('integer',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI031S_URI'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZI039S_UFI'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZSAX_RS0'] = ('CodeList',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZSAX_RX0'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZSAX_RX3'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CART_TRACK_C']['ZSAX_RX4'] = ('StructuredText',('AP010'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ADR'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['AOO'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ARA'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['BEN'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['CAA'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['CNCP'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['COS'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['COS']['AL376']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['FFN'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['FFN2'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['FFN3'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['FUFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['FURL'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['GDBV'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['GDBV']['AL376']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['HGT'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['LMC'] = ('Boolean',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['LZN'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['OTH'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['PCF'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['WID'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI001_SDV'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI001_SRT'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI001_SRT']['AL376']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI002_UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI004_RCG'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI004_RCG']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI005_FNA'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI005_GNT'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI005_GNT']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI005_NFN'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI006_MEM'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI020_GE4'] = ('CodeList',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI026_CTUC'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL376']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI026_CTUL'] = ('integer',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI026_CTUU'] = ('integer',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI031S_URI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZI039S_UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZSAX_RS0'] = ('CodeList',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZSAX_RX0'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZSAX_RX3'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZSAX_RX4'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_P']['ZVH'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ADR'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['AOO'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ARA'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['BEN'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['CAA'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['CNCP'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['COS'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['COS']['AL376']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['FFN'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['FFN2'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['FFN3'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['FUFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['FURL'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['GDBV'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['GDBV']['AL376']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['HGT'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['LMC'] = ('Boolean',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['LZN'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['OTH'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['PCF'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['WID'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI001_SDV'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI001_SRT'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI001_SRT']['AL376']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI002_UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI004_RCG'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI004_RCG']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI005_FNA'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI005_GNT'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI005_GNT']['AL376']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI005_NFN'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI006_MEM'] = ('String',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI020_GE4'] = ('CodeList',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI026_CTUC'] = ('Enumeration',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL376']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI026_CTUL'] = ('integer',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI026_CTUU'] = ('integer',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI031S_URI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZI039S_UFI'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZSAX_RS0'] = ('CodeList',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZSAX_RX0'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZSAX_RX3'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZSAX_RX4'] = ('StructuredText',('AL376'))
    field_information['GGDM 3.0']['CASTLE_COMPLEX_S']['ZVH'] = ('Real',('AL376'))
    field_information['GGDM 3.0']['CASTLE_P']['ADR'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['AOO'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ARA'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['AWP'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['BEN'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['BNF'] = ('Integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['CAA'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['CAA']['AL375']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CASTLE_P']['CNCP'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['COS'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['COS']['AL375']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CASTLE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['FFN'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_P']['FFN2'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_P']['FFN3'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_P']['FUFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['FURL'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['GDBV'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['GDBV']['AL375']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CASTLE_P']['HGT'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['HST'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_P']['HST2'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_P']['HST3'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_P']['LMC'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['LZN'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['MUB'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['OTH'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['PCF'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CASTLE_P']['UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['VOI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['WID'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI001_SDV'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI001_SRT'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL375']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CASTLE_P']['ZI002_UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI004_RCG'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CASTLE_P']['ZI005_FNA'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI005_GNT'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CASTLE_P']['ZI005_NFN'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI006_MEM'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI020_GE4'] = ('CodeList',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI026_CTUC'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CASTLE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL375']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CASTLE_P']['ZI026_CTUL'] = ('integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI026_CTUU'] = ('integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI031S_URI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZI039S_UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZSAX_RS0'] = ('CodeList',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZSAX_RX0'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZSAX_RX3'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZSAX_RX4'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_P']['ZVH'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ADR'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['AOO'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ARA'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['AWP'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['BEN'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['BNF'] = ('Integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['CAA'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['CAA']['AL375']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CASTLE_S']['CNCP'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['COS'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['COS']['AL375']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CASTLE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['FFN'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_S']['FFN2'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_S']['FFN3'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['GGDM 3.0']['CASTLE_S']['FUFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['FURL'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['GDBV'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['GDBV']['AL375']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CASTLE_S']['HGT'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['HST'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_S']['HST2'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_S']['HST3'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CASTLE_S']['LMC'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['LZN'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['MUB'] = ('Boolean',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['OTH'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['PCF'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CASTLE_S']['UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['VOI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['WID'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI001_SDV'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI001_SRT'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL375']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CASTLE_S']['ZI002_UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI004_RCG'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CASTLE_S']['ZI005_FNA'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI005_GNT'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL375']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CASTLE_S']['ZI005_NFN'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI006_MEM'] = ('String',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI020_GE4'] = ('CodeList',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI026_CTUC'] = ('Enumeration',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CASTLE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL375']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CASTLE_S']['ZI026_CTUL'] = ('integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI026_CTUU'] = ('integer',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI031S_URI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZI039S_UFI'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZSAX_RS0'] = ('CodeList',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZSAX_RX0'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZSAX_RX3'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZSAX_RX4'] = ('StructuredText',('AL375'))
    field_information['GGDM 3.0']['CASTLE_S']['ZVH'] = ('Real',('AL375'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['AOO'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ARA'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['AWP'] = ('Boolean',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['BEN'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['CAA'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['CAA']['AC020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['CNCP'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['COS'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['COS']['AC020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['FUFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['FURL'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['GDBV'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['GDBV']['AC020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['HGT'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['LMC'] = ('Boolean',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['LZN'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['OTH'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['PCF'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['VCM'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['VCM2'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['VCM3'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['VOI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['WID'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI001_SDV'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI001_SRT'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI001_SRT']['AC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI002_UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI004_RCG'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI004_RCG']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI005_FNA'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI005_GNT'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI005_GNT']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI005_NFN'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI006_MEM'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI020_GE4'] = ('CodeList',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI026_CTUC'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI026_CTUL'] = ('integer',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI026_CTUU'] = ('integer',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI031S_URI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZI039S_UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZSAX_RS0'] = ('CodeList',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZSAX_RX0'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZSAX_RX3'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZSAX_RX4'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_P']['ZVH'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['AOO'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ARA'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['AWP'] = ('Boolean',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['BEN'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['CAA'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['CAA']['AC020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['CNCP'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['COS'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['COS']['AC020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['FUFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['FURL'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['GDBV'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['GDBV']['AC020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['HGT'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['LMC'] = ('Boolean',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['LZN'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['OTH'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['PCF'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['VCM'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['VCM2'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['VCM3'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['VOI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['WID'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI001_SDV'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI001_SRT'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI001_SRT']['AC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI002_UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI004_RCG'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI004_RCG']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI005_FNA'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI005_GNT'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI005_GNT']['AC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI005_NFN'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI006_MEM'] = ('String',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI020_GE4'] = ('CodeList',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI026_CTUC'] = ('Enumeration',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI026_CTUL'] = ('integer',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI026_CTUU'] = ('integer',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI031S_URI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZI039S_UFI'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZSAX_RS0'] = ('CodeList',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZSAX_RX0'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZSAX_RX3'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZSAX_RX4'] = ('StructuredText',('AC020'))
    field_information['GGDM 3.0']['CATALYTIC_CRACKER_S']['ZVH'] = ('Real',('AC020'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ARA'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['BEN'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['CAA'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['CAA']['AQ063']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['CNCP'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['COS'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['COS']['AQ063']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['FUFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['FURL'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['GDBV'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['GDBV']['AQ063']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['HGT'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['LMC'] = ('Boolean',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['LZN'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['MCC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['MCC2'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['MCC3'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['OTH'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['PCF'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['SGCC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['SGCL'] = ('real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['SGCU'] = ('real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['TRS'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['TRS2'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['TRS3'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['WID'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['WLE'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI001_SDV'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI001_SRT'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ063']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI002_UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI004_RCG'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI005_FNA'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI005_GNT'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI005_NFN'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI006_MEM'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI020_GE4'] = ('CodeList',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI026_CTUC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI026_CTUL'] = ('integer',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI026_CTUU'] = ('integer',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI031S_URI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZI039S_UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZSAX_RS0'] = ('CodeList',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZSAX_RX0'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZSAX_RX3'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZSAX_RX4'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_C']['ZVH'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ARA'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['BEN'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['CAA'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['CAA']['AQ063']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['CNCP'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['COS'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['COS']['AQ063']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['FUFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['FURL'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['GDBV'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AQ063']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['HGT'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['LMC'] = ('Boolean',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['LZN'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['MCC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['MCC2'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['MCC3'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,62,64,65,84,86,88,104,117,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['OTH'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['PCF'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['SGCC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['SGCL'] = ('real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['SGCU'] = ('real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['TRS'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['TRS2'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['TRS3'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,5,9,10,12,13,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['WID'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['WLE'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ063']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI005_FNA'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI005_GNT'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ063']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI005_NFN'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI006_MEM'] = ('String',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI026_CTUL'] = ('integer',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI026_CTUU'] = ('integer',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AQ063'))
    field_information['GGDM 3.0']['CAUSEWAY_STRUCTURE_S']['ZVH'] = ('Real',('AQ063'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['BEN'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['CAA'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['CAA']['DB028']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['CNCP'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['COS'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['COS']['DB028']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['DZP'] = ('Real',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['FUFI'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['FURL'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['GDBV'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['GDBV']['DB028']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['LEA'] = ('Real',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['OTH'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['PCF'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['PCF']['DB028']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['UFI'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI001_SDV'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI001_SRT'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI001_SRT']['DB028']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI002_UFI'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI004_RCG'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI004_RCG']['DB028']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI005_FNA'] = ('String',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI005_GNT'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI005_GNT']['DB028']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI005_NFN'] = ('String',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI006_MEM'] = ('String',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI020_GE4'] = ('CodeList',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI026_CTUC'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB028']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI026_CTUL'] = ('integer',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI026_CTUU'] = ('integer',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI031S_URI'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI039S_UFI'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI071_CTX'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_CTX'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_CTX']['DB028']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI071_FFN'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI071_FFN2'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN2'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN2']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI071_FFN3'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN3'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_FFN3']['DB028']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZI071_UAO'] = ('Enumeration',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_UAO'] = {}
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['EnumeratedIndexValues']['ZI071_UAO']['DB028']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZSAX_RS0'] = ('CodeList',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZSAX_RX0'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZSAX_RX3'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_CHAMBER_S']['ZSAX_RX4'] = ('StructuredText',('DB028'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['AOO'] = ('Real',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['BEN'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['CAA'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['CAA']['DB029']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['FUFI'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['FURL'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['GDBV'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['GDBV']['DB029']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['LMC'] = ('Boolean',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['LZN'] = ('Real',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['OHC'] = ('Real',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['OTH'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['PCF'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['PCF']['DB029']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['UFI'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI001_SDV'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI001_SRT'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI001_SRT']['DB029']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI002_UFI'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI004_RCG'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI004_RCG']['DB029']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI005_FNA'] = ('String',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI005_GNT'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI005_GNT']['DB029']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI005_NFN'] = ('String',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI006_MEM'] = ('String',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI020_GE4'] = ('CodeList',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI025_HDP'] = ('Real',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI026_CTUC'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB029']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI026_CTUL'] = ('integer',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI026_CTUU'] = ('integer',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI031S_URI'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI039S_UFI'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI071_CTX'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_CTX'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_CTX']['DB029']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI071_FFN'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI071_FFN2'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN2'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN2']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI071_FFN3'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN3'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_FFN3']['DB029']  = (-999999,530,563,835,930,999)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZI071_UAO'] = ('Enumeration',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_UAO'] = {}
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['EnumeratedIndexValues']['ZI071_UAO']['DB029']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZSAX_RS0'] = ('CodeList',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZSAX_RX0'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZSAX_RX3'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CAVE_MOUTH_P']['ZSAX_RX4'] = ('StructuredText',('DB029'))
    field_information['GGDM 3.0']['CEMETERY_P']['ADR'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['AOO'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ARA'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['BEN'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['CAA'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['CAA']['AL030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CEMETERY_P']['CNCP'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['COS'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['COS']['AL030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CEMETERY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['FUFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['FURL'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['GDBV'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['GDBV']['AL030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CEMETERY_P']['HGT'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['LMC'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['LZN'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['OTH'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['PCF'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CEMETERY_P']['SDQ'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['WID'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI001_SDV'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI001_SRT'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI001_SRT']['AL030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CEMETERY_P']['ZI002_UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI004_RCG'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI004_RCG']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CEMETERY_P']['ZI005_FNA'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI005_GNT'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI005_GNT']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CEMETERY_P']['ZI005_NFN'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI006_MEM'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI020_GE4'] = ('CodeList',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI026_CTUC'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CEMETERY_P']['ZI026_CTUL'] = ('integer',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI026_CTUU'] = ('integer',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI031S_URI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZI037_REL'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CEMETERY_P']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CEMETERY_P']['ZI039S_UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZSAX_RS0'] = ('CodeList',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZSAX_RX0'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZSAX_RX3'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZSAX_RX4'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_P']['ZVH'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ADR'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['AOO'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ARA'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['BEN'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['CAA'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['CAA']['AL030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CEMETERY_S']['CNCP'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['COS'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['COS']['AL030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CEMETERY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['FUFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['FURL'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['GDBV'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['GDBV']['AL030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CEMETERY_S']['HGT'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['LMC'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['LZN'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['OTH'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['PCF'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CEMETERY_S']['SDQ'] = ('Boolean',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['WID'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI001_SDV'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI001_SRT'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI001_SRT']['AL030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CEMETERY_S']['ZI002_UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI004_RCG'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI004_RCG']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CEMETERY_S']['ZI005_FNA'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI005_GNT'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI005_GNT']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CEMETERY_S']['ZI005_NFN'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI006_MEM'] = ('String',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI020_GE4'] = ('CodeList',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI026_CTUC'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CEMETERY_S']['ZI026_CTUL'] = ('integer',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI026_CTUU'] = ('integer',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI031S_URI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZI037_REL'] = ('Enumeration',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CEMETERY_S']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['CEMETERY_S']['ZI039S_UFI'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZSAX_RS0'] = ('CodeList',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZSAX_RX0'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZSAX_RX3'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZSAX_RX4'] = ('StructuredText',('AL030'))
    field_information['GGDM 3.0']['CEMETERY_S']['ZVH'] = ('Real',('AL030'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ARA'] = ('Real',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['BEN'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['CNCP'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['COS'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['COS']['AH070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['CHECKPOINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['FFN'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['FFN2'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN2']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['FFN3'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['FFN3']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['FUFI'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['FURL'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['GDBV'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['GDBV']['AH070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['LMC'] = ('Boolean',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['LZN'] = ('Real',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['OTH'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['TRS'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['TRS2'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS2']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['TRS3'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['TRS3']['AH070']  = (-999999,1,7,8,9,12,13,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['UFI'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['WID'] = ('Real',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI001_SDV'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI001_SRT'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI001_SRT']['AH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI002_UFI'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI004_RCG'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI004_RCG']['AH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI005_FNA'] = ('String',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI005_GNT'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI005_GNT']['AH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI005_NFN'] = ('String',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI006_MEM'] = ('String',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI020_GE4'] = ('CodeList',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI026_CTUC'] = ('Enumeration',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CHECKPOINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI026_CTUL'] = ('integer',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI026_CTUU'] = ('integer',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI031S_URI'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZI039S_UFI'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZSAX_RS0'] = ('CodeList',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZSAX_RX0'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZSAX_RX3'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CHECKPOINT_P']['ZSAX_RX4'] = ('StructuredText',('AH070'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ARA'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['BEN'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['CAA'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['CAA']['NU010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['CNCP'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['COS'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['COS']['NU010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CISTERN_AON_S']['DMF'] = ('Integer',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['FUFI'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['FURL'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['GDBV'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['GDBV']['NU010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['HGT'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['LMC'] = ('Boolean',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['LUN'] = ('Boolean',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['LZN'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['OTH'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['PCF'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['PCF']['NU010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CISTERN_AON_S']['PMPR'] = ('Boolean',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['UFI'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['VCM'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['VCM2'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM2']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['VCM3'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['VCM3']['NU010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['VLM'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['WDST'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['WDST']['NU010']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI001_SDV'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI001_SRT'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NU010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI002_UFI'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI004_RCG'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_FNA'] = ('String',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_FNA2'] = ('String',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_GNT'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_GNT2'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_NFN'] = ('String',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI005_NFN2'] = ('String',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI006_MEM'] = ('String',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI020_GE4'] = ('CodeList',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_ASE'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_CFR'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_CLO'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_CYN'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_FMR'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_FRR'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_HAR'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_HYP'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NU010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_MGN'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_PHW'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_SCC'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NU010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_SUL'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_TDS'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_TEP'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_TUR'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WAC'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WTNO'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WUR'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WUR2'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WUR3'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_WUR4'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NU010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI024_YWQ'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NU010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI026_CTUC'] = ('Enumeration',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CISTERN_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NU010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI026_CTUL'] = ('integer',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI026_CTUU'] = ('integer',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI031S_URI'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZI039S_UFI'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZSAX_RS0'] = ('CodeList',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZSAX_RX0'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZSAX_RX3'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZSAX_RX4'] = ('StructuredText',('NU010'))
    field_information['GGDM 3.0']['CISTERN_AON_S']['ZVH'] = ('Real',('NU010'))
    field_information['GGDM 3.0']['CISTERN_P']['AOO'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ARA'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['BEN'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['CAA'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['CAA']['BI010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CISTERN_P']['CNCP'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['COS'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['COS']['BI010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CISTERN_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['FUFI'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['FURL'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['GDBV'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['GDBV']['BI010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CISTERN_P']['HGT'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['LMC'] = ('Boolean',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['LUN'] = ('Boolean',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['LZN'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['OTH'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['PCF'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['PCF']['BI010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CISTERN_P']['PMPR'] = ('Boolean',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['UFI'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['VCM'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_P']['VCM2'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM2']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_P']['VCM3'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['VCM3']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['CISTERN_P']['VLM'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['WDST'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['WDST']['BI010']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['CISTERN_P']['WID'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI001_SDV'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI001_SRT'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI001_SRT']['BI010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI002_UFI'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI004_RCG'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI004_RCG']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_FNA'] = ('String',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_FNA2'] = ('String',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_GNT'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI005_GNT']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_GNT2'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI005_GNT2']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_NFN'] = ('String',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI005_NFN2'] = ('String',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI006_MEM'] = ('String',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI020_GE4'] = ('CodeList',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_ASE'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_CFR'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_CLO'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_CYN'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_FMR'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_FRR'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_HAR'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_HYP'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_HYP']['BI010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_MGN'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_PHW'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_SCC'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_SCC']['BI010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_SUL'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_TDS'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_TEP'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_TUR'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WAC'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WTNO'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WUR'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WUR2'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR2']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WUR3'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR3']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_WUR4'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_WUR4']['BI010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI024_YWQ'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI024_YWQ']['BI010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CISTERN_P']['ZI026_CTUC'] = ('Enumeration',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CISTERN_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CISTERN_P']['ZI026_CTUL'] = ('integer',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI026_CTUU'] = ('integer',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI031S_URI'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZI039S_UFI'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZSAX_RS0'] = ('CodeList',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZSAX_RX0'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZSAX_RX3'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZSAX_RX4'] = ('StructuredText',('BI010'))
    field_information['GGDM 3.0']['CISTERN_P']['ZVH'] = ('Real',('BI010'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ARA'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['BEN'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['F_CODE'] = ('CONSTRAINED_STRING',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['FUFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['FURL'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['GDBV'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['GDBV']['EC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CLEARED_WAY_C']['LZN'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['OTH'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['VTI'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['WID'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI001_SDV'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI001_SRT'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI001_SRT']['EC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI002_UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI004_RCG'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI004_RCG']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI005_FNA'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI005_GNT'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI005_GNT']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI005_NFN'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI006_MEM'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI020_GE4'] = ('CodeList',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI026_CTUC'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_C']['EnumeratedIndexValues']['ZI026_CTUC']['EC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI026_CTUL'] = ('integer',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI026_CTUU'] = ('integer',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI031S_URI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZI039S_UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZSAX_RS0'] = ('CodeList',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZSAX_RX0'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZSAX_RX3'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_C']['ZSAX_RX4'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ARA'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['BEN'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['FUFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['FURL'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['GDBV'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['GDBV']['EC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CLEARED_WAY_S']['LZN'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['OTH'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['VTI'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['WID'] = ('Real',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI001_SDV'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI001_SRT'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI001_SRT']['EC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI002_UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI004_RCG'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI004_RCG']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI005_FNA'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI005_GNT'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI005_GNT']['EC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI005_NFN'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI006_MEM'] = ('String',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI020_GE4'] = ('CodeList',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI026_CTUC'] = ('Enumeration',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CLEARED_WAY_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI026_CTUL'] = ('integer',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI026_CTUU'] = ('integer',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI031S_URI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZI039S_UFI'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZSAX_RS0'] = ('CodeList',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZSAX_RX0'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZSAX_RX3'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CLEARED_WAY_S']['ZSAX_RX4'] = ('StructuredText',('EC040'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RS6'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX0'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX1'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX2'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX3'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX4'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX5'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX6'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RX7'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RY1'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CODE_LIST_T']['RY2'] = ('Codelist',('TBCDL'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ARA'] = ('Real',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['BEN'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['CAA'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['CAA']['FA210']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['CAM'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['CAM'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['CAM']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['FUFI'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['FURL'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['GDBV'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['GDBV']['FA210']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['LZN'] = ('Real',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['OTH'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['SRL'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['SRL']['FA210']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['UFI'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['WID'] = ('Real',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI001_SDV'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI001_SRT'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['FA210']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI002_UFI'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI004_RCG'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI005_FNA'] = ('String',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI005_GNT'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI005_NFN'] = ('String',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI006_MEM'] = ('String',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI020_GE4'] = ('CodeList',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI026_CTUC'] = ('Enumeration',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA210']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI026_CTUL'] = ('integer',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI026_CTUU'] = ('integer',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI031S_URI'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZI039S_UFI'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZSAX_RS0'] = ('CodeList',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZSAX_RX0'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZSAX_RX3'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONSERVATION_AREA_S']['ZSAX_RX4'] = ('StructuredText',('FA210'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ARA'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['BEN'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['CCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['CCG'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['CSO'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['CSO'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['F_CODE'] = ('CONSTRAINED_STRING',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['FUFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['FURL'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['GDBV'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['GDBV']['FA012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['LZN'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['OTH'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['WID'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI001_SDV'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI001_SRT'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI001_SRT']['FA012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI002_UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI004_RCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI004_RCG']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI005_FNA'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI005_GNT'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI005_GNT']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI005_NFN'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI006_MEM'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI020_GE4'] = ('CodeList',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI026_CTUC'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['EnumeratedIndexValues']['ZI026_CTUC']['FA012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI026_CTUL'] = ('integer',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI026_CTUU'] = ('integer',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI031S_URI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZI039S_UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZSAX_RS0'] = ('CodeList',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZSAX_RX0'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZSAX_RX3'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_P']['ZSAX_RX4'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ARA'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['BEN'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['CCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['CCG'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['CSO'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['CSO'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['FUFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['FURL'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['GDBV'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['GDBV']['FA012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['LZN'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['OTH'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['WID'] = ('Real',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI001_SDV'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI001_SRT'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI001_SRT']['FA012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI002_UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI004_RCG'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI004_RCG']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI005_FNA'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI005_GNT'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI005_GNT']['FA012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI005_NFN'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI006_MEM'] = ('String',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI020_GE4'] = ('CodeList',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI026_CTUC'] = ('Enumeration',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI026_CTUL'] = ('integer',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI026_CTUU'] = ('integer',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI031S_URI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZI039S_UFI'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZSAX_RS0'] = ('CodeList',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZSAX_RX0'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZSAX_RX3'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTAMINATED_REGION_S']['ZSAX_RX4'] = ('StructuredText',('FA012'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ADR'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['AOO'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ARA'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['AWP'] = ('Boolean',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['BEN'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['CAA'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['CAA']['AQ060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['CNCP'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['COS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['COS']['AQ060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['FFN'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['FFN2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['FFN3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['FUFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['FURL'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['GDBV'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['GDBV']['AQ060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['HGT'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['LMC'] = ('Boolean',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['LZN'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['OTH'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['PCF'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['SSR'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['SSR2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['SSR3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['TRS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['VCM'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['VCM2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['VCM3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['VOI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['WID'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI001_SDV'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI001_SRT'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI002_UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI004_RCG'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI005_FNA'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI005_GNT'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI005_NFN'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI006_MEM'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI020_GE4'] = ('CodeList',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI026_CTUC'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI026_CTUL'] = ('integer',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI026_CTUU'] = ('integer',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI031S_URI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZI039S_UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZSAX_RS0'] = ('CodeList',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZSAX_RX0'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZSAX_RX3'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZSAX_RX4'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_P']['ZVH'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ADR'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['AOO'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ARA'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['AWP'] = ('Boolean',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['BEN'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['CAA'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['CAA']['AQ060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['CNCP'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['COS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['COS']['AQ060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['FFN'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['FFN2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['FFN3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,495,505,507,508,510,511,513,520,525,847,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['FUFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['FURL'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['GDBV'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['GDBV']['AQ060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['HGT'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['LMC'] = ('Boolean',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['LZN'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['OTH'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['PCF'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['SSR'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['SSR2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['SSR3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['TRS'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['VCM'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['VCM2'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['VCM3'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['VOI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['WID'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI001_SDV'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI001_SRT'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI002_UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI004_RCG'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI005_FNA'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI005_GNT'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI005_NFN'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI006_MEM'] = ('String',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI020_GE4'] = ('CodeList',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI026_CTUC'] = ('Enumeration',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI026_CTUL'] = ('integer',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI026_CTUU'] = ('integer',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI031S_URI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZI039S_UFI'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZSAX_RS0'] = ('CodeList',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZSAX_RX0'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZSAX_RX3'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZSAX_RX4'] = ('StructuredText',('AQ060'))
    field_information['GGDM 3.0']['CONTROL_TOWER_S']['ZVH'] = ('Real',('AQ060'))
    field_information['GGDM 3.0']['CONVEYOR_C']['AOO'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ARA'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['AWP'] = ('Boolean',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['BEN'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['CAA'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CAA']['AF020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['CNCP'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['COS'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['COS']['AF020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CONVEYOR_C']['CVT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['CVT2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT2'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT2']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['CVT3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT3'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['CVT3']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['F_CODE'] = ('CONSTRAINED_STRING',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['FUFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['FURL'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['GDBV'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['GDBV']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['HGT'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['LMC'] = ('Boolean',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['LZN'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['OTH'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['PCF'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['PCF']['AF020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CONVEYOR_C']['UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['VCM'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['VCM2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM2']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['VCM3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['VCM3']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['VOI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['WID'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI001_SDV'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI001_SRT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI001_SRT']['AF020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI002_UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI004_RCG'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI004_RCG']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI005_FNA'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI005_GNT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI005_GNT']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI005_NFN'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI006_MEM'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI020_GE4'] = ('CodeList',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI026_CTUC'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONVEYOR_C']['EnumeratedIndexValues']['ZI026_CTUC']['AF020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI026_CTUL'] = ('integer',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI026_CTUU'] = ('integer',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI031S_URI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZI039S_UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZSAX_RS0'] = ('CodeList',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZSAX_RX0'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZSAX_RX3'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZSAX_RX4'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_C']['ZVH'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['AOO'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ARA'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['AWP'] = ('Boolean',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['BEN'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['CAA'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CAA']['AF020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['CNCP'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['COS'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['COS']['AF020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CONVEYOR_P']['CVT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['CVT2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT2'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT2']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['CVT3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT3'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['CVT3']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['FUFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['FURL'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['GDBV'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['GDBV']['AF020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['HGT'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['LMC'] = ('Boolean',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['LZN'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['OTH'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['PCF'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['PCF']['AF020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CONVEYOR_P']['UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['VCM'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['VCM2'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM2']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['VCM3'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['VCM3']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['VOI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['WID'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI001_SDV'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI001_SRT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI001_SRT']['AF020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI002_UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI004_RCG'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI004_RCG']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI005_FNA'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI005_GNT'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI005_GNT']['AF020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI005_NFN'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI006_MEM'] = ('String',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI020_GE4'] = ('CodeList',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI026_CTUC'] = ('Enumeration',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CONVEYOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI026_CTUL'] = ('integer',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI026_CTUU'] = ('integer',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI031S_URI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZI039S_UFI'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZSAX_RS0'] = ('CodeList',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZSAX_RX0'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZSAX_RX3'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZSAX_RX4'] = ('StructuredText',('AF020'))
    field_information['GGDM 3.0']['CONVEYOR_P']['ZVH'] = ('Real',('AF020'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ADR'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['AOO'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ARA'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['BEN'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['CAA'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['CAA']['AD055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['CNCP'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['COS'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['COS']['AD055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['FFN'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['FFN2'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['FFN3'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['FUFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['FURL'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['GDBV'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AD055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['HGT'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['LMC'] = ('Boolean',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['LZN'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['OTH'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['PCF'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['WID'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AD055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI005_FNA'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI005_NFN'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI006_MEM'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI026_CTUL'] = ('integer',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI026_CTUU'] = ('integer',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_P']['ZVH'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ADR'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['AOO'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ARA'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['BEN'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['CAA'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['CAA']['AD055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['CNCP'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['COS'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['COS']['AD055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['FFN'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['FFN2'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['FFN3'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['FUFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['FURL'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['GDBV'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AD055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['HGT'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['LMC'] = ('Boolean',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['LZN'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['OTH'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['PCF'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['WID'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AD055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI005_FNA'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AD055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI005_NFN'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI006_MEM'] = ('String',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI026_CTUL'] = ('integer',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI026_CTUU'] = ('integer',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AD055'))
    field_information['GGDM 3.0']['COOLING_FACILITY_S']['ZVH'] = ('Real',('AD055'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['AOO'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ARA'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['AWP'] = ('Boolean',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['BEN'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['CAA'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['CAA']['AF030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['CNCP'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['COS'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['COS']['AF030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['FUFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['FURL'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['GDBV'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['GDBV']['AF030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['HGT'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['LMC'] = ('Boolean',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['LZN'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['OTH'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['PCF'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['VCM'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['VCM2'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['VCM3'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['VOI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['WID'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI001_SDV'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI001_SRT'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['AF030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI002_UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI004_RCG'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI005_FNA'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI005_GNT'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI005_NFN'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI006_MEM'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI020_GE4'] = ('CodeList',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI026_CTUC'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI026_CTUL'] = ('integer',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI026_CTUU'] = ('integer',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI031S_URI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZI039S_UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZSAX_RS0'] = ('CodeList',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZSAX_RX0'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZSAX_RX3'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZSAX_RX4'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_P']['ZVH'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['AOO'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ARA'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['AWP'] = ('Boolean',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['BEN'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['CAA'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['CAA']['AF030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['CNCP'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['COS'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['COS']['AF030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['FUFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['FURL'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['GDBV'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['GDBV']['AF030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['HGT'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['LMC'] = ('Boolean',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['LZN'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['OTH'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['PCF'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['VCM'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['VCM2'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['VCM3'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['VOI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['WID'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI001_SDV'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI001_SRT'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT']['AF030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI002_UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI004_RCG'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI005_FNA'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI005_GNT'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT']['AF030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI005_NFN'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI006_MEM'] = ('String',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI020_GE4'] = ('CodeList',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI026_CTUC'] = ('Enumeration',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['COOLING_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AF030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI026_CTUL'] = ('integer',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI026_CTUU'] = ('integer',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI031S_URI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZI039S_UFI'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZSAX_RS0'] = ('CodeList',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZSAX_RX0'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZSAX_RX3'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZSAX_RX4'] = ('StructuredText',('AF030'))
    field_information['GGDM 3.0']['COOLING_TOWER_S']['ZVH'] = ('Real',('AF030'))
    field_information['GGDM 3.0']['COURTYARD_S']['ARA'] = ('Real',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['BEN'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['FUFI'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['FURL'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['GDBV'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['GDBV']['AL175']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['COURTYARD_S']['HGT'] = ('Real',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['LZN'] = ('Real',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['OTH'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['PCF'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['PCF']['AL175']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['COURTYARD_S']['UFI'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['WID'] = ('Real',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI001_SDV'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI001_SRT'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI001_SRT']['AL175']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI002_UFI'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI004_RCG'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI004_RCG']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI005_FNA'] = ('String',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI005_GNT'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI005_GNT']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI005_NFN'] = ('String',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI006_MEM'] = ('String',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI020_GE4'] = ('CodeList',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI026_CTUC'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL175']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI026_CTUL'] = ('integer',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI026_CTUU'] = ('integer',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI031S_URI'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZI037_REL'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI037_REL']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI037_RFA'] = ('Enumeration',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['COURTYARD_S']['EnumeratedIndexValues']['ZI037_RFA']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['COURTYARD_S']['ZI039S_UFI'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZSAX_RS0'] = ('CodeList',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZSAX_RX0'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZSAX_RX3'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['COURTYARD_S']['ZSAX_RX4'] = ('StructuredText',('AL175'))
    field_information['GGDM 3.0']['CRANE_P']['AOO'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ARA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['AWP'] = ('Boolean',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['BEN'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['CAA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CAA']['AF040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CRANE_P']['CNCP'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['COS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['COS']['AF040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CRANE_P']['CRA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CRA'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,8,9,10,99,999)
    field_information['GGDM 3.0']['CRANE_P']['CRM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CRANE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['FUFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['FURL'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['GDBV'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['GDBV']['AF040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRANE_P']['HGT'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['LCA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['LMC'] = ('Boolean',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['LZN'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['OTH'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['PCF'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CRANE_P']['SRL'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CRANE_P']['TRS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_P']['TRS2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_P']['TRS3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_P']['UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['VCM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_P']['VCM2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_P']['VCM3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_P']['VOI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['WID'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI001_SDV'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI001_SRT'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI001_SRT']['AF040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRANE_P']['ZI002_UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI004_RCG'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI004_RCG']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRANE_P']['ZI005_FNA'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI005_GNT'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI005_GNT']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRANE_P']['ZI005_NFN'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI006_MEM'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI020_GE4'] = ('CodeList',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI026_CTUC'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRANE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRANE_P']['ZI026_CTUL'] = ('integer',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI026_CTUU'] = ('integer',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI031S_URI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZI039S_UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZSAX_RS0'] = ('CodeList',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZSAX_RX0'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZSAX_RX3'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZSAX_RX4'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_P']['ZVH'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['AOO'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ARA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['AWP'] = ('Boolean',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['BEN'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['CAA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CAA']['AF040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['CRANE_S']['CNCP'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['COS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['COS']['AF040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CRANE_S']['CRA'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CRA'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,8,9,10,99,999)
    field_information['GGDM 3.0']['CRANE_S']['CRM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CRANE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['FUFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['FURL'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['GDBV'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['GDBV']['AF040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRANE_S']['HGT'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['LCA'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['LMC'] = ('Boolean',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['LZN'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['OTH'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['PCF'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CRANE_S']['SRL'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['CRANE_S']['TRS'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_S']['TRS2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_S']['TRS3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['GGDM 3.0']['CRANE_S']['UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['VCM'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_S']['VCM2'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_S']['VCM3'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['CRANE_S']['VOI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['WID'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI001_SDV'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI001_SRT'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI001_SRT']['AF040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRANE_S']['ZI002_UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI004_RCG'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI004_RCG']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRANE_S']['ZI005_FNA'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI005_GNT'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI005_GNT']['AF040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRANE_S']['ZI005_NFN'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI006_MEM'] = ('String',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI020_GE4'] = ('CodeList',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI026_CTUC'] = ('Enumeration',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRANE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AF040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRANE_S']['ZI026_CTUL'] = ('integer',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI026_CTUU'] = ('integer',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI031S_URI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZI039S_UFI'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZSAX_RS0'] = ('CodeList',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZSAX_RX0'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZSAX_RX3'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZSAX_RX4'] = ('StructuredText',('AF040'))
    field_information['GGDM 3.0']['CRANE_S']['ZVH'] = ('Real',('AF040'))
    field_information['GGDM 3.0']['CRATER_P']['ARA'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['BEN'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['DZP'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['FUFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['FURL'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['GDBV'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['GDBV']['DB185']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRATER_P']['LMC'] = ('Boolean',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['LZN'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['OTH'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['WID'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI001_SDV'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI001_SRT'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI001_SRT']['DB185']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRATER_P']['ZI002_UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI004_RCG'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI004_RCG']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRATER_P']['ZI005_FNA'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI005_GNT'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI005_GNT']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRATER_P']['ZI005_NFN'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI006_MEM'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI020_GE4'] = ('CodeList',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI026_CTUC'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRATER_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB185']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRATER_P']['ZI026_CTUL'] = ('integer',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI026_CTUU'] = ('integer',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI031S_URI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZI039S_UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZSAX_RS0'] = ('CodeList',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZSAX_RX0'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZSAX_RX3'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_P']['ZSAX_RX4'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ARA'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['BEN'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['DZP'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['FUFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['FURL'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['GDBV'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['GDBV']['DB185']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRATER_S']['LMC'] = ('Boolean',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['LZN'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['OTH'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['WID'] = ('Real',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI001_SDV'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI001_SRT'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI001_SRT']['DB185']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRATER_S']['ZI002_UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI004_RCG'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI004_RCG']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRATER_S']['ZI005_FNA'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI005_GNT'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI005_GNT']['DB185']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRATER_S']['ZI005_NFN'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI006_MEM'] = ('String',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI020_GE4'] = ('CodeList',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI026_CTUC'] = ('Enumeration',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRATER_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB185']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRATER_S']['ZI026_CTUL'] = ('integer',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI026_CTUU'] = ('integer',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI031S_URI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZI039S_UFI'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZSAX_RS0'] = ('CodeList',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZSAX_RX0'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZSAX_RX3'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CRATER_S']['ZSAX_RX4'] = ('StructuredText',('DB185'))
    field_information['GGDM 3.0']['CREVASSE_C']['ARA'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['BEN'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['DZP'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['FUFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['FURL'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['GDBV'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['GDBV']['BJ031']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CREVASSE_C']['LZN'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['OTH'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['PFD'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['SNDC'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['SNDC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVASSE_C']['SNDL'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['SNDU'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['WID'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI001_SDV'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI001_SRT'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI001_SRT']['BJ031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CREVASSE_C']['ZI002_UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI004_RCG'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI004_RCG']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CREVASSE_C']['ZI006_MEM'] = ('String',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI020_GE4'] = ('CodeList',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI026_CTUC'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CREVASSE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVASSE_C']['ZI026_CTUL'] = ('integer',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI026_CTUU'] = ('integer',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI031S_URI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZI039S_UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZSAX_RS0'] = ('CodeList',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZSAX_RX0'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZSAX_RX3'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZSAX_RX4'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_C']['ZVH'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ARA'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['BEN'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['DZP'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['FUFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['FURL'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['GDBV'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['GDBV']['BJ031']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CREVASSE_S']['LZN'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['OTH'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['PFD'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['SNDC'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['SNDC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVASSE_S']['SNDL'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['SNDU'] = ('real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['WID'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI001_SDV'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI001_SRT'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ031']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CREVASSE_S']['ZI002_UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI004_RCG'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CREVASSE_S']['ZI006_MEM'] = ('String',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI020_GE4'] = ('CodeList',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI026_CTUC'] = ('Enumeration',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CREVASSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ031']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVASSE_S']['ZI026_CTUL'] = ('integer',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI026_CTUU'] = ('integer',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI031S_URI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZI039S_UFI'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZSAX_RS0'] = ('CodeList',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZSAX_RX0'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZSAX_RX3'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZSAX_RX4'] = ('StructuredText',('BJ031'))
    field_information['GGDM 3.0']['CREVASSE_S']['ZVH'] = ('Real',('BJ031'))
    field_information['GGDM 3.0']['CREVICE_C']['ARA'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['BEN'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['DZP'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['FUFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['FURL'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['GDBV'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['GDBV']['DB061']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CREVICE_C']['LZN'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['MCC'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_C']['MCC2'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_C']['MCC3'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_C']['OTH'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['PFD'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['WID'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI001_SDV'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI001_SRT'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI001_SRT']['DB061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CREVICE_C']['ZI002_UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI004_RCG'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI004_RCG']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CREVICE_C']['ZI005_FNA'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI005_GNT'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI005_GNT']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CREVICE_C']['ZI005_NFN'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI006_MEM'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI020_GE4'] = ('CodeList',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI026_CTUC'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CREVICE_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVICE_C']['ZI026_CTUL'] = ('integer',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI026_CTUU'] = ('integer',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI031S_URI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZI039S_UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZSAX_RS0'] = ('CodeList',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZSAX_RX0'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZSAX_RX3'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZSAX_RX4'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_C']['ZVH'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ARA'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['BEN'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['DZP'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['FUFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['FURL'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['GDBV'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['GDBV']['DB061']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CREVICE_S']['LZN'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['MCC'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_S']['MCC2'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_S']['MCC3'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['CREVICE_S']['OTH'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['PFD'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['WID'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI001_SDV'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI001_SRT'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI001_SRT']['DB061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CREVICE_S']['ZI002_UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI004_RCG'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI004_RCG']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CREVICE_S']['ZI005_FNA'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI005_GNT'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI005_GNT']['DB061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CREVICE_S']['ZI005_NFN'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI006_MEM'] = ('String',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI020_GE4'] = ('CodeList',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI026_CTUC'] = ('Enumeration',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CREVICE_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CREVICE_S']['ZI026_CTUL'] = ('integer',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI026_CTUU'] = ('integer',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI031S_URI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZI039S_UFI'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZSAX_RS0'] = ('CodeList',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZSAX_RX0'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZSAX_RX3'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZSAX_RX4'] = ('StructuredText',('DB061'))
    field_information['GGDM 3.0']['CREVICE_S']['ZVH'] = ('Real',('DB061'))
    field_information['GGDM 3.0']['CRIB_P']['BEN'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['CNCP'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['COS'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['COS']['BD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CRIB_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['FUFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['FURL'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['GDBV'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['GDBV']['BD020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRIB_P']['OTH'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['PCF'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['PCF']['BD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CRIB_P']['UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZHBH_TEC'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_P']['ZHBH_TEC2'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC2']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_P']['ZHBH_TEC3'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZHBH_TEC3']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_P']['ZI001_SDV'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI001_SRT'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI001_SRT']['BD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRIB_P']['ZI002_UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI004_RCG'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI004_RCG']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRIB_P']['ZI005_FNA'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI005_GNT'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI005_GNT']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRIB_P']['ZI005_NFN'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI006_MEM'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI020_GE4'] = ('CodeList',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI025_HDP'] = ('Real',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI025_WLE'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI025_WLE']['BD020']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['CRIB_P']['ZI026_CTUC'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRIB_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRIB_P']['ZI026_CTUL'] = ('integer',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI026_CTUU'] = ('integer',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI031S_URI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZI039S_UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZSAX_RS0'] = ('CodeList',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZSAX_RX0'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZSAX_RX3'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_P']['ZSAX_RX4'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['BEN'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['CNCP'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['COS'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['COS']['BD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CRIB_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['FUFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['FURL'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['GDBV'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['GDBV']['BD020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CRIB_S']['OTH'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['PCF'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['PCF']['BD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CRIB_S']['UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZHBH_TEC'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_S']['ZHBH_TEC2'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC2']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_S']['ZHBH_TEC3'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZHBH_TEC3']['BD020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['CRIB_S']['ZI001_SDV'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI001_SRT'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI001_SRT']['BD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CRIB_S']['ZI002_UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI004_RCG'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI004_RCG']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CRIB_S']['ZI005_FNA'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI005_GNT'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI005_GNT']['BD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CRIB_S']['ZI005_NFN'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI006_MEM'] = ('String',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI020_GE4'] = ('CodeList',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI025_HDP'] = ('Real',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI025_WLE'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI025_WLE']['BD020']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['CRIB_S']['ZI026_CTUC'] = ('Enumeration',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CRIB_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CRIB_S']['ZI026_CTUL'] = ('integer',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI026_CTUU'] = ('integer',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI031S_URI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZI039S_UFI'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZSAX_RS0'] = ('CodeList',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZSAX_RX0'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZSAX_RX3'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CRIB_S']['ZSAX_RX4'] = ('StructuredText',('BD020'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ARA'] = ('Real',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['BEN'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['FUFI'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['FURL'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['GDBV'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['GDBV']['EA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['LMC'] = ('Boolean',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['LZN'] = ('Real',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['OTH'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['UFI'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['VTI'] = ('Real',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['WID'] = ('Real',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI001_SDV'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI001_SRT'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI001_SRT']['EA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI002_UFI'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI004_RCG'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI004_RCG']['EA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI005_FNA'] = ('String',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI005_GNT'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI005_GNT']['EA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI005_NFN'] = ('String',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI006_MEM'] = ('String',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_CSP'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_CSP2'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP2']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_CSP3'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_CSP3']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FFP'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FFP2'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP2']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FFP3'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FFP3']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FMM'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FMM2'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM2']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_FMM3'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_FMM3']['EA010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_IRG'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI013_IRG']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI013_PIG'] = ('Boolean',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI020_GE4'] = ('CodeList',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI026_CTUC'] = ('Enumeration',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CROP_LAND_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI026_CTUL'] = ('integer',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI026_CTUU'] = ('integer',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI031S_URI'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZI039S_UFI'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZSAX_RS0'] = ('CodeList',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZSAX_RX0'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZSAX_RX3'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROP_LAND_S']['ZSAX_RX4'] = ('StructuredText',('EA010'))
    field_information['GGDM 3.0']['CROSSING_P']['ARA'] = ('Real',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['BEN'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['CSC'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CROSSING_P']['CSC2'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC2']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CROSSING_P']['CSC3'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['CSC3']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CROSSING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['FUFI'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['FURL'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['GDBV'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['GDBV']['AQ062']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CROSSING_P']['LZN'] = ('Real',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['OTH'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['TRS'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['CROSSING_P']['TRS2'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS2']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['CROSSING_P']['TRS3'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['TRS3']['AQ062']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['CROSSING_P']['UFI'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['WID'] = ('Real',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI001_SDV'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI001_SRT'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ062']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CROSSING_P']['ZI002_UFI'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI004_RCG'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ062']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CROSSING_P']['ZI005_FNA'] = ('String',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI005_GNT'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ062']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CROSSING_P']['ZI005_NFN'] = ('String',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI006_MEM'] = ('String',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI020_GE4'] = ('CodeList',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI026_CTUC'] = ('Enumeration',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ062']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CROSSING_P']['ZI026_CTUL'] = ('integer',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI026_CTUU'] = ('integer',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI031S_URI'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZI039S_UFI'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZSAX_RS0'] = ('CodeList',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZSAX_RX0'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZSAX_RX3'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CROSSING_P']['ZSAX_RX4'] = ('StructuredText',('AQ062'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ARA'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['BEN'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['CUL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['CUL'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['FUFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['FURL'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['GDBV'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['GDBV']['ZD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['LZN'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['OTH'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['WID'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI001_SDV'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI001_SRT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT']['ZD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI002_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI004_RCG'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI005_GNT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI020_GE4'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI026_CTUC'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI026_CTUL'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI026_CTUU'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI031S_URI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZI039S_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZSAX_RX0'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_P']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ARA'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['BEN'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['CUL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['CUL'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['FUFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['FURL'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['GDBV'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['GDBV']['ZD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['LZN'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['OTH'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['WID'] = ('Real',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI001_SDV'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI001_SRT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT']['ZD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI002_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI004_RCG'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI005_GNT'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI020_GE4'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI026_CTUC'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI026_CTUL'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI026_CTUU'] = ('integer',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI031S_URI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZI039S_UFI'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZSAX_RX0'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULTURAL_CONTEXT_LOCATION_S']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['GGDM 3.0']['CULVERT_C']['AOO'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ARA'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['BEN'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['CNCP'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['COS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['COS']['AQ065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CULVERT_C']['CTC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['CTC'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CULVERT_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['FUFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['FURL'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['GDBV'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['GDBV']['AQ065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CULVERT_C']['LZN'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['MCC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_C']['MCC2'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_C']['MCC3'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_C']['OTH'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['PCF'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CULVERT_C']['TCS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['TCS'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CULVERT_C']['UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['WID'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI001_SDV'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI001_SRT'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CULVERT_C']['ZI002_UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI004_RCG'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CULVERT_C']['ZI006_MEM'] = ('String',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI020_GE4'] = ('CodeList',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI026_CTUC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CULVERT_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CULVERT_C']['ZI026_CTUL'] = ('integer',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI026_CTUU'] = ('integer',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI031S_URI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZI039S_UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZSAX_RS0'] = ('CodeList',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZSAX_RX0'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZSAX_RX3'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_C']['ZSAX_RX4'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['AOO'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ARA'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['BEN'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['CNCP'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['COS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['COS']['AQ065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['CULVERT_P']['CTC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['CTC'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CULVERT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['FUFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['FURL'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['GDBV'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['GDBV']['AQ065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CULVERT_P']['LZN'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['MCC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_P']['MCC2'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_P']['MCC3'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['GGDM 3.0']['CULVERT_P']['OTH'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['PCF'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CULVERT_P']['TCS'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['TCS'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['CULVERT_P']['UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['WID'] = ('Real',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI001_SDV'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI001_SRT'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CULVERT_P']['ZI002_UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI004_RCG'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CULVERT_P']['ZI006_MEM'] = ('String',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI020_GE4'] = ('CodeList',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI026_CTUC'] = ('Enumeration',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CULVERT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CULVERT_P']['ZI026_CTUL'] = ('integer',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI026_CTUU'] = ('integer',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI031S_URI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZI039S_UFI'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZSAX_RS0'] = ('CodeList',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZSAX_RX0'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZSAX_RX3'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CULVERT_P']['ZSAX_RX4'] = ('StructuredText',('AQ065'))
    field_information['GGDM 3.0']['CUT_C']['ARA'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['BEN'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['CET'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['CET'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['CET']['DB070']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['CUT_C']['DZP'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['FUFI'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['FURL'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['GDBV'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['GDBV']['DB070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CUT_C']['HDP'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['HGT'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['LZN'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['OTH'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['PCF'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['PCF']['DB070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['CUT_C']['PFD'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['PFH'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['SGCC'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['SGCC']['DB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CUT_C']['SGCL'] = ('real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['SGCU'] = ('real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['TRS'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_C']['TRS2'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS2']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_C']['TRS3'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['TRS3']['DB070']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_C']['UFI'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['WID'] = ('Real',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI001_SDV'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI001_SRT'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI001_SRT']['DB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CUT_C']['ZI002_UFI'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI004_RCG'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI004_RCG']['DB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CUT_C']['ZI005_FNA'] = ('String',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI005_GNT'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI005_GNT']['DB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['CUT_C']['ZI005_NFN'] = ('String',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI006_MEM'] = ('String',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI020_GE4'] = ('CodeList',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI026_CTUC'] = ('Enumeration',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CUT_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CUT_C']['ZI026_CTUL'] = ('integer',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI026_CTUU'] = ('integer',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI031S_URI'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZI039S_UFI'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZSAX_RS0'] = ('CodeList',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZSAX_RX0'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZSAX_RX3'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_C']['ZSAX_RX4'] = ('StructuredText',('DB070'))
    field_information['GGDM 3.0']['CUT_LINE_C']['BEN'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['FUFI'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['FURL'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['GDBV'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['GDBV']['DB071']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['LZN'] = ('Real',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['OTH'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['PFH'] = ('Real',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['SGCC'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['SGCC']['DB071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CUT_LINE_C']['SGCL'] = ('real',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['SGCU'] = ('real',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['TRS'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['TRS2'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS2']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['TRS3'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['TRS3']['DB071']  = (-999999,2,5,12,13,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['UFI'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI001_SDV'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI001_SRT'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI001_SRT']['DB071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI002_UFI'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI004_RCG'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI004_RCG']['DB071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI006_MEM'] = ('String',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI020_GE4'] = ('CodeList',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI026_CTUC'] = ('Enumeration',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['CUT_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI026_CTUL'] = ('integer',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI026_CTUU'] = ('integer',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI031S_URI'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZI039S_UFI'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZSAX_RS0'] = ('CodeList',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZSAX_RX0'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZSAX_RX3'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['CUT_LINE_C']['ZSAX_RX4'] = ('StructuredText',('DB071'))
    field_information['GGDM 3.0']['DAM_C']['AOO'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ARA'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['AWP'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['BEN'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['CAA'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DAM_C']['CNCP'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['COS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DAM_C']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['DAM_C']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_C']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_C']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_C']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['DAM_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['FUFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['FURL'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['GDBV'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DAM_C']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['HGT'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['LMC'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['MCC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_C']['MCC2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_C']['MCC3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_C']['OTH'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['PCF'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DAM_C']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_C']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_C']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_C']['UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['VOI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI001_SDV'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI001_SRT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DAM_C']['ZI002_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI004_RCG'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DAM_C']['ZI005_FNA'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI005_FNA2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI005_FNA3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI005_GNT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_C']['ZI005_GNT2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_C']['ZI005_GNT3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_C']['ZI005_NFN'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI005_NFN2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI005_NFN3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI006_MEM'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI020_GE4'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI024_WPAC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DAM_C']['ZI026_CTUC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DAM_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DAM_C']['ZI026_CTUL'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI026_CTUU'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI031S_URI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZI039S_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZSAX_RS0'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZSAX_RX0'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZSAX_RX3'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZSAX_RX4'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_C']['ZVH'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['AOO'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ARA'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['AWP'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['BEN'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['CAA'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DAM_P']['CNCP'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['COS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DAM_P']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['DAM_P']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_P']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_P']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_P']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['DAM_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['FUFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['FURL'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['GDBV'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DAM_P']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['HGT'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['LMC'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['MCC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_P']['MCC2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_P']['MCC3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_P']['OTH'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['PCF'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DAM_P']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_P']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_P']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_P']['UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['VOI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI001_SDV'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI001_SRT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DAM_P']['ZI002_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI004_RCG'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DAM_P']['ZI005_FNA'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI005_FNA2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI005_FNA3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI005_GNT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_P']['ZI005_GNT2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_P']['ZI005_GNT3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_P']['ZI005_NFN'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI005_NFN2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI005_NFN3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI006_MEM'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI020_GE4'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI024_WPAC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DAM_P']['ZI026_CTUC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DAM_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DAM_P']['ZI026_CTUL'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI026_CTUU'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI031S_URI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZI039S_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZSAX_RS0'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZSAX_RX0'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZSAX_RX3'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZSAX_RX4'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_P']['ZVH'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['AOO'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ARA'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['AWP'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['BEN'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['CAA'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DAM_S']['CNCP'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['COS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['COS']['BI020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DAM_S']['DFT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFT'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFT']['BI020']  = (-999999,1,2)
    field_information['GGDM 3.0']['DAM_S']['DFU'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_S']['DFU2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU2'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_S']['DFU3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU3'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DFU3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['DAM_S']['DSD'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DSD'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['DSD']['BI020']  = (-999999,101,102,103,104,105,106,107,999)
    field_information['GGDM 3.0']['DAM_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['FUFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['FURL'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['GDBV'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['GDBV']['BI020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DAM_S']['HGS'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['HGT'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['LDC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['LMC'] = ('Boolean',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['MCC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_S']['MCC2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_S']['MCC3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,8,9,21,62,64,86,104,107,108,117,150,160,999)
    field_information['GGDM 3.0']['DAM_S']['OTH'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['PCF'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DAM_S']['TRS'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_S']['TRS2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_S']['TRS3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['GGDM 3.0']['DAM_S']['UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['VOI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['WOC'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI001_SDV'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI001_SRT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI001_SRT']['BI020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DAM_S']['ZI002_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI004_RCG'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI004_RCG']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DAM_S']['ZI005_FNA'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI005_FNA2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI005_FNA3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI005_GNT'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_S']['ZI005_GNT2'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT2']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_S']['ZI005_GNT3'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI005_GNT3']['BI020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DAM_S']['ZI005_NFN'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI005_NFN2'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI005_NFN3'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI006_MEM'] = ('String',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI020_GE4'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI024_WPAC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI024_WPAC']['BI020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DAM_S']['ZI026_CTUC'] = ('Enumeration',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DAM_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DAM_S']['ZI026_CTUL'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI026_CTUU'] = ('integer',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI031S_URI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZI039S_UFI'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZSAX_RS0'] = ('CodeList',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZSAX_RX0'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZSAX_RX3'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZSAX_RX4'] = ('StructuredText',('BI020'))
    field_information['GGDM 3.0']['DAM_S']['ZVH'] = ('Real',('BI020'))
    field_information['GGDM 3.0']['DATASET_S']['AHA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['AVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['CID'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['CPS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['CPS'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['CPS']['ZI031']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['DATASET_S']['DQS'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EQS'] = ('Integer',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ETS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['ETS'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['ETS']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,43,44,45,46,47,48,49,50,51,52,53,56,57,58,59,60,61,998,999)
    field_information['GGDM 3.0']['DATASET_S']['ETZ'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['FURL'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['HVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['HZD'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['HZD'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['HZD']['ZI031']  = (-999999,2,3,4,5,6,7,8,9,10,12,13,14,15,16,17,19,20,21,22,23,24,25,26,27,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,118,119,120,121,123,125,126,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,158,159,161,162,163,164,165,166,167,169,170,171,172,174,175,176,177,178,179,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,204,205,206,207,209,210,211,212,213,215,216,217,218,219,220,221,222,223,224,225,226,227,228,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269,270,271,272,273,274,276,277,278,279,280,281,282,283,285,286,287,288,289,290,292,293,294,295,296,297,298,299,300,301,302,305,306,307,308,309,310,311,312,313,314,315,998,999)
    field_information['GGDM 3.0']['DATASET_S']['MDE'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['MEM'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['OTH'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['RCG'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['RCG']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DATASET_S']['RTL'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['SCVN'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['URI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['VDT'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['VDT'] = {}
    field_information['GGDM 3.0']['DATASET_S']['EnumeratedIndexValues']['VDT']['ZI031']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['DATASET_S']['ZI002_UFI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZI020_GE4'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZI020_GE42'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZI020_GE43'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZI020_GE44'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZSAX_RS0'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZSAX_RX0'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZSAX_RX3'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_S']['ZSAX_RX4'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['AHA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['AVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['CID'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['CPS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['CPS'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['CPS']['ZI031']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['DATASET_T']['DQS'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EQS'] = ('Integer',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ETS'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['ETS'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['ETS']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,43,44,45,46,47,48,49,50,51,52,53,56,57,58,59,60,61,998,999)
    field_information['GGDM 3.0']['DATASET_T']['ETZ'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['FURL'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['HVA'] = ('Real',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['HZD'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['HZD'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['HZD']['ZI031']  = (-999999,2,3,4,5,6,7,8,9,10,12,13,14,15,16,17,19,20,21,22,23,24,25,26,27,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,118,119,120,121,123,125,126,128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,149,150,151,152,153,154,155,156,157,158,159,161,162,163,164,165,166,167,169,170,171,172,174,175,176,177,178,179,181,182,183,184,185,186,187,188,189,190,191,192,193,194,195,196,197,198,199,200,201,202,204,205,206,207,209,210,211,212,213,215,216,217,218,219,220,221,222,223,224,225,226,227,228,230,231,232,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250,251,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269,270,271,272,273,274,276,277,278,279,280,281,282,283,285,286,287,288,289,290,292,293,294,295,296,297,298,299,300,301,302,305,306,307,308,309,310,311,312,313,314,315,998,999)
    field_information['GGDM 3.0']['DATASET_T']['MDE'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['MEM'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['OTH'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['RCG'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['RCG']['ZI031']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DATASET_T']['RTL'] = ('String',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['SCVN'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['URI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['VDT'] = ('Enumeration',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['VDT'] = {}
    field_information['GGDM 3.0']['DATASET_T']['EnumeratedIndexValues']['VDT']['ZI031']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['DATASET_T']['ZI002_UFI'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE4'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE42'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE43'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZI020_GE44'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RS0'] = ('CodeList',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX0'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX3'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DATASET_T']['ZSAX_RX4'] = ('StructuredText',('ZI031'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ARA'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['BEN'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['CNCP'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['COS'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['COS']['GB050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['F_CODE'] = ('CONSTRAINED_STRING',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['FUFI'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['FURL'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['GDBV'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['GDBV']['GB050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['HGT'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['LNU'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['LZN'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['MCC'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['MCC2'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC2']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['MCC3'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['MCC3']['GB050']  = (-999999,5,8,9,21,62,64,83,86,88,104,117,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['OTH'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['PCF'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['PCF']['GB050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['UFI'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['WID'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI001_SDV'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI001_SRT'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI001_SRT']['GB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI002_UFI'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI004_RCG'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI004_RCG']['GB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI005_FNA'] = ('String',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI005_GNT'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI005_GNT']['GB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI005_NFN'] = ('String',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI006_MEM'] = ('String',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI020_GE4'] = ('CodeList',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI026_CTUC'] = ('Enumeration',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['EnumeratedIndexValues']['ZI026_CTUC']['GB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI026_CTUL'] = ('integer',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI026_CTUU'] = ('integer',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI031S_URI'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZI039S_UFI'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZSAX_RS0'] = ('CodeList',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZSAX_RX0'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZSAX_RX3'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZSAX_RX4'] = ('StructuredText',('GB050'))
    field_information['GGDM 3.0']['DEFENSIVE_REVETMENT_C']['ZVH'] = ('Real',('GB050'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ARA'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['BEN'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['DZP'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['FUFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['FURL'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['GDBV'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['GDBV']['DB080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEPRESSION_P']['LZN'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['OTH'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['PFD'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['SGCC'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['SGCC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPRESSION_P']['SGCL'] = ('real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['SGCU'] = ('real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['WID'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI001_SDV'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI001_SRT'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI001_SRT']['DB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI002_UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI004_RCG'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI004_RCG']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI005_FNA'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI005_GNT'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI005_GNT']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI005_NFN'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI006_MEM'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI020_GE4'] = ('CodeList',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI026_CTUC'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEPRESSION_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI026_CTUL'] = ('integer',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI026_CTUU'] = ('integer',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI031S_URI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZI039S_UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZSAX_RS0'] = ('CodeList',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZSAX_RX0'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZSAX_RX3'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_P']['ZSAX_RX4'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ARA'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['BEN'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['DZP'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['FUFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['FURL'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['GDBV'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['GDBV']['DB080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEPRESSION_S']['LZN'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['OTH'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['PFD'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['SGCC'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['SGCC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPRESSION_S']['SGCL'] = ('real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['SGCU'] = ('real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['WID'] = ('Real',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI001_SDV'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI001_SRT'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI001_SRT']['DB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI002_UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI004_RCG'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI004_RCG']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI005_FNA'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI005_GNT'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI005_GNT']['DB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI005_NFN'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI006_MEM'] = ('String',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI020_GE4'] = ('CodeList',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI026_CTUC'] = ('Enumeration',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEPRESSION_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI026_CTUL'] = ('integer',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI026_CTUU'] = ('integer',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI031S_URI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZI039S_UFI'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZSAX_RS0'] = ('CodeList',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZSAX_RX0'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZSAX_RX3'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPRESSION_S']['ZSAX_RX4'] = ('StructuredText',('DB080'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['BEN'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['FUFI'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['FURL'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['GDBV'] = ('Enumeration',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['GDBV']['BE019']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEPTH_AREA_S']['OTH'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['UFI'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI001_SDV'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI001_SRT'] = ('Enumeration',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['BE019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI002_UFI'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI004_RCG'] = ('Enumeration',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['BE019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI006_MEM'] = ('String',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI020_GE4'] = ('CodeList',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI026_CTUC'] = ('Enumeration',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEPTH_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['BE019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI026_CTUL'] = ('integer',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI026_CTUU'] = ('integer',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI031S_URI'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZI039S_UFI'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZSAX_RS0'] = ('CodeList',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZSAX_RX0'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZSAX_RX3'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_AREA_S']['ZSAX_RX4'] = ('StructuredText',('BE019'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['BEN'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['CRV'] = ('Real',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['F_CODE'] = ('CONSTRAINED_STRING',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['FUFI'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['FURL'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['GDBV'] = ('Enumeration',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['GDBV']['BE015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['OTH'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['UFI'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI001_SDV'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI001_SRT'] = ('Enumeration',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI001_SRT']['BE015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI002_UFI'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI004_RCG'] = ('Enumeration',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI004_RCG']['BE015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI006_MEM'] = ('String',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI020_GE4'] = ('CodeList',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI026_CTUC'] = ('Enumeration',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['EnumeratedIndexValues']['ZI026_CTUC']['BE015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI026_CTUL'] = ('integer',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI026_CTUU'] = ('integer',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI031S_URI'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZI039S_UFI'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZSAX_RS0'] = ('CodeList',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZSAX_RX0'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZSAX_RX3'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CONTOUR_C']['ZSAX_RX4'] = ('StructuredText',('BE015'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['BEN'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['CRV'] = ('Real',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['FUFI'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['FURL'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['GDBV'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['GDBV']['BE010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['OTH'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['UFI'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI001_SDV'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI001_SRT'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI001_SRT']['BE010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI002_UFI'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI004_RCG'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI004_RCG']['BE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI006_MEM'] = ('String',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_DCR'] = ('Boolean',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_DKC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_DKC2'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC2'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC2']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_DKC3'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC3'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_DKC3']['BE010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_SVC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_SVC'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_SVC']['BE010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_TEC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_TEC2'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC2'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC2']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_TEC3'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC3'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_TEC3']['BE010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_VDC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_VDC'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI012_VDC']['BE010']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI012_VDR'] = ('String',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI020_GE4'] = ('CodeList',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI026_CTUC'] = ('Enumeration',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BE010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI026_CTUL'] = ('integer',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI026_CTUU'] = ('integer',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI031S_URI'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZI039S_UFI'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZSAX_RS0'] = ('CodeList',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZSAX_RX0'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZSAX_RX3'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DEPTH_CURVE_C']['ZSAX_RX4'] = ('StructuredText',('BE010'))
    field_information['GGDM 3.0']['DESERT_S']['ARA'] = ('Real',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['BEN'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['F_CODE'] = ('CONSTRAINED_STRING',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['FUFI'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['FURL'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['GDBV'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['GDBV']['EE030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DESERT_S']['LZN'] = ('Real',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['OTH'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['TSM'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['DESERT_S']['TSM2'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM2'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM2']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['DESERT_S']['TSM3'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM3'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['TSM3']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['GGDM 3.0']['DESERT_S']['UFI'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['WID'] = ('Real',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI001_SDV'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI001_SRT'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI001_SRT']['EE030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DESERT_S']['ZI002_UFI'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI004_RCG'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI004_RCG']['EE030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DESERT_S']['ZI005_FNA'] = ('String',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI005_GNT'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI005_GNT']['EE030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DESERT_S']['ZI005_NFN'] = ('String',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI006_MEM'] = ('String',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI020_GE4'] = ('CodeList',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI026_CTUC'] = ('Enumeration',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DESERT_S']['EnumeratedIndexValues']['ZI026_CTUC']['EE030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DESERT_S']['ZI026_CTUL'] = ('integer',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI026_CTUU'] = ('integer',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI031S_URI'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZI039S_UFI'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZSAX_RS0'] = ('CodeList',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZSAX_RX0'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZSAX_RX3'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DESERT_S']['ZSAX_RX4'] = ('StructuredText',('EE030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ARA'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['BEN'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['FUFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['FURL'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['GDBV'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['GDBV']['BD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['LZN'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['OTH'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['WID'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI001_SDV'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI001_SRT'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI001_SRT']['BD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI002_UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI004_RCG'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI004_RCG']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI005_FNA'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI005_GNT'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI005_GNT']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI005_NFN'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI006_MEM'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI020_GE4'] = ('CodeList',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI026_CTUC'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI026_CTUL'] = ('integer',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI026_CTUU'] = ('integer',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI031S_URI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZI039S_UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZSAX_RS0'] = ('CodeList',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZSAX_RX0'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZSAX_RX3'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_P']['ZSAX_RX4'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ARA'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['BEN'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['FUFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['FURL'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['GDBV'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['GDBV']['BD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['LZN'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['OTH'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['WID'] = ('Real',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI001_SDV'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI001_SRT'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI001_SRT']['BD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI002_UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI004_RCG'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI004_RCG']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI005_FNA'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI005_GNT'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI005_GNT']['BD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI005_NFN'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI006_MEM'] = ('String',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI020_GE4'] = ('CodeList',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI026_CTUC'] = ('Enumeration',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI026_CTUL'] = ('integer',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI026_CTUU'] = ('integer',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI031S_URI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZI039S_UFI'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZSAX_RS0'] = ('CodeList',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZSAX_RX0'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZSAX_RX3'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISCOLOURED_WATER_S']['ZSAX_RX4'] = ('StructuredText',('BD030'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['AOO'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['BEN'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['CAA'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['CAA']['AT010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['CNCP'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['COS'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['COS']['AT010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['FUFI'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['FURL'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['GDBV'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['GDBV']['AT010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['HEI'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['HGT'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['LMC'] = ('Boolean',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['LZN'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['MCC'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['MCC2'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC2']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['MCC3'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['MCC3']['AT010']  = (-999999,64,152,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['OTH'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['PCF'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['PCF']['AT010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['UFI'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['WID'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI001_SDV'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI001_SRT'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI001_SRT']['AT010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI002_UFI'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI004_RCG'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI004_RCG']['AT010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI005_FNA'] = ('String',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI005_GNT'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI005_GNT']['AT010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI005_NFN'] = ('String',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI006_MEM'] = ('String',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI020_GE4'] = ('CodeList',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI026_CTUC'] = ('Enumeration',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISH_AERIAL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AT010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI026_CTUL'] = ('integer',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI026_CTUU'] = ('integer',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI031S_URI'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZI039S_UFI'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZSAX_RS0'] = ('CodeList',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZSAX_RX0'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZSAX_RX3'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZSAX_RX4'] = ('StructuredText',('AT010'))
    field_information['GGDM 3.0']['DISH_AERIAL_P']['ZVH'] = ('Real',('AT010'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['AOO'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ARA'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['AWP'] = ('Boolean',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['BEN'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['CNCP'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['COS'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['COS']['AB000']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['FUFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['FURL'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['GDBV'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['GDBV']['AB000']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['HGT'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['LMC'] = ('Boolean',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['LZN'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['OTH'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['PBY'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['PBY2'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['PBY3'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['PCF'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['VOI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['WID'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI001_SDV'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI001_SRT'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AB000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI002_UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI004_RCG'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI005_FNA'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI005_GNT'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI005_NFN'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI006_MEM'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI020_GE4'] = ('CodeList',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AB000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI026_CTUL'] = ('integer',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI026_CTUU'] = ('integer',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI031S_URI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZSAX_RS0'] = ('CodeList',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_P']['ZVH'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['AOO'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ARA'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['AWP'] = ('Boolean',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['BEN'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['CNCP'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['COS'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['COS']['AB000']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['FUFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['FURL'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['GDBV'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['GDBV']['AB000']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['HGT'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['LMC'] = ('Boolean',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['LZN'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['OTH'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['PBY'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['PBY2'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['PBY3'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['PCF'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['VOI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['WID'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI001_SDV'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI001_SRT'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AB000']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI002_UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI004_RCG'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI005_FNA'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI005_GNT'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AB000']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI005_NFN'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI006_MEM'] = ('String',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI020_GE4'] = ('CodeList',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AB000']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI026_CTUL'] = ('integer',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI026_CTUU'] = ('integer',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI031S_URI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZSAX_RS0'] = ('CodeList',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AB000'))
    field_information['GGDM 3.0']['DISPOSAL_SITE_S']['ZVH'] = ('Real',('AB000'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['BEN'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['FUFI'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['FURL'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['GDBV'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['GDBV']['ZB036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['HGT'] = ('Real',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['MAN'] = ('Boolean',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['OTH'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['PCF'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['PCF']['ZB036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['TRS'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['TRS2'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS2']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['TRS3'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['TRS3']['ZB036']  = (-999999,5,7,9,12,13,17,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['UFI'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI001_SDV'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI001_SRT'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI001_SRT']['ZB036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI002_UFI'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI004_RCG'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI004_RCG']['ZB036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI005_FNA'] = ('String',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI005_GNT'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI005_GNT']['ZB036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI005_NFN'] = ('String',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI006_MEM'] = ('String',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI020_GE4'] = ('CodeList',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI026_CTUC'] = ('Enumeration',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZB036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI026_CTUL'] = ('integer',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI026_CTUU'] = ('integer',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI031S_URI'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZI039S_UFI'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZSAX_RS0'] = ('CodeList',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZSAX_RX0'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZSAX_RX3'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZSAX_RX4'] = ('StructuredText',('ZB036'))
    field_information['GGDM 3.0']['DISTANCE_MARK_P']['ZVH'] = ('Real',('ZB036'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ARA'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BEN'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_AWBA'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_AWBB'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_SHDA'] = ('Boolean',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_SHDB'] = ('Boolean',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_SLTA'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BH141_SLTA']['NM030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_SLTB'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BH141_SLTB']['NM030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['BH141_WBHA'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHAC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BPWHAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHAL'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHAU'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHBC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BPWHBC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHBL'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BPWHBU'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCAC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BWVCAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCAL'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCAU'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCBC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['BWVCBC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCBL'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['BWVCBU'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['CAA'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['CAA']['NM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['CDA'] = ('Boolean',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['CNCP'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['COS'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['COS']['NM030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['DITCH_AON_S']['DIT'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['DIT']['NM030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['DMF'] = ('Integer',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['DOXY'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['DZP'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['FRZ'] = ('Boolean',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['FUFI'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['FURL'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['GDBV'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['GDBV']['NM030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['LMC'] = ('Boolean',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['OTH'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['PCF'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['PCF']['NM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DITCH_AON_S']['PWAC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['PWAC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['PWAL'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['PWAU'] = ('real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['UFI'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['WVA'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI001_SDV'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI001_SRT'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI002_UFI'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI004_RCG'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI006_MEM'] = ('String',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI020_GE4'] = ('CodeList',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_ASE'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_CFR'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_CLO'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_CYN'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_FMR'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_FRR'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_HAR'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_HYP'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_MGN'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_PHW'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_SCC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_SUL'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_TDS'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_TEP'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_TUR'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WAC'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WPAC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WPAC']['NM030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WTNO'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WUR'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DITCH_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI026_CTUL'] = ('integer',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI026_CTUU'] = ('integer',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI031S_URI'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZSAX_RS0'] = ('CodeList',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM030'))
    field_information['GGDM 3.0']['DITCH_AON_S']['ZVH'] = ('Real',('NM030'))
    field_information['GGDM 3.0']['DITCH_C']['ARA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BBMCA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BBMCA2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BBMCA3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCA3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BBMCB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BBMCB2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BBMCB3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BBMCB3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BEN'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_AWBA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_AWBB'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_IBOA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_C']['BH141_IBOB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_C']['BH141_SHDA'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_SHDB'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_SLTA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BH141_SLTB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BH141_WBHA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BH141_WBHB'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BMC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BMC2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BMC3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BMC3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_C']['BPWHAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BPWHAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWHAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWHBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BPWHBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWHBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWSAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BPWSAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWSAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWSBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BPWSBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BPWSBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BWVCAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BWVCAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BWVCAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BWVCBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['BWVCBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['BWVCBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['CAA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['CAA']['BH030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DITCH_C']['CDA'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['CDL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['CNCP'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['COS'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['COS']['BH030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['DITCH_C']['CWT'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['DEV'] = ('Integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['DIT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['DIT']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_C']['DOXY'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['DZP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['FRZ'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['FUFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['FURL'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['GDBV'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['GDBV']['BH030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DITCH_C']['HDP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['HGT'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['LEA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['LMC'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['LOC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['LOC']['BH030']  = (-999999,40,44)
    field_information['GGDM 3.0']['DITCH_C']['LZN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['MWD'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['OTH'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['PCF'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DITCH_C']['PWA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['RLE'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['RLE']['BH030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['DITCH_C']['SBB'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WD3'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WDAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['WDAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['WDAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WDAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WDH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WDL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WID'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WVA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WVH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['WVL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI001_SDV'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI001_SRT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI001_SRT']['BH030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI002_UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI004_RCG'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI004_RCG']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI005_FNA'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI005_FNA2'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI005_FNA3'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI005_GNT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI005_GNT2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI005_GNT3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI005_GNT3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI005_NFN'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI005_NFN2'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI005_NFN3'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI006_MEM'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI020_GE4'] = ('CodeList',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_ASE'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_AWO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_AWOI'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_AWOX'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_CFR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_CLO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_CYN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_FMR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_FRR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_HAR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_HYP'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_MGN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_PHW'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_SCC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_SCC']['BH030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_SQN'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_SQN']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_SUL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_TDS'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_TEP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_TUR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WAC'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WPAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WPAC']['BH030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WSG'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WSG']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WTNO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WUR'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WUR2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WUR3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_WUR4'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_WUR4']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI024_YWQ'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_C']['ZI026_CTUC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DITCH_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_C']['ZI026_CTUL'] = ('integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI026_CTUU'] = ('integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI031S_URI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZI039S_UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZSAX_RS0'] = ('CodeList',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZSAX_RX0'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZSAX_RX3'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZSAX_RX4'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_C']['ZVH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ARA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BBMCA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BBMCA2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BBMCA3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCA3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BBMCB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BBMCB2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BBMCB3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BBMCB3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BEN'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_AWBA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_AWBB'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_IBOA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_S']['BH141_IBOB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_S']['BH141_SHDA'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_SHDB'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_SLTA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BH141_SLTB'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BH141_WBHA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BH141_WBHB'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BMC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BMC2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BMC3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BMC3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['DITCH_S']['BPWHAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BPWHAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWHAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWHBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BPWHBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWHBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWSAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BPWSAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWSAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWSBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BPWSBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BPWSBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BWVCAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BWVCAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BWVCAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BWVCBC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['BWVCBL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['BWVCBU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['CAA'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['CAA']['BH030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DITCH_S']['CDA'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['CDL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['CNCP'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['COS'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['COS']['BH030']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['DITCH_S']['CWT'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['DEV'] = ('Integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['DIT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['DIT'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['DIT']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_S']['DOXY'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['DZP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['FRZ'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['FUFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['FURL'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['GDBV'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['GDBV']['BH030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DITCH_S']['HDP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['HGT'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['LEA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['LMC'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['LOC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['LOC']['BH030']  = (-999999,40,44)
    field_information['GGDM 3.0']['DITCH_S']['LZN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['MWD'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['OTH'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['PCF'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DITCH_S']['PWA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['RLE'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['RLE']['BH030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['DITCH_S']['SBB'] = ('Boolean',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WD3'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WDAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['WDAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['WDAL'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WDAU'] = ('real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WDH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WDL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WID'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WVA'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WVH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['WVL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI001_SDV'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI001_SRT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI001_SRT']['BH030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI002_UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI004_RCG'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI004_RCG']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI005_FNA'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI005_FNA2'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI005_FNA3'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI005_GNT'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI005_GNT2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI005_GNT3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI005_NFN'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI005_NFN2'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI005_NFN3'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI006_MEM'] = ('String',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI020_GE4'] = ('CodeList',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_ASE'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_AWO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_AWOI'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_AWOX'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_CFR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_CLO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_CYN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_FMR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_FRR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_HAR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_HYP'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_MGN'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_PHW'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_SCC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_SCC']['BH030']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_SQN'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_SQN']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_SUL'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_TDS'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_TEP'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_TUR'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WAC'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WPAC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WPAC']['BH030']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WSG'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WSG']['BH030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WTNO'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WUR'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WUR2'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WUR3'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_WUR4'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI024_YWQ'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['DITCH_S']['ZI026_CTUC'] = ('Enumeration',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DITCH_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DITCH_S']['ZI026_CTUL'] = ('integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI026_CTUU'] = ('integer',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI031S_URI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZI039S_UFI'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZSAX_RS0'] = ('CodeList',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZSAX_RX0'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZSAX_RX3'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZSAX_RX4'] = ('StructuredText',('BH030'))
    field_information['GGDM 3.0']['DITCH_S']['ZVH'] = ('Real',('BH030'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ARA'] = ('Real',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['BEN'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['CNCP'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['COS'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['COS']['BB080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DOLPHIN_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['FUFI'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['FURL'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['GDBV'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['GDBV']['BB080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DOLPHIN_P']['LZN'] = ('Real',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['OTH'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['PCF'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['PCF']['BB080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DOLPHIN_P']['UFI'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI001_SDV'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI001_SRT'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI001_SRT']['BB080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI002_UFI'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI004_RCG'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI004_RCG']['BB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI005_FNA'] = ('String',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI005_GNT'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI005_GNT']['BB080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI005_NFN'] = ('String',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI006_MEM'] = ('String',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI020_GE4'] = ('CodeList',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI026_CTUC'] = ('Enumeration',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DOLPHIN_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI026_CTUL'] = ('integer',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI026_CTUU'] = ('integer',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI031S_URI'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZI039S_UFI'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZSAX_RS0'] = ('CodeList',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZSAX_RX0'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZSAX_RX3'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DOLPHIN_P']['ZSAX_RX4'] = ('StructuredText',('BB080'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ARA'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['BEN'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['CNCP'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['COS'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['COS']['AL060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['FUFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['FURL'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['GDBV'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['GDBV']['AL060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['HGT'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['LZN'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['MCC'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['MCC2'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['MCC3'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['OTH'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['PCF'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['WID'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI001_SDV'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI001_SRT'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI001_SRT']['AL060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI002_UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI004_RCG'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI004_RCG']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI006_MEM'] = ('String',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI020_GE4'] = ('CodeList',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI026_CTUC'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI026_CTUL'] = ('integer',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI026_CTUU'] = ('integer',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI031S_URI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZI039S_UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZSAX_RS0'] = ('CodeList',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZSAX_RX0'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZSAX_RX3'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_C']['ZSAX_RX4'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ARA'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['BEN'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['CNCP'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['COS'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['COS']['AL060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['FUFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['FURL'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['GDBV'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['GDBV']['AL060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['HGT'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['LZN'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['MCC'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['MCC2'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['MCC3'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['OTH'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['PCF'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['WID'] = ('Real',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI001_SDV'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI001_SRT'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI001_SRT']['AL060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI002_UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI004_RCG'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI004_RCG']['AL060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI006_MEM'] = ('String',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI020_GE4'] = ('CodeList',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI026_CTUC'] = ('Enumeration',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI026_CTUL'] = ('integer',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI026_CTUU'] = ('integer',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI031S_URI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZI039S_UFI'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZSAX_RS0'] = ('CodeList',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZSAX_RX0'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZSAX_RX3'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAGONS_TEETH_S']['ZSAX_RX4'] = ('StructuredText',('AL060'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ARA'] = ('Real',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['BEN'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['F_CODE'] = ('CONSTRAINED_STRING',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['FUFI'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['FURL'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['GDBV'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['GDBV']['NA170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['LZN'] = ('Real',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['OTH'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['PCF'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['PCF']['NA170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['PRVR'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['UFI'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['VTI'] = ('Real',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['WID'] = ('Real',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI001_SDV'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI001_SRT'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI001_SRT']['NA170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI002_UFI'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI004_RCG'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI004_RCG']['NA170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI005_FNA'] = ('String',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI005_GNT'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI005_GNT']['NA170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI005_NFN'] = ('String',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI006_MEM'] = ('String',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI020_GE4'] = ('CodeList',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI026_CTUC'] = ('Enumeration',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['EnumeratedIndexValues']['ZI026_CTUC']['NA170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI026_CTUL'] = ('integer',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI026_CTUU'] = ('integer',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI031S_URI'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZI039S_UFI'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZSAX_RS0'] = ('CodeList',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZSAX_RX0'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZSAX_RX3'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DRAINAGE_BASIN_S']['ZSAX_RX4'] = ('StructuredText',('NA170'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ARA'] = ('Real',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['BEN'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['CAA'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['CAA']['FC034']  = (-999999,1,2,5,6,7,11,16,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['DAN'] = ('String',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['FUFI'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['FURL'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['GDBV'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['GDBV']['FC034']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['HDP'] = ('Real',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['LZN'] = ('Real',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['MAN'] = ('Boolean',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['MAS'] = ('Boolean',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['OTH'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['UFI'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['WID'] = ('Real',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_DCR'] = ('Boolean',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_DKC'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_DKC2'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC2']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_DKC3'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC3']['FC034']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_SVC'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_SVC']['FC034']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_TEC'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_TEC2'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC2']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_TEC3'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC3']['FC034']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_VDC'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZHDP_VDC']['FC034']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZHDP_VDR'] = ('String',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI001_SDV'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI001_SRT'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['FC034']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI002_UFI'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI004_RCG'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['FC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI005_FNA'] = ('String',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI005_GNT'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['FC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI005_NFN'] = ('String',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI006_MEM'] = ('String',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI020_GE4'] = ('CodeList',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI026_CTUC'] = ('Enumeration',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DREDGED_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC034']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI026_CTUL'] = ('integer',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI026_CTUU'] = ('integer',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI031S_URI'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZI039S_UFI'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZSAX_RS0'] = ('CodeList',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZSAX_RX0'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZSAX_RX3'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DREDGED_AREA_S']['ZSAX_RX4'] = ('StructuredText',('FC034'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ADR'] = ('String',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['AOO'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ARA'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['BEN'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['CAA'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['CAA']['AK070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['CNCP'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['COS'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['COS']['AK070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['FFN'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['FFN2'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN2']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['FFN3'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['FFN3']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['FUFI'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['FURL'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['GDBV'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['GDBV']['AK070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['HGT'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['LMC'] = ('Boolean',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['LZN'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['OTH'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['PCF'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['PCF']['AK070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['UFI'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['WID'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI001_SDV'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI001_SRT'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI002_UFI'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI004_RCG'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI005_FNA'] = ('String',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI005_GNT'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI005_NFN'] = ('String',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI006_MEM'] = ('String',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI020_GE4'] = ('CodeList',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI026_CTUC'] = ('Enumeration',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI026_CTUL'] = ('integer',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI026_CTUU'] = ('integer',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI031S_URI'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZI039S_UFI'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZSAX_RS0'] = ('CodeList',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZSAX_RX0'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZSAX_RX3'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZSAX_RX4'] = ('StructuredText',('AK070'))
    field_information['GGDM 3.0']['DRIVE_IN_THEATRE_S']['ZVH'] = ('Real',('AK070'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['AOO'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ARA'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['BEN'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['CAA'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['CAA']['BB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['CNCP'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['COS'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['COS']['BB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['DRY_DOCK_S']['DZP'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['FUFI'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['FURL'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['GDBV'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['GDBV']['BB090']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['HGT'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['LMC'] = ('Boolean',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['LNU'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['LZN'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['MCC'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['MCC2'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC2']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['MCC3'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['MCC3']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['MWD'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['OTH'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['PCF'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['PCF']['BB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['DRY_DOCK_S']['UFI'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['WDU'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['WID'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI001_SDV'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI001_SRT'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI001_SRT']['BB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI002_UFI'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI004_RCG'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI004_RCG']['BB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI005_FNA'] = ('String',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI005_GNT'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI005_GNT']['BB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI005_NFN'] = ('String',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI006_MEM'] = ('String',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI020_GE4'] = ('CodeList',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI026_CTUC'] = ('Enumeration',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['DRY_DOCK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI026_CTUL'] = ('integer',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI026_CTUU'] = ('integer',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI031S_URI'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZI039S_UFI'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZSAX_RS0'] = ('CodeList',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZSAX_RX0'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZSAX_RX3'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZSAX_RX4'] = ('StructuredText',('BB090'))
    field_information['GGDM 3.0']['DRY_DOCK_S']['ZVH'] = ('Real',('BB090'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ADR'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['AOO'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ARA'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['BEN'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['CAA'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['CAA']['AD010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['CNCP'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['COS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['COS']['AD010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EPW'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['FUFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['FURL'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['GDBV'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['GDBV']['AD010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['HGT'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['LMC'] = ('Boolean',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['LZN'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['OTH'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['PCF'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['POS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['POS2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS2'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['POS3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS3'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['VCM'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['VCM2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['VCM3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['WID'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI001_SDV'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI001_SRT'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AD010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI002_UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI004_RCG'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI005_FNA'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI005_GNT'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI005_NFN'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI006_MEM'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI020_GE4'] = ('CodeList',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI026_CTUL'] = ('integer',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI026_CTUU'] = ('integer',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI031S_URI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZSAX_RS0'] = ('CodeList',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_P']['ZVH'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ADR'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['AOO'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ARA'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['BEN'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['CAA'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['CAA']['AD010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['CNCP'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['COS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['COS']['AD010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EPW'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['FUFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['FURL'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['GDBV'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['GDBV']['AD010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['HGT'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['LMC'] = ('Boolean',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['LZN'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['OTH'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['PCF'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['POS'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['POS2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS2'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['POS3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS3'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['VCM'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['VCM2'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['VCM3'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['WID'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI001_SDV'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI001_SRT'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AD010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI002_UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI004_RCG'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI005_FNA'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI005_GNT'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AD010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI005_NFN'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI006_MEM'] = ('String',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI020_GE4'] = ('CodeList',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI026_CTUL'] = ('integer',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI026_CTUU'] = ('integer',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI031S_URI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZSAX_RS0'] = ('CodeList',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AD010'))
    field_information['GGDM 3.0']['ELECTRIC_POWER_STATION_S']['ZVH'] = ('Real',('AD010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['BEN'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ESC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ESC'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ESC']['CA010']  = (-999999,1,2,4,5,6)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['F_CODE'] = ('CONSTRAINED_STRING',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['FUFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['FURL'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['GDBV'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['GDBV']['CA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['HQC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['HQC'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['HQC']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,12,13,14,15,16,18,19,20,21,22,23,98,99,999)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['OTH'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI001_SDV'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI001_SRT'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI001_SRT']['CA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI002_UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI004_RCG'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI004_RCG']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI006_MEM'] = ('String',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI020_GE4'] = ('CodeList',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI026_CTUC'] = ('Enumeration',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['EnumeratedIndexValues']['ZI026_CTUC']['CA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI026_CTUL'] = ('integer',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI026_CTUU'] = ('integer',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI031S_URI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZI039S_UFI'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZSAX_RS0'] = ('CodeList',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZSAX_RX0'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZSAX_RX3'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZSAX_RX4'] = ('StructuredText',('CA010'))
    field_information['GGDM 3.0']['ELEVATION_CONTOUR_C']['ZVH'] = ('Real',('CA010'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ARA'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['BEN'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['CAA'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['CAA']['DB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['CET'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['CET'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['CNCP'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['COS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['COS']['DB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EMBANKMENT_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['FIC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['FIC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['FUFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['FURL'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['GDBV'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['GDBV']['DB090']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['HGT'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['LMC'] = ('Boolean',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['LZN'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['MCC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['MCC2'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['MCC3'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['OTH'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['PCF'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EMBANKMENT_C']['PFH'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['SGCC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EMBANKMENT_C']['SGCL'] = ('real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['SGCU'] = ('real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['TRS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['TRS2'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['TRS3'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['WID'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['WLE'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI001_SDV'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI001_SRT'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI001_SRT']['DB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI002_UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI004_RCG'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI004_RCG']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI005_FNA'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI005_GNT'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI005_GNT']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI005_NFN'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI006_MEM'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI020_GE4'] = ('CodeList',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI026_CTUC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI026_CTUL'] = ('integer',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI026_CTUU'] = ('integer',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI031S_URI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZI039S_UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZSAX_RS0'] = ('CodeList',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZSAX_RX0'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZSAX_RX3'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZSAX_RX4'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_C']['ZVH'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ARA'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['BEN'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['CAA'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['CAA']['DB090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['CET'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['CET'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['CNCP'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['COS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['COS']['DB090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EMBANKMENT_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['FIC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['FIC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['FUFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['FURL'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['GDBV'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['GDBV']['DB090']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['HGT'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['LMC'] = ('Boolean',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['LZN'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['MCC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['MCC2'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['MCC3'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,64,84,86,104,117,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['OTH'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['PCF'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EMBANKMENT_S']['PFH'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['SGCC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EMBANKMENT_S']['SGCL'] = ('real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['SGCU'] = ('real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['TRS'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['TRS2'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['TRS3'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['WID'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['WLE'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI001_SDV'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI001_SRT'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI001_SRT']['DB090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI002_UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI004_RCG'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI004_RCG']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI005_FNA'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI005_GNT'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI005_GNT']['DB090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI005_NFN'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI006_MEM'] = ('String',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI020_GE4'] = ('CodeList',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI026_CTUC'] = ('Enumeration',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EMBANKMENT_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI026_CTUL'] = ('integer',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI026_CTUU'] = ('integer',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI031S_URI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZI039S_UFI'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZSAX_RS0'] = ('CodeList',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZSAX_RX0'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZSAX_RX3'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZSAX_RX4'] = ('StructuredText',('DB090'))
    field_information['GGDM 3.0']['EMBANKMENT_S']['ZVH'] = ('Real',('DB090'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['AOO'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ARA'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['AWP'] = ('Boolean',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['BEN'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['CAA'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['CAA']['AF060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['CNCP'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['COS'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['COS']['AF060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ETY'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ETY'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['FUFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['FURL'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['GDBV'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['GDBV']['AF060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['HGT'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['LMC'] = ('Boolean',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['LZN'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['OTH'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['PCF'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['SRL'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['VOI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['WID'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI001_SDV'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI001_SRT'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI001_SRT']['AF060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI002_UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI004_RCG'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI004_RCG']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI005_FNA'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI005_GNT'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI005_GNT']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI005_NFN'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI006_MEM'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI020_GE4'] = ('CodeList',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI026_CTUC'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI026_CTUL'] = ('integer',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI026_CTUU'] = ('integer',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI031S_URI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZI039S_UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZSAX_RS0'] = ('CodeList',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZSAX_RX0'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZSAX_RX3'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZSAX_RX4'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_P']['ZVH'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['AOO'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ARA'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['AWP'] = ('Boolean',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['BEN'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['CAA'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['CAA']['AF060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['CNCP'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['COS'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['COS']['AF060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ETY'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ETY'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['FUFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['FURL'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['GDBV'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['GDBV']['AF060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['HGT'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['LMC'] = ('Boolean',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['LZN'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['OTH'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['PCF'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['SRL'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['VOI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['WID'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI001_SDV'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI001_SRT'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI001_SRT']['AF060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI002_UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI004_RCG'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI004_RCG']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI005_FNA'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI005_GNT'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI005_GNT']['AF060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI005_NFN'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI006_MEM'] = ('String',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI020_GE4'] = ('CodeList',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI026_CTUC'] = ('Enumeration',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AF060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI026_CTUL'] = ('integer',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI026_CTUU'] = ('integer',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI031S_URI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZI039S_UFI'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZSAX_RS0'] = ('CodeList',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZSAX_RX0'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZSAX_RX3'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZSAX_RX4'] = ('StructuredText',('AF060'))
    field_information['GGDM 3.0']['ENGINE_TEST_CELL_S']['ZVH'] = ('Real',('AF060'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ARA'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['BEN'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['CNCP'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['COS'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['COS']['AH025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['DZP'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EET'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['EET'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['F_CODE'] = ('CONSTRAINED_STRING',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['FUFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['FURL'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['GDBV'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['GDBV']['AH025']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['HST'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['HST2'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['HST3'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['LMC'] = ('Boolean',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['LZN'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['OTH'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['PCF'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['PFHC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['PFHC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['PFHL'] = ('real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['PFHU'] = ('real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['WD3'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['WID'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['YSU'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['YSU']['AH025']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI001_SDV'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI001_SRT'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI001_SRT']['AH025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI002_UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI004_RCG'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI004_RCG']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI005_FNA'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI005_GNT'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI005_GNT']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI005_NFN'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI006_MEM'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI020_GE4'] = ('CodeList',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI026_CTUC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['EnumeratedIndexValues']['ZI026_CTUC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI026_CTUL'] = ('integer',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI026_CTUU'] = ('integer',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI031S_URI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZI039S_UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZSAX_RS0'] = ('CodeList',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZSAX_RX0'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZSAX_RX3'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_C']['ZSAX_RX4'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ARA'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['BEN'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['CNCP'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['COS'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['COS']['AH025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['DZP'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EET'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['EET'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['FUFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['FURL'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['GDBV'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['GDBV']['AH025']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['HST'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['HST2'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['HST3'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['LMC'] = ('Boolean',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['LZN'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['OTH'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['PCF'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['PFHC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['PFHC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['PFHL'] = ('real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['PFHU'] = ('real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['WD3'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['WID'] = ('Real',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['YSU'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['YSU']['AH025']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI001_SDV'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI001_SRT'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI001_SRT']['AH025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI002_UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI004_RCG'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI004_RCG']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI005_FNA'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI005_GNT'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI005_GNT']['AH025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI005_NFN'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI006_MEM'] = ('String',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI020_GE4'] = ('CodeList',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI026_CTUC'] = ('Enumeration',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AH025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI026_CTUL'] = ('integer',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI026_CTUU'] = ('integer',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI031S_URI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZI039S_UFI'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZSAX_RS0'] = ('CodeList',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZSAX_RX0'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZSAX_RX3'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_EARTHWORK_S']['ZSAX_RX4'] = ('StructuredText',('AH025'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ARA'] = ('Real',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['BEN'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['CIW'] = ('Boolean',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['FUFI'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['FURL'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['GDBV'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['GDBV']['AP033']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['LZN'] = ('Real',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['MES'] = ('Boolean',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['OTH'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['PCF'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['PCF']['AP033']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['UFI'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['WID'] = ('Real',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI001_SDV'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI001_SRT'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AP033']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI002_UFI'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI004_RCG'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AP033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI005_FNA'] = ('String',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI005_NFN'] = ('String',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI006_MEM'] = ('String',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI016_ROC'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI016_ROC']['AP033']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI016_WTC'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI016_WTC']['AP033']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI020_GE4'] = ('CodeList',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AP033']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI026_CTUL'] = ('integer',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI026_CTUU'] = ('integer',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI031S_URI'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZSAX_RS0'] = ('CodeList',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENGINEERED_TURNAROUND_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AP033'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['AHA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['AVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['DQS'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EQS'] = ('Integer',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['HVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['MDE'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['OTH'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['RCG'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['RCG']['ZI039']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['SCVN'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['UFI'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_SDP'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_SDV'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_SPS'] = ('Boolean',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_SRT'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['ZI001_SRT']['ZI039']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_VSC'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['ZI001_VSC'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['EnumeratedIndexValues']['ZI001_VSC']['ZI039']  = (-999999,1,2,3,4,5,6,998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_VSD'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI001_VSN'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_S']['ZI004_PRE'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['AHA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['AVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['DQS'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EQS'] = ('Integer',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['HVA'] = ('Real',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['MDE'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['OTH'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['RCG'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['RCG'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['RCG']['ZI039']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['SCVN'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['UFI'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SDP'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SDV'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SPS'] = ('Boolean',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_SRT'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_SRT']['ZI039']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSC'] = ('Enumeration',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_VSC'] = {}
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['EnumeratedIndexValues']['ZI001_VSC']['ZI039']  = (-999999,1,2,3,4,5,6,998,999)
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSD'] = ('StructuredText',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI001_VSN'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ENTITY_COLLECTION_METADATA_T']['ZI004_PRE'] = ('String',('ZI039'))
    field_information['GGDM 3.0']['ESKER_C']['ARA'] = ('Real',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['BEN'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['FUFI'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['FURL'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['GDBV'] = ('Enumeration',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['GDBV']['DB100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ESKER_C']['HGT'] = ('Real',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['LMC'] = ('Boolean',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['LZN'] = ('Real',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['OTH'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['UFI'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['WID'] = ('Real',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI001_SDV'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI001_SRT'] = ('Enumeration',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI001_SRT']['DB100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ESKER_C']['ZI002_UFI'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI004_RCG'] = ('Enumeration',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI004_RCG']['DB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ESKER_C']['ZI005_FNA'] = ('String',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI005_GNT'] = ('Enumeration',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI005_GNT']['DB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ESKER_C']['ZI005_NFN'] = ('String',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI006_MEM'] = ('String',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI020_GE4'] = ('CodeList',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI026_CTUC'] = ('Enumeration',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ESKER_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ESKER_C']['ZI026_CTUL'] = ('integer',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI026_CTUU'] = ('integer',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI031S_URI'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZI039S_UFI'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZSAX_RS0'] = ('CodeList',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZSAX_RX0'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZSAX_RX3'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZSAX_RX4'] = ('StructuredText',('DB100'))
    field_information['GGDM 3.0']['ESKER_C']['ZVH'] = ('Real',('DB100'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['AOO'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ARA'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['AWP'] = ('Boolean',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['BEN'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['CAA'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['CAA']['AF050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['CNCP'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['COS'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['COS']['AF050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['FUFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['FURL'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['GDBV'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['GDBV']['AF050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['HGT'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['LMC'] = ('Boolean',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['LZN'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['OTH'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['PCF'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['VOI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['WID'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI001_SDV'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI001_SRT'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI001_SRT']['AF050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI002_UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI004_RCG'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI004_RCG']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI005_FNA'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI005_GNT'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI005_GNT']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI005_NFN'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI006_MEM'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI020_GE4'] = ('CodeList',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI026_CTUC'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AF050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI026_CTUL'] = ('integer',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI026_CTUU'] = ('integer',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI031S_URI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZI039S_UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZSAX_RS0'] = ('CodeList',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZSAX_RX0'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZSAX_RX3'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZSAX_RX4'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_C']['ZVH'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['AOO'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ARA'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['AWP'] = ('Boolean',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['BEN'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['CAA'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['CAA']['AF050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['CNCP'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['COS'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['COS']['AF050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['FUFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['FURL'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['GDBV'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['GDBV']['AF050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['HGT'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['LMC'] = ('Boolean',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['LZN'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['OTH'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['PCF'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['VOI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['WID'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI001_SDV'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI001_SRT'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI001_SRT']['AF050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI002_UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI004_RCG'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI004_RCG']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI005_FNA'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI005_GNT'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI005_GNT']['AF050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI005_NFN'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI006_MEM'] = ('String',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI020_GE4'] = ('CodeList',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI026_CTUC'] = ('Enumeration',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI026_CTUL'] = ('integer',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI026_CTUU'] = ('integer',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI031S_URI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZI039S_UFI'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZSAX_RS0'] = ('CodeList',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZSAX_RX0'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZSAX_RX3'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZSAX_RX4'] = ('StructuredText',('AF050'))
    field_information['GGDM 3.0']['EXCAVATING_MACHINE_P']['ZVH'] = ('Real',('AF050'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['AOO'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ARA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['BEN'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['CNCP'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['COS'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['COS']['AA010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['DZP'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['FFN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['FFN2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['FFN3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['FUFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['FURL'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['GDBV'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['GDBV']['AA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['HGT'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['HST'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['HST2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['HST3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['LEA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['LMC'] = ('Boolean',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['LOC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['LZN'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['MZN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['MZN'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,13,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['OTH'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['PCF'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['PPO'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['PPO2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['PPO3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['UMA'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['UMA'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['WID'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI001_SDV'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI001_SRT'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI001_SRT']['AA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI002_UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI004_RCG'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI004_RCG']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI005_FNA'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI005_GNT'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI005_GNT']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI005_NFN'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI006_MEM'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI020_GE4'] = ('CodeList',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI026_CTUC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI026_CTUL'] = ('integer',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI026_CTUU'] = ('integer',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI031S_URI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZI039S_UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZSAX_RS0'] = ('CodeList',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZSAX_RX0'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZSAX_RX3'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZSAX_RX4'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_P']['ZVH'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['AOO'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ARA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['BEN'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['CNCP'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['COS'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['COS']['AA010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['DZP'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['FFN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['FFN2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['FFN3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['FUFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['FURL'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['GDBV'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['GDBV']['AA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['HGT'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['HST'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['HST2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['HST3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['LEA'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['LMC'] = ('Boolean',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['LOC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['LZN'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['MZN'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['MZN'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,13,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['OTH'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['PCF'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['PPO'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['PPO2'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['PPO3'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['UMA'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['UMA'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['WID'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI001_SDV'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI001_SRT'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI001_SRT']['AA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI002_UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI004_RCG'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI004_RCG']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI005_FNA'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI005_GNT'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI005_GNT']['AA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI005_NFN'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI006_MEM'] = ('String',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI020_GE4'] = ('CodeList',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI026_CTUC'] = ('Enumeration',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI026_CTUL'] = ('integer',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI026_CTUU'] = ('integer',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI031S_URI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZI039S_UFI'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZSAX_RS0'] = ('CodeList',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZSAX_RX0'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZSAX_RX3'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZSAX_RX4'] = ('StructuredText',('AA010'))
    field_information['GGDM 3.0']['EXTRACTION_MINE_S']['ZVH'] = ('Real',('AA010'))
    field_information['GGDM 3.0']['FACILITY_P']['ADR'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ADUR'] = ('Integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['AOO'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ARA'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['BEN'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['CAA'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FACILITY_P']['CNCP'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['COS'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['COS']['AL010']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['FFN'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_P']['FFN2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_P']['FFN3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_P']['FUFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['FURL'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['GDBV'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['GDBV']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FACILITY_P']['HGT'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['LMC'] = ('Boolean',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['LZN'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['OTH'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['PCF'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FACILITY_P']['UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['VCM'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_P']['VCM2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_P']['VCM3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_P']['WID'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['WLSS'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['WSRC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['WSRC'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['WSRC']['AL010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AL010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_FNA'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_FNA2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_FNA3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_GNT2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_GNT3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_NFN'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_NFN2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI005_NFN3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI006_MEM'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PBY'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PBY2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PBY3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PPO'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PPO2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PPO3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PRW'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PRW2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI014_PRW3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI018_WIT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI020_GE4'] = ('CodeList',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FACILITY_P']['ZI026_CTUL'] = ('integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI026_CTUU'] = ('integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZI037_REL'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI037_RFA'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['FACILITY_P']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_P']['ZVH'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ADR'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ADUR'] = ('Integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['AOO'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ARA'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['BEN'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['CAA'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FACILITY_S']['CNCP'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['COS'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['COS']['AL010']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['FFN'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_S']['FFN2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_S']['FFN3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,915,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FACILITY_S']['FUFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['FURL'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['GDBV'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['GDBV']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FACILITY_S']['HGT'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['LMC'] = ('Boolean',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['LZN'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['OTH'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['PCF'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FACILITY_S']['UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['VCM'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_S']['VCM2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_S']['VCM3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FACILITY_S']['WID'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['WLSS'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['WSRC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['WSRC'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['WSRC']['AL010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AL010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_FNA'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_FNA2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_FNA3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_GNT2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_GNT3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_NFN'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_NFN2'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI005_NFN3'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI006_MEM'] = ('String',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PBY'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PBY2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PBY3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PPO'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PPO2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PPO3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PRW'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PRW2'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI014_PRW3'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI018_WIT'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI020_GE4'] = ('CodeList',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FACILITY_S']['ZI026_CTUL'] = ('integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI026_CTUU'] = ('integer',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZI037_REL'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI037_RFA'] = ('Enumeration',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['FACILITY_S']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AL010'))
    field_information['GGDM 3.0']['FACILITY_S']['ZVH'] = ('Real',('AL010'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ADR'] = ('String',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['AOO'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ARA'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['BEN'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['CAA'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['CAA']['AK090']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['CNCP'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['COS'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['COS']['AK090']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FAIRGROUND_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['FFN'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['FFN2'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN2']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['FFN3'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['FFN3']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['FUFI'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['FURL'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['GDBV'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['GDBV']['AK090']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['HGT'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['LMC'] = ('Boolean',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['LZN'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['OTH'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['PCF'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['PCF']['AK090']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FAIRGROUND_S']['UFI'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['WID'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI001_SDV'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI001_SRT'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI001_SRT']['AK090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI002_UFI'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI004_RCG'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI004_RCG']['AK090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI005_FNA'] = ('String',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI005_GNT'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI005_GNT']['AK090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI005_NFN'] = ('String',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI006_MEM'] = ('String',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI020_GE4'] = ('CodeList',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI026_CTUC'] = ('Enumeration',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FAIRGROUND_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI026_CTUL'] = ('integer',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI026_CTUU'] = ('integer',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI031S_URI'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZI039S_UFI'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZSAX_RS0'] = ('CodeList',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZSAX_RX0'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZSAX_RX3'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZSAX_RX4'] = ('StructuredText',('AK090'))
    field_information['GGDM 3.0']['FAIRGROUND_S']['ZVH'] = ('Real',('AK090'))
    field_information['GGDM 3.0']['FENCE_C']['BAT'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['BAT'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['BAT']['AL070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FENCE_C']['BEN'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['CAA'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['CAA']['AL070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FENCE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['FEF'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['FEF'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['FEF']['AL070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FENCE_C']['FTI'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['FTI'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['FTI']['AL070']  = (-999999,1,2,5,6,7,8,9,999)
    field_information['GGDM 3.0']['FENCE_C']['FUFI'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['FURL'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['GDBV'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['GDBV']['AL070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FENCE_C']['HGT'] = ('Real',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['LMC'] = ('Boolean',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['LZN'] = ('Real',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['MCC'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['FENCE_C']['MCC2'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC2']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['FENCE_C']['MCC3'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['MCC3']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['GGDM 3.0']['FENCE_C']['OTH'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['PCF'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['PCF']['AL070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FENCE_C']['PFHC'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['PFHC']['AL070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FENCE_C']['PFHL'] = ('real',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['PFHU'] = ('real',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['THI'] = ('Real',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['UFI'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI001_SDV'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI001_SRT'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI001_SRT']['AL070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FENCE_C']['ZI002_UFI'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI004_RCG'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI004_RCG']['AL070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FENCE_C']['ZI006_MEM'] = ('String',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI020_GE4'] = ('CodeList',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI026_CTUC'] = ('Enumeration',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FENCE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FENCE_C']['ZI026_CTUL'] = ('integer',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI026_CTUU'] = ('integer',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI031S_URI'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZI039S_UFI'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZSAX_RS0'] = ('CodeList',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZSAX_RX0'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZSAX_RX3'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZSAX_RX4'] = ('StructuredText',('AL070'))
    field_information['GGDM 3.0']['FENCE_C']['ZVH'] = ('Real',('AL070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['AOO'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['BEN'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['CAA'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['CAA']['AQ070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['CNCP'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['COS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['COS']['AQ070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['FCL'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['FER'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['FER'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['FER']['AQ070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['FUFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['FURL'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['GDBV'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['GDBV']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['LMC'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['LZN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['MCX'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['OPT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['OPT']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['OTH'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['PSN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_ROI'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_ROI2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI2']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_ROI3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['RIN_ROI3']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_RTN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_RTN2'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['RIN_RTN3'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['SPD'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['SPM'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['TRS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['TRS2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS2']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['TRS3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['TRS3']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI001_SDV'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI001_SRT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI002_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI004_RCG'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI005_FNA'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI005_GNT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI005_NFN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI006_MEM'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI020_GE4'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI026_CTUC'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI026_CTUL'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI026_CTUU'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI031S_URI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZI039S_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZSAX_RS0'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZSAX_RX0'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZSAX_RX3'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_C']['ZSAX_RX4'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['AOO'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['BEN'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['CAA'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['CAA']['AQ070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['CNCP'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['COS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['COS']['AQ070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['FCL'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['FER'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['FER'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['FER']['AQ070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['FUFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['FURL'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['GDBV'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['GDBV']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['LMC'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['LZN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['MCX'] = ('Boolean',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['OPT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['OPT']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['OTH'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['PSN'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_ROI'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_ROI2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI2']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_ROI3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['RIN_ROI3']['AQ070']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_RTN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_RTN2'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['RIN_RTN3'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['SPD'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['SPM'] = ('Real',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['TRS'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['TRS2'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS2']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['TRS3'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['TRS3']['AQ070']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI001_SDV'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI001_SRT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI002_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI004_RCG'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI005_FNA'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI005_GNT'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI005_NFN'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI006_MEM'] = ('String',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI020_GE4'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI026_CTUC'] = ('Enumeration',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI026_CTUL'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI026_CTUU'] = ('integer',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI031S_URI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZI039S_UFI'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZSAX_RS0'] = ('CodeList',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZSAX_RX0'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZSAX_RX3'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_CROSSING_P']['ZSAX_RX4'] = ('StructuredText',('AQ070'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ADR'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['AOO'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ARA'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ATB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['AWP'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['BEN'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['CAA'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['CAA']['AQ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['CNCP'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['COS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['COS']['AQ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FERRY_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['FFN'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['FUFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['FURL'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['GDBV'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['GDBV']['AQ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['HGT'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['HST'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['HST2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['HST3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['LMC'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['LZN'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['MUB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['OTH'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['PCF'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FERRY_STATION_P']['SSR'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['TRS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['VOI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['WID'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI001_SDV'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI001_SRT'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI002_UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI004_RCG'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI005_FNA'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI005_GNT'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI005_NFN'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI006_MEM'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI020_GE4'] = ('CodeList',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI026_CTUL'] = ('integer',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI026_CTUU'] = ('integer',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI031S_URI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZSAX_RS0'] = ('CodeList',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_P']['ZVH'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ADR'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['AOO'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ARA'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ATB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['AWP'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['BEN'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['CAA'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['CAA']['AQ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['CNCP'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['COS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['COS']['AQ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FERRY_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['FFN'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['FUFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['FURL'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['GDBV'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['GDBV']['AQ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['HGT'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['HST'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['HST2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['HST3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['LMC'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['LZN'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['MUB'] = ('Boolean',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['OTH'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['PCF'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FERRY_STATION_S']['SSR'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['TRS'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['VOI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['WID'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI001_SDV'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI001_SRT'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI002_UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI004_RCG'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI005_FNA'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI005_GNT'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI005_NFN'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI006_MEM'] = ('String',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI020_GE4'] = ('CodeList',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FERRY_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI026_CTUL'] = ('integer',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI026_CTUU'] = ('integer',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI031S_URI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZSAX_RS0'] = ('CodeList',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AQ080'))
    field_information['GGDM 3.0']['FERRY_STATION_S']['ZVH'] = ('Real',('AQ080'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['BEN'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['CAA'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['CAA']['AL017']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['CNCP'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['COS'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['COS']['AL017']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['FUFI'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['FURL'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['GDBV'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['GDBV']['AL017']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['HGT'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['LMC'] = ('Boolean',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['LZN'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['OTH'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['PCF'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['PCF']['AL017']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['UFI'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI001_SDV'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI001_SRT'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL017']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI002_UFI'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI004_RCG'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI005_FNA'] = ('String',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI005_GNT'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI005_GNT']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI005_NFN'] = ('String',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI006_MEM'] = ('String',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI020_GE4'] = ('CodeList',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_ASE'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_CFR'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_CLO'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_CYN'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_FMR'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_FRR'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_HAR'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_MGN'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_PHW'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_SCC'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_SCC']['AL017']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_SUL'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_TDS'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_TEP'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_TUR'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_WAC'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_WTNO'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_WUR'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_WUR']['AL017']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI024_YWQ'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI024_YWQ']['AL017']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI026_CTUC'] = ('Enumeration',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL017']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI026_CTUL'] = ('integer',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI026_CTUU'] = ('integer',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI031S_URI'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZI039S_UFI'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZSAX_RS0'] = ('CodeList',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZSAX_RX0'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZSAX_RX3'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZSAX_RX4'] = ('StructuredText',('AL017'))
    field_information['GGDM 3.0']['FIRE_HYDRANT_P']['ZVH'] = ('Real',('AL017'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['AOO'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ARA'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['BEN'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['CAA'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['CNCP'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['COS'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['COS']['FA015']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FFN'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FFN2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FFN3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FRT2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FRT3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FUFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['FURL'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['GDBV'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['GDBV']['FA015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['HGT'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['LZN'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['OTH'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['PCF'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['PRM'] = ('Boolean',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['WID'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['YSU'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI001_SDV'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI001_SRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI001_SRT']['FA015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI002_UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI004_RCG'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI004_RCG']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI005_FNA'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI005_GNT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI005_GNT']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI005_NFN'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI006_MEM'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI020_GE4'] = ('CodeList',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI025_HDP'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI026_CTUC'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['FA015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI026_CTUL'] = ('integer',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI026_CTUU'] = ('integer',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI031S_URI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZI039S_UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZSAX_RS0'] = ('CodeList',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZSAX_RX0'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZSAX_RX3'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZSAX_RX4'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_P']['ZVH'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['AOO'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ARA'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['BEN'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['CAA'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['CNCP'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['COS'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['COS']['FA015']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FFN'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FFN2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FFN3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FRT2'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FRT3'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FUFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['FURL'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['GDBV'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['GDBV']['FA015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['HGT'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['LZN'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['OTH'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['PCF'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['PRM'] = ('Boolean',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['WID'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['YSU'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI001_SDV'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI001_SRT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI001_SRT']['FA015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI002_UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI004_RCG'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI004_RCG']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI005_FNA'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI005_GNT'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI005_GNT']['FA015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI005_NFN'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI006_MEM'] = ('String',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI020_GE4'] = ('CodeList',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI025_HDP'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI026_CTUC'] = ('Enumeration',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FIRING_RANGE_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI026_CTUL'] = ('integer',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI026_CTUU'] = ('integer',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI031S_URI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZI039S_UFI'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZSAX_RS0'] = ('CodeList',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZSAX_RX0'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZSAX_RX3'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZSAX_RX4'] = ('StructuredText',('FA015'))
    field_information['GGDM 3.0']['FIRING_RANGE_S']['ZVH'] = ('Real',('FA015'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['AOO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ARA'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['BEN'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['CAA'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['CAA']['BH051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['CNCP'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['COS'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['COS']['BH051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['FUFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['FURL'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['GDBV'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['GDBV']['BH051']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['LMC'] = ('Boolean',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['LZN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['OTH'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['PCF'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['PPO'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['PPO2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['PPO3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['VLM'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['WID'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['BH051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI005_FNA'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI005_NFN'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI006_MEM'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI020_GE4'] = ('CodeList',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_ASE'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_CFR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_CLO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_CYN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_FMR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_FRR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_HAR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_HYP'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_HYP']['BH051']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_MGN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_PHW'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_SCC'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_SCC']['BH051']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_SUL'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_TDS'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_TEP'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_TUR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WAC'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WTNO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WUR'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WUR2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WUR3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_WUR4'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI024_YWQ'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH051']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI026_CTUL'] = ('integer',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI026_CTUU'] = ('integer',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['AOO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ARA'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['BEN'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['CAA'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['CAA']['BH051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['CNCP'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['COS'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['COS']['BH051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['FUFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['FURL'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['GDBV'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['GDBV']['BH051']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['LMC'] = ('Boolean',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['LZN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['OTH'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['PCF'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['PPO'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['PPO2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['PPO3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['VLM'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['WID'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['BH051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI005_FNA'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI005_NFN'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI006_MEM'] = ('String',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI020_GE4'] = ('CodeList',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_ASE'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_CFR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_CLO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_CYN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_FMR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_FRR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_HAR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_HYP'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_HYP']['BH051']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_MGN'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_PHW'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_SCC'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_SCC']['BH051']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_SUL'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_TDS'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_TEP'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_TUR'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WAC'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WTNO'] = ('Real',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WUR'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WUR2'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WUR3'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_WUR4'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI024_YWQ'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH051']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI026_CTUL'] = ('integer',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI026_CTUU'] = ('integer',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_FARM_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('BH051'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ARA'] = ('Real',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['BEN'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['CNCP'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['COS'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['COS']['BI060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FISH_LADDER_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['FUFI'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['FURL'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['GDBV'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['GDBV']['BI060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISH_LADDER_C']['LZN'] = ('Real',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['OTH'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['PCF'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['PCF']['BI060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISH_LADDER_C']['UFI'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['WID'] = ('Real',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI001_SDV'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI001_SRT'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI001_SRT']['BI060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI002_UFI'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI004_RCG'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI004_RCG']['BI060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI005_FNA'] = ('String',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI005_GNT'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI005_GNT']['BI060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI005_NFN'] = ('String',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI006_MEM'] = ('String',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI020_GE4'] = ('CodeList',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI026_CTUC'] = ('Enumeration',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISH_LADDER_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI026_CTUL'] = ('integer',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI026_CTUU'] = ('integer',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI031S_URI'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZI039S_UFI'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZSAX_RS0'] = ('CodeList',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZSAX_RX0'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZSAX_RX3'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_LADDER_C']['ZSAX_RX4'] = ('StructuredText',('BI060'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['AOO'] = ('Real',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['BEN'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['CAA'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['CAA']['BB110']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['FISH_WEIR_P']['CNCP'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['COS'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['COS']['BB110']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FISH_WEIR_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['FUFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['FURL'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['GDBV'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['GDBV']['BB110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISH_WEIR_P']['LZN'] = ('Real',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['OTH'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['PCF'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['PCF']['BB110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISH_WEIR_P']['PSE'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI001_SDV'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI001_SRT'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI001_SRT']['BB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI002_UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI004_RCG'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI004_RCG']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI005_FNA'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI005_GNT'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI005_GNT']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI005_NFN'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI006_MEM'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI020_GE4'] = ('CodeList',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI026_CTUC'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI026_CTUL'] = ('integer',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI026_CTUU'] = ('integer',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI031S_URI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZI039S_UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZSAX_RS0'] = ('CodeList',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZSAX_RX0'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZSAX_RX3'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_P']['ZSAX_RX4'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['AOO'] = ('Real',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['BEN'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['CAA'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['CAA']['BB110']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['FISH_WEIR_S']['CNCP'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['COS'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['COS']['BB110']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['FISH_WEIR_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['FUFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['FURL'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['GDBV'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['GDBV']['BB110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISH_WEIR_S']['LZN'] = ('Real',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['OTH'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['PCF'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['PCF']['BB110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISH_WEIR_S']['PSE'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI001_SDV'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI001_SRT'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI001_SRT']['BB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI002_UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI004_RCG'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI004_RCG']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI005_FNA'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI005_GNT'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI005_GNT']['BB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI005_NFN'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI006_MEM'] = ('String',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI020_GE4'] = ('CodeList',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI026_CTUC'] = ('Enumeration',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISH_WEIR_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI026_CTUL'] = ('integer',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI026_CTUU'] = ('integer',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI031S_URI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZI039S_UFI'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZSAX_RS0'] = ('CodeList',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZSAX_RX0'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZSAX_RX3'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISH_WEIR_S']['ZSAX_RX4'] = ('StructuredText',('BB110'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ARA'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['BEN'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['F_CODE'] = ('CONSTRAINED_STRING',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['FUFI'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['FURL'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['GDBV'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['GDBV']['BB100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['HGT'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['LZN'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['OTH'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['PCF'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['PCF']['BB100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['UFI'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['WID'] = ('Real',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI001_SDV'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI001_SRT'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI001_SRT']['BB100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI002_UFI'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI004_RCG'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI004_RCG']['BB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI005_FNA'] = ('String',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI005_GNT'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI005_GNT']['BB100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI005_NFN'] = ('String',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI006_MEM'] = ('String',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI020_GE4'] = ('CodeList',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI026_CTUC'] = ('Enumeration',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FISHING_STAKES_C']['EnumeratedIndexValues']['ZI026_CTUC']['BB100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI026_CTUL'] = ('integer',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI026_CTUU'] = ('integer',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI031S_URI'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZI039S_UFI'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZSAX_RS0'] = ('CodeList',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZSAX_RX0'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZSAX_RX3'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FISHING_STAKES_C']['ZSAX_RX4'] = ('StructuredText',('BB100'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['AWP'] = ('Boolean',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['BEN'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['FUFI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['FURL'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['GDBV'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['GDBV']['AL073']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLAGPOLE_P']['HEI'] = ('Real',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['HGT'] = ('Real',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['LMC'] = ('Boolean',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['OTH'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['PCF'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['PCF']['AL073']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLAGPOLE_P']['UFI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['VOI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI001_SDV'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI001_SRT'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL073']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI002_UFI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI004_RCG'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL073']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI005_FNA'] = ('String',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI005_GNT'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL073']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI005_NFN'] = ('String',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI006_MEM'] = ('String',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI020_GE4'] = ('CodeList',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI026_CTUC'] = ('Enumeration',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLAGPOLE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL073']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI026_CTUL'] = ('integer',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI026_CTUU'] = ('integer',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI031S_URI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZI039S_UFI'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZSAX_RS0'] = ('CodeList',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZSAX_RX0'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZSAX_RX3'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZSAX_RX4'] = ('StructuredText',('AL073'))
    field_information['GGDM 3.0']['FLAGPOLE_P']['ZVH'] = ('Real',('AL073'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['AOO'] = ('Real',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['AWP'] = ('Boolean',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['BEN'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['CAA'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['CAA']['AF070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['CNCP'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['COS'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['COS']['AF070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['FUFI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['FURL'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['GDBV'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['GDBV']['AF070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['GUG'] = ('Boolean',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['HGT'] = ('Real',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['LMC'] = ('Boolean',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['LZN'] = ('Real',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['OTH'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['PCF'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['PCF']['AF070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['SRL'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['SRL']['AF070']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['UFI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['VCM'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['VCM2'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM2']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['VCM3'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['VCM3']['AF070']  = (-999999,4,8,9,15,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['VOI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['WID'] = ('Real',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI001_SDV'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI001_SRT'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI001_SRT']['AF070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI002_UFI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI004_RCG'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI004_RCG']['AF070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI006_MEM'] = ('String',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI020_GE4'] = ('CodeList',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI026_CTUC'] = ('Enumeration',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLARE_PIPE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI026_CTUL'] = ('integer',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI026_CTUU'] = ('integer',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI031S_URI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZI039S_UFI'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZSAX_RS0'] = ('CodeList',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZSAX_RX0'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZSAX_RX3'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZSAX_RX4'] = ('StructuredText',('AF070'))
    field_information['GGDM 3.0']['FLARE_PIPE_P']['ZVH'] = ('Real',('AF070'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['AOO'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ARA'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['BEN'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['CAA'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['CAA']['BB199']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['CNCP'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['COS'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['COS']['BB199']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['DZP'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['FUFI'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['FURL'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['GDBV'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['GDBV']['BB199']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['HGT'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['LMC'] = ('Boolean',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['LZN'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['MCC'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['MCC']['BB199']  = (-999999,107,117,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['MCC2'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['MCC2']['BB199']  = (-999999,107,117,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['MWD'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['OTH'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['PCF'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['PCF']['BB199']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['UFI'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['WID'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI001_SDV'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI001_SRT'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI001_SRT']['BB199']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI002_UFI'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI004_RCG'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI004_RCG']['BB199']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI005_FNA'] = ('String',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI005_GNT'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI005_GNT']['BB199']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI005_NFN'] = ('String',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI006_MEM'] = ('String',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI020_GE4'] = ('CodeList',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI026_CTUC'] = ('Enumeration',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB199']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI026_CTUL'] = ('integer',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI026_CTUU'] = ('integer',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI031S_URI'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZI039S_UFI'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZSAX_RS0'] = ('CodeList',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZSAX_RX0'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZSAX_RX3'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZSAX_RX4'] = ('StructuredText',('BB199'))
    field_information['GGDM 3.0']['FLOATING_DRY_DOCK_S']['ZVH'] = ('Real',('BB199'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['AOO'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ARA'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['BEN'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['CNCP'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['COS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['FUFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['FURL'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['GDBV'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['HDP'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['HGT'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['LZN'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['MCC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['MCC2'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['MCC3'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['OTH'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['PCF'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['WID'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI001_SDV'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI001_SRT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI002_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI004_RCG'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI005_FNA'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI005_GNT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI005_NFN'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI006_MEM'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI020_GE4'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI026_CTUC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI026_CTUL'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI026_CTUU'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI031S_URI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZI039S_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZSAX_RS0'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZSAX_RX0'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZSAX_RX3'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZSAX_RX4'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_C']['ZVH'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['AOO'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ARA'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['BEN'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['CNCP'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['COS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['FUFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['FURL'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['GDBV'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['HDP'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['HGT'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['LZN'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['MCC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['MCC2'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['MCC3'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['OTH'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['PCF'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['WID'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI005_FNA'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI005_GNT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI005_NFN'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI006_MEM'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI020_GE4'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI026_CTUL'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI026_CTUU'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_P']['ZVH'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['AOO'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ARA'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['BEN'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['CNCP'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['COS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['COS']['BI044']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['FCS'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['FCS'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['FUFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['FURL'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['GDBV'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['GDBV']['BI044']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['HDP'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['HGT'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['LZN'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['MCC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['MCC2'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['MCC3'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['OTH'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['PCF'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['WID'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['BI044']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI005_FNA'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI005_GNT'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT']['BI044']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI005_NFN'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI006_MEM'] = ('String',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI020_GE4'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI044']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI026_CTUL'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI026_CTUU'] = ('integer',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('BI044'))
    field_information['GGDM 3.0']['FLOOD_CONTROL_STRUCTURE_S']['ZVH'] = ('Real',('BI044'))
    field_information['GGDM 3.0']['FORD_C']['ARA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['BEN'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_C']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_C']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_C']['CIW'] = ('Boolean',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['CNCP'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['COS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FORD_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['FUFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['FURL'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['GDBV'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORD_C']['LZN'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['OTH'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['PCF'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FORD_C']['TRS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_C']['TRS2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_C']['TRS3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_C']['UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['WID'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI001_SDV'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI001_SRT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORD_C']['ZI002_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI004_RCG'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORD_C']['ZI005_FNA'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI005_GNT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORD_C']['ZI005_NFN'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI006_MEM'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI016_ROC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORD_C']['ZI020_GE4'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI026_CTUC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORD_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORD_C']['ZI026_CTUL'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI026_CTUU'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI031S_URI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZI039S_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZSAX_RS0'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZSAX_RX0'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZSAX_RX3'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_C']['ZSAX_RX4'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ARA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['BEN'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_P']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_P']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_P']['CIW'] = ('Boolean',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['CNCP'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['COS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FORD_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['FUFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['FURL'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['GDBV'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORD_P']['LZN'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['OTH'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['PCF'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FORD_P']['TRS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_P']['TRS2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_P']['TRS3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_P']['UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['WID'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI001_SDV'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI001_SRT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORD_P']['ZI002_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI004_RCG'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORD_P']['ZI005_FNA'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI005_GNT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORD_P']['ZI005_NFN'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI006_MEM'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI016_ROC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORD_P']['ZI020_GE4'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI026_CTUC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORD_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORD_P']['ZI026_CTUL'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI026_CTUU'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI031S_URI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZI039S_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZSAX_RS0'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZSAX_RX0'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZSAX_RX3'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_P']['ZSAX_RX4'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ARA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['BEN'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['BMC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_S']['BMC2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC2']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_S']['BMC3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['BMC3']['BH070']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['FORD_S']['CIW'] = ('Boolean',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['CNCP'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['COS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['COS']['BH070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FORD_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['FUFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['FURL'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['GDBV'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['GDBV']['BH070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORD_S']['LZN'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['OTH'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['PCF'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FORD_S']['TRS'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_S']['TRS2'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_S']['TRS3'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,9,13,18,23,999)
    field_information['GGDM 3.0']['FORD_S']['UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['WBD'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['WID'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['WVA'] = ('Real',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI001_SDV'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI001_SRT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI001_SRT']['BH070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORD_S']['ZI002_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI004_RCG'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI004_RCG']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORD_S']['ZI005_FNA'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI005_GNT'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI005_GNT']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORD_S']['ZI005_NFN'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI006_MEM'] = ('String',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI016_ROC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORD_S']['ZI020_GE4'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI026_CTUC'] = ('Enumeration',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORD_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORD_S']['ZI026_CTUL'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI026_CTUU'] = ('integer',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI031S_URI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZI039S_UFI'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZSAX_RS0'] = ('CodeList',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZSAX_RX0'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZSAX_RX3'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORD_S']['ZSAX_RX4'] = ('StructuredText',('BH070'))
    field_information['GGDM 3.0']['FORESHORE_S']['BEN'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['FUFI'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['FURL'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['GDBV'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['GDBV']['BA023']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_MCC1'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_MCC1'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_MCC1']['BA023']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_MCC2'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_MCC2'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_MCC2']['BA023']  = (-999999,4,7,8,10,12,14,15,16,18,22,24,25,28,36,37,45,46,49,52,55,58,59,61,63,65,66,69,70,73,75,79,80,81,84,88,90,92,96,98,99,103,104,105,106,108,111,115,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_PSC1'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_PSC1'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_PSC1']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_PSC2'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_PSC2'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_PSC2']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,17,18,19,20,21,22,23,24,25,26,27,29,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_SCO1'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_SCO1'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_SCO1']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['FORESHORE_S']['MBC_SCO2'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_SCO2'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['MBC_SCO2']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,999)
    field_information['GGDM 3.0']['FORESHORE_S']['OTH'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['STP'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['STP'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['STP']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['FORESHORE_S']['SWC'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['SWC'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['SWC']['BA023']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['FORESHORE_S']['UFI'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI001_SDV'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI001_SRT'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI001_SRT']['BA023']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORESHORE_S']['ZI002_UFI'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI004_RCG'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI004_RCG']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORESHORE_S']['ZI005_FNA'] = ('String',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI005_GNT'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI005_GNT']['BA023']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORESHORE_S']['ZI005_NFN'] = ('String',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI006_MEM'] = ('String',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI020_GE4'] = ('CodeList',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI026_CTUC'] = ('Enumeration',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORESHORE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BA023']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORESHORE_S']['ZI026_CTUL'] = ('integer',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI026_CTUU'] = ('integer',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI031S_URI'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZI039S_UFI'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZSAX_RS0'] = ('CodeList',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZSAX_RX0'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZSAX_RX3'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FORESHORE_S']['ZSAX_RX4'] = ('StructuredText',('BA023'))
    field_information['GGDM 3.0']['FOREST_C']['AOO'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ARA'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['BEN'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['DMBC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_C']['DMBL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['DMBU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['DMT'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['F_CODE'] = ('CONSTRAINED_STRING',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['FUFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['FURL'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['GDBV'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['GDBV']['EC015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOREST_C']['HGT'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['LMC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['LZN'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['OTH'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['PVH'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['SBC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['SDSC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_C']['SDSL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['SDSU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['TRE'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FOREST_C']['TSCC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_C']['TSCL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['TSCU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['VSP'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_C']['VSP2'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_C']['VSP3'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_C']['VTI'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['WID'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI001_SDV'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI001_SRT'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI001_SRT']['EC015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOREST_C']['ZI002_UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI004_RCG'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI004_RCG']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOREST_C']['ZI005_FNA'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI005_GNT'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI005_GNT']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOREST_C']['ZI005_NFN'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI006_MEM'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI020_GE4'] = ('CodeList',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI026_CTUC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOREST_C']['EnumeratedIndexValues']['ZI026_CTUC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_C']['ZI026_CTUL'] = ('integer',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI026_CTUU'] = ('integer',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI031S_URI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZI039S_UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZSAX_RS0'] = ('CodeList',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZSAX_RX0'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZSAX_RX3'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZSAX_RX4'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_C']['ZVH'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ARA'] = ('Real',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['BEN'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['FUFI'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['FURL'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['GDBV'] = ('Enumeration',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['GDBV']['EC060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['LZN'] = ('Real',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['OTH'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['TWS'] = ('Boolean',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['UFI'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['WID'] = ('Real',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI001_SDV'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI001_SRT'] = ('Enumeration',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI001_SRT']['EC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI002_UFI'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI004_RCG'] = ('Enumeration',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI004_RCG']['EC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI005_FNA'] = ('String',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI005_GNT'] = ('Enumeration',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI005_GNT']['EC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI005_NFN'] = ('String',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI006_MEM'] = ('String',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI020_GE4'] = ('CodeList',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI026_CTUC'] = ('Enumeration',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI026_CTUL'] = ('integer',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI026_CTUU'] = ('integer',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI031S_URI'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZI039S_UFI'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZSAX_RS0'] = ('CodeList',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZSAX_RX0'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZSAX_RX3'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_CLEARING_S']['ZSAX_RX4'] = ('StructuredText',('EC060'))
    field_information['GGDM 3.0']['FOREST_S']['AOO'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ARA'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['BEN'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['DMBC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_S']['DMBL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['DMBU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['DMT'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['FUFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['FURL'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['GDBV'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['GDBV']['EC015']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOREST_S']['HGT'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['LMC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['LZN'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['OTH'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['PVH'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['SBC'] = ('Boolean',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['SDSC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_S']['SDSL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['SDSU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['TRE'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FOREST_S']['TSCC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_S']['TSCL'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['TSCU'] = ('real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['VSP'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_S']['VSP2'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_S']['VSP3'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,8,25,999)
    field_information['GGDM 3.0']['FOREST_S']['VTI'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['WID'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI001_SDV'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI001_SRT'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI001_SRT']['EC015']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOREST_S']['ZI002_UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI004_RCG'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI004_RCG']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOREST_S']['ZI005_FNA'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI005_GNT'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI005_GNT']['EC015']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOREST_S']['ZI005_NFN'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI006_MEM'] = ('String',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI020_GE4'] = ('CodeList',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI026_CTUC'] = ('Enumeration',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOREST_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOREST_S']['ZI026_CTUL'] = ('integer',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI026_CTUU'] = ('integer',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI031S_URI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZI039S_UFI'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZSAX_RS0'] = ('CodeList',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZSAX_RX0'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZSAX_RX3'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZSAX_RX4'] = ('StructuredText',('EC015'))
    field_information['GGDM 3.0']['FOREST_S']['ZVH'] = ('Real',('EC015'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ADR'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['AOO'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ARA'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ATB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['AWP'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['BEN'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['BNF'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['CAA'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['CNCP'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['COS'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['COS']['AH055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FFN'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FFN2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FFN3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FUFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FURL'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['FZR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FZR'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['GDBV'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['GDBV']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['HGT'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['HST'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['HST2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['HST3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['LMC'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['LZN'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['MUB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['OTH'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['PCF'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['RLE'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['RLE']['AH055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['SSR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['SSR2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['SSR3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['VCM'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['VCM2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['VCM3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['VOI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['WID'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['WPST'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['WTYP'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['WTYP']['AH055']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['YSU'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI001_SDV'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI001_SRT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI001_SRT']['AH055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI002_UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI004_RCG'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI004_RCG']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI005_FNA'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI005_GNT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI005_GNT']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI005_NFN'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI006_MEM'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI018_WIT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI020_GE4'] = ('CodeList',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI026_CTUC'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AH055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI026_CTUL'] = ('integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI026_CTUU'] = ('integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI031S_URI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZI039S_UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZSAX_RS0'] = ('CodeList',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZSAX_RX0'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZSAX_RX3'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZSAX_RX4'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_P']['ZVH'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ADR'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['AOO'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ARA'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ATB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['AWP'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['BEN'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['BNF'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['CAA'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['CNCP'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['COS'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['COS']['AH055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['F_CODE'] = ('CONSTRAINED_STRING',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FFN'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FFN2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FFN3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,559,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FUFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FURL'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['FZR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FZR'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['GDBV'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['GDBV']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['HGT'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['HST'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['HST2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['HST3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['LMC'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['LZN'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['MUB'] = ('Boolean',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['OTH'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['PCF'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['RLE'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['RLE']['AH055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['SSR'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['SSR2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['SSR3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['VCM'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['VCM2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['VCM3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['VOI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['WID'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['WPST'] = ('Integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['WTYP'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['WTYP'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['WTYP']['AH055']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['YSU'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI001_SDV'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI001_SRT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI001_SRT']['AH055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI002_UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI004_RCG'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI004_RCG']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI005_FNA'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI005_GNT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI005_GNT']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI005_NFN'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI006_MEM'] = ('String',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI018_WIT'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI020_GE4'] = ('CodeList',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI026_CTUC'] = ('Enumeration',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['EnumeratedIndexValues']['ZI026_CTUC']['AH055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI026_CTUL'] = ('integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI026_CTUU'] = ('integer',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI031S_URI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZI039S_UFI'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZSAX_RS0'] = ('CodeList',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZSAX_RX0'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZSAX_RX3'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZSAX_RX4'] = ('StructuredText',('AH055'))
    field_information['GGDM 3.0']['FORTIFIED_BUILDING_S']['ZVH'] = ('Real',('AH055'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ARA'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['BEN'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['DTN'] = ('Boolean',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['FUFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['FURL'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['GDBV'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['GDBV']['BD050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOUL_GROUND_P']['LZN'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['OTH'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['WID'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI001_SDV'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI001_SRT'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI001_SRT']['BD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI002_UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI004_RCG'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI004_RCG']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI005_FNA'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI005_GNT'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI005_GNT']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI005_NFN'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI006_MEM'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI020_GE4'] = ('CodeList',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI026_CTUC'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI026_CTUL'] = ('integer',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI026_CTUU'] = ('integer',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI031S_URI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZI039S_UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZSAX_RS0'] = ('CodeList',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZSAX_RX0'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZSAX_RX3'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_P']['ZSAX_RX4'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ARA'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['BEN'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['DTN'] = ('Boolean',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['FUFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['FURL'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['GDBV'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['GDBV']['BD050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOUL_GROUND_S']['LZN'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['OTH'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['WID'] = ('Real',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI001_SDV'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI001_SRT'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI001_SRT']['BD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI002_UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI004_RCG'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI004_RCG']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI005_FNA'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI005_GNT'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI005_GNT']['BD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI005_NFN'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI006_MEM'] = ('String',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI020_GE4'] = ('CodeList',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI026_CTUC'] = ('Enumeration',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOUL_GROUND_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI026_CTUL'] = ('integer',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI026_CTUU'] = ('integer',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI031S_URI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZI039S_UFI'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZSAX_RS0'] = ('CodeList',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZSAX_RX0'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZSAX_RX3'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUL_GROUND_S']['ZSAX_RX4'] = ('StructuredText',('BD050'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ARA'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['BEN'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['CAA'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['CAA']['BH075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['CNCP'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['COS'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['COS']['BH075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FOUNTAIN_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['FUFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['FURL'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['GDBV'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['GDBV']['BH075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['HGT'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['LMC'] = ('Boolean',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['LZN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['OTH'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['PCF'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FOUNTAIN_P']['UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['VLM'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['WID'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI001_SDV'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI001_SRT'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI001_SRT']['BH075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI002_UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI004_RCG'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI004_RCG']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI005_FNA'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI005_GNT'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI005_GNT']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI005_NFN'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI006_MEM'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI020_GE4'] = ('CodeList',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_ASE'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_CFR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_CLO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_CYN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_FMR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_FRR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_HAR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_MGN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_PHW'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_SCC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_SCC']['BH075']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_SUL'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_TDS'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_TEP'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_TUR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WAC'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WTNO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WUR'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WUR2'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WUR3'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_WUR4'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI026_CTUC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI026_CTUL'] = ('integer',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI026_CTUU'] = ('integer',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI031S_URI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZI039S_UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZSAX_RS0'] = ('CodeList',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZSAX_RX0'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZSAX_RX3'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZSAX_RX4'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_P']['ZVH'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ARA'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['BEN'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['CAA'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['CAA']['BH075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['CNCP'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['COS'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['COS']['BH075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FOUNTAIN_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['FUFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['FURL'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['GDBV'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['GDBV']['BH075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['HGT'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['LMC'] = ('Boolean',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['LZN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['OTH'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['PCF'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FOUNTAIN_S']['UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['VLM'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['WID'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI001_SDV'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI001_SRT'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI001_SRT']['BH075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI002_UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI004_RCG'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI004_RCG']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI005_FNA'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI005_GNT'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI005_GNT']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI005_NFN'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI006_MEM'] = ('String',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI020_GE4'] = ('CodeList',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_ASE'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_CFR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_CLO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_CYN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_FMR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_FRR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_HAR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_MGN'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_PHW'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_SCC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_SCC']['BH075']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_SUL'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_TDS'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_TEP'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_TUR'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WAC'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WTNO'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WUR'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WUR2'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WUR3'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_WUR4'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI026_CTUC'] = ('Enumeration',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FOUNTAIN_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI026_CTUL'] = ('integer',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI026_CTUU'] = ('integer',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI031S_URI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZI039S_UFI'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZSAX_RS0'] = ('CodeList',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZSAX_RX0'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZSAX_RX3'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZSAX_RX4'] = ('StructuredText',('BH075'))
    field_information['GGDM 3.0']['FOUNTAIN_S']['ZVH'] = ('Real',('BH075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ADR'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['AOO'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ARA'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['BEN'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['CAA'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['CNCP'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['COS'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['COS']['AM075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['FFN'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['FFN2'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['FFN3'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['FUFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['FURL'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['GDBV'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AM075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['HGT'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['LMC'] = ('Boolean',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['LUN'] = ('Boolean',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['LZN'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['OTH'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['PCF'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['WID'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AM075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI005_FNA'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI005_NFN'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI006_MEM'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI026_CTUL'] = ('integer',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI026_CTUU'] = ('integer',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_P']['ZVH'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ADR'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['AOO'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ARA'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['BEN'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['CAA'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['CNCP'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['COS'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['COS']['AM075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['FFN'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['FFN2'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['FFN3'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['FUFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['FURL'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['GDBV'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AM075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['HGT'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['LMC'] = ('Boolean',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['LUN'] = ('Boolean',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['LZN'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['OTH'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['PCF'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['WID'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AM075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI005_FNA'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AM075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI005_NFN'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI006_MEM'] = ('String',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI026_CTUL'] = ('integer',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI026_CTUU'] = ('integer',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AM075'))
    field_information['GGDM 3.0']['FUEL_STORAGE_FACILITY_S']['ZVH'] = ('Real',('AM075'))
    field_information['GGDM 3.0']['GANTRY_C']['AOO'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ARA'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['AWP'] = ('Boolean',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['BEN'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['CAA'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['CAA']['AL080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GANTRY_C']['CNCP'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['COS'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['COS']['AL080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GANTRY_C']['CRM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['GANTRY_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['FFN'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_C']['FFN2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_C']['FFN3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_C']['FUFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['FURL'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['GDBV'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['GDBV']['AL080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GANTRY_C']['HGT'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['LMC'] = ('Boolean',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['LZN'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['OTH'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['PCF'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GANTRY_C']['UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['VCM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_C']['VCM2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_C']['VCM3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_C']['VOI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['WID'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI001_SDV'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI001_SRT'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI001_SRT']['AL080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GANTRY_C']['ZI002_UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI004_RCG'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI004_RCG']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GANTRY_C']['ZI006_MEM'] = ('String',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI020_GE4'] = ('CodeList',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI026_CTUC'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GANTRY_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GANTRY_C']['ZI026_CTUL'] = ('integer',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI026_CTUU'] = ('integer',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI031S_URI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZI039S_UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZSAX_RS0'] = ('CodeList',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZSAX_RX0'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZSAX_RX3'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZSAX_RX4'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_C']['ZVH'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['AOO'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ARA'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['AWP'] = ('Boolean',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['BEN'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['CAA'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['CAA']['AL080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GANTRY_P']['CNCP'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['COS'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['COS']['AL080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GANTRY_P']['CRM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['CRM'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['GANTRY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['FFN'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_P']['FFN2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_P']['FFN3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['GGDM 3.0']['GANTRY_P']['FUFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['FURL'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['GDBV'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['GDBV']['AL080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GANTRY_P']['HGT'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['LMC'] = ('Boolean',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['LZN'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['OTH'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['PCF'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GANTRY_P']['UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['VCM'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_P']['VCM2'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_P']['VCM3'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['GGDM 3.0']['GANTRY_P']['VOI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['WID'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI001_SDV'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI001_SRT'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI001_SRT']['AL080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GANTRY_P']['ZI002_UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI004_RCG'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI004_RCG']['AL080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GANTRY_P']['ZI006_MEM'] = ('String',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI020_GE4'] = ('CodeList',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI026_CTUC'] = ('Enumeration',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GANTRY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GANTRY_P']['ZI026_CTUL'] = ('integer',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI026_CTUU'] = ('integer',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI031S_URI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZI039S_UFI'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZSAX_RS0'] = ('CodeList',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZSAX_RX0'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZSAX_RX3'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZSAX_RX4'] = ('StructuredText',('AL080'))
    field_information['GGDM 3.0']['GANTRY_P']['ZVH'] = ('Real',('AL080'))
    field_information['GGDM 3.0']['GATE_C']['AOO'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['BEN'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['CAA'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GATE_C']['CNCP'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['COS'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['COS']['AP040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GATE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['FFN'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_C']['FFN2'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_C']['FFN3'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_C']['FUFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['FURL'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['GDBV'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['GDBV']['AP040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GATE_C']['GTC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['GTC'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['GATE_C']['HGT'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['LZN'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['OTH'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['PCF'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GATE_C']['THI'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['TRS'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_C']['TRS2'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_C']['TRS3'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_C']['UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['WD2'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI001_SDV'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI001_SRT'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI001_SRT']['AP040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GATE_C']['ZI002_UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI004_RCG'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI004_RCG']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GATE_C']['ZI005_FNA'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI005_GNT'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI005_GNT']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GATE_C']['ZI005_NFN'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI006_MEM'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI020_GE4'] = ('CodeList',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI026_CTUC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GATE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GATE_C']['ZI026_CTUL'] = ('integer',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI026_CTUU'] = ('integer',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI031S_URI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZI039S_UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZSAX_RS0'] = ('CodeList',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZSAX_RX0'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZSAX_RX3'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_C']['ZSAX_RX4'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['AOO'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['BEN'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['CAA'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GATE_P']['CNCP'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['COS'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['COS']['AP040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GATE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['FFN'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_P']['FFN2'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_P']['FFN3'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['GGDM 3.0']['GATE_P']['FUFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['FURL'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['GDBV'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['GDBV']['AP040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GATE_P']['GTC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['GTC'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['GATE_P']['HGT'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['LZN'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['OTH'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['PCF'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GATE_P']['THI'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['TRS'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_P']['TRS2'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_P']['TRS3'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,3,9,12,13,16,999)
    field_information['GGDM 3.0']['GATE_P']['UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['WD2'] = ('Real',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI001_SDV'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI001_SRT'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI001_SRT']['AP040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GATE_P']['ZI002_UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI004_RCG'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI004_RCG']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GATE_P']['ZI005_FNA'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI005_GNT'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI005_GNT']['AP040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GATE_P']['ZI005_NFN'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI006_MEM'] = ('String',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI020_GE4'] = ('CodeList',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI026_CTUC'] = ('Enumeration',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GATE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AP040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GATE_P']['ZI026_CTUL'] = ('integer',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI026_CTUU'] = ('integer',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI031S_URI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZI039S_UFI'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZSAX_RS0'] = ('CodeList',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZSAX_RX0'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZSAX_RX3'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GATE_P']['ZSAX_RX4'] = ('StructuredText',('AP040'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['BEN'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['CAA'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['CAA']['BI070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['CNCP'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['COS'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['COS']['BI070']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['DZP'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['FUFI'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['FURL'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['GDBV'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['GDBV']['BI070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['OTH'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['PCF'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['PCF']['BI070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['PWAC'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['PWAC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['PWAL'] = ('real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['PWAU'] = ('real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['UFI'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WDAC'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['WDAC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WDAL'] = ('real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WDAU'] = ('real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WDH'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WDL'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WVA'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WVH'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['WVL'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI001_SDV'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI001_SRT'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['BI070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI002_UFI'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI004_RCG'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_FNA'] = ('String',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_FNA2'] = ('String',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_GNT'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_GNT2'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT2']['BI070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_NFN'] = ('String',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI005_NFN2'] = ('String',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI006_MEM'] = ('String',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI020_GE4'] = ('CodeList',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_ASE'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_AWO'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_AWOI'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_AWOX'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_CFR'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_CLO'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_CYN'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_FMR'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_FRR'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_HAR'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_MGN'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_PHW'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_SCC'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI024_SCC']['BI070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_SUL'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_TDS'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_TEP'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_TUR'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_WAC'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI024_WTNO'] = ('Real',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI026_CTUC'] = ('Enumeration',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GAUGING_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI026_CTUL'] = ('integer',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI026_CTUU'] = ('integer',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI031S_URI'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZI039S_UFI'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZSAX_RS0'] = ('CodeList',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZSAX_RX0'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZSAX_RX3'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GAUGING_STATION_P']['ZSAX_RX4'] = ('StructuredText',('BI070'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['BEN'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['CPA'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['CPA'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['CPA']['ZB060']  = (-999999,1,2,3,5)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['FUFI'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['FURL'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['GDBV'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['GDBV']['ZB060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['OTH'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['UFI'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI001_SDV'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI001_SRT'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['ZB060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI002_UFI'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI004_RCG'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['ZB060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI005_FNA'] = ('String',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI005_GNT'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['ZB060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI005_NFN'] = ('String',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI006_MEM'] = ('String',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI020_GE4'] = ('CodeList',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI026_CTUC'] = ('Enumeration',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZB060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI026_CTUL'] = ('integer',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI026_CTUU'] = ('integer',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI031S_URI'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZI039S_UFI'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZSAX_RS0'] = ('CodeList',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZSAX_RX0'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZSAX_RX3'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZSAX_RX4'] = ('StructuredText',('ZB060'))
    field_information['GGDM 3.0']['GEODETIC_POINT_P']['ZVH'] = ('Real',('ZB060'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ARA'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['BEN'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['FDI'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['FUFI'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['FURL'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['GDBV'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['GDBV']['DB110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['GFT'] = ('Boolean',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['GFY'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['GFY'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['GFY']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['LZN'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['OTH'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['SDI'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['UFI'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['WID'] = ('Real',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI001_SDV'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI001_SRT'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI001_SRT']['DB110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI002_UFI'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI004_RCG'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI004_RCG']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI005_FNA'] = ('String',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI005_GNT'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI005_GNT']['DB110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI005_NFN'] = ('String',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI006_MEM'] = ('String',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI020_GE4'] = ('CodeList',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI026_CTUC'] = ('Enumeration',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI026_CTUL'] = ('integer',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI026_CTUU'] = ('integer',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI031S_URI'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZI039S_UFI'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZSAX_RS0'] = ('CodeList',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZSAX_RX0'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZSAX_RX3'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOLOGIC_FAULT_C']['ZSAX_RX4'] = ('StructuredText',('DB110'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ARA'] = ('Real',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['BEN'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['FUFI'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['FURL'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['GDBV'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['GDBV']['FA002']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['GEC'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['GEC'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['GEC']['FA002']  = (-999999,5,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['OTH'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['UFI'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI001_SDV'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI001_SRT'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI001_SRT']['FA002']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI002_UFI'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI004_RCG'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI004_RCG']['FA002']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI005_FNA'] = ('String',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI005_GNT'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI005_GNT']['FA002']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI005_NFN'] = ('String',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI006_MEM'] = ('String',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI020_GE4'] = ('CodeList',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI020_IC4'] = ('String',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI026_CTUC'] = ('Enumeration',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA002']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI026_CTUL'] = ('integer',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI026_CTUU'] = ('integer',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI031S_URI'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZI039S_UFI'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZSAX_RS0'] = ('CodeList',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZSAX_RX0'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZSAX_RX3'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOPOLITICAL_ENTITY_S']['ZSAX_RX4'] = ('StructuredText',('FA002'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['AQN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ARA'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['BEN'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['CAA'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['CAA']['DB115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['DOF'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['FUFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['FURL'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['GDBV'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['GDBV']['DB115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['GOT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['GOT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['LMC'] = ('Boolean',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['LZN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['OTH'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['WID'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI001_SDV'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI001_SRT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI001_SRT']['DB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI002_UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI004_RCG'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI004_RCG']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_FNA'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_FNA2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_FNA3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_GNT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_GNT2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_GNT3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI005_GNT3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_NFN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_NFN2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI005_NFN3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI006_MEM'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI020_GE4'] = ('CodeList',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_ASE'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_AWO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_AWOI'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_AWOX'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_CFR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_CLO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_CYN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_FMR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_FRR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_HAR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_HYP'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_HYP']['DB115']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_MGN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_PHW'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_SCC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_SCC']['DB115']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_SUL'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_TDS'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_TEP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_TUR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WAC'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WTNO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WUR'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WUR2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WUR3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_WUR4'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_WUR4']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI024_YWQ'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI024_YWQ']['DB115']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI025_HDP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI026_CTUC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI026_CTUL'] = ('integer',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI026_CTUU'] = ('integer',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI031S_URI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZI039S_UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZSAX_RS0'] = ('CodeList',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZSAX_RX0'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZSAX_RX3'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_P']['ZSAX_RX4'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['AQN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ARA'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['BEN'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['CAA'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['CAA']['DB115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['DOF'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['FUFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['FURL'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['GDBV'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['GDBV']['DB115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['GOT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['GOT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['LMC'] = ('Boolean',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['LZN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['OTH'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['WID'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI001_SDV'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI001_SRT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI001_SRT']['DB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI002_UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI004_RCG'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI004_RCG']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_FNA'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_FNA2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_FNA3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_GNT'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_GNT2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_GNT3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI005_GNT3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_NFN'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_NFN2'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI005_NFN3'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI006_MEM'] = ('String',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI020_GE4'] = ('CodeList',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_ASE'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_AWO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_AWOI'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_AWOX'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_CFR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_CLO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_CYN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_FMR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_FRR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_HAR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_HYP'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_HYP']['DB115']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_MGN'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_PHW'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_SCC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_SCC']['DB115']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_SUL'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_TDS'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_TEP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_TUR'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WAC'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WTNO'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WUR'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WUR2'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR2']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WUR3'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR3']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_WUR4'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_WUR4']['DB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI024_YWQ'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI024_YWQ']['DB115']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI025_HDP'] = ('Real',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI026_CTUC'] = ('Enumeration',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI026_CTUL'] = ('integer',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI026_CTUU'] = ('integer',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI031S_URI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZI039S_UFI'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZSAX_RS0'] = ('CodeList',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZSAX_RX0'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZSAX_RX3'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GEOTHERMAL_OUTLET_S']['ZSAX_RX4'] = ('StructuredText',('DB115'))
    field_information['GGDM 3.0']['GLACIER_S']['ARA'] = ('Real',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['BEN'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['FUFI'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['FURL'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['GDBV'] = ('Enumeration',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['GDBV']['BJ030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GLACIER_S']['LZN'] = ('Real',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['OTH'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['UFI'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['WID'] = ('Real',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI001_SDV'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI001_SRT'] = ('Enumeration',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GLACIER_S']['ZI002_UFI'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI004_RCG'] = ('Enumeration',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GLACIER_S']['ZI005_FNA'] = ('String',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI005_GNT'] = ('Enumeration',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GLACIER_S']['ZI005_NFN'] = ('String',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI006_MEM'] = ('String',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI020_GE4'] = ('CodeList',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI026_CTUC'] = ('Enumeration',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GLACIER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GLACIER_S']['ZI026_CTUL'] = ('integer',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI026_CTUU'] = ('integer',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI031S_URI'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZI039S_UFI'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZSAX_RS0'] = ('CodeList',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZSAX_RX0'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZSAX_RX3'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZSAX_RX4'] = ('StructuredText',('BJ030'))
    field_information['GGDM 3.0']['GLACIER_S']['ZVH'] = ('Real',('BJ030'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ADR'] = ('String',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['AOO'] = ('Real',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ARA'] = ('Real',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['BEN'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['CAA'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['CAA']['AK100']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['CNCP'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['COS'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['COS']['AK100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['FUFI'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['FURL'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['GDBV'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['GDBV']['AK100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['LMC'] = ('Boolean',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['LZN'] = ('Real',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['OTH'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['PCF'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['PCF']['AK100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['UFI'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['WID'] = ('Real',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI001_SDV'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI001_SRT'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI002_UFI'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI004_RCG'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI005_FNA'] = ('String',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI005_GNT'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI005_NFN'] = ('String',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI006_MEM'] = ('String',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI020_GE4'] = ('CodeList',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI026_CTUC'] = ('Enumeration',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GOLF_COURSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI026_CTUL'] = ('integer',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI026_CTUU'] = ('integer',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI031S_URI'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZI039S_UFI'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZSAX_RS0'] = ('CodeList',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZSAX_RX0'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZSAX_RX3'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_COURSE_S']['ZSAX_RX4'] = ('StructuredText',('AK100'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ADR'] = ('String',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ARA'] = ('Real',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['BEN'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['CNCP'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['COS'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['COS']['AK101']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['FUFI'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['FURL'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['GDBV'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['GDBV']['AK101']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['LMC'] = ('Boolean',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['LZN'] = ('Real',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['OTH'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['PCF'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['PCF']['AK101']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['UFI'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['WID'] = ('Real',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI001_SDV'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI001_SRT'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK101']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI002_UFI'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI004_RCG'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK101']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI005_FNA'] = ('String',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI005_GNT'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK101']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI005_NFN'] = ('String',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI006_MEM'] = ('String',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI020_GE4'] = ('CodeList',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI026_CTUC'] = ('Enumeration',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK101']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI026_CTUL'] = ('integer',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI026_CTUU'] = ('integer',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI031S_URI'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZI039S_UFI'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZSAX_RS0'] = ('CodeList',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZSAX_RX0'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZSAX_RX3'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GOLF_DRIVING_RANGE_S']['ZSAX_RX4'] = ('StructuredText',('AK101'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ADR'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['AOO'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ARA'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['AWP'] = ('Boolean',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['BEN'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['CAA'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['CAA']['AM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['CNCP'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['COS'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['COS']['AM030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['FUFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['FURL'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['GDBV'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['GDBV']['AM030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['HGT'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['LMC'] = ('Boolean',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['LZN'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['OTH'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['PCF'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['SSR'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['SSR2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['SSR3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['VCM'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['VCM2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['VCM3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['VOI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['WID'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI001_SDV'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI001_SRT'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI001_SRT']['AM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI002_UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI004_RCG'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI004_RCG']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI005_FNA'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI005_GNT'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI005_GNT']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI005_NFN'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI006_MEM'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI020_GE4'] = ('CodeList',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI026_CTUC'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI026_CTUL'] = ('integer',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI026_CTUU'] = ('integer',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI031S_URI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZI039S_UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZSAX_RS0'] = ('CodeList',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZSAX_RX0'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZSAX_RX3'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZSAX_RX4'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_P']['ZVH'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ADR'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['AOO'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ARA'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['AWP'] = ('Boolean',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['BEN'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['CAA'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['CAA']['AM030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['CNCP'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['COS'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['COS']['AM030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['FUFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['FURL'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['GDBV'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['GDBV']['AM030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['HGT'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['LMC'] = ('Boolean',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['LZN'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['OTH'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['PCF'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['SSR'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['SSR2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['SSR3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['VCM'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['VCM2'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['VCM3'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['VOI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['WID'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI001_SDV'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI001_SRT'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI001_SRT']['AM030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI002_UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI004_RCG'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI004_RCG']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI005_FNA'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI005_GNT'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI005_GNT']['AM030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI005_NFN'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI006_MEM'] = ('String',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI020_GE4'] = ('CodeList',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI026_CTUC'] = ('Enumeration',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI026_CTUL'] = ('integer',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI026_CTUU'] = ('integer',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI031S_URI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZI039S_UFI'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZSAX_RS0'] = ('CodeList',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZSAX_RX0'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZSAX_RX3'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZSAX_RX4'] = ('StructuredText',('AM030'))
    field_information['GGDM 3.0']['GRAIN_ELEVATOR_S']['ZVH'] = ('Real',('AM030'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['AOO'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ARA'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['AWP'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['BEN'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['CAA'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['CAA']['AM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['CNCP'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['COS'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['COS']['AM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['FUFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['FURL'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['GDBV'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['GDBV']['AM020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['HGT'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['LMC'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['LUN'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['LZN'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['OTH'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['PCF'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['SSR'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['SSR2'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['SSR3'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['VCM'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['VCM2'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['VCM3'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['VOI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['WID'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['AM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI005_FNA'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI005_GNT'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI005_NFN'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI006_MEM'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI020_GE4'] = ('CodeList',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI026_CTUL'] = ('integer',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI026_CTUU'] = ('integer',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_P']['ZVH'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['AOO'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ARA'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['AWP'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['BEN'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['CAA'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['CAA']['AM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['CNCP'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['COS'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['COS']['AM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['FUFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['FURL'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['GDBV'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AM020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['HGT'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['LMC'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['LUN'] = ('Boolean',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['LZN'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['OTH'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['PCF'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['SSR'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['SSR2'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['SSR3'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['VCM'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['VCM2'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['VCM3'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['VOI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['WID'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI005_FNA'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI005_GNT'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT']['AM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI005_NFN'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI006_MEM'] = ('String',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI026_CTUL'] = ('integer',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI026_CTUU'] = ('integer',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AM020'))
    field_information['GGDM 3.0']['GRAIN_STORAGE_STRUCTURE_S']['ZVH'] = ('Real',('AM020'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['AOO'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ARA'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['AWP'] = ('Boolean',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['BEN'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['CAA'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['CAA']['AK110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRANDSTAND_P']['CNCP'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['COS'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['COS']['AK110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRANDSTAND_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['FUFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['FURL'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['GDBV'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['GDBV']['AK110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRANDSTAND_P']['HGT'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['LMC'] = ('Boolean',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['LZN'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['OTH'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['PCF'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRANDSTAND_P']['UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['VOI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['WID'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI001_SDV'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI001_SRT'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI001_SRT']['AK110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI002_UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI004_RCG'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI004_RCG']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI005_FNA'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI005_GNT'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI005_GNT']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI005_NFN'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI006_MEM'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI020_GE4'] = ('CodeList',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI026_CTUC'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI026_CTUL'] = ('integer',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI026_CTUU'] = ('integer',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI031S_URI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZI039S_UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZSAX_RS0'] = ('CodeList',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZSAX_RX0'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZSAX_RX3'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZSAX_RX4'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_P']['ZVH'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['AOO'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ARA'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['AWP'] = ('Boolean',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['BEN'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['CAA'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['CAA']['AK110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GRANDSTAND_S']['CNCP'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['COS'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['COS']['AK110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GRANDSTAND_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['FUFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['FURL'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['GDBV'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['GDBV']['AK110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRANDSTAND_S']['HGT'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['LMC'] = ('Boolean',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['LZN'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['OTH'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['PCF'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GRANDSTAND_S']['UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['VOI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['WID'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI001_SDV'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI001_SRT'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI001_SRT']['AK110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI002_UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI004_RCG'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI004_RCG']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI005_FNA'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI005_GNT'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI005_GNT']['AK110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI005_NFN'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI006_MEM'] = ('String',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI020_GE4'] = ('CodeList',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI026_CTUC'] = ('Enumeration',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRANDSTAND_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI026_CTUL'] = ('integer',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI026_CTUU'] = ('integer',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI031S_URI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZI039S_UFI'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZSAX_RS0'] = ('CodeList',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZSAX_RX0'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZSAX_RX3'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZSAX_RX4'] = ('StructuredText',('AK110'))
    field_information['GGDM 3.0']['GRANDSTAND_S']['ZVH'] = ('Real',('AK110'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ARA'] = ('Real',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['BEN'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['F_CODE'] = ('CONSTRAINED_STRING',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['FFN'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['FFN2'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN2']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['FFN3'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['FFN3']['EB010']  = (-999999,14,907,921,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['FUFI'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['FURL'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['GDBV'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['GDBV']['EB010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['LZN'] = ('Real',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['OTH'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['TWS'] = ('Boolean',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['UFI'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['VEG'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['VEG'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['VEG']['EB010']  = (-999999,8,10,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['VTI'] = ('Real',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['WID'] = ('Real',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI001_SDV'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI001_SRT'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI001_SRT']['EB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI002_UFI'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI004_RCG'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI004_RCG']['EB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI005_FNA'] = ('String',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI005_GNT'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI005_GNT']['EB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI005_NFN'] = ('String',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI006_MEM'] = ('String',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI020_GE4'] = ('CodeList',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI026_CTUC'] = ('Enumeration',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GRASSLAND_S']['EnumeratedIndexValues']['ZI026_CTUC']['EB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI026_CTUL'] = ('integer',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI026_CTUU'] = ('integer',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI031S_URI'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZI039S_UFI'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZSAX_RS0'] = ('CodeList',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZSAX_RX0'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZSAX_RX3'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GRASSLAND_S']['ZSAX_RX4'] = ('StructuredText',('EB010'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ADR'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['AOO'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ARA'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ATB'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['BEN'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['CAA'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['CAA']['AJ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['CNCP'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['COS'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['COS']['AJ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GREENHOUSE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['FFN'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['FFN2'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['FFN3'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['FUFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['FURL'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['GDBV'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['GDBV']['AJ110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['HGT'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['LMC'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['LZN'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['OTH'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['PCF'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GREENHOUSE_P']['SSR'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['SSR2'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['SSR3'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['WID'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI001_SDV'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI001_SRT'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI002_UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI004_RCG'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI005_FNA'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI005_GNT'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI005_NFN'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI006_MEM'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI020_GE4'] = ('CodeList',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI026_CTUC'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI026_CTUL'] = ('integer',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI026_CTUU'] = ('integer',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI031S_URI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZI039S_UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZSAX_RS0'] = ('CodeList',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZSAX_RX0'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZSAX_RX3'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZSAX_RX4'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_P']['ZVH'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ADR'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['AOO'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ARA'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ATB'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['BEN'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['CAA'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['CAA']['AJ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['CNCP'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['COS'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['COS']['AJ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['GREENHOUSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['FFN'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['FFN2'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['FFN3'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['FUFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['FURL'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['GDBV'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['GDBV']['AJ110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['HGT'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['LMC'] = ('Boolean',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['LZN'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['OTH'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['PCF'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['GREENHOUSE_S']['SSR'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['SSR2'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['SSR3'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['WID'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI001_SDV'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI001_SRT'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI002_UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI004_RCG'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI005_FNA'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI005_GNT'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI005_NFN'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI006_MEM'] = ('String',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI020_GE4'] = ('CodeList',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI026_CTUC'] = ('Enumeration',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GREENHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI026_CTUL'] = ('integer',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI026_CTUU'] = ('integer',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI031S_URI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZI039S_UFI'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZSAX_RS0'] = ('CodeList',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZSAX_RX0'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZSAX_RX3'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZSAX_RX4'] = ('StructuredText',('AJ110'))
    field_information['GGDM 3.0']['GREENHOUSE_S']['ZVH'] = ('Real',('AJ110'))
    field_information['GGDM 3.0']['GROVE_P']['ARA'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['BEN'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['COA'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COA']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['GROVE_P']['COC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COC']['EC050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['GROVE_P']['COG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['COG']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['GROVE_P']['DMBC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['DMBC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_P']['DMBL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['DMBU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['DMT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['F_CODE'] = ('CONSTRAINED_STRING',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['FEO'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['FUFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['FURL'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['GDBV'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['GDBV']['EC050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GROVE_P']['HGT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['LMC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['LZN'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['OTH'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['PVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['SBC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['SDSC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['SDSC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_P']['SDSL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['SDSU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['STR'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['TRE'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['TRE']['EC050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['GROVE_P']['TSCC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['TSCC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_P']['TSCL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['TSCU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['VSP'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_P']['VSP2'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP2']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_P']['VSP3'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['VSP3']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_P']['VTI'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['WCL'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['WID'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI001_SDV'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI001_SRT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI001_SRT']['EC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GROVE_P']['ZI002_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI004_RCG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI004_RCG']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GROVE_P']['ZI005_FNA'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI005_GNT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI005_GNT']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GROVE_P']['ZI005_NFN'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI006_MEM'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI020_GE4'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI026_CTUC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GROVE_P']['EnumeratedIndexValues']['ZI026_CTUC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_P']['ZI026_CTUL'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI026_CTUU'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI031S_URI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZI039S_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZSAX_RS0'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZSAX_RX0'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZSAX_RX3'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZSAX_RX4'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_P']['ZVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ARA'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['BEN'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['COA'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COA']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['GROVE_S']['COC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COC']['EC050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['GROVE_S']['COG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['COG']['EC050']  = (-999999,2,4)
    field_information['GGDM 3.0']['GROVE_S']['DMBC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['DMBC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_S']['DMBL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['DMBU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['DMT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['FEO'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['FUFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['FURL'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['GDBV'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['GDBV']['EC050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['GROVE_S']['HGT'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['LMC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['LZN'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['OTH'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['PVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['SBC'] = ('Boolean',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['SDSC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['SDSC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_S']['SDSL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['SDSU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['STR'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['TRE'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['TRE']['EC050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['GROVE_S']['TSCC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['TSCC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_S']['TSCL'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['TSCU'] = ('real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['VSP'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_S']['VSP2'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP2']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_S']['VSP3'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['VSP3']['EC050']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['GROVE_S']['VTI'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['WCL'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['WID'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI001_SDV'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI001_SRT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI001_SRT']['EC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['GROVE_S']['ZI002_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI004_RCG'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI004_RCG']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['GROVE_S']['ZI005_FNA'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI005_GNT'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI005_GNT']['EC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['GROVE_S']['ZI005_NFN'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI006_MEM'] = ('String',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI020_GE4'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI026_CTUC'] = ('Enumeration',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['GROVE_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['GROVE_S']['ZI026_CTUL'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI026_CTUU'] = ('integer',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI031S_URI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZI039S_UFI'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZSAX_RS0'] = ('CodeList',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZSAX_RX0'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZSAX_RX3'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZSAX_RX4'] = ('StructuredText',('EC050'))
    field_information['GGDM 3.0']['GROVE_S']['ZVH'] = ('Real',('EC050'))
    field_information['GGDM 3.0']['HARBOUR_S']['ARA'] = ('Real',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['BEN'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['CAA'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['CAA']['BB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HARBOUR_S']['CNCP'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['COS'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['COS']['BB005']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['HARBOUR_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['FHC'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HARBOUR_S']['FHC2'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC2'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC2']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HARBOUR_S']['FHC3'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC3'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['FHC3']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['HARBOUR_S']['FUFI'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['FURL'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['GDBV'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['GDBV']['BB005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARBOUR_S']['LMC'] = ('Boolean',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['LZN'] = ('Real',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['OTH'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['PCF'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['PCF']['BB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HARBOUR_S']['TID'] = ('Boolean',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['UFI'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['WID'] = ('Real',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['WPI'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI001_SDV'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI001_SRT'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI001_SRT']['BB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HARBOUR_S']['ZI002_UFI'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI004_RCG'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI004_RCG']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_FNA'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_FNA2'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_GNT'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI005_GNT']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_GNT2'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI005_GNT2']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_NFN'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI005_NFN2'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI006_MEM'] = ('String',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI020_GE4'] = ('CodeList',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI026_CTUC'] = ('Enumeration',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HARBOUR_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HARBOUR_S']['ZI026_CTUL'] = ('integer',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI026_CTUU'] = ('integer',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI031S_URI'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZI039S_UFI'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZSAX_RS0'] = ('CodeList',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZSAX_RX0'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZSAX_RX3'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_S']['ZSAX_RX4'] = ('StructuredText',('BB005'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ARA'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['BEN'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['CAA'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['CAA']['BB008']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['DOXY'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['FUFI'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['FURL'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['GDBV'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['GDBV']['BB008']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['LZN'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['OTH'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['UFI'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['WID'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI001_SDV'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI001_SRT'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI001_SRT']['BB008']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI002_UFI'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI004_RCG'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI004_RCG']['BB008']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI006_MEM'] = ('String',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI020_GE4'] = ('CodeList',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_ASE'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_CFR'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_CLO'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_CYN'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_FMR'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_FRR'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_HAR'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_HYP'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI024_HYP']['BB008']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_MGN'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_PHW'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_SCC'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI024_SCC']['BB008']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_SUL'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_TDS'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_TEP'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_TUR'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_WAC'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI024_WTNO'] = ('Real',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI026_CTUC'] = ('Enumeration',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB008']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI026_CTUL'] = ('integer',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI026_CTUU'] = ('integer',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI031S_URI'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZI039S_UFI'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZSAX_RS0'] = ('CodeList',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZSAX_RX0'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZSAX_RX3'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARBOUR_WATERS_S']['ZSAX_RX4'] = ('StructuredText',('BB008'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ADR'] = ('String',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['AOO'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ARA'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['AWP'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['BEN'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['CAA'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['CAA']['GB250']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['CNCP'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['COS'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['COS']['GB250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['FFN'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['FFN2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['FFN3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['FUFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['FURL'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['GDBV'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['GDBV']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['HGT'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['HST'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['HST2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['HST3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['HTP'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['HTP']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['LMC'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['LZN'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['MUB'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['OTH'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['PCF'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['SSR'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['SSR2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['SSR3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['VOI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['WID'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI001_SDV'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI001_SRT'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI001_SRT']['GB250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI002_UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI004_RCG'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI004_RCG']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI006_MEM'] = ('String',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI020_GE4'] = ('CodeList',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI026_CTUC'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI026_CTUL'] = ('integer',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI026_CTUU'] = ('integer',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI031S_URI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZI039S_UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZSAX_RS0'] = ('CodeList',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZSAX_RX0'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZSAX_RX3'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZSAX_RX4'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_P']['ZVH'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ADR'] = ('String',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['AOO'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ARA'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['AWP'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['BEN'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['CAA'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['CAA']['GB250']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['CNCP'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['COS'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['COS']['GB250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['FFN'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['FFN2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['FFN3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['FUFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['FURL'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['GDBV'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['GDBV']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['HGT'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['HST'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['HST2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['HST3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['HTP'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HTP'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['HTP']['GB250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['LMC'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['LZN'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['MUB'] = ('Boolean',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['OTH'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['PCF'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['SSR'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['SSR2'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['SSR3'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['VOI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['WID'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI001_SDV'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI001_SRT'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI001_SRT']['GB250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI002_UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI004_RCG'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI004_RCG']['GB250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI006_MEM'] = ('String',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI020_GE4'] = ('CodeList',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI026_CTUC'] = ('Enumeration',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI026_CTUL'] = ('integer',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI026_CTUU'] = ('integer',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI031S_URI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZI039S_UFI'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZSAX_RS0'] = ('CodeList',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZSAX_RX0'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZSAX_RX3'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZSAX_RX4'] = ('StructuredText',('GB250'))
    field_information['GGDM 3.0']['HARDENED_AIRCRAFT_SHELTER_S']['ZVH'] = ('Real',('GB250'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ARA'] = ('Real',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['BEN'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['FUFI'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['FURL'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['GDBV'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['GDBV']['BD130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['LZN'] = ('Real',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['MCC'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['MCC2'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC2']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['MCC3'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['MCC3']['BD130']  = (-999999,24,25,52,84,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['OTH'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['UFI'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZHBH_TEC'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZHBH_TEC2'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC2']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZHBH_TEC3'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZHBH_TEC3']['BD130']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI001_SDV'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI001_SRT'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI001_SRT']['BD130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI002_UFI'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI004_RCG'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI004_RCG']['BD130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI005_FNA'] = ('String',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI005_GNT'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI005_GNT']['BD130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI005_NFN'] = ('String',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI006_MEM'] = ('String',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI020_GE4'] = ('CodeList',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI025_HDP'] = ('Real',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI025_UHS'] = ('Boolean',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI025_WLE'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI025_WLE']['BD130']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI026_CTUC'] = ('Enumeration',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI026_CTUL'] = ('integer',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI026_CTUU'] = ('integer',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI031S_URI'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZI039S_UFI'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZSAX_RS0'] = ('CodeList',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZSAX_RX0'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZSAX_RX3'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HAZARDOUS_ROCK_P']['ZSAX_RX4'] = ('StructuredText',('BD130'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ADR'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['AOO'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ARA'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['BEN'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['CAA'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['CAA']['AD050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['CNCP'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['COS'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['COS']['AD050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['FFN'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['FFN2'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['FFN3'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['FUFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['FURL'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['GDBV'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AD050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['HGT'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['LMC'] = ('Boolean',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['LZN'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['OTH'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['PCF'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['VCM'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['VCM2'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['VCM3'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['WID'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI005_FNA'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI005_NFN'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI006_MEM'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI026_CTUL'] = ('integer',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI026_CTUU'] = ('integer',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_P']['ZVH'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ADR'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['AOO'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ARA'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['BEN'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['CAA'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['CAA']['AD050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['CNCP'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['COS'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['COS']['AD050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['FFN'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['FFN2'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['FFN3'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['FUFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['FURL'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['GDBV'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AD050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['HGT'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['LMC'] = ('Boolean',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['LZN'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['OTH'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['PCF'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['VCM'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['VCM2'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['VCM3'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['WID'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AD050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI005_FNA'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AD050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI005_NFN'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI006_MEM'] = ('String',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI026_CTUL'] = ('integer',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI026_CTUU'] = ('integer',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AD050'))
    field_information['GGDM 3.0']['HEATING_FACILITY_S']['ZVH'] = ('Real',('AD050'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ARA'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['BEN'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['F_CODE'] = ('CONSTRAINED_STRING',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['FUFI'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['FURL'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['GDBV'] = ('Enumeration',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['GDBV']['EA020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HEDGEROW_C']['HGT'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['LMC'] = ('Boolean',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['LZN'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['OTH'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['PVH'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['UFI'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['VTI'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['WID'] = ('Real',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI001_SDV'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI001_SRT'] = ('Enumeration',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI001_SRT']['EA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI002_UFI'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI004_RCG'] = ('Enumeration',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI004_RCG']['EA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI006_MEM'] = ('String',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI020_GE4'] = ('CodeList',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI026_CTUC'] = ('Enumeration',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HEDGEROW_C']['EnumeratedIndexValues']['ZI026_CTUC']['EA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI026_CTUL'] = ('integer',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI026_CTUU'] = ('integer',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI031S_URI'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZI039S_UFI'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZSAX_RS0'] = ('CodeList',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZSAX_RX0'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZSAX_RX3'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HEDGEROW_C']['ZSAX_RX4'] = ('StructuredText',('EA020'))
    field_information['GGDM 3.0']['HELIPAD_P']['ARA'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['AXS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HELIPAD_P']['BEN'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['CAA'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HELIPAD_P']['CNCP'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['COS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['COS']['GB030']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['HELIPAD_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['FUFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['FURL'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['GDBV'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['GDBV']['GB030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HELIPAD_P']['HAF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['HAF'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['GGDM 3.0']['HELIPAD_P']['HGT'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['LZN'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['OTH'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['PCF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HELIPAD_P']['UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['WID'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI001_SDV'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI001_SRT'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI001_SRT']['GB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI002_UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI004_RCG'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI004_RCG']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI005_FNA'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI005_GNT'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI005_GNT']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI005_NFN'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI006_MEM'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASP'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASP2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASP3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASU'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASU2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASU3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_ASX'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI019_SFS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI020_GE4'] = ('CodeList',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI026_CTUC'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HELIPAD_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPAD_P']['ZI026_CTUL'] = ('integer',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI026_CTUU'] = ('integer',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI031S_URI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZI039S_UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZSAX_RS0'] = ('CodeList',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZSAX_RX0'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZSAX_RX3'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZSAX_RX4'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_P']['ZVH'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ARA'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['AXS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['HELIPAD_S']['BEN'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['CAA'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HELIPAD_S']['CNCP'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['COS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['COS']['GB030']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['HELIPAD_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['FUFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['FURL'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['GDBV'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['GDBV']['GB030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HELIPAD_S']['HAF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['HAF'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['GGDM 3.0']['HELIPAD_S']['HGT'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['LZN'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['OTH'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['PCF'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HELIPAD_S']['UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['WID'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI001_SDV'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI001_SRT'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI001_SRT']['GB030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI002_UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI004_RCG'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI004_RCG']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI005_FNA'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI005_GNT'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI005_GNT']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI005_NFN'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI006_MEM'] = ('String',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASP'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASP2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASP3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASU'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASU2'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASU3'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_ASX'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI019_SFS'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI020_GE4'] = ('CodeList',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI026_CTUC'] = ('Enumeration',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HELIPAD_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPAD_S']['ZI026_CTUL'] = ('integer',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI026_CTUU'] = ('integer',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI031S_URI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZI039S_UFI'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZSAX_RS0'] = ('CodeList',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZSAX_RX0'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZSAX_RX3'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZSAX_RX4'] = ('StructuredText',('GB030'))
    field_information['GGDM 3.0']['HELIPAD_S']['ZVH'] = ('Real',('GB030'))
    field_information['GGDM 3.0']['HELIPORT_P']['ARA'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ASY'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['GGDM 3.0']['HELIPORT_P']['BEN'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['CAA'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HELIPORT_P']['CNCP'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['COS'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HELIPORT_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['FPT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HELIPORT_P']['FUFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['FURL'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['GDBV'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['GDBV']['GB035']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HELIPORT_P']['IKO'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['LZN'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['MAG'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['NA8'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['NAO'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['OTH'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['PCF'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HELIPORT_P']['PEC'] = ('Boolean',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['WID'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI001_SDV'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI001_SRT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI001_SRT']['GB035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HELIPORT_P']['ZI002_UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI004_RCG'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI004_RCG']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HELIPORT_P']['ZI005_FNA'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI005_GNT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI005_GNT']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HELIPORT_P']['ZI005_NFN'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI006_MEM'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI020_GE4'] = ('CodeList',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI026_CTUC'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HELIPORT_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPORT_P']['ZI026_CTUL'] = ('integer',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI026_CTUU'] = ('integer',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI031S_URI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZI039S_UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZSAX_RS0'] = ('CodeList',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZSAX_RX0'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZSAX_RX3'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZSAX_RX4'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZVA'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_P']['ZVH'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ARA'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ASY'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['GGDM 3.0']['HELIPORT_S']['BEN'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['CAA'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HELIPORT_S']['CNCP'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['COS'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HELIPORT_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['FPT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['HELIPORT_S']['FUFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['FURL'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['GDBV'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['GDBV']['GB035']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HELIPORT_S']['IKO'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['LZN'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['MAG'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['NA8'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['NAO'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['OTH'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['PCF'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HELIPORT_S']['PEC'] = ('Boolean',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['WID'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI001_SDV'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI001_SRT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI001_SRT']['GB035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HELIPORT_S']['ZI002_UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI004_RCG'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI004_RCG']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HELIPORT_S']['ZI005_FNA'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI005_GNT'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI005_GNT']['GB035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HELIPORT_S']['ZI005_NFN'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI006_MEM'] = ('String',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI020_GE4'] = ('CodeList',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI026_CTUC'] = ('Enumeration',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HELIPORT_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HELIPORT_S']['ZI026_CTUL'] = ('integer',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI026_CTUU'] = ('integer',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI031S_URI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZI039S_UFI'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZSAX_RS0'] = ('CodeList',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZSAX_RX0'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZSAX_RX3'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZSAX_RX4'] = ('StructuredText',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZVA'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HELIPORT_S']['ZVH'] = ('Real',('GB035'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['AOO'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ARA'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['BEN'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['CNCP'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['COS'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['COS']['AJ030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['FUFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['FURL'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['GDBV'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['GDBV']['AJ030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['HGT'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['LMC'] = ('Boolean',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['LZN'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['OTH'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['PCF'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['WID'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI001_SDV'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI001_SRT'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI002_UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI004_RCG'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI005_FNA'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI005_GNT'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI005_NFN'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI006_MEM'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI020_GE4'] = ('CodeList',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI026_CTUC'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI026_CTUL'] = ('integer',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI026_CTUU'] = ('integer',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI031S_URI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZI039S_UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZSAX_RS0'] = ('CodeList',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZSAX_RX0'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZSAX_RX3'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZSAX_RX4'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_P']['ZVH'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['AOO'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ARA'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['BEN'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['CNCP'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['COS'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['COS']['AJ030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['FUFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['FURL'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['GDBV'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['GDBV']['AJ030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['HGT'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['LMC'] = ('Boolean',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['LZN'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['OTH'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['PCF'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['WID'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI001_SDV'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI001_SRT'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI002_UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI004_RCG'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI005_FNA'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI005_GNT'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI005_NFN'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI006_MEM'] = ('String',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI020_GE4'] = ('CodeList',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI026_CTUC'] = ('Enumeration',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HOLDING_PEN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI026_CTUL'] = ('integer',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI026_CTUU'] = ('integer',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI031S_URI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZI039S_UFI'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZSAX_RS0'] = ('CodeList',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZSAX_RX0'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZSAX_RX3'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZSAX_RX4'] = ('StructuredText',('AJ030'))
    field_information['GGDM 3.0']['HOLDING_PEN_S']['ZVH'] = ('Real',('AJ030'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ARA'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['BEN'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['FUFI'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['FURL'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['GDBV'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['GDBV']['EA055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['HGT'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['LMC'] = ('Boolean',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['LZN'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['OTH'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['UFI'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['VTI'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['WID'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI001_SDV'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI001_SRT'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT']['EA055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI002_UFI'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI004_RCG'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG']['EA055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI006_MEM'] = ('String',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI013_CSP'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_CSP']['EA055']  = (18,)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI013_FFP'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI013_FFP2'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP2']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI013_FFP3'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP3']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI013_IRG'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI013_IRG']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI020_GE4'] = ('CodeList',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI026_CTUC'] = ('Enumeration',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HOP_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI026_CTUL'] = ('integer',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI026_CTUU'] = ('integer',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI031S_URI'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZI039S_UFI'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZSAX_RS0'] = ('CodeList',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZSAX_RX0'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZSAX_RX3'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZSAX_RX4'] = ('StructuredText',('EA055'))
    field_information['GGDM 3.0']['HOP_FIELD_S']['ZVH'] = ('Real',('EA055'))
    field_information['GGDM 3.0']['HOPPER_P']['AOO'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ARA'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['AWP'] = ('Boolean',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['BEN'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['CAA'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['CAA']['AF080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HOPPER_P']['CNCP'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['COS'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['COS']['AF080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HOPPER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['FUFI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['FURL'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['GDBV'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['GDBV']['AF080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HOPPER_P']['HGT'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['LMC'] = ('Boolean',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['LZN'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['OTH'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['PCF'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['PCF']['AF080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HOPPER_P']['UFI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['VOI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['WID'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI001_SDV'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI001_SRT'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI001_SRT']['AF080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HOPPER_P']['ZI002_UFI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI004_RCG'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI004_RCG']['AF080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HOPPER_P']['ZI005_FNA'] = ('String',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI005_GNT'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI005_GNT']['AF080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HOPPER_P']['ZI005_NFN'] = ('String',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI006_MEM'] = ('String',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI020_GE4'] = ('CodeList',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI026_CTUC'] = ('Enumeration',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HOPPER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HOPPER_P']['ZI026_CTUL'] = ('integer',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI026_CTUU'] = ('integer',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI031S_URI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZI039S_UFI'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZSAX_RS0'] = ('CodeList',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZSAX_RX0'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZSAX_RX3'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZSAX_RX4'] = ('StructuredText',('AF080'))
    field_information['GGDM 3.0']['HOPPER_P']['ZVH'] = ('Real',('AF080'))
    field_information['GGDM 3.0']['HULK_P']['AOO'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ARA'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['AWP'] = ('Boolean',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['BEN'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['CAA'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['CAA']['BD181']  = (-999999,5,7,16,999)
    field_information['GGDM 3.0']['HULK_P']['CNCP'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['COS'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['COS']['BD181']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HULK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['FUFI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['FURL'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['GDBV'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['GDBV']['BD181']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HULK_P']['HGT'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['LMC'] = ('Boolean',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['LZN'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['OTH'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['PCF'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['PCF']['BD181']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HULK_P']['UFI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['VOI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['WID'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI001_SDV'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI001_SRT'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI001_SRT']['BD181']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HULK_P']['ZI002_UFI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI004_RCG'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI004_RCG']['BD181']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HULK_P']['ZI005_FNA'] = ('String',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI005_GNT'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI005_GNT']['BD181']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HULK_P']['ZI005_NFN'] = ('String',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI006_MEM'] = ('String',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI020_GE4'] = ('CodeList',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI026_CTUC'] = ('Enumeration',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HULK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD181']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HULK_P']['ZI026_CTUL'] = ('integer',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI026_CTUU'] = ('integer',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI031S_URI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZI039S_UFI'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZSAX_RS0'] = ('CodeList',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZSAX_RX0'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZSAX_RX3'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZSAX_RX4'] = ('StructuredText',('BD181'))
    field_information['GGDM 3.0']['HULK_P']['ZVH'] = ('Real',('BD181'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ARA'] = ('Real',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['BEN'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['FUFI'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['FURL'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['GDBV'] = ('Enumeration',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['GDBV']['BH077']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HUMMOCK_S']['LZN'] = ('Real',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['OTH'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['UFI'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['VTI'] = ('Real',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['WID'] = ('Real',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI001_SDV'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI001_SRT'] = ('Enumeration',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI001_SRT']['BH077']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI002_UFI'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI004_RCG'] = ('Enumeration',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI004_RCG']['BH077']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI006_MEM'] = ('String',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI020_GE4'] = ('CodeList',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI026_CTUC'] = ('Enumeration',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HUMMOCK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH077']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI026_CTUL'] = ('integer',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI026_CTUU'] = ('integer',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI031S_URI'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZI039S_UFI'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZSAX_RS0'] = ('CodeList',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZSAX_RX0'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZSAX_RX3'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUMMOCK_S']['ZSAX_RX4'] = ('StructuredText',('BH077'))
    field_information['GGDM 3.0']['HUT_P']['ADR'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['AOO'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ARA'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['BEN'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['CAA'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['CAA']['AL099']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HUT_P']['CNCP'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['COS'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['COS']['AL099']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HUT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['FFN'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_P']['FFN2'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_P']['FFN3'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_P']['FUFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['FURL'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['GDBV'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['GDBV']['AL099']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HUT_P']['HGT'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['LMC'] = ('Boolean',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['LZN'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['OTH'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['PCF'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HUT_P']['UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['WID'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI001_SDV'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI001_SRT'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HUT_P']['ZI002_UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI004_RCG'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HUT_P']['ZI005_FNA'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI005_GNT'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI005_GNT']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HUT_P']['ZI005_NFN'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI006_MEM'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI020_GE4'] = ('CodeList',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI026_CTUC'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HUT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HUT_P']['ZI026_CTUL'] = ('integer',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI026_CTUU'] = ('integer',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI031S_URI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZI039S_UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZSAX_RS0'] = ('CodeList',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZSAX_RX0'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZSAX_RX3'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZSAX_RX4'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_P']['ZVH'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ADR'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['AOO'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ARA'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['BEN'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['CAA'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['CAA']['AL099']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HUT_S']['CNCP'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['COS'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['COS']['AL099']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HUT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['FFN'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_S']['FFN2'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_S']['FFN3'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['GGDM 3.0']['HUT_S']['FUFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['FURL'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['GDBV'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['GDBV']['AL099']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HUT_S']['HGT'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['LMC'] = ('Boolean',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['LZN'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['OTH'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['PCF'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HUT_S']['UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['WID'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI001_SDV'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI001_SRT'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI001_SRT']['AL099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HUT_S']['ZI002_UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI004_RCG'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI004_RCG']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HUT_S']['ZI005_FNA'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI005_GNT'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI005_GNT']['AL099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HUT_S']['ZI005_NFN'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI006_MEM'] = ('String',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI020_GE4'] = ('CodeList',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI026_CTUC'] = ('Enumeration',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HUT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HUT_S']['ZI026_CTUL'] = ('integer',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI026_CTUU'] = ('integer',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI031S_URI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZI039S_UFI'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZSAX_RS0'] = ('CodeList',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZSAX_RX0'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZSAX_RX3'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZSAX_RX4'] = ('StructuredText',('AL099'))
    field_information['GGDM 3.0']['HUT_S']['ZVH'] = ('Real',('AL099'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ADR'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['AOO'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ARA'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['BEN'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['CAA'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['CAA']['AC040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['CNCP'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['COS'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['COS']['AC040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['FFN'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['FFN2'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['FFN3'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['FUFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['FURL'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['GDBV'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['HGT'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['LMC'] = ('Boolean',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['LZN'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['OTH'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['PCF'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['WID'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI005_FNA'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI005_NFN'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI006_MEM'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI014_PPO'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI014_PPO2'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI014_PPO3'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI026_CTUL'] = ('integer',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI026_CTUU'] = ('integer',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_P']['ZVH'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ADR'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['AOO'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ARA'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['BEN'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['CAA'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['CAA']['AC040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['CNCP'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['COS'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['COS']['AC040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['FFN'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['FFN2'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['FFN3'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['FUFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['FURL'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['GDBV'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['HGT'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['LMC'] = ('Boolean',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['LZN'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['OTH'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['PCF'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['WID'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI005_FNA'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI005_NFN'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI006_MEM'] = ('String',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI014_PPO'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI014_PPO2'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI014_PPO3'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI026_CTUL'] = ('integer',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI026_CTUU'] = ('integer',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBON_PROD_FACILITY_S']['ZVH'] = ('Real',('AC040'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ARA'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['BEN'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['FUFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['FURL'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['GDBV'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['GDBV']['AA052']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['LZN'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['OTH'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['PPO'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['PPO2'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO2']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['PPO3'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['PPO3']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['WID'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI001_SDV'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI001_SRT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI001_SRT']['AA052']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI002_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI004_RCG'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI004_RCG']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI005_FNA'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI005_GNT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI005_GNT']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI005_NFN'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI006_MEM'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI020_GE4'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI026_CTUC'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA052']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI026_CTUL'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI026_CTUU'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI031S_URI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZI039S_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZSAX_RS0'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZSAX_RX0'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZSAX_RX3'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_P']['ZSAX_RX4'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ARA'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['BEN'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['FUFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['FURL'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['GDBV'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['GDBV']['AA052']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['LZN'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['OTH'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['PPO'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['PPO2'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO2']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['PPO3'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['PPO3']['AA052']  = (-999999,45,83,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['WID'] = ('Real',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI001_SDV'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI001_SRT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT']['AA052']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI002_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI004_RCG'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI005_FNA'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI005_GNT'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT']['AA052']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI005_NFN'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI006_MEM'] = ('String',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI020_GE4'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI026_CTUC'] = ('Enumeration',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AA052']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI026_CTUL'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI026_CTUU'] = ('integer',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI031S_URI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZI039S_UFI'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZSAX_RS0'] = ('CodeList',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZSAX_RX0'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZSAX_RX3'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['HYDROCARBONS_FIELD_S']['ZSAX_RX4'] = ('StructuredText',('AA052'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ARA'] = ('Real',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['BEN'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['FUFI'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['FURL'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['GDBV'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['GDBV']['BJ099']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['LND'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['LND'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['LND']['BJ099']  = (-999999,19,41,56,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['LZN'] = ('Real',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['OTH'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['SNDC'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['SNDC']['BJ099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_CAP_S']['SNDL'] = ('real',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['SNDU'] = ('real',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['SRD'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['SRD'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['SRD']['BJ099']  = (-999999,1,17,36,70,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['UFI'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['WID'] = ('Real',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI001_SDV'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI001_SRT'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ099']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI002_UFI'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI004_RCG'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ099']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI005_FNA'] = ('String',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI005_GNT'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ099']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI005_NFN'] = ('String',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI006_MEM'] = ('String',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI020_GE4'] = ('CodeList',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI026_CTUC'] = ('Enumeration',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ICE_CAP_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ099']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI026_CTUL'] = ('integer',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI026_CTUU'] = ('integer',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI031S_URI'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZI039S_UFI'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZSAX_RS0'] = ('CodeList',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZSAX_RX0'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZSAX_RX3'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CAP_S']['ZSAX_RX4'] = ('StructuredText',('BJ099'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['BEN'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['F_CODE'] = ('CONSTRAINED_STRING',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['FUFI'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['FURL'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['GDBV'] = ('Enumeration',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['GDBV']['BJ040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ICE_CLIFF_C']['HGT'] = ('Real',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['LZN'] = ('Real',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['OTH'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['PFH'] = ('Real',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['UFI'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI001_SDV'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI001_SRT'] = ('Enumeration',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI001_SRT']['BJ040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI002_UFI'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI004_RCG'] = ('Enumeration',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI004_RCG']['BJ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI005_FNA'] = ('String',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI005_GNT'] = ('Enumeration',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI005_GNT']['BJ040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI005_NFN'] = ('String',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI006_MEM'] = ('String',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI020_GE4'] = ('CodeList',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI026_CTUC'] = ('Enumeration',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ICE_CLIFF_C']['EnumeratedIndexValues']['ZI026_CTUC']['BJ040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI026_CTUL'] = ('integer',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI026_CTUU'] = ('integer',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI031S_URI'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZI039S_UFI'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZSAX_RS0'] = ('CodeList',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZSAX_RX0'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZSAX_RX3'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZSAX_RX4'] = ('StructuredText',('BJ040'))
    field_information['GGDM 3.0']['ICE_CLIFF_C']['ZVH'] = ('Real',('BJ040'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ARA'] = ('Real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['BEN'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['FUFI'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['FURL'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['GDBV'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['GDBV']['BJ060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['HGT'] = ('Real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['LMC'] = ('Boolean',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['LZN'] = ('Real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['MCC'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['MCC2'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC2']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['MCC3'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['MCC3']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['OTH'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['SNDC'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['SNDC']['BJ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_PEAK_P']['SNDL'] = ('real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['SNDU'] = ('real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['UFI'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['WID'] = ('Real',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI001_SDV'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI001_SRT'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI001_SRT']['BJ060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI002_UFI'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI004_RCG'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI004_RCG']['BJ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI005_FNA'] = ('String',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI005_GNT'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI005_GNT']['BJ060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI005_NFN'] = ('String',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI006_MEM'] = ('String',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI020_GE4'] = ('CodeList',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI026_CTUC'] = ('Enumeration',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ICE_PEAK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BJ060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI026_CTUL'] = ('integer',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI026_CTUU'] = ('integer',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI031S_URI'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZI039S_UFI'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZSAX_RS0'] = ('CodeList',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZSAX_RX0'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZSAX_RX3'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZSAX_RX4'] = ('StructuredText',('BJ060'))
    field_information['GGDM 3.0']['ICE_PEAK_P']['ZVH'] = ('Real',('BJ060'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['BEN'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['CNCP'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['COS'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['COS']['AQ075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['FUFI'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['FURL'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['GDBV'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['GDBV']['AQ075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['LZN'] = ('Real',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['OTH'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['PCF'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['PCF']['AQ075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['PSN'] = ('Real',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_ROI'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_ROI2'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI2']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_ROI3'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['RIN_ROI3']['AQ075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_RTN'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_RTN2'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['RIN_RTN3'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['SPD'] = ('Real',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['SPM'] = ('Real',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['UFI'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['WID'] = ('Real',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI001_SDV'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI001_SRT'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI002_UFI'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI004_RCG'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI005_FNA'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI005_GNT'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI005_NFN'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI006_MEM'] = ('String',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI020_GE4'] = ('CodeList',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI026_CTUC'] = ('Enumeration',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ICE_ROUTE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI026_CTUL'] = ('integer',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI026_CTUU'] = ('integer',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI031S_URI'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZI039S_UFI'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZSAX_RS0'] = ('CodeList',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZSAX_RX0'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZSAX_RX3'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_ROUTE_C']['ZSAX_RX4'] = ('StructuredText',('AQ075'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ARA'] = ('Real',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['BEN'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['FUFI'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['FURL'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['GDBV'] = ('Enumeration',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['GDBV']['BJ065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ICE_SHELF_S']['LZN'] = ('Real',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['OTH'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['UFI'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['WID'] = ('Real',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI001_SDV'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI001_SRT'] = ('Enumeration',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI002_UFI'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI004_RCG'] = ('Enumeration',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI005_FNA'] = ('String',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI005_GNT'] = ('Enumeration',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI005_NFN'] = ('String',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI006_MEM'] = ('String',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI020_GE4'] = ('CodeList',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI026_CTUC'] = ('Enumeration',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ICE_SHELF_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI026_CTUL'] = ('integer',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI026_CTUU'] = ('integer',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI031S_URI'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZI039S_UFI'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZSAX_RS0'] = ('CodeList',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZSAX_RX0'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZSAX_RX3'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['ICE_SHELF_S']['ZSAX_RX4'] = ('StructuredText',('BJ065'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ADR'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['AOO'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ARA'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['BEN'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['CAA'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['CAA']['AL270']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['CNCP'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['COS'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['COS']['AL270']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['DMBC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['DMBL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['DMBU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['DMT'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['FFN'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['FFN2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['FFN3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['FUFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['FURL'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['GDBV'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['GDBV']['AL270']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['HGT'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['LMC'] = ('Boolean',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['LZN'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['OTH'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['PCF'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['PVH'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['SDSC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['SDSL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['SDSU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['TRE'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['TSCC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['TSCL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['TSCU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['VSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['VSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['VSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['VTI'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['WID'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI001_SDV'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI001_SRT'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI001_SRT']['AL270']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI002_UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI004_RCG'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI004_RCG']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI005_FNA'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI005_GNT'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI005_GNT']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI005_NFN'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI006_MEM'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_CSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_CSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_CSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FFP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FFP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FFP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FMM'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FMM2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_FMM3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI013_PIG'] = ('Boolean',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI020_GE4'] = ('CodeList',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI026_CTUC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI026_CTUL'] = ('integer',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI026_CTUU'] = ('integer',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI031S_URI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZI039S_UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZSAX_RS0'] = ('CodeList',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZSAX_RX0'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZSAX_RX3'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZSAX_RX4'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_P']['ZVH'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ADR'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['AOO'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ARA'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['BEN'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['CAA'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['CAA']['AL270']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['CNCP'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['COS'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['COS']['AL270']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['DMBC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['DMBL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['DMBU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['DMT'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['FFN'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['FFN2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['FFN3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['FUFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['FURL'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['GDBV'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['GDBV']['AL270']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['HGT'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['LMC'] = ('Boolean',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['LZN'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['OTH'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['PCF'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['PVH'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['SDSC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['SDSL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['SDSU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['TRE'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['TSCC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['TSCL'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['TSCU'] = ('real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['VSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['VSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['VSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['VTI'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['WID'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI001_SDV'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI001_SRT'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI001_SRT']['AL270']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI002_UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI004_RCG'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI004_RCG']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI005_FNA'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI005_GNT'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI005_GNT']['AL270']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI005_NFN'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI006_MEM'] = ('String',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_CSP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_CSP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_CSP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FFP'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FFP2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FFP3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FMM'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FMM2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_FMM3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI013_PIG'] = ('Boolean',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI020_GE4'] = ('CodeList',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI026_CTUC'] = ('Enumeration',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI026_CTUL'] = ('integer',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI026_CTUU'] = ('integer',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI031S_URI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZI039S_UFI'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZSAX_RS0'] = ('CodeList',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZSAX_RX0'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZSAX_RX3'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZSAX_RX4'] = ('StructuredText',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FARM_S']['ZVH'] = ('Real',('AL270'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['AOO'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ARA'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['BEN'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['CAA'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['CAA']['AC060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['CNCP'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['COS'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['COS']['AC060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['FUFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['FURL'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['GDBV'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['GDBV']['AC060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['HGT'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['LMC'] = ('Boolean',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['LZN'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['OTH'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['PCF'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['PPO'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['PPO2'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['PPO3'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['WID'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI001_SDV'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI001_SRT'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI001_SRT']['AC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI002_UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI004_RCG'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI004_RCG']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI005_FNA'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI005_GNT'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI005_GNT']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI005_NFN'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI006_MEM'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI020_GE4'] = ('CodeList',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI026_CTUC'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI026_CTUL'] = ('integer',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI026_CTUU'] = ('integer',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI031S_URI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZI039S_UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZSAX_RS0'] = ('CodeList',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZSAX_RX0'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZSAX_RX3'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZSAX_RX4'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_P']['ZVH'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['AOO'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ARA'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['BEN'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['CAA'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['CAA']['AC060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['CNCP'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['COS'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['COS']['AC060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['FUFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['FURL'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['GDBV'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['GDBV']['AC060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['HGT'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['LMC'] = ('Boolean',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['LZN'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['OTH'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['PCF'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['PPO'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['PPO2'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['PPO3'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['WID'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI001_SDV'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI001_SRT'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI001_SRT']['AC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI002_UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI004_RCG'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI004_RCG']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI005_FNA'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI005_GNT'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI005_GNT']['AC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI005_NFN'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI006_MEM'] = ('String',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI020_GE4'] = ('CodeList',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI026_CTUC'] = ('Enumeration',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI026_CTUL'] = ('integer',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI026_CTUU'] = ('integer',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI031S_URI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZI039S_UFI'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZSAX_RS0'] = ('CodeList',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZSAX_RX0'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZSAX_RX3'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZSAX_RX4'] = ('StructuredText',('AC060'))
    field_information['GGDM 3.0']['INDUSTRIAL_FURNACE_S']['ZVH'] = ('Real',('AC060'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ARA'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['AZC'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BEN'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_AWBA'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_AWBB'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_SHDA'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_SHDB'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_SLTA'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BH141_SLTA']['NM082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_SLTB'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BH141_SLTB']['NM082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BH141_WBHA'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHAC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BPWHAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHAL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHAU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHBC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BPWHBC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHBL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BPWHBU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCAC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BWVCAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCAL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCAU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCBC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['BWVCBC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCBL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['BWVCBU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['CAA'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['CAA']['NM082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['CNCP'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['COS'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['COS']['NM082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['DMD'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['DMF'] = ('Integer',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['DOXY'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['DZP'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FFN'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FFN2'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN2']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FFN3'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['FFN3']['NM082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FRZ'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FUFI'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['FURL'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['GDBV'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['GDBV']['NM082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['IWT'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['IWT']['NM082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['LMC'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['MNS'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['OTH'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['PCF'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['PCF']['NM082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['PWAC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['PWAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['PWAL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['PWAU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['TID'] = ('Boolean',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['UFI'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['VLM'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['WDAC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['WDAC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['WDAL'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['WDAU'] = ('real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['WDH'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['WDL'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI001_SDV'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI001_SRT'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI002_UFI'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI004_RCG'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI006_MEM'] = ('String',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI020_GE4'] = ('CodeList',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_ASE'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_CFR'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_CLO'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_CYN'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_FMR'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_FRR'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_HAR'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_HYP'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_MGN'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_PHW'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_RTP'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_RTP']['NM082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_SCC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM082']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_SUL'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_TDS'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_TEP'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_TUR'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WAC'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WTNO'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WUR'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI026_CTUL'] = ('integer',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI026_CTUU'] = ('integer',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI031S_URI'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZSAX_RS0'] = ('CodeList',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_AON_S']['ZVH'] = ('Real',('NM082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ARA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['AZC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BEN'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_AWBA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_AWBB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_IBOA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_IBOB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_SHDA'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_SHDB'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_SLTA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_SLTB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_WBHA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BH141_WBHB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWHBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BPWSBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['BWVCBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['CAA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['CAA']['BH082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['CNCP'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['COS'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['COS']['BH082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['DMD'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['DOXY'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['DZP'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FFN'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FFN2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FFN3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FRZ'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FUFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['FURL'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['GDBV'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['GDBV']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['IWT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['LMC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['LZN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['MNS'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['OTH'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['PCF'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['PWAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['PWAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['PWAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['PWAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['TID'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['VLM'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WDAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['WDAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WDAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WDAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WDH'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WDL'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['WID'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI001_SDV'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI001_SRT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI001_SRT']['BH082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI002_UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI004_RCG'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI004_RCG']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_FNA'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_FNA2'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_FNA3'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_GNT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_GNT2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_GNT3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI005_GNT3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_NFN'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_NFN2'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI005_NFN3'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI006_MEM'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI020_GE4'] = ('CodeList',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_ASE'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_CFR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_CLO'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_CYN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_FMR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_FRR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_HAR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_HYP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_MGN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_PHW'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_RTP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_RTP']['BH082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_SCC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_SUL'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_TDS'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_TEP'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_TUR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WAC'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WTNO'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WUR'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WUR2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WUR3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_WUR4'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI024_YWQ'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI026_CTUC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI026_CTUL'] = ('integer',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI026_CTUU'] = ('integer',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI031S_URI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZI039S_UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZSAX_RS0'] = ('CodeList',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZSAX_RX0'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZSAX_RX3'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZSAX_RX4'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_P']['ZVH'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ARA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['AZC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BEN'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_AWBA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_AWBB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_IBOA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_IBOB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_SHDA'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_SHDB'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_SLTA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_SLTB'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_WBHA'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BH141_WBHB'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWHBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BPWSBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCBC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCBL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['BWVCBU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['CAA'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['CAA']['BH082']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['CNCP'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['COS'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['COS']['BH082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['DMD'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['DOXY'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['DZP'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FFN'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FFN2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FFN3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FRZ'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FUFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['FURL'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['GDBV'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['GDBV']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['IWT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['IWT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['LMC'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['LZN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['MNS'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['OTH'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['PCF'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['PWAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['PWAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['PWAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['PWAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['TID'] = ('Boolean',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['VLM'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WDAC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['WDAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WDAL'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WDAU'] = ('real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WDH'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WDL'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['WID'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI001_SDV'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI001_SRT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI001_SRT']['BH082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI002_UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI004_RCG'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI004_RCG']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_FNA'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_FNA2'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_FNA3'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_GNT'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_GNT2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_GNT3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_NFN'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_NFN2'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI005_NFN3'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI006_MEM'] = ('String',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI020_GE4'] = ('CodeList',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_ASE'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_CFR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_CLO'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_CYN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_FMR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_FRR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_HAR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_HYP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_MGN'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_PHW'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_RTP'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_RTP'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_RTP']['BH082']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_SCC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_SUL'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_TDS'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_TEP'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_TUR'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WAC'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WTNO'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WUR'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WUR2'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WUR3'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_WUR4'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI024_YWQ'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI026_CTUC'] = ('Enumeration',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI026_CTUL'] = ('integer',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI026_CTUU'] = ('integer',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI031S_URI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZI039S_UFI'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZSAX_RS0'] = ('CodeList',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZSAX_RX0'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZSAX_RX3'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZSAX_RX4'] = ('StructuredText',('BH082'))
    field_information['GGDM 3.0']['INLAND_WATERBODY_S']['ZVH'] = ('Real',('BH082'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['BEN'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['F_CODE'] = ('CONSTRAINED_STRING',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['FUFI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['FURL'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['GDBV'] = ('Enumeration',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['GDBV']['SU030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['LZN'] = ('Real',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['OTH'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['UFI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['VOI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI001_SDV'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI001_SRT'] = ('Enumeration',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT']['SU030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI002_UFI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI004_RCG'] = ('Enumeration',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG']['SU030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI005_FNA'] = ('String',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI005_GNT'] = ('Enumeration',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNT']['SU030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI005_NFN'] = ('String',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI006_MEM'] = ('String',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI020_GE4'] = ('CodeList',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI026_CTUC'] = ('Enumeration',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC']['SU030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI026_CTUL'] = ('integer',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI026_CTUU'] = ('integer',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI031S_URI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZI039S_UFI'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZSAX_RS0'] = ('CodeList',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZSAX_RX0'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZSAX_RX3'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_BOUNDARY_C']['ZSAX_RX4'] = ('StructuredText',('SU030'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ADR'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['AOO'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ARA'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['BEN'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['CAA'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['CAA']['AL011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INSTALLATION_P']['CNCP'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['COS'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['COS']['AL011']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['INSTALLATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['FUFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['FURL'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['GDBV'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['GDBV']['AL011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INSTALLATION_P']['LMC'] = ('Boolean',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['LZN'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['OTH'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['PCF'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INSTALLATION_P']['UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['WID'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI001_SDV'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI001_SRT'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AL011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI002_UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI004_RCG'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI005_FNA'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI005_GNT'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI005_NFN'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI006_MEM'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI020_GE4'] = ('CodeList',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI026_CTUC'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI026_CTUL'] = ('integer',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI026_CTUU'] = ('integer',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI031S_URI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZI039S_UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZSAX_RS0'] = ('CodeList',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZSAX_RX0'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZSAX_RX3'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_P']['ZSAX_RX4'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ADR'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['AOO'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ARA'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['BEN'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['CAA'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['CAA']['AL011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['INSTALLATION_S']['CNCP'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['COS'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['COS']['AL011']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['INSTALLATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['FUFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['FURL'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['GDBV'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['GDBV']['AL011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INSTALLATION_S']['LMC'] = ('Boolean',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['LZN'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['OTH'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['PCF'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INSTALLATION_S']['UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['WID'] = ('Real',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI001_SDV'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI001_SRT'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AL011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI002_UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI004_RCG'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI005_FNA'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI005_GNT'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AL011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI005_NFN'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI006_MEM'] = ('String',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI020_GE4'] = ('CodeList',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI026_CTUC'] = ('Enumeration',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INSTALLATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI026_CTUL'] = ('integer',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI026_CTUU'] = ('integer',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI031S_URI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZI039S_UFI'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZSAX_RS0'] = ('CodeList',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZSAX_RX0'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZSAX_RX3'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSTALLATION_S']['ZSAX_RX4'] = ('StructuredText',('AL011'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['BEN'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['BET'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['BET'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['BET']['BC080']  = (-999999,7,11,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,39,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,86,87,91,92,93,94,95,96,97,98,101,102,103,111,113,114,115,116,117,118,119,122,123,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['FUFI'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['FURL'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['GDBV'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['GDBV']['BC080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['HBH'] = ('Real',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['HGT'] = ('Real',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['MCC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['MCC2'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC2']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['MCC3'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['MCC3']['BC080']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['OTH'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['PCF'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['PCF']['BC080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['TZP'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['TZP'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['TZP']['BC080']  = (-999999,1,5,15,16,33,34,35,36,37,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['UFI'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_DCR'] = ('Boolean',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_DKC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_DKC2'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC2'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC2']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_DKC3'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC3'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_DKC3']['BC080']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_SVC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_SVC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_SVC']['BC080']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_TEC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_TEC2'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC2']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_TEC3'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_TEC3']['BC080']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_VDC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_VDC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZHBH_VDC']['BC080']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZHBH_VDR'] = ('String',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI001_SDV'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI001_SRT'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI001_SRT']['BC080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI002_UFI'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI004_RCG'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI004_RCG']['BC080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI005_FNA'] = ('String',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI005_GNT'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI005_GNT']['BC080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI005_NFN'] = ('String',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI006_MEM'] = ('String',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI020_GE4'] = ('CodeList',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI026_CTUC'] = ('Enumeration',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI026_CTUL'] = ('integer',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI026_CTUU'] = ('integer',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI031S_URI'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZI039S_UFI'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZSAX_RS0'] = ('CodeList',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZSAX_RX0'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZSAX_RX3'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZSAX_RX4'] = ('StructuredText',('BC080'))
    field_information['GGDM 3.0']['INSUBSTANTIAL_NAV_MARK_P']['ZVH'] = ('Real',('BC080'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ADR'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ARA'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['BEN'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['CNCP'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['COS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['COS']['AL201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['FUFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['FURL'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['GDBV'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['GDBV']['AL201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['HGT'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['HSS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['HSS'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['LMC'] = ('Boolean',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['LZN'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['OTH'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['PCF'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['WID'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI001_SDV'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI001_SRT'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI002_UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI004_RCG'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI005_FNA'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI005_GNT'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI005_NFN'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI006_MEM'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI020_GE4'] = ('CodeList',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI026_CTUL'] = ('integer',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI026_CTUU'] = ('integer',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI031S_URI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI037_REL'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI037_RFA'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_P']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZSAX_RS0'] = ('CodeList',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_P']['ZVH'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ADR'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ARA'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['BEN'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['CNCP'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['COS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['COS']['AL201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['FUFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['FURL'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['GDBV'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['GDBV']['AL201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['HGT'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['HSS'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['HSS'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['LMC'] = ('Boolean',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['LZN'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['OTH'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['PCF'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['WID'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI001_SDV'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI001_SRT'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI002_UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI004_RCG'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI005_FNA'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI005_GNT'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI005_NFN'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI006_MEM'] = ('String',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI020_GE4'] = ('CodeList',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI026_CTUL'] = ('integer',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI026_CTUU'] = ('integer',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI031S_URI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI037_REL'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI037_RFA'] = ('Enumeration',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['INTEREST_SITE_S']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZSAX_RS0'] = ('CodeList',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AL201'))
    field_information['GGDM 3.0']['INTEREST_SITE_S']['ZVH'] = ('Real',('AL201'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['BEN'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['FUFI'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['FURL'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['GDBV'] = ('Enumeration',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['GDBV']['FA110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['OTH'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['UFI'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI001_SDV'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI001_SRT'] = ('Enumeration',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI001_SRT']['FA110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI002_UFI'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI004_RCG'] = ('Enumeration',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI004_RCG']['FA110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI006_MEM'] = ('String',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI020_GE4'] = ('CodeList',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI026_CTUC'] = ('Enumeration',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['FA110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI026_CTUL'] = ('integer',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI026_CTUU'] = ('integer',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI031S_URI'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZI039S_UFI'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZSAX_RS0'] = ('CodeList',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZSAX_RX0'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZSAX_RX3'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['INTERNATIONAL_DATE_LINE_C']['ZSAX_RX4'] = ('StructuredText',('FA110'))
    field_information['GGDM 3.0']['ISLAND_P']['AOO'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ARA'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['ISLAND_P']['BA000_VDR'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['BEN'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['F_CODE'] = ('CONSTRAINED_STRING',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['FUFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['FURL'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['GDBV'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['GDBV']['BA030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ISLAND_P']['HGT'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['LMC'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['LZN'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['OTH'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['SHD'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['SLT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['ISLAND_P']['UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['WID'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI001_SDV'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI001_SRT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI001_SRT']['BA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ISLAND_P']['ZI002_UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI004_RCG'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI004_RCG']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ISLAND_P']['ZI005_FNA'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI005_GNT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI005_GNT']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ISLAND_P']['ZI005_NFN'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI006_MEM'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI020_GE4'] = ('CodeList',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI026_CTUC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ISLAND_P']['EnumeratedIndexValues']['ZI026_CTUC']['BA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ISLAND_P']['ZI026_CTUL'] = ('integer',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI026_CTUU'] = ('integer',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI031S_URI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZI039S_UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZSAX_RS0'] = ('CodeList',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZSAX_RX0'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZSAX_RX3'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZSAX_RX4'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_P']['ZVH'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['AOO'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ARA'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['ISLAND_S']['BA000_VDR'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['BEN'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['F_CODE'] = ('CONSTRAINED_STRING',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['FUFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['FURL'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['GDBV'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['GDBV']['BA030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ISLAND_S']['HGT'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['LMC'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['LZN'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['OTH'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['SHD'] = ('Boolean',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['SLT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['ISLAND_S']['UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['WID'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI001_SDV'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI001_SRT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI001_SRT']['BA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ISLAND_S']['ZI002_UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI004_RCG'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI004_RCG']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ISLAND_S']['ZI005_FNA'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI005_GNT'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI005_GNT']['BA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ISLAND_S']['ZI005_NFN'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI006_MEM'] = ('String',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI020_GE4'] = ('CodeList',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI026_CTUC'] = ('Enumeration',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ISLAND_S']['EnumeratedIndexValues']['ZI026_CTUC']['BA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ISLAND_S']['ZI026_CTUL'] = ('integer',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI026_CTUU'] = ('integer',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI031S_URI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZI039S_UFI'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZSAX_RS0'] = ('CodeList',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZSAX_RX0'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZSAX_RX3'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZSAX_RX4'] = ('StructuredText',('BA030'))
    field_information['GGDM 3.0']['ISLAND_S']['ZVH'] = ('Real',('BA030'))
    field_information['GGDM 3.0']['LAGOON_S']['BEN'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['BMC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['LAGOON_S']['BMC2'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC2']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['LAGOON_S']['BMC3'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['BMC3']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,999)
    field_information['GGDM 3.0']['LAGOON_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['FUFI'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['FURL'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['GDBV'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['GDBV']['BH190']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAGOON_S']['OTH'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['PWAC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['PWAC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAGOON_S']['PWAL'] = ('real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['PWAU'] = ('real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['UFI'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['WDAC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['WDAC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAGOON_S']['WDAL'] = ('real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['WDAU'] = ('real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['WDH'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['WDL'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI001_SDV'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI001_SRT'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI001_SRT']['BH190']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI002_UFI'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI004_RCG'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI004_RCG']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_FNA'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_FNA2'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_FNA3'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_GNT'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_GNT2'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_GNT3'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_NFN'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_NFN2'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI005_NFN3'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI006_MEM'] = ('String',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI020_GE4'] = ('CodeList',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_ASE'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_CFR'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_CLO'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_CYN'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_FMR'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_FRR'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_HAR'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_HYP'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI024_HYP']['BH190']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_MGN'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_PHW'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_SCC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI024_SCC']['BH190']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_SUL'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_TDS'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_TEP'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_TUR'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_WAC'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI024_WTNO'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI025_HDP'] = ('Real',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI025_WLE'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI025_WLE']['BH190']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['LAGOON_S']['ZI026_CTUC'] = ('Enumeration',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAGOON_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAGOON_S']['ZI026_CTUL'] = ('integer',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI026_CTUU'] = ('integer',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI031S_URI'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZI039S_UFI'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZSAX_RS0'] = ('CodeList',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZSAX_RX0'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZSAX_RX3'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAGOON_S']['ZSAX_RX4'] = ('StructuredText',('BH190'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['APT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['APT2'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT2'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT2']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['APT3'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT3'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['APT3']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ARA'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ASY'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['BEN'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['CAA'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['CNCP'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['COS'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['FPT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['FUFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['FURL'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['GDBV'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['GDBV']['GB005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['IKO'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['LASZ'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['LZN'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['MAG'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['NA8'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['NAO'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['OTH'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['PCF'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['PEC'] = ('Boolean',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['WID'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI001_SDV'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI001_SRT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI001_SRT']['GB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI002_UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI004_RCG'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI004_RCG']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI005_FNA'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI005_GNT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI005_GNT']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI005_NFN'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI006_MEM'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI020_GE4'] = ('CodeList',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI026_CTUC'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI026_CTUL'] = ('integer',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI026_CTUU'] = ('integer',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI031S_URI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI039S_UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZI103_MVD'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZSAX_RS0'] = ('CodeList',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZSAX_RX0'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZSAX_RX3'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZSAX_RX4'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZVA'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_P']['ZVH'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['APT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['APT2'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT2'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT2']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['APT3'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT3'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['APT3']['GB005']  = (-999999,1,2,3,5,6,7,8,12,13,16,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ARA'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ASY'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['BEN'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['CAA'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['CNCP'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['COS'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['FPT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['FPT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['FUFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['FURL'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['GDBV'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['GDBV']['GB005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['IKO'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['LASZ'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['LZN'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['MAG'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['NA8'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['NAO'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['OTH'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['PCF'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['PEC'] = ('Boolean',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['WID'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI001_SDV'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI001_SRT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI001_SRT']['GB005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI002_UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI004_RCG'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI004_RCG']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI005_FNA'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI005_GNT'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI005_GNT']['GB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI005_NFN'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI006_MEM'] = ('String',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI020_GE4'] = ('CodeList',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI026_CTUC'] = ('Enumeration',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAND_AERODROME_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI026_CTUL'] = ('integer',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI026_CTUU'] = ('integer',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI031S_URI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI039S_UFI'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZI103_MVD'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZSAX_RS0'] = ('CodeList',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZSAX_RX0'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZSAX_RX3'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZSAX_RX4'] = ('StructuredText',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZVA'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_AERODROME_S']['ZVH'] = ('Real',('GB005'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ARA'] = ('Real',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['BEN'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['CAA'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['CAA']['IA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['CDM'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['CDY'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['CDY'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['CDY']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['CSI'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['CSY'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['F_CODE'] = ('CONSTRAINED_STRING',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['FUFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['FURL'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['GDBV'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['GDBV']['IA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['OTH'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI001_SDV'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI001_SRT'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI001_SRT']['IA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI002_UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI004_RCG'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI004_RCG']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI005_FNA'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI005_GNT'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI005_GNT']['IA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI005_NFN'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI006_MEM'] = ('String',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI020_GE4'] = ('CodeList',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI026_CTUC'] = ('Enumeration',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAND_PARCEL_S']['EnumeratedIndexValues']['ZI026_CTUC']['IA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI026_CTUL'] = ('integer',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI026_CTUU'] = ('integer',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI031S_URI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZI039S_UFI'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZSAX_RS0'] = ('CodeList',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZSAX_RX0'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZSAX_RX3'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_PARCEL_S']['ZSAX_RX4'] = ('StructuredText',('IA040'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ARA'] = ('Real',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['BEN'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['DZP'] = ('Real',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['FUFI'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['FURL'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['GDBV'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['GDBV']['BH090']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['INU'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['INU'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['INU']['BH090']  = (-999999,1,2)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['LZN'] = ('Real',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['OTH'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['UFI'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['WID'] = ('Real',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI001_SDV'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI001_SRT'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI001_SRT']['BH090']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI002_UFI'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI004_RCG'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI004_RCG']['BH090']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI005_FNA'] = ('String',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI005_GNT'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI005_GNT']['BH090']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI005_NFN'] = ('String',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI006_MEM'] = ('String',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI020_GE4'] = ('CodeList',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI024_HYP'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI024_HYP']['BH090']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI026_CTUC'] = ('Enumeration',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH090']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI026_CTUL'] = ('integer',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI026_CTUU'] = ('integer',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI031S_URI'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZI039S_UFI'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZSAX_RS0'] = ('CodeList',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZSAX_RX0'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZSAX_RX3'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_SUBJECT_TO_INUNDATION_S']['ZSAX_RX4'] = ('StructuredText',('BH090'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['AZC'] = ('Boolean',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['BA000_VDC'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['BA000_VDC']['BA010']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['BA000_VDR'] = ('String',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['BEN'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['F_CODE'] = ('CONSTRAINED_STRING',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['FUFI'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['FURL'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['GDBV'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['GDBV']['BA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['LZN'] = ('Real',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['OTH'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['SHD'] = ('Boolean',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['SHO'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['SHO'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['SHO']['BA010']  = (-999999,1,2,7,8,9,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['SLT'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['SLT']['BA010']  = (-999999,6,8,10,11,12,13,14,16,17,18,998,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['UFI'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI001_SDV'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI001_SRT'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT']['BA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI002_UFI'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI004_RCG'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG']['BA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI005_FNA'] = ('String',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI005_GNT'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNT']['BA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI005_NFN'] = ('String',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI006_MEM'] = ('String',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI020_GE4'] = ('CodeList',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI026_CTUC'] = ('Enumeration',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC']['BA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI026_CTUL'] = ('integer',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI026_CTUU'] = ('integer',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI031S_URI'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZI039S_UFI'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZSAX_RS0'] = ('CodeList',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZSAX_RX0'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZSAX_RX3'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LAND_WATER_BOUNDARY_C']['ZSAX_RX4'] = ('StructuredText',('BA010'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['BEN'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['F_CODE'] = ('CONSTRAINED_STRING',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['FUFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['FURL'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['GDBV'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['GDBV']['STB23']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LANDING_ZONE_P']['OTH'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI001_SDV'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI001_SRT'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI001_SRT']['STB23']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI002_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI004_RCG'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI004_RCG']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI006_MEM'] = ('String',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI020_GE4'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI026_CTUC'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_P']['EnumeratedIndexValues']['ZI026_CTUC']['STB23']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI026_CTUL'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI026_CTUU'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI031S_URI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZI039S_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZSAX_RS0'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZSAX_RX0'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZSAX_RX3'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_P']['ZSAX_RX4'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['BEN'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['F_CODE'] = ('CONSTRAINED_STRING',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['FUFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['FURL'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['GDBV'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['GDBV']['STB23']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LANDING_ZONE_S']['OTH'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI001_SDV'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI001_SRT'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI001_SRT']['STB23']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI002_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI004_RCG'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI004_RCG']['STB23']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI006_MEM'] = ('String',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI020_GE4'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI026_CTUC'] = ('Enumeration',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LANDING_ZONE_S']['EnumeratedIndexValues']['ZI026_CTUC']['STB23']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI026_CTUL'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI026_CTUU'] = ('integer',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI031S_URI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZI039S_UFI'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZSAX_RS0'] = ('CodeList',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZSAX_RX0'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZSAX_RX3'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDING_ZONE_S']['ZSAX_RX4'] = ('StructuredText',('STB23'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ARA'] = ('Real',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['BEN'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['FUFI'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['FURL'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['GDBV'] = ('Enumeration',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['GDBV']['DB211']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['LZN'] = ('Real',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['OTH'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['UFI'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['WID'] = ('Real',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI001_SDV'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI001_SRT'] = ('Enumeration',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI001_SRT']['DB211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI002_UFI'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI004_RCG'] = ('Enumeration',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI004_RCG']['DB211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI005_FNA'] = ('String',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI005_GNT'] = ('Enumeration',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI005_GNT']['DB211']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI005_NFN'] = ('String',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI006_MEM'] = ('String',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI020_GE4'] = ('CodeList',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI026_CTUC'] = ('Enumeration',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI026_CTUL'] = ('integer',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI026_CTUU'] = ('integer',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI031S_URI'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZI039S_UFI'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZSAX_RS0'] = ('CodeList',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZSAX_RX0'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZSAX_RX3'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LANDSLIDE_MASS_S']['ZSAX_RX4'] = ('StructuredText',('DB211'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['AOO'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ARA'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['BEN'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['CNCP'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['COS'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['COS']['GB040']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['FUFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['FURL'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['GDBV'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['GDBV']['GB040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['HGT'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['LZN'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['MCC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['MCC2'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['MCC3'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['OTH'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['PCF'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['WID'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI001_SDV'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI001_SRT'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI001_SRT']['GB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI002_UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI004_RCG'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI004_RCG']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI005_FNA'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI005_GNT'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI005_GNT']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI005_NFN'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI006_MEM'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI020_GE4'] = ('CodeList',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI026_CTUC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI026_CTUL'] = ('integer',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI026_CTUU'] = ('integer',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI031S_URI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZI039S_UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZSAX_RS0'] = ('CodeList',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZSAX_RX0'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZSAX_RX3'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZSAX_RX4'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_P']['ZVH'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['AOO'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ARA'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['BEN'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['CNCP'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['COS'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['COS']['GB040']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['FUFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['FURL'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['GDBV'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['GDBV']['GB040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['HGT'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['LZN'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['MCC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['MCC2'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['MCC3'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['OTH'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['PCF'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['WID'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI001_SDV'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI001_SRT'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI001_SRT']['GB040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI002_UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI004_RCG'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI004_RCG']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI005_FNA'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI005_GNT'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI005_GNT']['GB040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI005_NFN'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI006_MEM'] = ('String',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI020_GE4'] = ('CodeList',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI026_CTUC'] = ('Enumeration',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI026_CTUL'] = ('integer',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI026_CTUU'] = ('integer',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI031S_URI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZI039S_UFI'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZSAX_RS0'] = ('CodeList',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZSAX_RX0'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZSAX_RX3'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZSAX_RX4'] = ('StructuredText',('GB040'))
    field_information['GGDM 3.0']['LAUNCH_PAD_S']['ZVH'] = ('Real',('GB040'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['BC040_CAA'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['BC040_CAA'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['BC040_CAA']['BC060']  = (-999999,3,5,7,16,999)
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['BC040_ZVH'] = ('Real',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['BEN'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['COL'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['FUFI'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['FURL'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['GDBV'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['GDBV']['BC060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['LSA'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['LSI'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['LST'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['LVN'] = ('Integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['OTH'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['UFI'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI001_SDV'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI001_SRT'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI001_SRT']['BC060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI002_UFI'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI004_RCG'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI004_RCG']['BC060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI006_MEM'] = ('String',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI020_GE4'] = ('CodeList',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI026_CTUC'] = ('Enumeration',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI026_CTUL'] = ('integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI026_CTUU'] = ('integer',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI031S_URI'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZI039S_UFI'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZSAX_RS0'] = ('CodeList',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZSAX_RX0'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZSAX_RX3'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SECTOR_P']['ZSAX_RX4'] = ('StructuredText',('BC060'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['AOO'] = ('Real',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['AWP'] = ('Boolean',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['BEN'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['CAA'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['CAA']['AL110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['FFN'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['FFN2'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN2']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['FFN3'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['FFN3']['AL110']  = (-999999,480,490,495,900,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['FUFI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['FURL'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['GDBV'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['GDBV']['AL110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['HGT'] = ('Real',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['LMC'] = ('Boolean',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['LZN'] = ('Real',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['OTH'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['PCF'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PCF']['AL110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['PYC'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PYC'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PYC']['AL110']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['PYM'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['PYM']['AL110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['TOS'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['TOS']['AL110']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['UFI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['VOI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['WID'] = ('Real',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI005_FNA'] = ('String',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI005_GNT'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI005_NFN'] = ('String',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI006_MEM'] = ('String',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI020_GE4'] = ('CodeList',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI026_CTUL'] = ('integer',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI026_CTUU'] = ('integer',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('AL110'))
    field_information['GGDM 3.0']['LIGHT_SUPPORT_STRUCTURE_P']['ZVH'] = ('Real',('AL110'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['AOO'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ARA'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['AWP'] = ('Boolean',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC034_BRF'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC034_BRF2'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC034_MRT'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC034_MRT2'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT2']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC034_MRT3'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC034_MRT3']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC040_COL'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC040_EOL'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC040_LVN'] = ('Integer',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC040_MLR'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BC101_SST'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['BC101_SST']['BC070']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['BEN'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['CAA'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['CAA']['BC070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['CNCP'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['COS'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['COS']['BC070']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['FUFI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['FURL'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['GDBV'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['GDBV']['BC070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['HGT'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['LMC'] = ('Boolean',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['LZN'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['OTH'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['PCF'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['PCF']['BC070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['REF'] = ('Boolean',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['UFI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['VOI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['WID'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI001_SDV'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI001_SRT'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI001_SRT']['BC070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI002_UFI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI004_RCG'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI004_RCG']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI005_FNA'] = ('String',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI005_GNT'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI005_GNT']['BC070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI005_NFN'] = ('String',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI006_MEM'] = ('String',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI020_GE4'] = ('CodeList',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI026_CTUC'] = ('Enumeration',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI026_CTUL'] = ('integer',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI026_CTUU'] = ('integer',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI031S_URI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZI039S_UFI'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZSAX_RS0'] = ('CodeList',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZSAX_RX0'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZSAX_RX3'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZSAX_RX4'] = ('StructuredText',('BC070'))
    field_information['GGDM 3.0']['LIGHT_VESSEL_P']['ZVH'] = ('Real',('BC070'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ADR'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['AOO'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ARA'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ATB'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['AWP'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['BC040_LCN'] = ('Integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['BC040_PER'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['BEN'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['CAA'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['CNCP'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['COS'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['FFN'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['FFN2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['FFN3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['FUFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['FURL'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['GDBV'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['GDBV']['BC050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['HGT'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['LMC'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['LZN'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['MAN'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['OTH'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['PCF'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['SSR'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['SSR2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['SSR3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['VCM'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['VCM2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['VCM3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['VOI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['WID'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI001_SDV'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI001_SRT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT']['BC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI002_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI004_RCG'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI005_FNA'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI005_GNT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI005_NFN'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI006_MEM'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI020_GE4'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI026_CTUC'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI026_CTUL'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI026_CTUU'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI031S_URI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZI039S_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZSAX_RS0'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZSAX_RX0'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZSAX_RX3'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZSAX_RX4'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_P']['ZVH'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ADR'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['AOO'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ARA'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ATB'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['AWP'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['BC040_LCN'] = ('Integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['BC040_PER'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['BEN'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['CAA'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['CNCP'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['COS'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['FFN'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['FFN2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['FFN3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['FUFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['FURL'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['GDBV'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['GDBV']['BC050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['HGT'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['LMC'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['LZN'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['MAN'] = ('Boolean',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['OTH'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['PCF'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['SSR'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['SSR2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['SSR3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['VCM'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['VCM2'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['VCM3'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['VOI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['WID'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI001_SDV'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI001_SRT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT']['BC050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI002_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI004_RCG'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI005_FNA'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI005_GNT'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT']['BC050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI005_NFN'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI006_MEM'] = ('String',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI020_GE4'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI026_CTUC'] = ('Enumeration',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BC050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI026_CTUL'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI026_CTUU'] = ('integer',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI031S_URI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZI039S_UFI'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZSAX_RS0'] = ('CodeList',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZSAX_RX0'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZSAX_RX3'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZSAX_RX4'] = ('StructuredText',('BC050'))
    field_information['GGDM 3.0']['LIGHTHOUSE_S']['ZVH'] = ('Real',('BC050'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ARA'] = ('Real',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['BEN'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['CNCP'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['COS'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['COS']['AB021']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['FUFI'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['FURL'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['GDBV'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['GDBV']['AB021']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['LMC'] = ('Boolean',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['LZN'] = ('Real',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['OTH'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['PCF'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['PCF']['AB021']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['UFI'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['WID'] = ('Real',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI001_SDV'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI001_SRT'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI001_SRT']['AB021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI002_UFI'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI004_RCG'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI004_RCG']['AB021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI005_FNA'] = ('String',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI005_GNT'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI005_GNT']['AB021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI005_NFN'] = ('String',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI006_MEM'] = ('String',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI020_GE4'] = ('CodeList',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI026_CTUC'] = ('Enumeration',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AB021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI026_CTUL'] = ('integer',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI026_CTUU'] = ('integer',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI031S_URI'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZI039S_UFI'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZSAX_RS0'] = ('CodeList',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZSAX_RX0'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZSAX_RX3'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LIQUID_DIFFUSER_P']['ZSAX_RX4'] = ('StructuredText',('AB021'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['BEN'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['FUFI'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['FURL'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['GDBV'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['GDBV']['ZC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['OTH'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['UFI'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['VAVC'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['VAVC'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['VAVC']['ZC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['VAVL'] = ('real',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['VAVU'] = ('real',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI001_SDV'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI001_SRT'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI001_SRT']['ZC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI002_UFI'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI004_RCG'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI004_RCG']['ZC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI006_MEM'] = ('String',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI020_GE4'] = ('CodeList',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI026_CTUC'] = ('Enumeration',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI026_CTUL'] = ('integer',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI026_CTUU'] = ('integer',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI031S_URI'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZI039S_UFI'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZSAX_RS0'] = ('CodeList',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZSAX_RX0'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZSAX_RX3'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCAL_MAGNETIC_ANOMALY_S']['ZSAX_RX4'] = ('StructuredText',('ZC040'))
    field_information['GGDM 3.0']['LOCK_C']['AOO'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ARA'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['BEN'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['CAA'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LOCK_C']['CNCP'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['COS'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LOCK_C']['DZP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['FUFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['FURL'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['GDBV'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOCK_C']['HDP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['HGT'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['LMC'] = ('Boolean',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['LNU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['LZN'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['MCC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_C']['MCC2'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_C']['MCC3'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_C']['MWD'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['OTH'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['PCF'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LOCK_C']['UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['WDU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['WID'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI001_SDV'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI001_SRT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOCK_C']['ZI002_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI004_RCG'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOCK_C']['ZI005_FNA'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI005_GNT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOCK_C']['ZI005_NFN'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI006_MEM'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI020_GE4'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI026_CTUC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOCK_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOCK_C']['ZI026_CTUL'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI026_CTUU'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI031S_URI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZI039S_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZSAX_RS0'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZSAX_RX0'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZSAX_RX3'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZSAX_RX4'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_C']['ZVH'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['AOO'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ARA'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['BEN'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['CAA'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LOCK_P']['CNCP'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['COS'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LOCK_P']['DZP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['FUFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['FURL'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['GDBV'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOCK_P']['HDP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['HGT'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['LMC'] = ('Boolean',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['LNU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['LZN'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['MCC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_P']['MCC2'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_P']['MCC3'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_P']['MWD'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['OTH'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['PCF'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LOCK_P']['UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['WDU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['WID'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI001_SDV'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI001_SRT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOCK_P']['ZI002_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI004_RCG'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOCK_P']['ZI005_FNA'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI005_GNT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOCK_P']['ZI005_NFN'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI006_MEM'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI020_GE4'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI026_CTUC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOCK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOCK_P']['ZI026_CTUL'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI026_CTUU'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI031S_URI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZI039S_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZSAX_RS0'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZSAX_RX0'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZSAX_RX3'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZSAX_RX4'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_P']['ZVH'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['AOO'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ARA'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['BEN'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['CAA'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['LOCK_S']['CNCP'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['COS'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['COS']['BI030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LOCK_S']['DZP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['FUFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['FURL'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['GDBV'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['GDBV']['BI030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOCK_S']['HDP'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['HGT'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['LMC'] = ('Boolean',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['LNU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['LZN'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['MCC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_S']['MCC2'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_S']['MCC3'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['GGDM 3.0']['LOCK_S']['MWD'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['OTH'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['PCF'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LOCK_S']['UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['WDU'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['WID'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI001_SDV'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI001_SRT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI001_SRT']['BI030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOCK_S']['ZI002_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI004_RCG'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI004_RCG']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOCK_S']['ZI005_FNA'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI005_GNT'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI005_GNT']['BI030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOCK_S']['ZI005_NFN'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI006_MEM'] = ('String',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI020_GE4'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI026_CTUC'] = ('Enumeration',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOCK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOCK_S']['ZI026_CTUL'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI026_CTUU'] = ('integer',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI031S_URI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZI039S_UFI'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZSAX_RS0'] = ('CodeList',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZSAX_RX0'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZSAX_RX3'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZSAX_RX4'] = ('StructuredText',('BI030'))
    field_information['GGDM 3.0']['LOCK_S']['ZVH'] = ('Real',('BI030'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ARA'] = ('Real',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['BEN'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['FUFI'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['FURL'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['GDBV'] = ('Enumeration',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['GDBV']['EE010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOGGING_SITE_S']['LZN'] = ('Real',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['OTH'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['UFI'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['VTI'] = ('Real',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['WID'] = ('Real',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI001_SDV'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI001_SRT'] = ('Enumeration',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['EE010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI002_UFI'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI004_RCG'] = ('Enumeration',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['EE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI005_FNA'] = ('String',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI005_GNT'] = ('Enumeration',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['EE010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI005_NFN'] = ('String',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI006_MEM'] = ('String',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI020_GE4'] = ('CodeList',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI026_CTUC'] = ('Enumeration',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOGGING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['EE010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI026_CTUL'] = ('integer',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI026_CTUU'] = ('integer',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI031S_URI'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZI039S_UFI'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZSAX_RS0'] = ('CodeList',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZSAX_RX0'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZSAX_RX3'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOGGING_SITE_S']['ZSAX_RX4'] = ('StructuredText',('EE010'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ARA'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['BEN'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['CNCP'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['COS'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['COS']['AK121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LOOKOUT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['FUFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['FURL'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['GDBV'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['GDBV']['AK121']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOOKOUT_P']['LMC'] = ('Boolean',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['LZN'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['OTH'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['PCF'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LOOKOUT_P']['UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['WID'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI001_SDV'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI001_SRT'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI001_SRT']['AK121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI002_UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI004_RCG'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI004_RCG']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI005_FNA'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI005_GNT'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI005_GNT']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI005_NFN'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI006_MEM'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI020_GE4'] = ('CodeList',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI026_CTUC'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOOKOUT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI026_CTUL'] = ('integer',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI026_CTUU'] = ('integer',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI031S_URI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZI039S_UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZSAX_RS0'] = ('CodeList',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZSAX_RX0'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZSAX_RX3'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_P']['ZSAX_RX4'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ARA'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['BEN'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['CNCP'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['COS'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['COS']['AK121']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['LOOKOUT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['FUFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['FURL'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['GDBV'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['GDBV']['AK121']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['LOOKOUT_S']['LMC'] = ('Boolean',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['LZN'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['OTH'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['PCF'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['LOOKOUT_S']['UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['WID'] = ('Real',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI001_SDV'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI001_SRT'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI001_SRT']['AK121']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI002_UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI004_RCG'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI004_RCG']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI005_FNA'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI005_GNT'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI005_GNT']['AK121']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI005_NFN'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI006_MEM'] = ('String',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI020_GE4'] = ('CodeList',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI026_CTUC'] = ('Enumeration',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['LOOKOUT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK121']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI026_CTUL'] = ('integer',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI026_CTUU'] = ('integer',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI031S_URI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZI039S_UFI'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZSAX_RS0'] = ('CodeList',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZSAX_RX0'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZSAX_RX3'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['LOOKOUT_S']['ZSAX_RX4'] = ('StructuredText',('AK121'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ADR'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['AOO'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ARA'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['BEN'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['BNF'] = ('Integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['CAA'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['CAA']['AL371']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['CNCP'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['COS'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['COS']['AL371']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['FUFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['FURL'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['GDBV'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['GDBV']['AL371']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['HGT'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['LMC'] = ('Boolean',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['LZN'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['OTH'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['PCF'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['PCF']['AL371']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['SSR'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['SSR2'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR2']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['SSR3'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['SSR3']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['VCM'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['VCM2'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM2']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['VCM3'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['VCM3']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['WID'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI001_SDV'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI001_SRT'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL371']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI002_UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI004_RCG'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI005_FNA'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI005_NFN'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI006_MEM'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI020_GE4'] = ('CodeList',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI026_CTUC'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL371']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI026_CTUL'] = ('integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI026_CTUU'] = ('integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI031S_URI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZI039S_UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZSAX_RS0'] = ('CodeList',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZSAX_RX0'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZSAX_RX3'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZSAX_RX4'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_P']['ZVH'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ADR'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['AOO'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ARA'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['BEN'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['BNF'] = ('Integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['CAA'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['CAA']['AL371']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['CNCP'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['COS'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['COS']['AL371']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['FUFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['FURL'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['GDBV'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['GDBV']['AL371']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['HGT'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['LMC'] = ('Boolean',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['LZN'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['OTH'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['PCF'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['PCF']['AL371']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['SSR'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['SSR2'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR2']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['SSR3'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['SSR3']['AL371']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['VCM'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['VCM2'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM2']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['VCM3'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['VCM3']['AL371']  = (-999999,3,4,6,8,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['WID'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI001_SDV'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI001_SRT'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL371']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI002_UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI004_RCG'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL371']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI005_FNA'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI005_NFN'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI006_MEM'] = ('String',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI020_GE4'] = ('CodeList',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI026_CTUC'] = ('Enumeration',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL371']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI026_CTUL'] = ('integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI026_CTUU'] = ('integer',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI031S_URI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZI039S_UFI'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZSAX_RS0'] = ('CodeList',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZSAX_RX0'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZSAX_RX3'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZSAX_RX4'] = ('StructuredText',('AL371'))
    field_information['GGDM 3.0']['MANOR_HOUSE_S']['ZVH'] = ('Real',('AL371'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ADR'] = ('String',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['AOO'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ARA'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['BEN'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['CAA'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['CAA']['AI021']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['CNCP'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['COS'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['COS']['AI021']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['FFN'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['FFN2'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN2']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['FFN3'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['FFN3']['AI021']  = (-999999,382,466,470,476,563,570,572,921,930,961,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['FUFI'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['FURL'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['GDBV'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['GDBV']['AI021']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['HGT'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['LMC'] = ('Boolean',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['LZN'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['OTH'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['PCF'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['PCF']['AI021']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['UFI'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['WID'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI001_SDV'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI001_SRT'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI001_SRT']['AI021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI002_UFI'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI004_RCG'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI004_RCG']['AI021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI005_FNA'] = ('String',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI005_GNT'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI005_GNT']['AI021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI005_NFN'] = ('String',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI006_MEM'] = ('String',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI020_GE4'] = ('CodeList',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI026_CTUC'] = ('Enumeration',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AI021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI026_CTUL'] = ('integer',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI026_CTUU'] = ('integer',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI031S_URI'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZI039S_UFI'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZSAX_RS0'] = ('CodeList',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZSAX_RX0'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZSAX_RX3'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZSAX_RX4'] = ('StructuredText',('AI021'))
    field_information['GGDM 3.0']['MANUFACTURED_HOME_PARK_S']['ZVH'] = ('Real',('AI021'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['AQF'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['AQF'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['AQF']['BH050']  = (-999999,1,2,3,4,8)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ARA'] = ('Real',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['BEN'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['CNCP'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['COA'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COA'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COA']['BH050']  = (-999999,2,4)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['COC'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COC']['BH050']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['COG'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COG'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COG']['BH050']  = (-999999,2,4)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['COS'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['COS']['BH050']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['FUFI'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['FURL'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['GDBV'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['GDBV']['BH050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['LMC'] = ('Boolean',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['LZN'] = ('Real',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['MFE'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['MFE'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['MFE']['BH050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['OTH'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['PCF'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PCF']['BH050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['PPO'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['PPO2'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO2']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['PPO3'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['PPO3']['BH050']  = (-999999,11,29,30,39,72,77,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['UFI'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['WID'] = ('Real',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI001_SDV'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI001_SRT'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['BH050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI002_UFI'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI004_RCG'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['BH050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI005_FNA'] = ('String',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI005_GNT'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['BH050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI005_NFN'] = ('String',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI006_MEM'] = ('String',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI020_GE4'] = ('CodeList',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI026_CTUC'] = ('Enumeration',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI026_CTUL'] = ('integer',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI026_CTUU'] = ('integer',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI031S_URI'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZI039S_UFI'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZSAX_RS0'] = ('CodeList',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZSAX_RX0'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZSAX_RX3'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARICULTURE_SITE_S']['ZSAX_RX4'] = ('StructuredText',('BH050'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ARA'] = ('Real',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['BEN'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['CAB'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['CAB'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['CAB']['FC037']  = (-999999,2,3,4,7,8,9,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['DAN'] = ('String',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['FUFI'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['FURL'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['GDBV'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['GDBV']['FC037']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['LZN'] = ('Real',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MAN'] = ('Boolean',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MCY'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MCY2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY2'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MCY3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY3'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MCY3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,14,15,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MLO'] = ('Boolean',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MNR'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MNR2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR2'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MNR3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR3'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MNR3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MRR'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MRR2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR2'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR2']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['MRR3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR3'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['MRR3']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,45,46,47,52,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['OPT'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['OPT'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['OPT']['FC037']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ORS'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ORS2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS2'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS2']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ORS3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS3'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ORS3']['FC037']  = (-999999,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['OTH'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['UFI'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['WID'] = ('Real',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['WPC'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['WPC2'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC2'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC2']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['WPC3'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC3'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['WPC3']['FC037']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI001_SDV'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI001_SRT'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['FC037']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI002_UFI'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI004_RCG'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI005_FNA'] = ('String',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI005_GNT'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['FC037']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI005_NFN'] = ('String',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI006_MEM'] = ('String',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI020_GE4'] = ('CodeList',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI026_CTUC'] = ('Enumeration',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC037']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI026_CTUL'] = ('integer',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI026_CTUU'] = ('integer',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI031S_URI'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZI039S_UFI'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZSAX_RS0'] = ('CodeList',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZSAX_RX0'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZSAX_RX3'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_CAUTION_AREA_S']['ZSAX_RX4'] = ('StructuredText',('FC037'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['BEN'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['BRG'] = ('Real',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['CAA'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['CAA']['FC021']  = (-999999,1,2,3,5,6,7,8,11,13,16,17,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['CFT'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['CFT'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['CFT']['FC021']  = (-999999,3,6,12,13,14,16,17,18,19,20,21,22,23,24,25,27,28,29,30,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DMC'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DPG'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DPG2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG2']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DPG3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DPG3']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DRP'] = ('String',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['DSP'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['DSP']['FC021']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['F_CODE'] = ('CONSTRAINED_STRING',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['FUFI'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['FURL'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['GDBV'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['GDBV']['FC021']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['LAF'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['LAF'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['LAF']['FC021']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['LZN'] = ('Real',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MAN'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MAS'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MCY'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MCY2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY2']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MCY3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MCY3']['FC021']  = (-999999,1,5,10,11,12,13,14,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MLO'] = ('Boolean',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MNR'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MNR2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR2']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MNR3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MNR3']['FC021']  = (-999999,7,8,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MRR'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MRR2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR2']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['MRR3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['MRR3']['FC021']  = (-999999,3,11,16,17,18,19,20,21,24,26,27,28,32,42,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NFP'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NFP2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP2']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NFP3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NFP3']['FC021']  = (-999999,4,6,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NOA'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NOA2'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA2'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA2']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['NOA3'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA3'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['NOA3']['FC021']  = (-999999,14,27,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['OTH'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['UFI'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI001_SDV'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI001_SRT'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI001_SRT']['FC021']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI002_UFI'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI004_RCG'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI004_RCG']['FC021']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI005_FNA'] = ('String',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI005_GNT'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI005_GNT']['FC021']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI005_NFN'] = ('String',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI006_MEM'] = ('String',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI020_GE4'] = ('CodeList',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI026_CTUC'] = ('Enumeration',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['EnumeratedIndexValues']['ZI026_CTUC']['FC021']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI026_CTUL'] = ('integer',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI026_CTUU'] = ('integer',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI031S_URI'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZI039S_UFI'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZSAX_RS0'] = ('CodeList',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZSAX_RX0'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZSAX_RX3'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_LIMIT_C']['ZSAX_RX4'] = ('StructuredText',('FC021'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ARA'] = ('Real',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC034_BRF'] = ('Integer',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC034_BRF2'] = ('Integer',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC034_MRT'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC034_MRT2'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT2']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC034_MRT3'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC034_MRT3']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC040_COL'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC040_MLR'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BC101_SST'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['BC101_SST']['BC041']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['BEN'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['CAA'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['CAA']['BC041']  = (-999999,3,5,16,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['CCR'] = ('String',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['CNCP'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['COC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['COC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['COC']['BC041']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['COS'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['COS']['BC041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['CPT'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['CPT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['CPT']['BC041']  = (-999999,1,2,3,4,5,6,7)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['DKS'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['DKS'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['DKS']['BC041']  = (-999999,1,2,3,4,5,6,7)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['FLT'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['FUFI'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['FURL'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['GDBV'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['GDBV']['BC041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['GUG'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['HGT'] = ('Real',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['IAA'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['IAS'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['LOC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['LOC']['BC041']  = (-999999,44,45)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['LZN'] = ('Real',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['MCC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['MCC']['BC041']  = (-999999,21,64,74,117,152,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['MRP'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['NSC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['NSC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['NSC']['BC041']  = (-999999,2,3,6,7,8,9,10)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['OTH'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['PCF'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['PCF']['BC041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['PRM'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['REF'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['SPT'] = ('Boolean',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['SRL'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['SRL']['BC041']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['TOS'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['TOS']['BC041']  = (-999999,6,8,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['TZP'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['TZP'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['TZP']['BC041']  = (-999999,1,2,3,4,5,7,8,10,11,12,13,14,15,16,19,28,33,34,35,36,37,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['UFI'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['WID'] = ('Real',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI001_SDV'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI001_SRT'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI001_SRT']['BC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI002_UFI'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI004_RCG'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI004_RCG']['BC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI006_MEM'] = ('String',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI020_GE4'] = ('CodeList',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI026_CTUC'] = ('Enumeration',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI026_CTUL'] = ('integer',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI026_CTUU'] = ('integer',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI031S_URI'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZI039S_UFI'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZSAX_RS0'] = ('CodeList',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZSAX_RX0'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZSAX_RX3'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZSAX_RX4'] = ('StructuredText',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAV_LIGHT_SUPPORT_P']['ZVH'] = ('Real',('BC041'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['BC040_COL'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['BC040_MLR'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['BC101_SST'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['BC101_SST']['BC010']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['BEN'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['CNCP'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['COS'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['COS']['BC010']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['FUFI'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['FURL'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['GDBV'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['GDBV']['BC010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['NMC'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['NMC2'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC2'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC2']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['NMC3'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC3'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['NMC3']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['OTH'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['PCF'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['PCF']['BC010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['REF'] = ('Boolean',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['TZP'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['TZP'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['TZP']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['UFI'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI001_SDV'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI001_SRT'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI001_SRT']['BC010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI002_UFI'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI004_RCG'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI004_RCG']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI005_FNA'] = ('String',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI005_GNT'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI005_GNT']['BC010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI005_NFN'] = ('String',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI006_MEM'] = ('String',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI020_GE4'] = ('CodeList',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI026_CTUC'] = ('Enumeration',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI026_CTUL'] = ('integer',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI026_CTUU'] = ('integer',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI031S_URI'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZI039S_UFI'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZSAX_RS0'] = ('CodeList',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZSAX_RX0'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZSAX_RX3'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_BEACON_P']['ZSAX_RX4'] = ('StructuredText',('BC010'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['BC010_REF'] = ('Boolean',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['BC010_TZP'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['BC010_TZP'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['BC010_TZP']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['BEN'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['CNCP'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['COL'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['COS'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['COS']['BC040']  = (-999999,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EOL'] = ('Real',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['FUFI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['FURL'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['GDBV'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['GDBV']['BC040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['IAA'] = ('Boolean',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['LFC'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['LFC2'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC2'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC2']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['LFC3'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC3'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['LFC3']['BC040']  = (-999999,1,4,6,7,8,9,10,11,12,13,14,16,17,18,19,20,21,22,25,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['LVN'] = ('Integer',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['MLR'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['NMC'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['NMC2'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC2'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC2']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['NMC3'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC3'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['NMC3']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['OTH'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['PCF'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['PCF']['BC040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['UFI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['VOI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI001_SDV'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI001_SRT'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI001_SRT']['BC040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI002_UFI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI004_RCG'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI004_RCG']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI005_FNA'] = ('String',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI005_GNT'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI005_GNT']['BC040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI005_NFN'] = ('String',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI006_MEM'] = ('String',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI020_GE4'] = ('CodeList',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI026_CTUC'] = ('Enumeration',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI026_CTUL'] = ('integer',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI026_CTUU'] = ('integer',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI031S_URI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZI039S_UFI'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZSAX_RS0'] = ('CodeList',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZSAX_RX0'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZSAX_RX3'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_LIGHT_P']['ZSAX_RX4'] = ('StructuredText',('BC040'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['BEN'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['FUFI'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['FURL'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['GDBV'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['GDBV']['BC055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['LZN'] = ('Real',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['MCC'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['MCC2'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC2']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['MCC3'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['MCC3']['BC055']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['OTH'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['PCF'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['PCF']['BC055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['UFI'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI001_SDV'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI001_SRT'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI001_SRT']['BC055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI002_UFI'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI004_RCG'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI004_RCG']['BC055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI005_FNA'] = ('String',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI005_GNT'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI005_GNT']['BC055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI005_NFN'] = ('String',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI006_MEM'] = ('String',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI020_GE4'] = ('CodeList',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI026_CTUC'] = ('Enumeration',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI026_CTUL'] = ('integer',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI026_CTUU'] = ('integer',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI031S_URI'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZI039S_UFI'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZSAX_RS0'] = ('CodeList',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZSAX_RX0'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZSAX_RX3'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_NAVIGATION_MARKER_P']['ZSAX_RX4'] = ('StructuredText',('BC055'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['BEN'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['BRR'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['FUFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['FURL'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['GDBV'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['GDBV']['FC130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['OTH'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI001_SDV'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI001_SRT'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI001_SRT']['FC130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI002_UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI004_RCG'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI004_RCG']['FC130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI005_FNA'] = ('String',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI005_GNT'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI005_GNT']['FC130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI005_NFN'] = ('String',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI006_MEM'] = ('String',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI020_GE4'] = ('CodeList',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI026_CTUC'] = ('Enumeration',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['FC130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI026_CTUL'] = ('integer',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI026_CTUU'] = ('integer',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI031S_URI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZI039S_UFI'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZSAX_RS0'] = ('CodeList',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZSAX_RX0'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZSAX_RX3'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADAR_REF_LINE_C']['ZSAX_RX4'] = ('StructuredText',('FC130'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['BC010_REF'] = ('Boolean',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['BC010_TZP'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['BC010_TZP'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['BC010_TZP']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,998,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['BEN'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['BRF'] = ('Integer',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['BRF2'] = ('Integer',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['CNCP'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['COS'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['COS']['BC034']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['F_CODE'] = ('CONSTRAINED_STRING',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['FUFI'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['FURL'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['GDBV'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['GDBV']['BC034']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['MRT'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['MRT'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['MRT']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ORC'] = ('Real',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['OTH'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['PCF'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['PCF']['BC034']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['UFI'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI001_SDV'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI001_SRT'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI001_SRT']['BC034']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI002_UFI'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI004_RCG'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI004_RCG']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI005_FNA'] = ('String',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI005_GNT'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI005_GNT']['BC034']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI005_NFN'] = ('String',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI006_MEM'] = ('String',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI020_GE4'] = ('CodeList',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI026_CTUC'] = ('Enumeration',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['EnumeratedIndexValues']['ZI026_CTUC']['BC034']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI026_CTUL'] = ('integer',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI026_CTUU'] = ('integer',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI031S_URI'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZI039S_UFI'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZSAX_RS0'] = ('CodeList',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZSAX_RX0'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZSAX_RX3'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_RADIOBEACON_P']['ZSAX_RX4'] = ('StructuredText',('BC034'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['BDS'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['BEN'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['BRR'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['BRS'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['DAN'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['DOF'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['DRP'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['F_CODE'] = ('CONSTRAINED_STRING',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['FUFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['FURL'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['GDBV'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['GDBV']['FC165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['HDP'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['LZN'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['MAN'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['OTH'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['RTT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['RTT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['RTT']['FC165']  = (-999999,2,3,4,5,11,13,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['WID'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_DCR'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_DKC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_DKC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC2']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_DKC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_DKC3']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_SVC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_SVC']['FC165']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_TEC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_TEC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC2']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_TEC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_TEC3']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_VDC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZHDP_VDC']['FC165']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZHDP_VDR'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI001_SDV'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI001_SRT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI001_SRT']['FC165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI002_UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI004_RCG'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI004_RCG']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI005_FNA'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI005_GNT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI005_GNT']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI005_NFN'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI006_MEM'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI020_GE4'] = ('CodeList',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI026_CTUC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['EnumeratedIndexValues']['ZI026_CTUC']['FC165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI026_CTUL'] = ('integer',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI026_CTUU'] = ('integer',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI031S_URI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZI039S_UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZSAX_RS0'] = ('CodeList',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZSAX_RX0'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZSAX_RX3'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_C']['ZSAX_RX4'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['BDS'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['BEN'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['BRR'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['BRS'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['DAN'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['DOF'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['DRP'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['FUFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['FURL'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['GDBV'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['GDBV']['FC165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['HDP'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['LZN'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['MAN'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['OTH'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['RTT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['RTT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['RTT']['FC165']  = (-999999,2,3,4,5,11,13,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['WID'] = ('Real',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_DCR'] = ('Boolean',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_DKC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_DKC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC2']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_DKC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_DKC3']['FC165']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_SVC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_SVC']['FC165']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_TEC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_TEC2'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC2']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_TEC3'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_TEC3']['FC165']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_VDC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZHDP_VDC']['FC165']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZHDP_VDR'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI001_SDV'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI001_SRT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI001_SRT']['FC165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI002_UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI004_RCG'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI004_RCG']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI005_FNA'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI005_GNT'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI005_GNT']['FC165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI005_NFN'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI006_MEM'] = ('String',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI020_GE4'] = ('CodeList',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI026_CTUC'] = ('Enumeration',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI026_CTUL'] = ('integer',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI026_CTUU'] = ('integer',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI031S_URI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZI039S_UFI'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZSAX_RS0'] = ('CodeList',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZSAX_RX0'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZSAX_RX3'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_ROUTE_S']['ZSAX_RX4'] = ('StructuredText',('FC165'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ARA'] = ('Real',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['BEN'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['CAA'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['CAA']['BB155']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['CNCP'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['COS'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['COS']['BB155']  = (-999999,3,4,6,9,13,14)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['FUFI'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['FURL'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['GDBV'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['GDBV']['BB155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['HGT'] = ('Real',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['LMC'] = ('Boolean',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['LZN'] = ('Real',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['OTH'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['PCF'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['PCF']['BB155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['STA'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['STA2'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA2'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA2']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['STA3'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA3'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['STA3']['BB155']  = (-999999,1,2,3,4,5,6,11,13,14,15,17,18,19,20,21,22,27,28,29,30,32,33,35,36,37,48,49,50,51,52,53,54,55,56,57,58,59,60,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['UFI'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['WID'] = ('Real',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI001_SDV'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI001_SRT'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['BB155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI002_UFI'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI004_RCG'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['BB155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI005_FNA'] = ('String',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI005_GNT'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['BB155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI005_NFN'] = ('String',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI006_MEM'] = ('String',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI018_BRF'] = ('Integer',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI018_WIT'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI018_WIT']['BB155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI020_GE4'] = ('CodeList',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI026_CTUC'] = ('Enumeration',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI026_CTUL'] = ('integer',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI026_CTUU'] = ('integer',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI031S_URI'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZI039S_UFI'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZSAX_RS0'] = ('CodeList',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZSAX_RX0'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZSAX_RX3'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARITIME_SIGNAL_STATION_P']['ZSAX_RX4'] = ('StructuredText',('BB155'))
    field_information['GGDM 3.0']['MARSH_S']['ARA'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['BEN'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['BMC'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['MARSH_S']['BMC2'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC2']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['MARSH_S']['BMC3'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['BMC3']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['MARSH_S']['CAA'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['CAA']['ED010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MARSH_S']['DMBC'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['DMBC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARSH_S']['DMBL'] = ('real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['DMBU'] = ('real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['DZP'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['F_CODE'] = ('CONSTRAINED_STRING',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['FUFI'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['FURL'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['GDBV'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['GDBV']['ED010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MARSH_S']['LZN'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['OTH'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['TID'] = ('Boolean',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['UFI'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['WDAC'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['WDAC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARSH_S']['WDAL'] = ('real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['WDAU'] = ('real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['WID'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI001_SDV'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI001_SRT'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI001_SRT']['ED010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI002_UFI'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI004_RCG'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI004_RCG']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI005_FNA'] = ('String',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI005_GNT'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI005_GNT']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI005_NFN'] = ('String',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI006_MEM'] = ('String',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI020_GE4'] = ('CodeList',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_ASE'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_CFR'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_CLO'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_CYN'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_FMR'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_FRR'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_HAR'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_HYP'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_HYP']['ED010']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['MARSH_S']['ZI024_MGN'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_PHW'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_SCC'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_SCC']['ED010']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI024_SUL'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_TDS'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_TEP'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_TUR'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_WAC'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_WTNO'] = ('Real',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI024_WUR'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_WUR']['ED010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI024_YWQ'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI024_YWQ']['ED010']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['MARSH_S']['ZI026_CTUC'] = ('Enumeration',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MARSH_S']['EnumeratedIndexValues']['ZI026_CTUC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MARSH_S']['ZI026_CTUL'] = ('integer',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI026_CTUU'] = ('integer',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI031S_URI'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZI039S_UFI'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZSAX_RS0'] = ('CodeList',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZSAX_RX0'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZSAX_RX3'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MARSH_S']['ZSAX_RX4'] = ('StructuredText',('ED010'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['BEN'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['BRR'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['FUFI'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['FURL'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['GDBV'] = ('Enumeration',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['GDBV']['FC100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['LOR'] = ('Real',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['OTH'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['UFI'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI001_SDV'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI001_SRT'] = ('Enumeration',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI001_SRT']['FC100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI002_UFI'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI004_RCG'] = ('Enumeration',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI004_RCG']['FC100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI005_FNA'] = ('String',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI005_GNT'] = ('Enumeration',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI005_GNT']['FC100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI005_NFN'] = ('String',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI006_MEM'] = ('String',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI020_GE4'] = ('CodeList',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI026_CTUC'] = ('Enumeration',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['FC100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI026_CTUL'] = ('integer',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI026_CTUU'] = ('integer',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI031S_URI'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZI039S_UFI'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZSAX_RS0'] = ('CodeList',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZSAX_RX0'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZSAX_RX3'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEASURED_DISTANCE_LINE_C']['ZSAX_RX4'] = ('StructuredText',('FC100'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['AOO'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ARA'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['AWP'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['BEN'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['CAA'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['CNCP'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['COS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['FUFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['FURL'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['GDBV'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['HEI'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['HGT'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['LMC'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['LZN'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['OTH'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['PCF'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['SSC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['VOI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['WID'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI001_SDV'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI001_SRT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI002_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI004_RCG'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI005_FNA'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI005_GNT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI005_NFN'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI006_MEM'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI020_GE4'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI026_CTUC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI026_CTUL'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI026_CTUU'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI031S_URI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZI039S_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZSAX_RS0'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZSAX_RX0'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZSAX_RX3'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZSAX_RX4'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_C']['ZVH'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['AOO'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ARA'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['AWP'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['BEN'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['CAA'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['CNCP'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['COS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['FUFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['FURL'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['GDBV'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['HEI'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['HGT'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['LMC'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['LZN'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['OTH'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['PCF'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['SSC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['VOI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['WID'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI001_SDV'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI001_SRT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI002_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI004_RCG'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI005_FNA'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI005_GNT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI005_NFN'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI006_MEM'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI020_GE4'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI026_CTUC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI026_CTUL'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI026_CTUU'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI031S_URI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZI039S_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZSAX_RS0'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZSAX_RX0'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZSAX_RX3'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZSAX_RX4'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_P']['ZVH'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['AOO'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ARA'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['AWP'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['BEN'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['CAA'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['CAA']['AL130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['CNCP'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['COS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['COS']['AL130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['FUFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['FURL'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['GDBV'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['GDBV']['AL130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['HEI'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['HGT'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['LMC'] = ('Boolean',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['LZN'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['OTH'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['PCF'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['SSC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['SSR'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['SSR2'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['SSR3'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['TOS'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['VOI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['WID'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI001_SDV'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI001_SRT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI001_SRT']['AL130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI002_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI004_RCG'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI004_RCG']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI005_FNA'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI005_GNT'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI005_GNT']['AL130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI005_NFN'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI006_MEM'] = ('String',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI020_GE4'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI026_CTUC'] = ('Enumeration',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI026_CTUL'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI026_CTUU'] = ('integer',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI031S_URI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZI039S_UFI'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZSAX_RS0'] = ('CodeList',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZSAX_RX0'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZSAX_RX3'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZSAX_RX4'] = ('StructuredText',('AL130'))
    field_information['GGDM 3.0']['MEMORIAL_MONUMENT_S']['ZVH'] = ('Real',('AL130'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['BEN'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['CAA'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['CAA']['STBM1']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['DSP'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['DSP'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['DSP']['STBM1']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['F_CODE'] = ('CONSTRAINED_STRING',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['FUFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['FURL'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['GDBV'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['GDBV']['STBM1']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['LZN'] = ('Real',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['MLUS'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['MLUS']['STBM1']  = (-999999,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['OTH'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI001_SDV'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI001_SRT'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI001_SRT']['STBM1']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI002_UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI004_RCG'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI004_RCG']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_FNAA'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_FNAB'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_GNTA'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTA'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTA']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_GNTB'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTB'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI005_GNTB']['STBM1']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_NFNA'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI005_NFNB'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI006_MEM'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI020_FI2A'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI020_FI2B'] = ('String',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI020_GE4'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI020_GE4A'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI020_GE4B'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI026_CTUC'] = ('Enumeration',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['EnumeratedIndexValues']['ZI026_CTUC']['STBM1']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI026_CTUL'] = ('integer',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI026_CTUU'] = ('integer',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI031S_URI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZI039S_UFI'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZSAX_RS0'] = ('CodeList',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZSAX_RX0'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZSAX_RX3'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_BOUNDARY_C']['ZSAX_RX4'] = ('StructuredText',('STBM1'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ADR'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['AOO'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ARA'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['BEN'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['CAA'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['CAA']['SU001']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['CNCP'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['COS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['COS']['SU001']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['FUFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['FURL'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['GDBV'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['GDBV']['SU001']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['LMC'] = ('Boolean',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['LUN'] = ('Boolean',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['LZN'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['MLOP'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['MLOP'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['MLOP']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['MLUS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['MLUS']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,18,19,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['OTH'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['PCF'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['WID'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['YSU'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI001_SDV'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI001_SRT'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI001_SRT']['SU001']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI002_UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI004_RCG'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI004_RCG']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI005_FNA'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI005_GNT'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI005_GNT']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI005_NFN'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI006_MEM'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI020_GE4'] = ('CodeList',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI026_CTUC'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['SU001']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI026_CTUL'] = ('integer',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI026_CTUU'] = ('integer',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI031S_URI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZI039S_UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZSAX_RS0'] = ('CodeList',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZSAX_RX0'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZSAX_RX3'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_P']['ZSAX_RX4'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ADR'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['AOO'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ARA'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['BEN'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['CAA'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['CAA']['SU001']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['CNCP'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['COS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['COS']['SU001']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['FUFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['FURL'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['GDBV'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['GDBV']['SU001']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['LMC'] = ('Boolean',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['LUN'] = ('Boolean',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['LZN'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['MLOP'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['MLOP'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['MLOP']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['MLUS'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['MLUS'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['MLUS']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,18,19,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['OTH'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['PCF'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['WID'] = ('Real',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['YSU'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI001_SDV'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI001_SRT'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI001_SRT']['SU001']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI002_UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI004_RCG'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI004_RCG']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI005_FNA'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI005_GNT'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI005_GNT']['SU001']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI005_NFN'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI006_MEM'] = ('String',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI020_GE4'] = ('CodeList',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI026_CTUC'] = ('Enumeration',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['SU001']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI026_CTUL'] = ('integer',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI026_CTUU'] = ('integer',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI031S_URI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZI039S_UFI'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZSAX_RS0'] = ('CodeList',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZSAX_RX0'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZSAX_RX3'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MILITARY_INSTALLATION_S']['ZSAX_RX4'] = ('StructuredText',('SU001'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['AOO'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ARA'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['AWP'] = ('Boolean',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['BEN'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['CAA'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['CAA']['AA020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['CNCP'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['COS'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['COS']['AA020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['FUFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['FURL'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['GDBV'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['GDBV']['AA020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['HGT'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['LMC'] = ('Boolean',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['LZN'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['OTH'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['PCF'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['PPO'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['PPO2'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['PPO3'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['VOI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['WID'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['AA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI006_MEM'] = ('String',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI020_GE4'] = ('CodeList',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI026_CTUL'] = ('integer',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI026_CTUU'] = ('integer',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_P']['ZVH'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['AOO'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ARA'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['AWP'] = ('Boolean',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['BEN'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['CAA'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['CAA']['AA020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['CNCP'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['COS'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['COS']['AA020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['FUFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['FURL'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['GDBV'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AA020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['HGT'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['LMC'] = ('Boolean',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['LZN'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['OTH'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['PCF'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['PPO'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['PPO2'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['PPO3'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['VOI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['WID'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AA020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AA020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI006_MEM'] = ('String',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AA020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI026_CTUL'] = ('integer',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI026_CTUU'] = ('integer',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AA020'))
    field_information['GGDM 3.0']['MINE_SHAFT_SUPERSTRUCTURE_S']['ZVH'] = ('Real',('AA020'))
    field_information['GGDM 3.0']['MINEFIELD_S']['AOO'] = ('Real',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ARA'] = ('Real',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['BEN'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['FUFI'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['FURL'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['GDBV'] = ('Enumeration',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['GDBV']['AL065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MINEFIELD_S']['LZN'] = ('Real',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['OTH'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['PCF'] = ('Enumeration',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['PCF']['AL065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MINEFIELD_S']['UFI'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['WID'] = ('Real',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI001_SDV'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI001_SRT'] = ('Enumeration',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI001_SRT']['AL065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI002_UFI'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI004_RCG'] = ('Enumeration',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI004_RCG']['AL065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI006_MEM'] = ('String',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI020_GE4'] = ('CodeList',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI026_CTUC'] = ('Enumeration',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MINEFIELD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI026_CTUL'] = ('integer',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI026_CTUU'] = ('integer',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI031S_URI'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZI039S_UFI'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZSAX_RS0'] = ('CodeList',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZSAX_RX0'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZSAX_RX3'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINEFIELD_S']['ZSAX_RX4'] = ('StructuredText',('AL065'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['AOO'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ARA'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['AWP'] = ('Boolean',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['BEN'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['CAA'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['CNCP'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['COS'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['COS']['AM040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['FUFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['FURL'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['GDBV'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['GDBV']['AM040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['HGT'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['LMC'] = ('Boolean',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['LZN'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['OTH'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['PRW'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['PRW2'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['PRW3'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['VOI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['WID'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI001_SDV'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI001_SRT'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI001_SRT']['AM040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI002_UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI004_RCG'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI004_RCG']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI006_MEM'] = ('String',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI020_GE4'] = ('CodeList',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI026_CTUC'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI026_CTUL'] = ('integer',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI026_CTUU'] = ('integer',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI031S_URI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZI039S_UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZSAX_RS0'] = ('CodeList',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZSAX_RX0'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZSAX_RX3'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZSAX_RX4'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_P']['ZVH'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['AOO'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ARA'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['AWP'] = ('Boolean',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['BEN'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['CAA'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['CNCP'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['COS'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['COS']['AM040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['FUFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['FURL'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['GDBV'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['GDBV']['AM040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['HGT'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['LMC'] = ('Boolean',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['LZN'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['OTH'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['PRW'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['PRW2'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['PRW3'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['VOI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['WID'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI001_SDV'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI001_SRT'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI001_SRT']['AM040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI002_UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI004_RCG'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI004_RCG']['AM040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI006_MEM'] = ('String',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI020_GE4'] = ('CodeList',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI026_CTUC'] = ('Enumeration',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MINERAL_PILE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI026_CTUL'] = ('integer',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI026_CTUU'] = ('integer',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI031S_URI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZI039S_UFI'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZSAX_RS0'] = ('CodeList',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZSAX_RX0'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZSAX_RX3'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZSAX_RX4'] = ('StructuredText',('AM040'))
    field_information['GGDM 3.0']['MINERAL_PILE_S']['ZVH'] = ('Real',('AM040'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['AOO'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ARA'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['BEN'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['CAA'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['CAA']['AL120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['CNCP'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['COS'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['COS']['AL120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['FUFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['FURL'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['GDBV'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['GDBV']['AL120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['LMC'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['LUN'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['LZN'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['MST'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['MST2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST2'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['MST3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST3'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['OTH'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['PCF'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['PRM'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['VCM'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['VCM2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM2']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['VCM3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['VCM3']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['WID'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['YSU'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI001_SDV'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI001_SRT'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI002_UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI004_RCG'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI005_FNA'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI005_GNT'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI005_NFN'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI006_MEM'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI020_GE4'] = ('CodeList',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI026_CTUC'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI026_CTUL'] = ('integer',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI026_CTUU'] = ('integer',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI031S_URI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZI039S_UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZSAX_RS0'] = ('CodeList',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZSAX_RX0'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZSAX_RX3'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZSAX_RX4'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_P']['ZVH'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['AOO'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ARA'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['BEN'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['CAA'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['CAA']['AL120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['CNCP'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['COS'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['COS']['AL120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['FUFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['FURL'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['GDBV'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['GDBV']['AL120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['LMC'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['LUN'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['LZN'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['MST'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['MST2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST2'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['MST3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST3'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['OTH'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['PCF'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['PRM'] = ('Boolean',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['VCM'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['VCM2'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM2']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['VCM3'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['VCM3']['AL120']  = (-999999,3,4,6,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['WID'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['YSU'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI001_SDV'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI001_SRT'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI002_UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI004_RCG'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI005_FNA'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI005_GNT'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI005_NFN'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI006_MEM'] = ('String',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI020_GE4'] = ('CodeList',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MISSILE_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI026_CTUL'] = ('integer',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI026_CTUU'] = ('integer',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI031S_URI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZSAX_RS0'] = ('CodeList',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AL120'))
    field_information['GGDM 3.0']['MISSILE_SITE_S']['ZVH'] = ('Real',('AL120'))
    field_information['GGDM 3.0']['MOAT_C']['ARA'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['BEN'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['CNCP'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['COS'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['COS']['BH100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MOAT_C']['DZP'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['FUFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['FURL'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['GDBV'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['GDBV']['BH100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOAT_C']['LZN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['MWD'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['OTH'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['PCF'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MOAT_C']['UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['VLM'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['WD3'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['WID'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI001_SDV'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI001_SRT'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI001_SRT']['BH100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOAT_C']['ZI002_UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI004_RCG'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI004_RCG']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOAT_C']['ZI006_MEM'] = ('String',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI020_GE4'] = ('CodeList',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_ASE'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_CFR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_CLO'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_CYN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_FMR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_FRR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_HAR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_HYP'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['MOAT_C']['ZI024_MGN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_PHW'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_SCC'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['MOAT_C']['ZI024_SUL'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_TDS'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_TEP'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_TUR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_WAC'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_WTNO'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI024_YWQ'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH100']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['MOAT_C']['ZI026_CTUC'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOAT_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOAT_C']['ZI026_CTUL'] = ('integer',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI026_CTUU'] = ('integer',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI031S_URI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZI039S_UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZSAX_RS0'] = ('CodeList',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZSAX_RX0'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZSAX_RX3'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZSAX_RX4'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_C']['ZVH'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ARA'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['BEN'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['CNCP'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['COS'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['COS']['BH100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MOAT_S']['DZP'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['FUFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['FURL'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['GDBV'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['GDBV']['BH100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOAT_S']['LZN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['MWD'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['OTH'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['PCF'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MOAT_S']['UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['VLM'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['WD3'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['WID'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI001_SDV'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI001_SRT'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI001_SRT']['BH100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOAT_S']['ZI002_UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI004_RCG'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI004_RCG']['BH100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOAT_S']['ZI006_MEM'] = ('String',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI020_GE4'] = ('CodeList',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_ASE'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_CFR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_CLO'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_CYN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_FMR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_FRR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_HAR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_HYP'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['MOAT_S']['ZI024_MGN'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_PHW'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_SCC'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['MOAT_S']['ZI024_SUL'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_TDS'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_TEP'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_TUR'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_WAC'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_WTNO'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI024_YWQ'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH100']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['MOAT_S']['ZI026_CTUC'] = ('Enumeration',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOAT_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOAT_S']['ZI026_CTUL'] = ('integer',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI026_CTUU'] = ('integer',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI031S_URI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZI039S_UFI'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZSAX_RS0'] = ('CodeList',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZSAX_RX0'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZSAX_RX3'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZSAX_RX4'] = ('StructuredText',('BH100'))
    field_information['GGDM 3.0']['MOAT_S']['ZVH'] = ('Real',('BH100'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['AOO'] = ('Real',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['AWP'] = ('Boolean',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['BEN'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['CAA'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['CAA']['AQ110']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['CNCP'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['COS'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['COS']['AQ110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MOORING_MAST_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['FUFI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['FURL'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['GDBV'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['GDBV']['AQ110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['GUG'] = ('Boolean',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['HGT'] = ('Real',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['LMC'] = ('Boolean',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['LZN'] = ('Real',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['OTH'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['PCF'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['PCF']['AQ110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MOORING_MAST_P']['PYM'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['PYM']['AQ110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['TOS'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['TOS']['AQ110']  = (-999999,6,12,13,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['UFI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['VOI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['WID'] = ('Real',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI001_SDV'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI001_SRT'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI002_UFI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI004_RCG'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI005_FNA'] = ('String',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI005_GNT'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI005_NFN'] = ('String',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI006_MEM'] = ('String',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI020_GE4'] = ('CodeList',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI026_CTUC'] = ('Enumeration',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOORING_MAST_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI026_CTUL'] = ('integer',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI026_CTUU'] = ('integer',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI031S_URI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZI039S_UFI'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZSAX_RS0'] = ('CodeList',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZSAX_RX0'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZSAX_RX3'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZSAX_RX4'] = ('StructuredText',('AQ110'))
    field_information['GGDM 3.0']['MOORING_MAST_P']['ZVH'] = ('Real',('AQ110'))
    field_information['GGDM 3.0']['MORAINE_S']['ARA'] = ('Real',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['BEN'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['FUFI'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['FURL'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['GDBV'] = ('Enumeration',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['GDBV']['BJ020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MORAINE_S']['LZN'] = ('Real',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['OTH'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['UFI'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['WID'] = ('Real',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI001_SDV'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI001_SRT'] = ('Enumeration',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MORAINE_S']['ZI002_UFI'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI004_RCG'] = ('Enumeration',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MORAINE_S']['ZI005_FNA'] = ('String',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI005_GNT'] = ('Enumeration',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MORAINE_S']['ZI005_NFN'] = ('String',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI006_MEM'] = ('String',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI020_GE4'] = ('CodeList',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI026_CTUC'] = ('Enumeration',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MORAINE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MORAINE_S']['ZI026_CTUL'] = ('integer',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI026_CTUU'] = ('integer',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI031S_URI'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZI039S_UFI'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZSAX_RS0'] = ('CodeList',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZSAX_RX0'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZSAX_RX3'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MORAINE_S']['ZSAX_RX4'] = ('StructuredText',('BJ020'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ADR'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['AOO'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ARA'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['BEN'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['CAA'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['CAA']['AQ170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['CNCP'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['COS'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['COS']['AQ170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['FFN'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['FFN2'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['FFN3'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['FUFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['FURL'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['GDBV'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['GDBV']['AQ170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['HGT'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['LMC'] = ('Boolean',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['LZN'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['OTH'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['PCF'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['SSR'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['SSR2'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['SSR3'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['WID'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI001_SDV'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI001_SRT'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI002_UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI004_RCG'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI005_FNA'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI005_GNT'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI005_NFN'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI006_MEM'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI020_GE4'] = ('CodeList',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI026_CTUL'] = ('integer',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI026_CTUU'] = ('integer',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI031S_URI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZSAX_RS0'] = ('CodeList',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_P']['ZVH'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ADR'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['AOO'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ARA'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['BEN'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['CAA'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['CAA']['AQ170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['CNCP'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['COS'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['COS']['AQ170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['FFN'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['FFN2'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['FFN3'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['FUFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['FURL'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['GDBV'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['GDBV']['AQ170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['HGT'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['LMC'] = ('Boolean',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['LZN'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['OTH'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['PCF'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['SSR'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['SSR2'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['SSR3'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['WID'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI001_SDV'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI001_SRT'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI002_UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI004_RCG'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI005_FNA'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI005_GNT'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI005_NFN'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI006_MEM'] = ('String',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI020_GE4'] = ('CodeList',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI026_CTUL'] = ('integer',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI026_CTUU'] = ('integer',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI031S_URI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZSAX_RS0'] = ('CodeList',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AQ170'))
    field_information['GGDM 3.0']['MOTOR_VEHICLE_STATION_S']['ZVH'] = ('Real',('AQ170'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['AOO'] = ('Real',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ARA'] = ('Real',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['BEN'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['FUFI'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['FURL'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['GDBV'] = ('Enumeration',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['GDBV']['DB150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['LZN'] = ('Real',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['OTH'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['UFI'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['WID'] = ('Real',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI001_SDV'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI001_SRT'] = ('Enumeration',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI001_SRT']['DB150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI002_UFI'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI004_RCG'] = ('Enumeration',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI004_RCG']['DB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI005_FNA'] = ('String',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI005_GNT'] = ('Enumeration',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI005_GNT']['DB150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI005_NFN'] = ('String',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI006_MEM'] = ('String',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI020_GE4'] = ('CodeList',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI026_CTUC'] = ('Enumeration',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI026_CTUL'] = ('integer',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI026_CTUU'] = ('integer',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI031S_URI'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZI039S_UFI'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZSAX_RS0'] = ('CodeList',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZSAX_RX0'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZSAX_RX3'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZSAX_RX4'] = ('StructuredText',('DB150'))
    field_information['GGDM 3.0']['MOUNTAIN_PASS_P']['ZVH'] = ('Real',('DB150'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ADR'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['AOO'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ARA'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['BEN'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['CAA'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['CNCP'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['COS'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['COS']['AM065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['FUFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['FURL'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['GDBV'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AM065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['HGT'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['LMC'] = ('Boolean',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['LUN'] = ('Boolean',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['LZN'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['OTH'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['PCF'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['WID'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AM065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI005_FNA'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI005_NFN'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI006_MEM'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI026_CTUL'] = ('integer',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI026_CTUU'] = ('integer',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_P']['ZVH'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ADR'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['AOO'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ARA'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['BEN'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['CAA'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['CNCP'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['COS'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['COS']['AM065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['FUFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['FURL'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['GDBV'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AM065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['HGT'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['LMC'] = ('Boolean',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['LUN'] = ('Boolean',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['LZN'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['OTH'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['PCF'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['WID'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AM065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI005_FNA'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AM065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI005_NFN'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI006_MEM'] = ('String',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI026_CTUL'] = ('integer',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI026_CTUU'] = ('integer',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AM065'))
    field_information['GGDM 3.0']['MUNITION_STORAGE_FACILITY_S']['ZVH'] = ('Real',('AM065'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['BEN'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['FUFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['FURL'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['GDBV'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['OTH'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI001_SDV'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI001_SRT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI002_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI004_RCG'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_FNA2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_FNA3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNR'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNR2'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNR3'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNT2'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_GNT3'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_NFN2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI005_NFN3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI006_MEM'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI015_GCUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI015_GCUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI015_GCUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI020_GE4'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI026_CTUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI026_CTUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI026_CTUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI031S_URI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZI039S_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZSAX_RS0'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZSAX_RX0'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZSAX_RX3'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_C']['ZSAX_RX4'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['BEN'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['FUFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['FURL'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['GDBV'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['OTH'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI001_SDV'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI001_SRT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI002_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI004_RCG'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_FNA2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_FNA3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNR'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNR2'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNR3'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNT2'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_GNT3'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_NFN2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI005_NFN3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI006_MEM'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI015_GCUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI015_GCUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI015_GCUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI020_GE4'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI026_CTUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI026_CTUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI026_CTUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI031S_URI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZI039S_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZSAX_RS0'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZSAX_RX0'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZSAX_RX3'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_P']['ZSAX_RX4'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['BEN'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['FUFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['FURL'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['GDBV'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['GDBV']['ZD040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['NLT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['NLT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['OTH'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI001_SDV'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI001_SRT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT']['ZD040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI002_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI004_RCG'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_FNA2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_FNA3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNR'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNR2'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNR3'] = ('Integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNT'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNT2'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_GNT3'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3']['ZD040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_NFN2'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI005_NFN3'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI006_MEM'] = ('String',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI015_GCUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI015_GCUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI015_GCUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI015_GCUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI015_GCUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI020_GE4'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI026_CTUC'] = ('Enumeration',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZD040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI026_CTUL'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI026_CTUU'] = ('integer',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI031S_URI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZI039S_UFI'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZSAX_RS0'] = ('CodeList',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZSAX_RX0'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZSAX_RX3'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NAMED_LOCATION_S']['ZSAX_RX4'] = ('StructuredText',('ZD040'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['AQN'] = ('String',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ARA'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['BEN'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['CAA'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['CAA']['NM170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['CNCP'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['COS'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['COS']['NM170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['DMF'] = ('Integer',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['DOF'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['DZP'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['FUFI'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['FURL'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['GDBV'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['GDBV']['NM170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['LUN'] = ('Boolean',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['OTH'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['PCF'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['PCF']['NM170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['SWT'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['SWT']['NM170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['UFI'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['VLM'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI001_SDV'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI001_SRT'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI002_UFI'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI004_RCG'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI006_MEM'] = ('String',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI020_GE4'] = ('CodeList',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_ASE'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_AWO'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_AWOI'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_AWOX'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_CFR'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_CLO'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_CYN'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_FMR'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_FRR'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_HAR'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_HYP'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_MGN'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_PHW'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_SCC'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_SUL'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_TDS'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_TEP'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_TUR'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WAC'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WTNO'] = ('Real',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WUR'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI026_CTUL'] = ('integer',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI026_CTUU'] = ('integer',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI031S_URI'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZSAX_RS0'] = ('CodeList',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['AQN'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ARA'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['BEN'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['CAA'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['CAA']['BH170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['CNCP'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['COS'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['COS']['BH170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['DOF'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['DZP'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['FUFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['FURL'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['GDBV'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['GDBV']['BH170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['LUN'] = ('Boolean',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['LZN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['OTH'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['PCF'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['SWT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['VLM'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['WDST'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WDST']['BH170']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['WID'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['WWM'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['WWM2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['WWM3'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['WWM3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI001_SDV'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI001_SRT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI001_SRT']['BH170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI002_UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI004_RCG'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI004_RCG']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_FNA'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_FNA2'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_GNT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI005_GNT']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_GNT2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI005_GNT2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_NFN'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI005_NFN2'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI006_MEM'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI020_GE4'] = ('CodeList',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_ASE'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_AWO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_AWOI'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_AWOX'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_CFR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_CLO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_CYN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_FMR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_FRR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_HAR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_HYP'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_MGN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_PHW'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_SCC'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_SUL'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_TDS'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_TEP'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_TUR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WAC'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WTNO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WUR'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WUR2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WUR3'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_WUR4'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI024_YWQ'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI026_CTUC'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI026_CTUL'] = ('integer',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI026_CTUU'] = ('integer',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI031S_URI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZI039S_UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZSAX_RS0'] = ('CodeList',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZSAX_RX0'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZSAX_RX3'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_P']['ZSAX_RX4'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['AQN'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ARA'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['BEN'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['CAA'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['CAA']['BH170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['CNCP'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['COS'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['COS']['BH170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['DOF'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['DZP'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['FUFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['FURL'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['GDBV'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['GDBV']['BH170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['LUN'] = ('Boolean',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['LZN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['OTH'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['PCF'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['SWT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['SWT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['VLM'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['WDST'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WDST']['BH170']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['WID'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['WWM'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['WWM2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['WWM3'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['WWM3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI001_SDV'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI001_SRT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI001_SRT']['BH170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI002_UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI004_RCG'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI004_RCG']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_FNA'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_FNA2'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_GNT'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI005_GNT']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_GNT2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_NFN'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI005_NFN2'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI006_MEM'] = ('String',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI020_GE4'] = ('CodeList',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_ASE'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_AWO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_AWOI'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_AWOX'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_CFR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_CLO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_CYN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_FMR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_FRR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_HAR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_HYP'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_MGN'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_PHW'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_SCC'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_SUL'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_TDS'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_TEP'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_TUR'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WAC'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WTNO'] = ('Real',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WUR'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WUR2'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WUR3'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_WUR4'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI024_YWQ'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI026_CTUC'] = ('Enumeration',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NATURAL_POOL_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI026_CTUL'] = ('integer',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI026_CTUU'] = ('integer',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI031S_URI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZI039S_UFI'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZSAX_RS0'] = ('CodeList',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZSAX_RX0'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZSAX_RX3'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NATURAL_POOL_S']['ZSAX_RX4'] = ('StructuredText',('BH170'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ARA'] = ('Real',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['BEN'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['CNCP'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['COS'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['COS']['BB115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['FUFI'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['FURL'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['GDBV'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['GDBV']['BB115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['LZN'] = ('Real',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['MCC'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['MCC2'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC2']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['MCC3'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['MCC3']['BB115']  = (-999999,21,51,62,64,117,150,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['OTH'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['PCF'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['PCF']['BB115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['UFI'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['WID'] = ('Real',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['WLE'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['WLE']['BB115']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI001_SDV'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI001_SRT'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI001_SRT']['BB115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI002_UFI'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI004_RCG'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI004_RCG']['BB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI005_FNA'] = ('String',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI005_GNT'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI005_GNT']['BB115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI005_NFN'] = ('String',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI006_MEM'] = ('String',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI020_GE4'] = ('CodeList',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI026_CTUC'] = ('Enumeration',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI026_CTUL'] = ('integer',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI026_CTUU'] = ('integer',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI031S_URI'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZI039S_UFI'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZSAX_RS0'] = ('CodeList',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZSAX_RX0'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZSAX_RX3'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAUTICAL_GRIDIRON_S']['ZSAX_RX4'] = ('StructuredText',('BB115'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ARA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCA2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCA3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCA3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCB2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BBMCB3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BBMCB3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BEN'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_AWBA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_AWBB'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_IBOA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_IBOA']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_IBOB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_IBOB']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_SHDA'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_SHDB'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_SLTA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_SLTA']['NM020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_SLTB'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BH141_SLTB']['NM020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_WBHA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BH141_WBHB'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BMC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BMC2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BMC3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BMC3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWHAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWHBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWHBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWSAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BPWSBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BPWSBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BWVCAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCBC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['BWVCBC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCBL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['BWVCBU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['CAA'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['CAA']['NM020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['CDA'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['CDL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['CNCP'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['COS'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['COS']['NM020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['CWT'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['DEV'] = ('Integer',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['DMF'] = ('Integer',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['DOXY'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['DZP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['FRZ'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['FUFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['FURL'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['GDBV'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['GDBV']['NM020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['HDP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['HGT'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['LEA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['LMC'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['LOC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['LOC']['NM020']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['LZN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['MWD'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['NVS'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['NVS']['NM020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['OTH'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['PCF'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['PCF']['NM020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['PWA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['RLE'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['RLE']['NM020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['SBB'] = ('Boolean',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WD3'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WDAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['WDAC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WDAL'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WDAU'] = ('real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WDH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WDL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WID'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WVA'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WVH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['WVL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI001_SDV'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI001_SRT'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI002_UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI004_RCG'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_FNA'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_FNA2'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_FNA3'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_GNT'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_GNT2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_GNT3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI005_GNT3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_NFN'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_NFN2'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI005_NFN3'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI006_MEM'] = ('String',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI020_GE4'] = ('CodeList',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_ASE'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_AWO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_AWOI'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_AWOX'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_CFR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_CLO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_CYN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_FMR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_FRR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_HAR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_HYP'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_MGN'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_PHW'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_SCC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_SQN'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_SQN']['NM020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_SUL'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_TDS'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_TEP'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_TUR'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WAC'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WPAC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WPAC']['NM020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WSG'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WSG']['NM020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WTNO'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WUR'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI026_CTUL'] = ('integer',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI026_CTUU'] = ('integer',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI031S_URI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZSAX_RS0'] = ('CodeList',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_AON_S']['ZVH'] = ('Real',('NM020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ARA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCA2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCA3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCA3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCB2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BBMCB3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BBMCB3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BEN'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_AWBA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_AWBB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_WBHA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BH141_WBHB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BMC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BMC2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BMC3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWHBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BPWSBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['BWVCBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['CAA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['CDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['CDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['CNCP'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['COS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['CWT'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['DEV'] = ('Integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['DOXY'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['DZP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['FRZ'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['FUFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['FURL'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['GDBV'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['GDBV']['BH020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['HDP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['HGT'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['LEA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['LMC'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['LOC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['LOC']['BH020']  = (-999999,40,44)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['LZN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['MWD'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['NVS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['OTH'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['PCF'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['PWA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['RLE'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['SBB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['TID'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WD3'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WDAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['WDAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WDAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WDAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WDH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WID'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WVA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['WVL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI001_SDV'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI001_SRT'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI001_SRT']['BH020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI002_UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI004_RCG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI004_RCG']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_FNA'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_FNA2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_FNA3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_GNT'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_GNT2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_GNT3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI005_GNT3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_NFN'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_NFN2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI005_NFN3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI006_MEM'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI020_GE4'] = ('CodeList',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_ASE'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_AWO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_AWOI'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_AWOX'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_CFR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_CLO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_CYN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_FMR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_FRR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_HAR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_MGN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_PHW'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_SCC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_SCC']['BH020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_SQN'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_SQN']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_SUL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_TDS'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_TEP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_TUR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WAC'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WPAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WPAC']['BH020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WSG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WSG']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WTNO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WUR'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WUR2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WUR3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_WUR4'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_WUR4']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI026_CTUC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI026_CTUL'] = ('integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI026_CTUU'] = ('integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI031S_URI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZI039S_UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZSAX_RS0'] = ('CodeList',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZSAX_RX0'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZSAX_RX3'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZSAX_RX4'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_C']['ZVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ARA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCA2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCA3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCA3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCB2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BBMCB3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BBMCB3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BEN'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_AWBA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_AWBB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_WBHA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BH141_WBHB'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BMC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BMC2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BMC3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,14,15,16,17,18,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWHBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BPWSBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCBL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['BWVCBU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['CAA'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['CDA'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['CDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['CNCP'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['COS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['CWT'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['DEV'] = ('Integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['DOXY'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['DZP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['FRZ'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['FUFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['FURL'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['GDBV'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['GDBV']['BH020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['HDP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['HGT'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['LEA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['LMC'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['LOC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['LOC']['BH020']  = (-999999,40,44)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['LZN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['MWD'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['NVS'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['OTH'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['PCF'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['PWA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['RLE'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['SBB'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['TID'] = ('Boolean',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WD3'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WDAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['WDAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WDAL'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WDAU'] = ('real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WDH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WDL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WID'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WVA'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['WVL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI001_SDV'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI001_SRT'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI001_SRT']['BH020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI002_UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI004_RCG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI004_RCG']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_FNA'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_FNA2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_FNA3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_GNT'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_GNT2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_GNT3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_NFN'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_NFN2'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI005_NFN3'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI006_MEM'] = ('String',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI020_GE4'] = ('CodeList',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_ASE'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_AWO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_AWOI'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_AWOX'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_CFR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_CLO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_CYN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_FMR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_FRR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_HAR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_MGN'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_PHW'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_SCC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_SCC']['BH020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_SQN'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_SQN']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_SUL'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_TDS'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_TEP'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_TUR'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WAC'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WPAC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WPAC']['BH020']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WSG'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WSG']['BH020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WTNO'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WUR'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WUR2'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WUR3'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_WUR4'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI026_CTUC'] = ('Enumeration',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI026_CTUL'] = ('integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI026_CTUU'] = ('integer',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI031S_URI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZI039S_UFI'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZSAX_RS0'] = ('CodeList',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZSAX_RX0'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZSAX_RX3'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZSAX_RX4'] = ('StructuredText',('BH020'))
    field_information['GGDM 3.0']['NAVIGABLE_CANAL_S']['ZVH'] = ('Real',('BH020'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ARA'] = ('Real',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['BEN'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['FUFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['FURL'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['GDBV'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['GDBV']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['NDX'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['NDX2'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX2'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX2']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['NDX3'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX3'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['NDX3']['AL024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['OTH'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI001_SDV'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI001_SRT'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI001_SRT']['AL024']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI002_UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI004_RCG'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI004_RCG']['AL024']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI005_FNA'] = ('String',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI005_GNT'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI005_GNT']['AL024']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI005_NFN'] = ('String',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI006_MEM'] = ('String',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI020_GE4'] = ('CodeList',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI026_CTUC'] = ('Enumeration',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL024']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI026_CTUL'] = ('integer',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI026_CTUU'] = ('integer',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI031S_URI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZI039S_UFI'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZSAX_RS0'] = ('CodeList',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZSAX_RX0'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZSAX_RX3'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NEIGHBOURHOOD_S']['ZSAX_RX4'] = ('StructuredText',('AL024'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['AOO'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ARA'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['AWP'] = ('Boolean',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['BEN'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['CAA'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['CAA']['AL014']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['CNCP'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['COS'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['COS']['AL014']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['FUFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['FURL'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['GDBV'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['GDBV']['AL014']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['HGT'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['LMC'] = ('Boolean',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['LZN'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['OTH'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['PCF'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['VOI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['WID'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI001_SDV'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI001_SRT'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL014']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI002_UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI004_RCG'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI005_FNA'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI005_GNT'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI005_NFN'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI006_MEM'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PBY'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PBY2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PBY3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PPO'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PPO2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PPO3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PRW'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PRW2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI014_PRW3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI020_GE4'] = ('CodeList',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI026_CTUC'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL014']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI026_CTUL'] = ('integer',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI026_CTUU'] = ('integer',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI031S_URI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZI039S_UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZSAX_RS0'] = ('CodeList',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZSAX_RX0'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZSAX_RX3'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZSAX_RX4'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_P']['ZVH'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['AOO'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ARA'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['AWP'] = ('Boolean',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['BEN'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['CAA'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['CAA']['AL014']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['CNCP'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['COS'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['COS']['AL014']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['FUFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['FURL'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['GDBV'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['GDBV']['AL014']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['HGT'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['LMC'] = ('Boolean',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['LZN'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['OTH'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['PCF'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['VOI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['WID'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI001_SDV'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI001_SRT'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL014']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI002_UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI004_RCG'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI005_FNA'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI005_GNT'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL014']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI005_NFN'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI006_MEM'] = ('String',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PBY'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PBY2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PBY3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PPO'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PPO2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PPO3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PRW'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PRW2'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI014_PRW3'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI020_GE4'] = ('CodeList',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI026_CTUC'] = ('Enumeration',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL014']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI026_CTUL'] = ('integer',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI026_CTUU'] = ('integer',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI031S_URI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZI039S_UFI'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZSAX_RS0'] = ('CodeList',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZSAX_RX0'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZSAX_RX3'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZSAX_RX4'] = ('StructuredText',('AL014'))
    field_information['GGDM 3.0']['NON_BUILDING_STRUCTURE_S']['ZVH'] = ('Real',('AL014'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ARA'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['BEN'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['CNCP'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['COS'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['COS']['AA054']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['FUFI'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['FURL'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['GDBV'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['GDBV']['AA054']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['HGT'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['LMC'] = ('Boolean',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['LZN'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['OTH'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['PCF'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PCF']['AA054']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['PPO'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['PPO2'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO2']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['PPO3'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['PPO3']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['RIP'] = ('Boolean',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['UFI'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['WEQ'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['WEQ2'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ2'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ2']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['WEQ3'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ3'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['WEQ3']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['WID'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI001_SDV'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI001_SRT'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI001_SRT']['AA054']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI002_UFI'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI004_RCG'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI004_RCG']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI005_FNA'] = ('String',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI005_GNT'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI005_NFN'] = ('String',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI006_MEM'] = ('String',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI020_GE4'] = ('CodeList',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI025_HDP'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI026_CTUC'] = ('Enumeration',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA054']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI026_CTUL'] = ('integer',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI026_CTUU'] = ('integer',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI031S_URI'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZI039S_UFI'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZSAX_RS0'] = ('CodeList',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZSAX_RX0'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZSAX_RX3'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZSAX_RX4'] = ('StructuredText',('AA054'))
    field_information['GGDM 3.0']['NON_WATER_WELL_P']['ZVH'] = ('Real',('AA054'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['AOO'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ARA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['AWP'] = ('Boolean',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['BEN'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['CAA'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['CNCP'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['COS'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['COS']['AD041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['DZP'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['FUFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['FURL'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['GDBV'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['GDBV']['AD041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['HGT'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['LEA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['LMC'] = ('Boolean',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['LZN'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['OTH'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['PCF'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['SSR'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['SSR2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['SSR3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['VCM'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['VCM2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['VCM3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['VOI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['WID'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI001_SDV'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI001_SRT'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI001_SRT']['AD041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI002_UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI004_RCG'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI004_RCG']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI005_FNA'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI005_GNT'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI005_GNT']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI005_NFN'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI006_MEM'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI020_GE4'] = ('CodeList',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI026_CTUC'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI026_CTUL'] = ('integer',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI026_CTUU'] = ('integer',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI031S_URI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZI039S_UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZSAX_RS0'] = ('CodeList',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZSAX_RX0'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZSAX_RX3'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZSAX_RX4'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_P']['ZVH'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['AOO'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ARA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['AWP'] = ('Boolean',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['BEN'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['CAA'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['CNCP'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['COS'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['COS']['AD041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['DZP'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['FUFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['FURL'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['GDBV'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['GDBV']['AD041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['HGT'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['LEA'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['LMC'] = ('Boolean',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['LZN'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['OTH'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['PCF'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['SSR'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['SSR2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['SSR3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['VCM'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['VCM2'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['VCM3'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['VOI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['WID'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI001_SDV'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI001_SRT'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI001_SRT']['AD041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI002_UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI004_RCG'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI004_RCG']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI005_FNA'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI005_GNT'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI005_GNT']['AD041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI005_NFN'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI006_MEM'] = ('String',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI020_GE4'] = ('CodeList',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI026_CTUC'] = ('Enumeration',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI026_CTUL'] = ('integer',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI026_CTUU'] = ('integer',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI031S_URI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZI039S_UFI'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZSAX_RS0'] = ('CodeList',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZSAX_RX0'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZSAX_RX3'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZSAX_RX4'] = ('StructuredText',('AD041'))
    field_information['GGDM 3.0']['NUCLEAR_REACTOR_CONTAINMENT_S']['ZVH'] = ('Real',('AD041'))
    field_information['GGDM 3.0']['OASIS_P']['ARA'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['BEN'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['F_CODE'] = ('CONSTRAINED_STRING',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['FUFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['FURL'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['GDBV'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['GDBV']['EC020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OASIS_P']['LZN'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['OTH'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['PCF'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OASIS_P']['UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['VTI'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['WID'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI001_SDV'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI001_SRT'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI001_SRT']['EC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OASIS_P']['ZI002_UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI004_RCG'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI004_RCG']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OASIS_P']['ZI005_FNA'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI005_GNT'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI005_GNT']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OASIS_P']['ZI005_NFN'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI006_MEM'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI020_GE4'] = ('CodeList',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI026_CTUC'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OASIS_P']['EnumeratedIndexValues']['ZI026_CTUC']['EC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OASIS_P']['ZI026_CTUL'] = ('integer',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI026_CTUU'] = ('integer',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI031S_URI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZI039S_UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZSAX_RS0'] = ('CodeList',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZSAX_RX0'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZSAX_RX3'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_P']['ZSAX_RX4'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ARA'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['BEN'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['F_CODE'] = ('CONSTRAINED_STRING',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['FUFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['FURL'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['GDBV'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['GDBV']['EC020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OASIS_S']['LZN'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['OTH'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['PCF'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OASIS_S']['UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['VTI'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['WID'] = ('Real',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI001_SDV'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI001_SRT'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI001_SRT']['EC020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OASIS_S']['ZI002_UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI004_RCG'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI004_RCG']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OASIS_S']['ZI005_FNA'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI005_GNT'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI005_GNT']['EC020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OASIS_S']['ZI005_NFN'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI006_MEM'] = ('String',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI020_GE4'] = ('CodeList',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI026_CTUC'] = ('Enumeration',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OASIS_S']['EnumeratedIndexValues']['ZI026_CTUC']['EC020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OASIS_S']['ZI026_CTUL'] = ('integer',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI026_CTUU'] = ('integer',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI031S_URI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZI039S_UFI'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZSAX_RS0'] = ('CodeList',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZSAX_RX0'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZSAX_RX3'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OASIS_S']['ZSAX_RX4'] = ('StructuredText',('EC020'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ADR'] = ('String',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['AOO'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ARA'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['BEN'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['CAA'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['CAA']['AG040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['CNCP'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['COS'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['COS']['AG040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['FFN'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['FFN2'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN2']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['FFN3'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['FFN3']['AG040']  = (-999999,382,459,466,482,535,550,572,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['FUFI'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['FURL'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['GDBV'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['GDBV']['AG040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['HGT'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['LMC'] = ('Boolean',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['LZN'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['OTH'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['PCF'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['PCF']['AG040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['UFI'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['WID'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI001_SDV'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI001_SRT'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI001_SRT']['AG040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI002_UFI'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI004_RCG'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI004_RCG']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI005_FNA'] = ('String',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI005_GNT'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI005_GNT']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI005_NFN'] = ('String',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI006_MEM'] = ('String',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PBY'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PBY2'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY2']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PBY3'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PBY3']['AG040']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PPO'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PPO2'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO2']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PPO3'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PPO3']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PRW'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PRW2'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW2']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI014_PRW3'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI014_PRW3']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI018_WIT'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI018_WIT']['AG040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI020_GE4'] = ('CodeList',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI026_CTUC'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AG040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI026_CTUL'] = ('integer',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI026_CTUU'] = ('integer',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI031S_URI'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI037_REL'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI037_REL']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI037_RFA'] = ('Enumeration',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['GGDM 3.0']['OFFICE_PARK_S']['EnumeratedIndexValues']['ZI037_RFA']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,999)
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZI039S_UFI'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZSAX_RS0'] = ('CodeList',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZSAX_RX0'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZSAX_RX3'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZSAX_RX4'] = ('StructuredText',('AG040'))
    field_information['GGDM 3.0']['OFFICE_PARK_S']['ZVH'] = ('Real',('AG040'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['AOO'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ARA'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['AWP'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['BC034_MRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['BC034_MRT2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT2']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['BC034_MRT3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC034_MRT3']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['BC101_SST'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['BC101_SST']['BD115']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['BEN'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['CAA'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['CNCP'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['COS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['COS']['BD115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['FUFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['FURL'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['GDBV'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['GDBV']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['HGT'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['LMC'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['LZN'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['OCS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['OCS'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['OTH'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['PCF'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['VCM'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['VCM2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['VCM3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['VOI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['WID'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI001_SDV'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI001_SRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI001_SRT']['BD115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI002_UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI004_RCG'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI004_RCG']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI005_FNA'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI005_GNT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI005_GNT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI005_NFN'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI006_MEM'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI020_GE4'] = ('CodeList',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI025_HDP'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI025_MAN'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI026_CTUC'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI026_CTUL'] = ('integer',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI026_CTUU'] = ('integer',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI031S_URI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZI039S_UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZSAX_RS0'] = ('CodeList',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZSAX_RX0'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZSAX_RX3'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZSAX_RX4'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_P']['ZVH'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['AOO'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ARA'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['AWP'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['BC034_MRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['BC034_MRT2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT2'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT2']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['BC034_MRT3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT3'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC034_MRT3']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['BC101_SST'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC101_SST'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['BC101_SST']['BD115']  = (-999999,1,2,3,4,6,7,8,9,10,14,15,16,98,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['BEN'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['CAA'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['CNCP'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['COS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['COS']['BD115']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['FUFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['FURL'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['GDBV'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['GDBV']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['HGT'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['LMC'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['LZN'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['OCS'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['OCS'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['OTH'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['PCF'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['VCM'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['VCM2'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['VCM3'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['VOI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['WID'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI001_SDV'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI001_SRT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI001_SRT']['BD115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI002_UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI004_RCG'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI004_RCG']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI005_FNA'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI005_GNT'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI005_GNT']['BD115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI005_NFN'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI006_MEM'] = ('String',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI020_GE4'] = ('CodeList',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI025_HDP'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI025_MAN'] = ('Boolean',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI026_CTUC'] = ('Enumeration',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI026_CTUL'] = ('integer',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI026_CTUU'] = ('integer',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI031S_URI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZI039S_UFI'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZSAX_RS0'] = ('CodeList',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZSAX_RX0'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZSAX_RX3'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZSAX_RX4'] = ('StructuredText',('BD115'))
    field_information['GGDM 3.0']['OFFSHORE_CONSTRUCTION_S']['ZVH'] = ('Real',('BD115'))
    field_information['GGDM 3.0']['ORCHARD_P']['ARA'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['BEN'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['DMBC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['DMBC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_P']['DMBL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['DMBU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['DMT'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['FUFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['FURL'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['GDBV'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['GDBV']['EA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ORCHARD_P']['HGT'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['LMC'] = ('Boolean',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['LZN'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['OTH'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['PVH'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['SDSC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['SDSC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_P']['SDSL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['SDSU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['TRE'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['TRE']['EA040']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ORCHARD_P']['TSCC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['TSCC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_P']['TSCL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['TSCU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['VTI'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['WID'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI001_SDV'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI001_SRT'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI001_SRT']['EA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI002_UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI004_RCG'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI004_RCG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI005_FNA'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI005_GNT'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI005_GNT']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI005_NFN'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI006_MEM'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_CSP'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_CSP2'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP2']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_CSP3'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_CSP3']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_FFP'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_FFP2'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP2']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_FFP3'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_FFP3']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI013_IRG'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI013_IRG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI020_GE4'] = ('CodeList',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI026_CTUC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ORCHARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_P']['ZI026_CTUL'] = ('integer',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI026_CTUU'] = ('integer',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI031S_URI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZI039S_UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZSAX_RS0'] = ('CodeList',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZSAX_RX0'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZSAX_RX3'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZSAX_RX4'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_P']['ZVH'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ARA'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['BEN'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['DMBC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['DMBC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_S']['DMBL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['DMBU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['DMT'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['FUFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['FURL'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['GDBV'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['GDBV']['EA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ORCHARD_S']['HGT'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['LMC'] = ('Boolean',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['LZN'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['OTH'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['PVH'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['SDSC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['SDSC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_S']['SDSL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['SDSU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['TRE'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['TRE']['EA040']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['ORCHARD_S']['TSCC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['TSCC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_S']['TSCL'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['TSCU'] = ('real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['VTI'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['WID'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI001_SDV'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI001_SRT'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI001_SRT']['EA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI002_UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI004_RCG'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI004_RCG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI005_FNA'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI005_GNT'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI005_GNT']['EA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI005_NFN'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI006_MEM'] = ('String',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_CSP'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_CSP2'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP2']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_CSP3'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_CSP3']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_FFP'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_FFP2'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP2']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_FFP3'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_FFP3']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI013_IRG'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI013_IRG']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI020_GE4'] = ('CodeList',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI026_CTUC'] = ('Enumeration',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ORCHARD_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ORCHARD_S']['ZI026_CTUL'] = ('integer',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI026_CTUU'] = ('integer',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI031S_URI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZI039S_UFI'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZSAX_RS0'] = ('CodeList',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZSAX_RX0'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZSAX_RX3'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZSAX_RX4'] = ('StructuredText',('EA040'))
    field_information['GGDM 3.0']['ORCHARD_S']['ZVH'] = ('Real',('EA040'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['AOO'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ARA'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['AWP'] = ('Boolean',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['BEN'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['CAA'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['CAA']['AK080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['CNCP'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['COS'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['COS']['AK080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['F_CODE'] = ('CONSTRAINED_STRING',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['FUFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['FURL'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['GDBV'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['GDBV']['AK080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['HEI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['HGT'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['LMC'] = ('Boolean',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['LZN'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['OTH'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['PCF'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['THI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['VOI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI001_SDV'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI001_SRT'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI001_SRT']['AK080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI002_UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI004_RCG'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI004_RCG']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI005_FNA'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI005_GNT'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI005_GNT']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI005_NFN'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI006_MEM'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI020_GE4'] = ('CodeList',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI026_CTUC'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['EnumeratedIndexValues']['ZI026_CTUC']['AK080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI026_CTUL'] = ('integer',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI026_CTUU'] = ('integer',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI031S_URI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZI039S_UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZSAX_RS0'] = ('CodeList',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZSAX_RX0'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZSAX_RX3'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZSAX_RX4'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_C']['ZVH'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['AOO'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ARA'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['AWP'] = ('Boolean',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['BEN'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['CAA'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['CAA']['AK080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['CNCP'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['COS'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['COS']['AK080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['FUFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['FURL'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['GDBV'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['GDBV']['AK080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['HEI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['HGT'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['LMC'] = ('Boolean',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['LZN'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['OTH'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['PCF'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['THI'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['VOI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI001_SDV'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI001_SRT'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI001_SRT']['AK080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI002_UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI004_RCG'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI004_RCG']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI005_FNA'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI005_GNT'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI005_GNT']['AK080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI005_NFN'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI006_MEM'] = ('String',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI020_GE4'] = ('CodeList',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI026_CTUC'] = ('Enumeration',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI026_CTUL'] = ('integer',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI026_CTUU'] = ('integer',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI031S_URI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZI039S_UFI'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZSAX_RS0'] = ('CodeList',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZSAX_RX0'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZSAX_RX3'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZSAX_RX4'] = ('StructuredText',('AK080'))
    field_information['GGDM 3.0']['OUTDOOR_THEATRE_SCREEN_P']['ZVH'] = ('Real',('AK080'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ARA'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['BCC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['BEN'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['DEV'] = ('Integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['FUFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['FURL'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['GDBV'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['GDBV']['AL155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['LZN'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['OHC'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['OOC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['OOC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['OTH'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['PCF'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['TRS'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['TRS2'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['TRS3'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['WID'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI001_SDV'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI001_SRT'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI001_SRT']['AL155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI002_UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI004_RCG'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI004_RCG']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI006_MEM'] = ('String',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI020_GE4'] = ('CodeList',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI026_CTUC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI026_CTUL'] = ('integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI026_CTUU'] = ('integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI031S_URI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZI039S_UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZSAX_RS0'] = ('CodeList',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZSAX_RX0'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZSAX_RX3'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_C']['ZSAX_RX4'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ARA'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['BCC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['BEN'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['DEV'] = ('Integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['FUFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['FURL'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['GDBV'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['GDBV']['AL155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['LZN'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['OHC'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['OOC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['OOC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['OTH'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['PCF'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['TRS'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['TRS2'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['TRS3'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['WID'] = ('Real',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI001_SDV'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI001_SRT'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI001_SRT']['AL155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI002_UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI004_RCG'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI004_RCG']['AL155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI006_MEM'] = ('String',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI020_GE4'] = ('CodeList',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI026_CTUC'] = ('Enumeration',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI026_CTUL'] = ('integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI026_CTUU'] = ('integer',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI031S_URI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZI039S_UFI'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZSAX_RS0'] = ('CodeList',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZSAX_RX0'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZSAX_RX3'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['OVERHEAD_OBSTRUCTION_P']['ZSAX_RX4'] = ('StructuredText',('AL155'))
    field_information['GGDM 3.0']['PACK_ICE_C']['BEN'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['FUFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['FURL'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['GDBV'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['GDBV']['BJ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PACK_ICE_C']['OTH'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['SSE'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI001_SDV'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI001_SRT'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI001_SRT']['BJ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI002_UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI004_RCG'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI004_RCG']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI005_FNA'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI005_GNT'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI005_GNT']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI005_NFN'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI006_MEM'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI020_GE4'] = ('CodeList',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI026_CTUC'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PACK_ICE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BJ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI026_CTUL'] = ('integer',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI026_CTUU'] = ('integer',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI031S_URI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZI039S_UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZSAX_RS0'] = ('CodeList',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZSAX_RX0'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZSAX_RX3'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_C']['ZSAX_RX4'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['BEN'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['FUFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['FURL'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['GDBV'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['GDBV']['BJ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PACK_ICE_S']['OTH'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['SSE'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI001_SDV'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI001_SRT'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI002_UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI004_RCG'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI005_FNA'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI005_GNT'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI005_NFN'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI006_MEM'] = ('String',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI020_GE4'] = ('CodeList',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI026_CTUC'] = ('Enumeration',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PACK_ICE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI026_CTUL'] = ('integer',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI026_CTUU'] = ('integer',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI031S_URI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZI039S_UFI'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZSAX_RS0'] = ('CodeList',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZSAX_RX0'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZSAX_RX3'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PACK_ICE_S']['ZSAX_RX4'] = ('StructuredText',('BJ070'))
    field_information['GGDM 3.0']['PARK_S']['ADI'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ADI'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ADI']['AK120']  = (-999999,2,3,4,6,999)
    field_information['GGDM 3.0']['PARK_S']['ADR'] = ('String',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ARA'] = ('Real',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['BEN'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['CAA'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['CAA']['AK120']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PARK_S']['CNCP'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['COS'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['COS']['AK120']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['FUFI'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['FURL'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['GDBV'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['GDBV']['AK120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARK_S']['LMC'] = ('Boolean',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['LZN'] = ('Real',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['OTH'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['PCF'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['PCF']['AK120']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARK_S']['SRL'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['SRL']['AK120']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['PARK_S']['UFI'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['WID'] = ('Real',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI001_SDV'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI001_SRT'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI001_SRT']['AK120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARK_S']['ZI002_UFI'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI004_RCG'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI004_RCG']['AK120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARK_S']['ZI005_FNA'] = ('String',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI005_GNT'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI005_GNT']['AK120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARK_S']['ZI005_NFN'] = ('String',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI006_MEM'] = ('String',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI020_GE4'] = ('CodeList',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI026_CTUC'] = ('Enumeration',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARK_S']['ZI026_CTUL'] = ('integer',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI026_CTUU'] = ('integer',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI031S_URI'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZI039S_UFI'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZSAX_RS0'] = ('CodeList',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZSAX_RX0'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZSAX_RX3'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARK_S']['ZSAX_RX4'] = ('StructuredText',('AK120'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ADR'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['AOO'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ARA'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['AWP'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['BEN'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['BNF'] = ('Integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['CAA'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['CAA']['AQ141']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['CNCP'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['COS'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['COS']['AQ141']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['FFN'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['FFN2'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['FFN3'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['FUFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['FURL'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['GDBV'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['GDBV']['AQ141']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['HGT'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['LMC'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['LUN'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['LZN'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['OTH'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['PCF'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['SSR'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['SSR2'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['SSR3'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['VOI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['WID'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI001_SDV'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI001_SRT'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ141']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI002_UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI004_RCG'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI005_FNA'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI005_GNT'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI005_NFN'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI006_MEM'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI020_GE4'] = ('CodeList',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI026_CTUC'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ141']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI026_CTUL'] = ('integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI026_CTUU'] = ('integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI031S_URI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZI039S_UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZSAX_RS0'] = ('CodeList',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZSAX_RX0'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZSAX_RX3'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZSAX_RX4'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_P']['ZVH'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ADR'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['AOO'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ARA'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['AWP'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['BEN'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['BNF'] = ('Integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['CAA'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['CAA']['AQ141']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['CNCP'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['COS'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['COS']['AQ141']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['FFN'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['FFN2'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['FFN3'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['FUFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['FURL'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['GDBV'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['GDBV']['AQ141']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['HGT'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['LMC'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['LUN'] = ('Boolean',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['LZN'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['OTH'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['PCF'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['SSR'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['SSR2'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['SSR3'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['VOI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['WID'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI001_SDV'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI001_SRT'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ141']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI002_UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI004_RCG'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI005_FNA'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI005_GNT'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ141']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI005_NFN'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI006_MEM'] = ('String',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI020_GE4'] = ('CodeList',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI026_CTUC'] = ('Enumeration',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ141']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI026_CTUL'] = ('integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI026_CTUU'] = ('integer',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI031S_URI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZI039S_UFI'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZSAX_RS0'] = ('CodeList',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZSAX_RX0'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZSAX_RX3'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZSAX_RX4'] = ('StructuredText',('AQ141'))
    field_information['GGDM 3.0']['PARKING_GARAGE_S']['ZVH'] = ('Real',('AQ141'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ARA'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['BEN'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['CNCP'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['COS'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['FUFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['FURL'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['GDBV'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['LMC'] = ('Boolean',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['LZN'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['OTH'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['PCF'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['WID'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI001_SDV'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI001_SRT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI002_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI004_RCG'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI005_FNA'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI005_GNT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI005_NFN'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI006_MEM'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI020_GE4'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI026_CTUC'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI026_CTUL'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI026_CTUU'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI031S_URI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZI039S_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZSAX_RS0'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZSAX_RX0'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZSAX_RX3'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_C']['ZSAX_RX4'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ARA'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['BEN'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['CNCP'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['COS'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['FUFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['FURL'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['GDBV'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['LMC'] = ('Boolean',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['LZN'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['OTH'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['PCF'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['WID'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI001_SDV'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI001_SRT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI002_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI004_RCG'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI005_FNA'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI005_GNT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI005_NFN'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI006_MEM'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI020_GE4'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI026_CTUC'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI026_CTUL'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI026_CTUU'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI031S_URI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZI039S_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZSAX_RS0'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZSAX_RX0'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZSAX_RX3'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_P']['ZSAX_RX4'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ARA'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['BEN'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['CNCP'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['COS'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['COS']['AL140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['FUFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['FURL'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['GDBV'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['GDBV']['AL140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['LMC'] = ('Boolean',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['LZN'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['OTH'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['PCF'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['WID'] = ('Real',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI001_SDV'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI001_SRT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI001_SRT']['AL140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI002_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI004_RCG'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI004_RCG']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI005_FNA'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI005_GNT'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI005_GNT']['AL140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI005_NFN'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI006_MEM'] = ('String',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI020_GE4'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI026_CTUC'] = ('Enumeration',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI026_CTUL'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI026_CTUU'] = ('integer',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI031S_URI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZI039S_UFI'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZSAX_RS0'] = ('CodeList',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZSAX_RX0'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZSAX_RX3'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PARTICLE_ACCELERATOR_S']['ZSAX_RX4'] = ('StructuredText',('AL140'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ARA'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['BEN'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['CNCP'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['COS'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['COS']['BH110']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PENSTOCK_C']['DIM'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['FUFI'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['FURL'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['GDBV'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['GDBV']['BH110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PENSTOCK_C']['HGT'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['LMC'] = ('Boolean',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['LOC'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['LOC']['BH110']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['PENSTOCK_C']['LZN'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['OTH'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['PCF'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['PCF']['BH110']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PENSTOCK_C']['SPT'] = ('Boolean',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['UFI'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI001_SDV'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI001_SRT'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI001_SRT']['BH110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI002_UFI'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI004_RCG'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI004_RCG']['BH110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI006_MEM'] = ('String',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI020_GE4'] = ('CodeList',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI026_CTUC'] = ('Enumeration',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PENSTOCK_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI026_CTUL'] = ('integer',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI026_CTUU'] = ('integer',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI031S_URI'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZI039S_UFI'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZSAX_RS0'] = ('CodeList',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZSAX_RX0'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZSAX_RX3'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZSAX_RX4'] = ('StructuredText',('BH110'))
    field_information['GGDM 3.0']['PENSTOCK_C']['ZVH'] = ('Real',('BH110'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ARA'] = ('Real',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['BEN'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['CNCP'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['COS'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['COS']['AK061']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['FUFI'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['FURL'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['GDBV'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['GDBV']['AK061']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['LMC'] = ('Boolean',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['LZN'] = ('Real',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['OTH'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['PCF'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['PCF']['AK061']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['UFI'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['WID'] = ('Real',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI001_SDV'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI001_SRT'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AK061']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI002_UFI'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI004_RCG'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AK061']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI005_FNA'] = ('String',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI005_GNT'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AK061']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI005_NFN'] = ('String',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI006_MEM'] = ('String',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI020_GE4'] = ('CodeList',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PICNIC_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK061']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI026_CTUL'] = ('integer',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI026_CTUU'] = ('integer',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI031S_URI'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZSAX_RS0'] = ('CodeList',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PICNIC_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AK061'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['BEN'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['CAA'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['CAA']['NU113']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['CNCP'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['COS'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['COS']['NU113']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['CWT'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['DEV'] = ('Integer',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['DIM'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['DMF'] = ('Integer',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['DZP'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['FLO'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['FUFI'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['FURL'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['GDBV'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['GDBV']['NU113']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['HGT'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['LEA'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['LMC'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['LOC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['LOC']['NU113']  = (-999999,17,23,40,44,45,46)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['LZN'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['MCC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['MCC2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC2']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['MCC3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['MCC3']['NU113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['NPL'] = ('Integer',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['OTH'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['OWO'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PCF'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PCF']['NU113']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PLT'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PLT2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT2'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT2']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PLT3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT3'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PLT3']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PMPR'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PPO'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PPO2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO2']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['PPO3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['PPO3']['NU113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['RLE'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['RLE']['NU113']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['RTA'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['RTA']['NU113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['SBB'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['SPT'] = ('Boolean',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['UFI'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['WVA'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI001_SDV'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI001_SRT'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NU113']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI002_UFI'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI004_RCG'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_FNA'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_FNA2'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_FNA3'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_GNT'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_GNT2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_GNT3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI005_GNT3']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_NFN'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_NFN2'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI005_NFN3'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI006_MEM'] = ('String',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI020_GE4'] = ('CodeList',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_ASE'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_AWO'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_AWOI'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_AWOX'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_CFR'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_CLO'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_CYN'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_FMR'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_FRR'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_HAR'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_MGN'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_PHW'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_SCC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NU113']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_SUL'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_TDS'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_TEP'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_TUR'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WAC'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WTNO'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WUR'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WUR2'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WUR3'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_WUR4'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NU113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI024_YWQ'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NU113']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI025_HDP'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI026_CTUC'] = ('Enumeration',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PIPELINE_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NU113']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI026_CTUL'] = ('integer',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI026_CTUU'] = ('integer',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI031S_URI'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZI039S_UFI'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZSAX_RS0'] = ('CodeList',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZSAX_RX0'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZSAX_RX3'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZSAX_RX4'] = ('StructuredText',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_AON_S']['ZVH'] = ('Real',('NU113'))
    field_information['GGDM 3.0']['PIPELINE_C']['BEN'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['CAA'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['CAA']['AQ113']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PIPELINE_C']['CNCP'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['COS'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['COS']['AQ113']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PIPELINE_C']['CWT'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['DEV'] = ('Integer',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['DIM'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['DZP'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['FLO'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['FUFI'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['FURL'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['GDBV'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['GDBV']['AQ113']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PIPELINE_C']['HGT'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['LEA'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['LMC'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['LOC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['LOC']['AQ113']  = (-999999,17,23,40,44,45,46)
    field_information['GGDM 3.0']['PIPELINE_C']['LZN'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['MCC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_C']['MCC2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC2']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_C']['MCC3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['MCC3']['AQ113']  = (-999999,2,21,23,51,54,62,64,74,77,83,107,117,999)
    field_information['GGDM 3.0']['PIPELINE_C']['NPL'] = ('Integer',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['OTH'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['OWO'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['PCF'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PCF']['AQ113']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PIPELINE_C']['PLT'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['PIPELINE_C']['PLT2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT2'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT2']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['PIPELINE_C']['PLT3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT3'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PLT3']['AQ113']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['PIPELINE_C']['PMPR'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['PPO'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_C']['PPO2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO2']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_C']['PPO3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['PPO3']['AQ113']  = (-999999,16,45,46,49,61,62,70,83,101,122,123,146,999)
    field_information['GGDM 3.0']['PIPELINE_C']['RLE'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['RLE']['AQ113']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['PIPELINE_C']['RTA'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['RTA']['AQ113']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['PIPELINE_C']['SBB'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['SPT'] = ('Boolean',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['UFI'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['VCO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['WVA'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI001_SDV'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI001_SRT'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ113']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI002_UFI'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI004_RCG'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_FNA'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_FNA2'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_FNA3'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_GNT'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_GNT2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT2']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_GNT3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI005_GNT3']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_NFN'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_NFN2'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI005_NFN3'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI006_MEM'] = ('String',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI020_GE4'] = ('CodeList',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_ASE'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_AWO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_AWOI'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_AWOX'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_CFR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_CLO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_CYN'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_FMR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_FRR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_HAR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_MGN'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_PHW'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_SCC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_SCC']['AQ113']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_SUL'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_TDS'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_TEP'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_TUR'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WAC'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WTNO'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WUR'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WUR2'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR2']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WUR3'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR3']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_WUR4'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_WUR4']['AQ113']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI024_YWQ'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI024_YWQ']['AQ113']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI025_HDP'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI026_CTUC'] = ('Enumeration',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PIPELINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ113']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PIPELINE_C']['ZI026_CTUL'] = ('integer',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI026_CTUU'] = ('integer',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI031S_URI'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZI039S_UFI'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZSAX_RS0'] = ('CodeList',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZSAX_RX0'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZSAX_RX3'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZSAX_RX4'] = ('StructuredText',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_C']['ZVH'] = ('Real',('AQ113'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ARA'] = ('Real',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['BEN'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['CNCP'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['COS'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['COS']['AL165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['FUFI'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['FURL'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['GDBV'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['GDBV']['AL165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['LZN'] = ('Real',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['OTH'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['PCF'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['PCF']['AL165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['UFI'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['WID'] = ('Real',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI001_SDV'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI001_SRT'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI002_UFI'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI004_RCG'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI005_FNA'] = ('String',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI005_GNT'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['AL165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI005_NFN'] = ('String',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI006_MEM'] = ('String',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI020_GE4'] = ('CodeList',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI026_CTUC'] = ('Enumeration',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI026_CTUL'] = ('integer',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI026_CTUU'] = ('integer',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI031S_URI'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZI039S_UFI'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZSAX_RS0'] = ('CodeList',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZSAX_RX0'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZSAX_RX3'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PIPELINE_CROSSING_POINT_P']['ZSAX_RX4'] = ('StructuredText',('AL165'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ADR'] = ('String',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ARA'] = ('Real',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['BEN'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['FUFI'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['FURL'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['GDBV'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['GDBV']['EA030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['LMC'] = ('Boolean',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['LZN'] = ('Real',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['OTH'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['UFI'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['VTI'] = ('Real',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['WID'] = ('Real',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI001_SDV'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI001_SRT'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI001_SRT']['EA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI002_UFI'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI004_RCG'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI004_RCG']['EA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI005_FNA'] = ('String',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI005_GNT'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI005_GNT']['EA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI005_NFN'] = ('String',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI006_MEM'] = ('String',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI013_CSP'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_CSP']['EA030']  = (-999999,1,2,4,5,6,7,10,15,17,19,23,24,29,38,40,41,42,43,45,46,47,159,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI013_FFP'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI013_FFP2'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP2']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI013_FFP3'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI013_FFP3']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI020_GE4'] = ('CodeList',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI026_CTUC'] = ('Enumeration',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI026_CTUL'] = ('integer',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI026_CTUU'] = ('integer',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI031S_URI'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZI039S_UFI'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZSAX_RS0'] = ('CodeList',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZSAX_RX0'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZSAX_RX3'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['PLANT_NURSERY_S']['ZSAX_RX4'] = ('StructuredText',('EA030'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ARA'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['BEN'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['FUFI'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['FURL'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['GDBV'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['GDBV']['BJ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['POLAR_ICE_S']['HGT'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['LZN'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['OTH'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['PFH'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['SNDC'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['SNDC']['BJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['POLAR_ICE_S']['SNDL'] = ('real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['SNDU'] = ('real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['SSE'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['UFI'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['WID'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI001_SDV'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI001_SRT'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI002_UFI'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI004_RCG'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI005_FNA'] = ('String',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI005_GNT'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI005_NFN'] = ('String',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI006_MEM'] = ('String',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI020_GE4'] = ('CodeList',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI026_CTUC'] = ('Enumeration',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['POLAR_ICE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI026_CTUL'] = ('integer',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI026_CTUU'] = ('integer',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI031S_URI'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZI039S_UFI'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZSAX_RS0'] = ('CodeList',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZSAX_RX0'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZSAX_RX3'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZSAX_RX4'] = ('StructuredText',('BJ080'))
    field_information['GGDM 3.0']['POLAR_ICE_S']['ZVH'] = ('Real',('BJ080'))
    field_information['GGDM 3.0']['PORT_P']['ADR'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['AOO'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ARA'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['BEN'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['CAA'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PORT_P']['CNCP'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['COS'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['COS']['BB009']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['PORT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['FFN'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_P']['FFN2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_P']['FFN3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_P']['FUFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['FURL'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['GDBV'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['GDBV']['BB009']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PORT_P']['HGT'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['LMC'] = ('Boolean',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['LZN'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['OTH'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['PCF'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PORT_P']['TID'] = ('Boolean',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['WID'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['WPI'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI001_SDV'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI001_SRT'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI001_SRT']['BB009']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PORT_P']['ZI002_UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI004_RCG'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI004_RCG']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PORT_P']['ZI005_FNA'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI005_GNT'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI005_GNT']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PORT_P']['ZI005_NFN'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI006_MEM'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_P']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_P']['ZI020_GE4'] = ('CodeList',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI026_CTUC'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PORT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB009']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PORT_P']['ZI026_CTUL'] = ('integer',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI026_CTUU'] = ('integer',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI031S_URI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZI039S_UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZSAX_RS0'] = ('CodeList',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZSAX_RX0'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZSAX_RX3'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZSAX_RX4'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_P']['ZVH'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ADR'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['AOO'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ARA'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['BEN'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['CAA'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PORT_S']['CNCP'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['COS'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['COS']['BB009']  = (-999999,1,2,3,4,6,9,13,14)
    field_information['GGDM 3.0']['PORT_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['FFN'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_S']['FFN2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_S']['FFN3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['GGDM 3.0']['PORT_S']['FUFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['FURL'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['GDBV'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['GDBV']['BB009']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PORT_S']['HGT'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['LMC'] = ('Boolean',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['LZN'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['OTH'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['PCF'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PORT_S']['TID'] = ('Boolean',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['WID'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['WPI'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI001_SDV'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI001_SRT'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI001_SRT']['BB009']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PORT_S']['ZI002_UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI004_RCG'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI004_RCG']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PORT_S']['ZI005_FNA'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI005_GNT'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI005_GNT']['BB009']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PORT_S']['ZI005_NFN'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI006_MEM'] = ('String',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_S']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['PORT_S']['ZI020_GE4'] = ('CodeList',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI026_CTUC'] = ('Enumeration',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PORT_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB009']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PORT_S']['ZI026_CTUL'] = ('integer',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI026_CTUU'] = ('integer',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI031S_URI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZI039S_UFI'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZSAX_RS0'] = ('CodeList',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZSAX_RX0'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZSAX_RX3'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZSAX_RX4'] = ('StructuredText',('BB009'))
    field_information['GGDM 3.0']['PORT_S']['ZVH'] = ('Real',('BB009'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ADR'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['AOO'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ARA'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['BEN'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['CAA'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['CAA']['AD030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['CNCP'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['COS'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['COS']['AD030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['FUFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['FURL'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['GDBV'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['GDBV']['AD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['HGT'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['LMC'] = ('Boolean',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['LZN'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['OTH'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['PCF'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['SBT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['SBT2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['SBT3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['VCM'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['VCM2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['VCM3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['WID'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI001_SDV'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI001_SRT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI002_UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI004_RCG'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI005_FNA'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI005_GNT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI005_NFN'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI006_MEM'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI020_GE4'] = ('CodeList',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI026_CTUC'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI026_CTUL'] = ('integer',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI026_CTUU'] = ('integer',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI031S_URI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZI039S_UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZSAX_RS0'] = ('CodeList',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZSAX_RX0'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZSAX_RX3'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZSAX_RX4'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_P']['ZVH'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ADR'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['AOO'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ARA'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['BEN'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['CAA'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['CAA']['AD030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['CNCP'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['COS'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['COS']['AD030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['FUFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['FURL'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['GDBV'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['GDBV']['AD030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['HGT'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['LMC'] = ('Boolean',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['LZN'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['OTH'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['PCF'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['SBT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['SBT2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['SBT3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['VCM'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['VCM2'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['VCM3'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['WID'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI001_SDV'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI001_SRT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AD030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI002_UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI004_RCG'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI005_FNA'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI005_GNT'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI005_NFN'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI006_MEM'] = ('String',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI020_GE4'] = ('CodeList',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI026_CTUC'] = ('Enumeration',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI026_CTUL'] = ('integer',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI026_CTUU'] = ('integer',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI031S_URI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZI039S_UFI'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZSAX_RS0'] = ('CodeList',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZSAX_RX0'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZSAX_RX3'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZSAX_RX4'] = ('StructuredText',('AD030'))
    field_information['GGDM 3.0']['POWER_SUBSTATION_S']['ZVH'] = ('Real',('AD030'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['AOO'] = ('Real',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['BEN'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['CAA'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['CAA']['AQ111']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['CNCP'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['COS'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['COS']['AQ111']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['FUFI'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['FURL'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['GDBV'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['GDBV']['AQ111']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['HGT'] = ('Real',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['LZN'] = ('Real',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['OTH'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['PCF'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['PCF']['AQ111']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['UFI'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['WID'] = ('Real',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI001_SDV'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI001_SRT'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ111']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI002_UFI'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI004_RCG'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ111']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI005_FNA'] = ('String',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI005_GNT'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ111']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI005_NFN'] = ('String',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI006_MEM'] = ('String',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI020_GE4'] = ('CodeList',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI026_CTUC'] = ('Enumeration',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ111']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI026_CTUL'] = ('integer',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI026_CTUU'] = ('integer',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI031S_URI'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZI039S_UFI'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZSAX_RS0'] = ('CodeList',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZSAX_RX0'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZSAX_RX3'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PREPARED_WATERCOURSE_CROSS_P']['ZSAX_RX4'] = ('StructuredText',('AQ111'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ADR'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ARA'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['BEN'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['CNCP'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['COS'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['COS']['AL170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['FUFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['FURL'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['GDBV'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['GDBV']['AL170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['LZN'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['OTH'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['PCF'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['PCF']['AL170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['WID'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI001_SDV'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI001_SRT'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI001_SRT']['AL170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI002_UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI004_RCG'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI004_RCG']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI005_FNA'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI005_GNT'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI005_GNT']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI005_NFN'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI006_MEM'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI020_GE4'] = ('CodeList',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI026_CTUC'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI026_CTUL'] = ('integer',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI026_CTUU'] = ('integer',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI031S_URI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZI039S_UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZSAX_RS0'] = ('CodeList',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZSAX_RX0'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZSAX_RX3'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_P']['ZSAX_RX4'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ADR'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ARA'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['BEN'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['CNCP'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['COS'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['COS']['AL170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['FUFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['FURL'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['GDBV'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['GDBV']['AL170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['LZN'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['OTH'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['PCF'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['PCF']['AL170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['WID'] = ('Real',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI001_SDV'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI001_SRT'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI001_SRT']['AL170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI002_UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI004_RCG'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI004_RCG']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI005_FNA'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI005_GNT'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI005_GNT']['AL170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI005_NFN'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI006_MEM'] = ('String',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI020_GE4'] = ('CodeList',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI026_CTUC'] = ('Enumeration',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI026_CTUL'] = ('integer',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI026_CTUU'] = ('integer',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI031S_URI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZI039S_UFI'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZSAX_RS0'] = ('CodeList',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZSAX_RX0'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZSAX_RX3'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUBLIC_SQUARE_S']['ZSAX_RX4'] = ('StructuredText',('AL170'))
    field_information['GGDM 3.0']['PUMP_P']['BEN'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['CAA'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['CAA']['T0181']  = (-999999,3,5,7,11,13,16,17,999)
    field_information['GGDM 3.0']['PUMP_P']['CNCP'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['COS'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['COS']['T0181']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUMP_P']['DZP'] = ('Real',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['F_CODE'] = ('CONSTRAINED_STRING',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['FUFI'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['FURL'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['GDBV'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['GDBV']['T0181']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMP_P']['HGT'] = ('Real',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['LUN'] = ('Boolean',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['OTH'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['PCF'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['PCF']['T0181']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUMP_P']['SPT'] = ('Boolean',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['UFI'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI001_SDV'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI001_SRT'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI001_SRT']['T0181']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUMP_P']['ZI002_UFI'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI004_RCG'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI004_RCG']['T0181']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUMP_P']['ZI006_MEM'] = ('String',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI020_GE4'] = ('CodeList',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI024_DRL'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_DRL']['T0181']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['PUMP_P']['ZI024_DVPT'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_DVPT']['T0181']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMP_P']['ZI024_PMP'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI024_PMP']['T0181']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PUMP_P']['ZI026_CTUC'] = ('Enumeration',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUMP_P']['EnumeratedIndexValues']['ZI026_CTUC']['T0181']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMP_P']['ZI026_CTUL'] = ('integer',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI026_CTUU'] = ('integer',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI031S_URI'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZI039S_UFI'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZSAX_RS0'] = ('CodeList',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZSAX_RX0'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZSAX_RX3'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMP_P']['ZSAX_RX4'] = ('StructuredText',('T0181'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ARA'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['BEN'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['CAA'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['CAA']['NU116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['CNCP'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['COS'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['COS']['NU116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['DMF'] = ('Integer',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['DZP'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['FFN'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['FFN2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN2']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['FFN3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['FFN3']['NU116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['FUFI'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['FURL'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['GDBV'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['GDBV']['NU116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['HGT'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['LMC'] = ('Boolean',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['LUN'] = ('Boolean',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['LZN'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['OTH'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['PCF'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PCF']['NU116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['PPO'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['PPO2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO2']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['PPO3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['PPO3']['NU116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['UFI'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['VCM'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['VCM2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM2']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['VCM3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['VCM3']['NU116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WDAC'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['WDAC']['NU116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WDAL'] = ('real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WDAU'] = ('real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WDH'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WDL'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['WID'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI001_SDV'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI001_SRT'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NU116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI002_UFI'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI004_RCG'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_FNA'] = ('String',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_FNA2'] = ('String',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_GNT'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_GNT2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_NFN'] = ('String',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI005_NFN2'] = ('String',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI006_MEM'] = ('String',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI020_GE4'] = ('CodeList',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_ASE'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_AWO'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_AWOI'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_AWOX'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_CFR'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_CLO'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_CYN'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_DRL'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_DRL']['NU116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_DVPT'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_DVPT']['NU116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_FMR'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_FRR'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_HAR'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_MGN'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_PHW'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_PMP'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_PMP']['NU116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_SCC'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NU116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_SUL'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_TDS'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_TEP'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_TUR'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WAC'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WTNO'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WUR'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WUR2'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WUR3'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_WUR4'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NU116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI024_YWQ'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NU116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI026_CTUC'] = ('Enumeration',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NU116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI026_CTUL'] = ('integer',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI026_CTUU'] = ('integer',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI031S_URI'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZI039S_UFI'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZSAX_RS0'] = ('CodeList',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZSAX_RX0'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZSAX_RX3'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZSAX_RX4'] = ('StructuredText',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_AON_S']['ZVH'] = ('Real',('NU116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ADR'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['AOO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ARA'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['BEN'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['CAA'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['CAA']['AQ116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['CNCP'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['COS'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['COS']['AQ116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['DZP'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['FFN'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['FFN2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['FFN3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['FUFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['FURL'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['GDBV'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['GDBV']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['HGT'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['LMC'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['LUN'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['LZN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['OTH'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['PCF'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['PPO'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['PPO2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['PPO3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['VCM'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['VCM2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['VCM3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WDAC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['WDAC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WDAL'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WDAU'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WDH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WDL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['WID'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI001_SDV'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI001_SRT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI002_UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI004_RCG'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_FNA'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_FNA2'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_GNT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_GNT2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI005_GNT2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_NFN'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI005_NFN2'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI006_MEM'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI020_GE4'] = ('CodeList',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_ASE'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_AWO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_AWOI'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_AWOX'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_CFR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_CLO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_CYN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_DRL'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_DRL']['AQ116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_DVPT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_DVPT']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_FMR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_FRR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_HAR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_MGN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_PHW'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_PMP'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_PMP']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_SCC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_SCC']['AQ116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_SUL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_TDS'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_TEP'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_TUR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WAC'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WTNO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WUR'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WUR2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WUR3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR3']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_WUR4'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_WUR4']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI024_YWQ'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI024_YWQ']['AQ116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI026_CTUL'] = ('integer',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI026_CTUU'] = ('integer',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI031S_URI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZSAX_RS0'] = ('CodeList',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_P']['ZVH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ADR'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['AOO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ARA'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['BEN'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['CAA'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['CAA']['AQ116']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['CNCP'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['COS'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['COS']['AQ116']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['DZP'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['FFN'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['FFN2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['FFN3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,360,361,362,363,370,500,505,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['FUFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['FURL'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['GDBV'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['GDBV']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['HGT'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['LMC'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['LUN'] = ('Boolean',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['LZN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['OTH'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['PCF'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['PPO'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['PPO2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['PPO3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['VCM'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['VCM2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['VCM3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WDAC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['WDAC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WDAL'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WDAU'] = ('real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WDH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WDL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['WID'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI001_SDV'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI001_SRT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ116']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI002_UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI004_RCG'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_FNA'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_FNA2'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_GNT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_GNT2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI005_GNT2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_NFN'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI005_NFN2'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI006_MEM'] = ('String',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI020_GE4'] = ('CodeList',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_ASE'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_AWO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_AWOI'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_AWOX'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_CFR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_CLO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_CYN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_DRL'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_DRL']['AQ116']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_DVPT'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_DVPT']['AQ116']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_FMR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_FRR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_HAR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_MGN'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_PHW'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_PMP'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_PMP']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_SCC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_SCC']['AQ116']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_SUL'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_TDS'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_TEP'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_TUR'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WAC'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WTNO'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WUR'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WUR2'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR2']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WUR3'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR3']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_WUR4'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_WUR4']['AQ116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI024_YWQ'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI024_YWQ']['AQ116']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PUMPING_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ116']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI026_CTUL'] = ('integer',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI026_CTUU'] = ('integer',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI031S_URI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZSAX_RS0'] = ('CodeList',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AQ116'))
    field_information['GGDM 3.0']['PUMPING_STATION_S']['ZVH'] = ('Real',('AQ116'))
    field_information['GGDM 3.0']['PYLON_P']['AOO'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ARA'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['AT005_CAB'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['PYLON_P']['AT005_CAB2'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB2'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB2']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['PYLON_P']['AT005_CAB3'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB3'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['AT005_CAB3']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['GGDM 3.0']['PYLON_P']['AWP'] = ('Boolean',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['BEN'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['CAA'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['CAA']['AT042']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['PYLON_P']['F_CODE'] = ('CONSTRAINED_STRING',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['FUFI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['FURL'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['GDBV'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['GDBV']['AT042']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['PYLON_P']['HGT'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['LMC'] = ('Boolean',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['LZN'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['OTH'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['PCF'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['PCF']['AT042']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['PYLON_P']['UFI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['VOI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['WID'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI001_SDV'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI001_SRT'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI001_SRT']['AT042']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI002_UFI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI004_RCG'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI004_RCG']['AT042']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI005_FNA'] = ('String',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI005_GNT'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI005_GNT']['AT042']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI005_NFN'] = ('String',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI006_MEM'] = ('String',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI020_GE4'] = ('CodeList',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI026_CTUC'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI026_CTUC']['AT042']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['PYLON_P']['ZI026_CTUL'] = ('integer',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI026_CTUU'] = ('integer',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI031S_URI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI032_GUG'] = ('Boolean',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZI032_PYC'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_PYC'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_PYC']['AT042']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI032_PYM'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_PYM'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_PYM']['AT042']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI032_TOS'] = ('Enumeration',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_TOS'] = {}
    field_information['GGDM 3.0']['PYLON_P']['EnumeratedIndexValues']['ZI032_TOS']['AT042']  = (-999999,6,8,11,12,13,999)
    field_information['GGDM 3.0']['PYLON_P']['ZI039S_UFI'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZSAX_RS0'] = ('CodeList',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZSAX_RX0'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZSAX_RX3'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZSAX_RX4'] = ('StructuredText',('AT042'))
    field_information['GGDM 3.0']['PYLON_P']['ZVH'] = ('Real',('AT042'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ARA'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['BEN'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['BH010_CAA'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['BH010_CAA'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['BH010_CAA']['BH012']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['CNCP'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['COS'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['COS']['BH012']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['DZP'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['FUFI'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['FURL'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['GDBV'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['GDBV']['BH012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['HGT'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['LMC'] = ('Boolean',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['LZN'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['OTH'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['PCF'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['PCF']['BH012']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['UFI'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['WID'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI001_SDV'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI001_SRT'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI001_SRT']['BH012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI002_UFI'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI004_RCG'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI004_RCG']['BH012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI005_FNA'] = ('String',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI005_GNT'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI005_GNT']['BH012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI005_NFN'] = ('String',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI006_MEM'] = ('String',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI020_GE4'] = ('CodeList',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_ASE'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_CFR'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_CLO'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_CYN'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_FMR'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_FRR'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_HAR'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_MGN'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_PHW'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_SCC'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI024_SCC']['BH012']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_SUL'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_TDS'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_TEP'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_TUR'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_WAC'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_WTNO'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI024_YWQ'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH012']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI026_CTUC'] = ('Enumeration',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI026_CTUL'] = ('integer',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI026_CTUU'] = ('integer',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI031S_URI'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZI039S_UFI'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZSAX_RS0'] = ('CodeList',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZSAX_RX0'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZSAX_RX3'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZSAX_RX4'] = ('StructuredText',('BH012'))
    field_information['GGDM 3.0']['QANAT_SHAFT_P']['ZVH'] = ('Real',('BH012'))
    field_information['GGDM 3.0']['RACETRACK_C']['ADR'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ARA'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['BEN'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['CNCP'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['COS'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['COS']['AK130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RACETRACK_C']['F_CODE'] = ('CONSTRAINED_STRING',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['FUFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['FURL'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['GDBV'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['GDBV']['AK130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RACETRACK_C']['HGT'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['LMC'] = ('Boolean',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['LZN'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['OTH'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['PCF'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RACETRACK_C']['RAY'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['RAY'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['RAY']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RACETRACK_C']['UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['WID'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI001_SDV'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI001_SRT'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI001_SRT']['AK130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RACETRACK_C']['ZI002_UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI004_RCG'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI004_RCG']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RACETRACK_C']['ZI005_FNA'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI005_GNT'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI005_GNT']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RACETRACK_C']['ZI005_NFN'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI006_MEM'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI020_GE4'] = ('CodeList',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI026_CTUC'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RACETRACK_C']['EnumeratedIndexValues']['ZI026_CTUC']['AK130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RACETRACK_C']['ZI026_CTUL'] = ('integer',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI026_CTUU'] = ('integer',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI031S_URI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZI039S_UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZSAX_RS0'] = ('CodeList',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZSAX_RX0'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZSAX_RX3'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_C']['ZSAX_RX4'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ADR'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ARA'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['BEN'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['CNCP'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['COS'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['COS']['AK130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RACETRACK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['FUFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['FURL'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['GDBV'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['GDBV']['AK130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RACETRACK_S']['HGT'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['LMC'] = ('Boolean',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['LZN'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['OTH'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['PCF'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RACETRACK_S']['RAY'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['RAY'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['RAY']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['RACETRACK_S']['UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['WID'] = ('Real',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI001_SDV'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI001_SRT'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI001_SRT']['AK130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RACETRACK_S']['ZI002_UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI004_RCG'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI004_RCG']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RACETRACK_S']['ZI005_FNA'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI005_GNT'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI005_GNT']['AK130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RACETRACK_S']['ZI005_NFN'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI006_MEM'] = ('String',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI020_GE4'] = ('CodeList',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI026_CTUC'] = ('Enumeration',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RACETRACK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RACETRACK_S']['ZI026_CTUL'] = ('integer',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI026_CTUU'] = ('integer',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI031S_URI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZI039S_UFI'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZSAX_RS0'] = ('CodeList',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZSAX_RX0'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZSAX_RX3'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RACETRACK_S']['ZSAX_RX4'] = ('StructuredText',('AK130'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ADR'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['AOO'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ARA'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['BEN'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['CAA'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['CAA']['AT045']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['CNCP'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['COS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['COS']['AT045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RADAR_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['FFN'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['FFN2'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['FFN3'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['FUFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['FURL'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['GDBV'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['GDBV']['AT045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['HGT'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['LMC'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['LZN'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['OTH'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['PCF'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RADAR_STATION_P']['PRM'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['RAS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['RAS'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['WID'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['YSU'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI001_SDV'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI001_SRT'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AT045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI002_UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI004_RCG'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI005_FNA'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI005_GNT'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI005_NFN'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI006_MEM'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI020_GE4'] = ('CodeList',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AT045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI026_CTUL'] = ('integer',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI026_CTUU'] = ('integer',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI031S_URI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZSAX_RS0'] = ('CodeList',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_P']['ZVH'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ADR'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['AOO'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ARA'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['BEN'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['CAA'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['CAA']['AT045']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['CNCP'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['COS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['COS']['AT045']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RADAR_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['FFN'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['FFN2'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['FFN3'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['FUFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['FURL'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['GDBV'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['GDBV']['AT045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['HGT'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['LMC'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['LZN'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['OTH'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['PCF'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RADAR_STATION_S']['PRM'] = ('Boolean',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['RAS'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['RAS'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['WID'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['YSU'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI001_SDV'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI001_SRT'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AT045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI002_UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI004_RCG'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI005_FNA'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI005_GNT'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AT045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI005_NFN'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI006_MEM'] = ('String',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI020_GE4'] = ('CodeList',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RADAR_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AT045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI026_CTUL'] = ('integer',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI026_CTUU'] = ('integer',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI031S_URI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZSAX_RS0'] = ('CodeList',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AT045'))
    field_information['GGDM 3.0']['RADAR_STATION_S']['ZVH'] = ('Real',('AT045'))
    field_information['GGDM 3.0']['RAILWAY_C']['BEN'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['CAA'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['CAA']['AN010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RAILWAY_C']['CNCP'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['COS'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['COS']['AN010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_C']['CWT'] = ('Boolean',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['DEV'] = ('Integer',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['F_CODE'] = ('CONSTRAINED_STRING',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['FUFI'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['FURL'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['GDBV'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['GDBV']['AN010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_C']['LMC'] = ('Boolean',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['LOC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['LOC']['AN010']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['RAILWAY_C']['LTN'] = ('Integer',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['LZN'] = ('Real',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['OTH'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['PCF'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['PCF']['AN010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_C']['RLE'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RLE']['AN010']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['RAILWAY_C']['RRC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_C']['RRC2'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC2'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC2']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_C']['RRC3'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC3'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RRC3']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_C']['RTA'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RTA'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RTA']['AN010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RAILWAY_C']['RWC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RWC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['RWC']['AN010']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RAILWAY_C']['SBB'] = ('Boolean',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['SGCC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['SGCC']['AN010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_C']['SGCL'] = ('real',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['SGCU'] = ('real',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['UFI'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['WID'] = ('Real',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI001_SDV'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI001_SRT'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI001_SRT']['AN010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI002_UFI'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI004_RCG'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI004_RCG']['AN010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI005_FNA'] = ('String',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI005_GNT'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI005_GNT']['AN010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI005_NFN'] = ('String',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI006_MEM'] = ('String',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI017_GAW'] = ('Real',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI017_RGC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_RGC']['AN010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI017_RIR'] = ('Boolean',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI017_RRA'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_RRA']['AN010']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI017_TRT'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI017_TRT']['AN010']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI020_GE4'] = ('CodeList',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI026_CTUC'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI026_CTUC']['AN010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI026_CTUL'] = ('integer',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI026_CTUU'] = ('integer',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI026_SUR'] = ('Enumeration',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['RAILWAY_C']['EnumeratedIndexValues']['ZI026_SUR']['AN010']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_C']['ZI031S_URI'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZI039S_UFI'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZSAX_RS0'] = ('CodeList',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZSAX_RX0'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZSAX_RX3'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_C']['ZSAX_RX4'] = ('StructuredText',('AN010'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['BEN'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['CNCP'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['COS'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['COS']['AN050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['CTL'] = ('Real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['CWT'] = ('Boolean',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['F_CODE'] = ('CONSTRAINED_STRING',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['FUFI'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['FURL'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['GDBV'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['GDBV']['AN050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['LOC'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['LOC']['AN050']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['LTN'] = ('Integer',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['LZN'] = ('Real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['OTH'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['PCF'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['PCF']['AN050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['RLE'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RLE']['AN050']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['RRC'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['RRC2'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC2'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC2']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['RRC3'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC3'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RRC3']['AN050']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['RSA'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RSA'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['RSA']['AN050']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['SBB'] = ('Boolean',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['SGCC'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['SGCC']['AN050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['SGCL'] = ('real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['SGCU'] = ('real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['UFI'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['WID'] = ('Real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI001_SDV'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI001_SRT'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI001_SRT']['AN050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI002_UFI'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI004_RCG'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI004_RCG']['AN050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI005_FNA'] = ('String',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI005_GNT'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI005_GNT']['AN050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI005_NFN'] = ('String',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI006_MEM'] = ('String',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI017_GAW'] = ('Real',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI017_RGC'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_RGC']['AN050']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI017_RIR'] = ('Boolean',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI017_RRA'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_RRA']['AN050']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI017_TRT'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI017_TRT']['AN050']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI020_GE4'] = ('CodeList',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI026_CTUC'] = ('Enumeration',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['EnumeratedIndexValues']['ZI026_CTUC']['AN050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI026_CTUL'] = ('integer',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI026_CTUU'] = ('integer',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI031S_URI'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZI039S_UFI'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZSAX_RS0'] = ('CodeList',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZSAX_RX0'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZSAX_RX3'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIDETRACK_C']['ZSAX_RX4'] = ('StructuredText',('AN050'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ARA'] = ('Real',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['BEN'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['CNCP'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['COS'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['COS']['AN085']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['FUFI'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['FURL'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['GDBV'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['GDBV']['AN085']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['LZN'] = ('Real',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['OTH'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['PCF'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['PCF']['AN085']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['UFI'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['WID'] = ('Real',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI001_SDV'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI001_SRT'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI001_SRT']['AN085']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI002_UFI'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI004_RCG'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI004_RCG']['AN085']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI005_FNA'] = ('String',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI005_GNT'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI005_GNT']['AN085']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI005_NFN'] = ('String',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI006_MEM'] = ('String',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI020_GE4'] = ('CodeList',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI026_CTUC'] = ('Enumeration',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AN085']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI026_CTUL'] = ('integer',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI026_CTUU'] = ('integer',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI031S_URI'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZI039S_UFI'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZSAX_RS0'] = ('CodeList',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZSAX_RX0'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZSAX_RX3'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_SIGNAL_P']['ZSAX_RX4'] = ('StructuredText',('AN085'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ARA'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['BEN'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['CNCP'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['COS'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['COS']['AN075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['FUFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['FURL'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['GDBV'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['GDBV']['AN075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['LMC'] = ('Boolean',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['LZN'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['OTH'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['PCF'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['WID'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI001_SDV'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI001_SRT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI001_SRT']['AN075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI002_UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI004_RCG'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI004_RCG']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI005_FNA'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI005_GNT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI005_GNT']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI005_NFN'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI006_MEM'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI017_GAW'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI017_RGC'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI017_RRA'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI017_TRT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI020_GE4'] = ('CodeList',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI026_CTUC'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AN075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI026_CTUL'] = ('integer',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI026_CTUU'] = ('integer',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI031S_URI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZI039S_UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZSAX_RS0'] = ('CodeList',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZSAX_RX0'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZSAX_RX3'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_P']['ZSAX_RX4'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ARA'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['BEN'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['CNCP'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['COS'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['COS']['AN075']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['FUFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['FURL'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['GDBV'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['GDBV']['AN075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['LMC'] = ('Boolean',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['LZN'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['OTH'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['PCF'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['WID'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI001_SDV'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI001_SRT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI001_SRT']['AN075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI002_UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI004_RCG'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI004_RCG']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI005_FNA'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI005_GNT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI005_GNT']['AN075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI005_NFN'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI006_MEM'] = ('String',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI017_GAW'] = ('Real',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI017_RGC'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI017_RRA'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI017_TRT'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI020_GE4'] = ('CodeList',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI026_CTUC'] = ('Enumeration',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AN075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI026_CTUL'] = ('integer',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI026_CTUU'] = ('integer',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI031S_URI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZI039S_UFI'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZSAX_RS0'] = ('CodeList',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZSAX_RX0'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZSAX_RX3'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_TURNTABLE_S']['ZSAX_RX4'] = ('StructuredText',('AN075'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ADR'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['AOO'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ARA'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['BEN'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['CAA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['CAA']['AN060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['CNCP'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['COS'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['COS']['AN060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['CTL'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['FFN'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['FFN2'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN2']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['FFN3'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['FFN3']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['FUFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['FURL'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['GDBV'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['GDBV']['AN060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['HGT'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['LMC'] = ('Boolean',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['LTN'] = ('Integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['LZN'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['OTH'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['PCF'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['PCF']['AN060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['WID'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI001_SDV'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI001_SRT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI001_SRT']['AN060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI002_UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI004_RCG'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI004_RCG']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI005_FNA'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI005_GNT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI005_GNT']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI005_NFN'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI006_MEM'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI017_GAW'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI017_RGC'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_RGC']['AN060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI017_RRA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_RRA']['AN060']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI017_TRT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI017_TRT']['AN060']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI020_GE4'] = ('CodeList',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI026_CTUC'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['AN060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI026_CTUL'] = ('integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI026_CTUU'] = ('integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI031S_URI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZI039S_UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZSAX_RS0'] = ('CodeList',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZSAX_RX0'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZSAX_RX3'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZSAX_RX4'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_P']['ZVH'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ADR'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['AOO'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ARA'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['BEN'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['CAA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['CAA']['AN060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['CNCP'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['COS'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['COS']['AN060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['CTL'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['FFN'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['FFN2'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN2']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['FFN3'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['FFN3']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['FUFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['FURL'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['GDBV'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['GDBV']['AN060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['HGT'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['LMC'] = ('Boolean',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['LTN'] = ('Integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['LZN'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['OTH'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['PCF'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['PCF']['AN060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['WID'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI001_SDV'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI001_SRT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI001_SRT']['AN060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI002_UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI004_RCG'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI004_RCG']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI005_FNA'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI005_GNT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI005_GNT']['AN060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI005_NFN'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI006_MEM'] = ('String',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI017_GAW'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI017_RGC'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_RGC']['AN060']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI017_RRA'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_RRA']['AN060']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI017_TRT'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI017_TRT']['AN060']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI020_GE4'] = ('CodeList',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI026_CTUC'] = ('Enumeration',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AN060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI026_CTUL'] = ('integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI026_CTUU'] = ('integer',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI031S_URI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZI039S_UFI'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZSAX_RS0'] = ('CodeList',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZSAX_RX0'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZSAX_RX3'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZSAX_RX4'] = ('StructuredText',('AN060'))
    field_information['GGDM 3.0']['RAILWAY_YARD_S']['ZVH'] = ('Real',('AN060'))
    field_information['GGDM 3.0']['RAMP_C']['AOO'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ARA'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['BEN'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['CNCP'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['COS'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['COS']['AL195']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAMP_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['FUFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['FURL'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['GDBV'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['GDBV']['AL195']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAMP_C']['LZN'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['OTH'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['PCF'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAMP_C']['UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['WID'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI001_SDV'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI001_SRT'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI001_SRT']['AL195']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAMP_C']['ZI002_UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI004_RCG'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI004_RCG']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAMP_C']['ZI005_FNA'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI005_GNT'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI005_GNT']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAMP_C']['ZI005_NFN'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI006_MEM'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI020_GE4'] = ('CodeList',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI026_CTUC'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAMP_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL195']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAMP_C']['ZI026_CTUL'] = ('integer',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI026_CTUU'] = ('integer',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI031S_URI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZI039S_UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZSAX_RS0'] = ('CodeList',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZSAX_RX0'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZSAX_RX3'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_C']['ZSAX_RX4'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['AOO'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ARA'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['BEN'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['CNCP'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['COS'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['COS']['AL195']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RAMP_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['FUFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['FURL'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['GDBV'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['GDBV']['AL195']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAMP_S']['LZN'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['OTH'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['PCF'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RAMP_S']['UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['WID'] = ('Real',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI001_SDV'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI001_SRT'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI001_SRT']['AL195']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAMP_S']['ZI002_UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI004_RCG'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI004_RCG']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAMP_S']['ZI005_FNA'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI005_GNT'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI005_GNT']['AL195']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAMP_S']['ZI005_NFN'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI006_MEM'] = ('String',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI020_GE4'] = ('CodeList',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI026_CTUC'] = ('Enumeration',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAMP_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL195']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAMP_S']['ZI026_CTUL'] = ('integer',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI026_CTUU'] = ('integer',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI031S_URI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZI039S_UFI'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZSAX_RS0'] = ('CodeList',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZSAX_RX0'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZSAX_RX3'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAMP_S']['ZSAX_RX4'] = ('StructuredText',('AL195'))
    field_information['GGDM 3.0']['RAPIDS_C']['AOO'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ARA'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['BEN'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['FUFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['FURL'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['GDBV'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAPIDS_C']['LMC'] = ('Boolean',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['LZN'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['OTH'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['WID'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI001_SDV'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI001_SRT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAPIDS_C']['ZI002_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI004_RCG'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAPIDS_C']['ZI005_FNA'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI005_GNT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAPIDS_C']['ZI005_NFN'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI006_MEM'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI020_GE4'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI026_CTUC'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAPIDS_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAPIDS_C']['ZI026_CTUL'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI026_CTUU'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI031S_URI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZI039S_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZSAX_RS0'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZSAX_RX0'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZSAX_RX3'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_C']['ZSAX_RX4'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['AOO'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ARA'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['BEN'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['FUFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['FURL'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['GDBV'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAPIDS_P']['LMC'] = ('Boolean',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['LZN'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['OTH'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['WID'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI001_SDV'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI001_SRT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAPIDS_P']['ZI002_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI004_RCG'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAPIDS_P']['ZI005_FNA'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI005_GNT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAPIDS_P']['ZI005_NFN'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI006_MEM'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI020_GE4'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI026_CTUC'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAPIDS_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAPIDS_P']['ZI026_CTUL'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI026_CTUU'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI031S_URI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZI039S_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZSAX_RS0'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZSAX_RX0'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZSAX_RX3'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_P']['ZSAX_RX4'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['AOO'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ARA'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['BEN'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['FUFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['FURL'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['GDBV'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['GDBV']['BH120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RAPIDS_S']['LMC'] = ('Boolean',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['LZN'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['OTH'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['WID'] = ('Real',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI001_SDV'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI001_SRT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI001_SRT']['BH120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RAPIDS_S']['ZI002_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI004_RCG'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI004_RCG']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RAPIDS_S']['ZI005_FNA'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI005_GNT'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI005_GNT']['BH120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RAPIDS_S']['ZI005_NFN'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI006_MEM'] = ('String',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI020_GE4'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI026_CTUC'] = ('Enumeration',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RAPIDS_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RAPIDS_S']['ZI026_CTUL'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI026_CTUU'] = ('integer',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI031S_URI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZI039S_UFI'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZSAX_RS0'] = ('CodeList',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZSAX_RX0'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZSAX_RX3'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RAPIDS_S']['ZSAX_RX4'] = ('StructuredText',('BH120'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['AOO'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ARA'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['BEN'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['CAA'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['CAA']['AB010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['CNCP'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['COS'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['COS']['AB010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['FUFI'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['FURL'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['GDBV'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['GDBV']['AB010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['HGT'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['LMC'] = ('Boolean',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['LZN'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['OTH'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['PCF'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['PCF']['AB010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['UFI'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['WID'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI001_SDV'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI001_SRT'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['AB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI002_UFI'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI004_RCG'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['AB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI005_FNA'] = ('String',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI005_GNT'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['AB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI005_NFN'] = ('String',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI006_MEM'] = ('String',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI020_GE4'] = ('CodeList',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI026_CTUC'] = ('Enumeration',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI026_CTUL'] = ('integer',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI026_CTUU'] = ('integer',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI031S_URI'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZI039S_UFI'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZSAX_RS0'] = ('CodeList',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZSAX_RX0'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZSAX_RX3'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZSAX_RX4'] = ('StructuredText',('AB010'))
    field_information['GGDM 3.0']['RECYCLING_SITE_S']['ZVH'] = ('Real',('AB010'))
    field_information['GGDM 3.0']['REEF_C']['BEN'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['F_CODE'] = ('CONSTRAINED_STRING',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['FUFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['FURL'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['GDBV'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['GDBV']['BD120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['REEF_C']['MCC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_C']['MCC2'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC2']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_C']['MCC3'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['MCC3']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_C']['OTH'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI001_SDV'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI001_SRT'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI001_SRT']['BD120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['REEF_C']['ZI002_UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI004_RCG'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI004_RCG']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['REEF_C']['ZI005_FNA'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI005_GNT'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI005_GNT']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['REEF_C']['ZI005_NFN'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI006_MEM'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI020_GE4'] = ('CodeList',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI025_HDP'] = ('Real',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI025_WLE'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI025_WLE']['BD120']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['REEF_C']['ZI026_CTUC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['REEF_C']['EnumeratedIndexValues']['ZI026_CTUC']['BD120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['REEF_C']['ZI026_CTUL'] = ('integer',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI026_CTUU'] = ('integer',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI031S_URI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZI039S_UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZSAX_RS0'] = ('CodeList',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZSAX_RX0'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZSAX_RX3'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_C']['ZSAX_RX4'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['BEN'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['FUFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['FURL'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['GDBV'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['GDBV']['BD120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['REEF_S']['MCC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_S']['MCC2'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC2']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_S']['MCC3'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['MCC3']['BD120']  = (-999999,24,25,84,999)
    field_information['GGDM 3.0']['REEF_S']['OTH'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI001_SDV'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI001_SRT'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI001_SRT']['BD120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['REEF_S']['ZI002_UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI004_RCG'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI004_RCG']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['REEF_S']['ZI005_FNA'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI005_GNT'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI005_GNT']['BD120']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['REEF_S']['ZI005_NFN'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI006_MEM'] = ('String',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI020_GE4'] = ('CodeList',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI025_HDP'] = ('Real',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI025_WLE'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI025_WLE']['BD120']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['REEF_S']['ZI026_CTUC'] = ('Enumeration',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['REEF_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['REEF_S']['ZI026_CTUL'] = ('integer',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI026_CTUU'] = ('integer',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI031S_URI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZI039S_UFI'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZSAX_RS0'] = ('CodeList',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZSAX_RX0'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZSAX_RX3'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['REEF_S']['ZSAX_RX4'] = ('StructuredText',('BD120'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['CCN'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['CDR'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['F_CODE'] = ('CONSTRAINED_STRING',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS1'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS2'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS4'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS5'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS6'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS8'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RS9'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX1'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX2'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX5'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX6'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX7'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RX9'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY0'] = ('String',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY1'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['SAX_RY2'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RESTRICTION_INFO_T']['UFI'] = ('StructuredText',('ZI002'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['AOO'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ARA'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['BEN'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['CNCP'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['COS'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['COS']['AL180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['FFN'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['FFN2'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN2']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['FFN3'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['FFN3']['AL180']  = (-999999,460,540,545,570,572,621,643,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['FUFI'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['FURL'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['GDBV'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['GDBV']['AL180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['HGT'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['LMC'] = ('Boolean',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['LZN'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['MCC'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['MCC2'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC2']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['MCC3'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['MCC3']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['OTH'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['PCF'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['PCF']['AL180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['UFI'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['WID'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI001_SDV'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI001_SRT'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI001_SRT']['AL180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI002_UFI'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI004_RCG'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI004_RCG']['AL180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI005_FNA'] = ('String',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI005_GNT'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI005_GNT']['AL180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI005_NFN'] = ('String',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI006_MEM'] = ('String',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI020_GE4'] = ('CodeList',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI026_CTUC'] = ('Enumeration',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RETAIL_STAND_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI026_CTUL'] = ('integer',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI026_CTUU'] = ('integer',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI031S_URI'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZI039S_UFI'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZSAX_RS0'] = ('CodeList',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZSAX_RX0'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZSAX_RX3'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZSAX_RX4'] = ('StructuredText',('AL180'))
    field_information['GGDM 3.0']['RETAIL_STAND_S']['ZVH'] = ('Real',('AL180'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ARA'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['BEN'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['CAA'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['CAA']['BH135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['DZP'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['FUFI'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['FURL'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['GDBV'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['GDBV']['BH135']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['LZN'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['OTH'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['UFI'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['VTI'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['WDAC'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['WDAC']['BH135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RICE_FIELD_S']['WDAL'] = ('real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['WDAU'] = ('real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['WID'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI001_SDV'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI001_SRT'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT']['BH135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI002_UFI'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI004_RCG'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI005_FNA'] = ('String',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI005_GNT'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI005_NFN'] = ('String',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI006_MEM'] = ('String',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_CSP'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_CSP']['BH135']  = (28,)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FFP'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FFP2'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP2']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FFP3'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FFP3']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FMM'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FMM2'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM2']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_FMM3'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI013_FMM3']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI013_PIG'] = ('Boolean',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI020_GE4'] = ('CodeList',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_ASE'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_CFR'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_CLO'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_CYN'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_FMR'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_FRR'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_HAR'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_HYP'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_HYP']['BH135']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_MGN'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_PHW'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_SCC'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_SCC']['BH135']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_SUL'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_TDS'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_TEP'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_TUR'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_WAC'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_WTNO'] = ('Real',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_WUR'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_WUR']['BH135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI024_YWQ'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH135']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI026_CTUC'] = ('Enumeration',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RICE_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI026_CTUL'] = ('integer',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI026_CTUU'] = ('integer',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI031S_URI'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZI039S_UFI'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZSAX_RS0'] = ('CodeList',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZSAX_RX0'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZSAX_RX3'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RICE_FIELD_S']['ZSAX_RX4'] = ('StructuredText',('BH135'))
    field_information['GGDM 3.0']['RIG_P']['AOO'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ARA'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['AWP'] = ('Boolean',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['BEN'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['CAA'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['CAA']['AA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RIG_P']['CNCP'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['COS'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['COS']['AA040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RIG_P']['F_CODE'] = ('CONSTRAINED_STRING',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['FUFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['FURL'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['GDBV'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['GDBV']['AA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RIG_P']['HGT'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['LMC'] = ('Boolean',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['LZN'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['OTH'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['PCF'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RIG_P']['PPO'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_P']['PPO2'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_P']['PPO3'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_P']['SRL'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RIG_P']['UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['VCM'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_P']['VCM2'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_P']['VCM3'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_P']['VOI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['WID'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI001_SDV'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI001_SRT'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI001_SRT']['AA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RIG_P']['ZI002_UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI004_RCG'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI004_RCG']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RIG_P']['ZI005_FNA'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI005_GNT'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI005_GNT']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIG_P']['ZI005_NFN'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI006_MEM'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI020_GE4'] = ('CodeList',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI026_CTUC'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RIG_P']['EnumeratedIndexValues']['ZI026_CTUC']['AA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIG_P']['ZI026_CTUL'] = ('integer',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI026_CTUU'] = ('integer',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI031S_URI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZI039S_UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZSAX_RS0'] = ('CodeList',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZSAX_RX0'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZSAX_RX3'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZSAX_RX4'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_P']['ZVH'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['AOO'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ARA'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['AWP'] = ('Boolean',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['BEN'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['CAA'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['CAA']['AA040']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RIG_S']['CNCP'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['COS'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['COS']['AA040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['RIG_S']['F_CODE'] = ('CONSTRAINED_STRING',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['FUFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['FURL'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['GDBV'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['GDBV']['AA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RIG_S']['HGT'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['LMC'] = ('Boolean',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['LZN'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['OTH'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['PCF'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RIG_S']['PPO'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_S']['PPO2'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_S']['PPO3'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['GGDM 3.0']['RIG_S']['SRL'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RIG_S']['UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['VCM'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_S']['VCM2'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_S']['VCM3'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['GGDM 3.0']['RIG_S']['VOI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['WID'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI001_SDV'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI001_SRT'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI001_SRT']['AA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RIG_S']['ZI002_UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI004_RCG'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI004_RCG']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RIG_S']['ZI005_FNA'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI005_GNT'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI005_GNT']['AA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIG_S']['ZI005_NFN'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI006_MEM'] = ('String',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI020_GE4'] = ('CodeList',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI026_CTUC'] = ('Enumeration',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RIG_S']['EnumeratedIndexValues']['ZI026_CTUC']['AA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIG_S']['ZI026_CTUL'] = ('integer',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI026_CTUU'] = ('integer',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI031S_URI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZI039S_UFI'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZSAX_RS0'] = ('CodeList',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZSAX_RX0'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZSAX_RX3'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZSAX_RX4'] = ('StructuredText',('AA040'))
    field_information['GGDM 3.0']['RIG_S']['ZVH'] = ('Real',('AA040'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ARA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCA2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCA3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCA3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCB'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCB2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BBMCB3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BBMCB3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BEN'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_AWBA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_AWBB'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_IBOA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_IBOA']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_IBOB'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_IBOB']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_SHDA'] = ('Boolean',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_SHDB'] = ('Boolean',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_SLTA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_SLTA']['NM140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_SLTB'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BH141_SLTB']['NM140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_WBHA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BH141_WBHB'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BMC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BMC2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC2']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BMC3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BMC3']['NM140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWHAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHAL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHAU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHBC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWHBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHBL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWHBU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWSAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSAL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSAU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSBC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BPWSBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSBL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BPWSBU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BWVCAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCAL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCAU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCBC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['BWVCBC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCBL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['BWVCBU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['CAA'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['CAA']['NM140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['CDA'] = ('Boolean',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['CDL'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['DMF'] = ('Integer',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['DOXY'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['DZP'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['FRZ'] = ('Boolean',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['FUFI'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['FURL'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['GDBV'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['GDBV']['NM140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['LOC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['LOC']['NM140']  = (-999999,40,44)
    field_information['GGDM 3.0']['RIVER_AON_S']['LZN'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['NVS'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['NVS']['NM140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['OTH'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['PWA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['TID'] = ('Boolean',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['UFI'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WCC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WCC']['NM140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['WD3'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WDAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WDAC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['WDAL'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WDAU'] = ('real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WDH'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WDL'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WID'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WMT'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['WMT']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['WVA'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WVH'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['WVL'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI001_SDV'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI001_SRT'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI002_UFI'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI004_RCG'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_FNA'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_FNA2'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_FNA3'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_GNT'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_GNT2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_GNT3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI005_GNT3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_NFN'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_NFN2'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI005_NFN3'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI006_MEM'] = ('String',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI020_GE4'] = ('CodeList',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_ASE'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_AWO'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_AWOI'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_AWOX'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_CFR'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_CLO'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_CYN'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_FMR'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_FRR'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_HAR'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_HYP'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_MGN'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_PHW'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_SCC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_SQN'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_SQN']['NM140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_SUL'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_TDS'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_TEP'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_TUR'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WAC'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WPAC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WPAC']['NM140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WSG'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WSG']['NM140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WTNO'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WUR'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI025_HDP'] = ('Real',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RIVER_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI026_CTUL'] = ('integer',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI026_CTUU'] = ('integer',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI031S_URI'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZSAX_RS0'] = ('CodeList',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM140'))
    field_information['GGDM 3.0']['RIVER_C']['ARA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BBMCA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BBMCA2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BBMCA3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCA3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BBMCB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BBMCB2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BBMCB3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BBMCB3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BEN'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_AWBA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_AWBB'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_IBOA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_C']['BH141_IBOB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_C']['BH141_SHDA'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_SHDB'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_SLTA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BH141_SLTB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BH141_WBHA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BH141_WBHB'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BMC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BMC2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BMC3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_C']['BPWHAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BPWHAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWHAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWHBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BPWHBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWHBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWSAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BPWSAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWSAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWSBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BPWSBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BPWSBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BWVCAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BWVCAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BWVCAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BWVCBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['BWVCBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['BWVCBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['CAA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['CAA']['BH140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RIVER_C']['CDA'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['CDL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['DOXY'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['DZP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['FRZ'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['FUFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['FURL'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['GDBV'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['GDBV']['BH140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RIVER_C']['LEA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['LMC'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['LOC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['LOC']['BH140']  = (-999999,40,44)
    field_information['GGDM 3.0']['RIVER_C']['LZN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['NVS'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['RIVER_C']['OTH'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['PWA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['STNB'] = ('Integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['TID'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['RIVER_C']['WD3'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WDAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WDAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['WDAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WDAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WDH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WDL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WID'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WMT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['RIVER_C']['WVA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WVH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['WVL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI001_SDV'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI001_SRT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI001_SRT']['BH140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI002_UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI004_RCG'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI004_RCG']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI005_FNA'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI005_FNA2'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI005_FNA3'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI005_GNT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI005_GNT2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI005_GNT3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI005_GNT3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI005_NFN'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI005_NFN2'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI005_NFN3'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI006_MEM'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI020_GE4'] = ('CodeList',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_ASE'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_AWO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_AWOI'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_AWOX'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_CFR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_CLO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_CYN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_FMR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_FRR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_HAR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_HYP'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_MGN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_PHW'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_SCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_SCC']['BH140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_SQN'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_SQN']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_SUL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_TDS'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_TEP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_TUR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WAC'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WPAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WPAC']['BH140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WSG'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WSG']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WTNO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WUR'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WUR2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WUR3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_WUR4'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_WUR4']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI024_YWQ'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_C']['ZI025_HDP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI026_CTUC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RIVER_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_C']['ZI026_CTUL'] = ('integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI026_CTUU'] = ('integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI031S_URI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZI039S_UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZSAX_RS0'] = ('CodeList',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZSAX_RX0'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZSAX_RX3'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZSAX_RX4'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_C']['ZVH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ARA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BBMCA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BBMCA2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA2'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BBMCA3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA3'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCA3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BBMCB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BBMCB2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB2'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BBMCB3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB3'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BBMCB3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BEN'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_AWBA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_AWBB'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_IBOA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_S']['BH141_IBOB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_S']['BH141_SHDA'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_SHDB'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_SLTA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BH141_SLTB'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BH141_WBHA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BH141_WBHB'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BMC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BMC2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BMC3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,9,14,15,18,999)
    field_information['GGDM 3.0']['RIVER_S']['BPWHAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BPWHAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWHAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWHBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BPWHBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWHBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWSAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BPWSAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWSAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWSBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BPWSBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BPWSBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BWVCAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BWVCAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BWVCAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BWVCBC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['BWVCBL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['BWVCBU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['CAA'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['CAA']['BH140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RIVER_S']['CDA'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['CDL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['DOXY'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['DZP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['FRZ'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['FUFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['FURL'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['GDBV'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['GDBV']['BH140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RIVER_S']['LEA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['LMC'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['LOC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['LOC']['BH140']  = (-999999,40,44)
    field_information['GGDM 3.0']['RIVER_S']['LZN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['NVS'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['NVS'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['RIVER_S']['OTH'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['PWA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['STNB'] = ('Integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['TID'] = ('Boolean',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WCC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,7,999)
    field_information['GGDM 3.0']['RIVER_S']['WD3'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WDAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WDAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['WDAL'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WDAU'] = ('real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WDH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WDL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WID'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WMT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WMT'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['RIVER_S']['WVA'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WVH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['WVL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI001_SDV'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI001_SRT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI001_SRT']['BH140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI002_UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI004_RCG'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI004_RCG']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI005_FNA'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI005_FNA2'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI005_FNA3'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI005_GNT'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI005_GNT2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI005_GNT3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI005_GNT3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI005_NFN'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI005_NFN2'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI005_NFN3'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI006_MEM'] = ('String',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI020_GE4'] = ('CodeList',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_ASE'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_AWO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_AWOI'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_AWOX'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_CFR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_CLO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_CYN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_FMR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_FRR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_HAR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_HYP'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_MGN'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_PHW'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_SCC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_SCC']['BH140']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_SQN'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_SQN'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_SQN']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_SUL'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_TDS'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_TEP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_TUR'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WAC'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WPAC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WPAC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WPAC']['BH140']  = (-999999,100,101,102,103,104,105,106,107)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WSG'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WSG'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WSG']['BH140']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WTNO'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WUR'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WUR2'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WUR3'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_WUR4'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI024_YWQ'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['RIVER_S']['ZI025_HDP'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI026_CTUC'] = ('Enumeration',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RIVER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RIVER_S']['ZI026_CTUL'] = ('integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI026_CTUU'] = ('integer',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI031S_URI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZI039S_UFI'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZSAX_RS0'] = ('CodeList',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZSAX_RX0'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZSAX_RX3'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZSAX_RX4'] = ('StructuredText',('BH140'))
    field_information['GGDM 3.0']['RIVER_S']['ZVH'] = ('Real',('BH140'))
    field_information['GGDM 3.0']['ROAD_C']['ARA'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['BEN'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['CAA'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['ROAD_C']['CIW'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['CNCP'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['COS'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['COS']['AP030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROAD_C']['CWT'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['DEV'] = ('Integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['FCO'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['FCO'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['GGDM 3.0']['ROAD_C']['FSC'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['FUFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['FURL'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['GDBV'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['GDBV']['AP030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROAD_C']['LOC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['ROAD_C']['LTN'] = ('Integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['LZN'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['MES'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['MWG'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ONE'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['OTH'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['PCF'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROAD_C']['PSN'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['PTG'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RIN_ROI'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_C']['RIN_ROI2'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_C']['RIN_ROI3'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RIN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_C']['RIN_RTN'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RIN_RTN2'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RIN_RTN3'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RLE'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['ROAD_C']['RMWC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_C']['RMWL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RMWU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ROR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['RTY'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RTY'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['RTY']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROAD_C']['SBB'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['SEP'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['SGCC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_C']['SGCL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['SGCU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['SPD'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['SPM'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['THR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['WD2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['WID'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['WT2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI001_SDV'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI001_SRT'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI001_SRT']['AP030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROAD_C']['ZI002_UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI004_RCG'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI004_RCG']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROAD_C']['ZI005_FNA'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI005_GNT'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI005_GNT']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROAD_C']['ZI005_NFN'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI006_MEM'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI016_ROC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['ROAD_C']['ZI016_WD1'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI016_WTC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROAD_C']['ZI020_GE4'] = ('CodeList',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI026_CTUC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_C']['ZI026_CTUL'] = ('integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI026_CTUU'] = ('integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI026_SUR'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['ROAD_C']['EnumeratedIndexValues']['ZI026_SUR']['AP030']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ROAD_C']['ZI031S_URI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZI039S_UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZSAX_RS0'] = ('CodeList',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZSAX_RX0'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZSAX_RX3'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_C']['ZSAX_RX4'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['AOO'] = ('Real',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['BEN'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['CAA'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['CAA']['AP020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['CNCP'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['COS'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['COS']['AP020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['CWT'] = ('Boolean',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['FUFI'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['FURL'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['GDBV'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['GDBV']['AP020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['LMC'] = ('Boolean',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['OTH'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_ROI'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_ROI2'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI2']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_ROI3'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIN_ROI3']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_RTN'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_RTN2'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIN_RTN3'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['RIT'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIT'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['RIT']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['UFI'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI001_SDV'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI001_SRT'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI001_SRT']['AP020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI002_UFI'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI004_RCG'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI004_RCG']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI005_FNA'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI005_GNT'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI005_GNT']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI005_NFN'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI006_MEM'] = ('String',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI020_GE4'] = ('CodeList',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI026_CTUC'] = ('Enumeration',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AP020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI026_CTUL'] = ('integer',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI026_CTUU'] = ('integer',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI031S_URI'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZI039S_UFI'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZSAX_RS0'] = ('CodeList',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZSAX_RX0'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZSAX_RX3'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_INTERCHANGE_P']['ZSAX_RX4'] = ('StructuredText',('AP020'))
    field_information['GGDM 3.0']['ROAD_S']['ARA'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['BEN'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['CAA'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['ROAD_S']['CIW'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['CNCP'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['COS'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['COS']['AP030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROAD_S']['CWT'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['DEV'] = ('Integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['F_CODE'] = ('CONSTRAINED_STRING',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['FCO'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['FCO'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['GGDM 3.0']['ROAD_S']['FSC'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['FUFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['FURL'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['GDBV'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['GDBV']['AP030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROAD_S']['LOC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['ROAD_S']['LTN'] = ('Integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['LZN'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['MES'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['MWG'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ONE'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['OTH'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['PCF'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROAD_S']['PSN'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['PTG'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RIN_ROI'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_S']['RIN_ROI2'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI2'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_S']['RIN_ROI3'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI3'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RIN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['ROAD_S']['RIN_RTN'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RIN_RTN2'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RIN_RTN3'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RLE'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['GGDM 3.0']['ROAD_S']['RMWC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_S']['RMWL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RMWU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ROR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['RTY'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RTY'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['RTY']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROAD_S']['SBB'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['SEP'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['SGCC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_S']['SGCL'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['SGCU'] = ('real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['SPD'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['SPM'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['THR'] = ('Boolean',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['WD2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['WID'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['WT2'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI001_SDV'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI001_SRT'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI001_SRT']['AP030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROAD_S']['ZI002_UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI004_RCG'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI004_RCG']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROAD_S']['ZI005_FNA'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI005_GNT'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI005_GNT']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROAD_S']['ZI005_NFN'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI006_MEM'] = ('String',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI016_ROC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['ROAD_S']['ZI016_WD1'] = ('Real',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI016_WTC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROAD_S']['ZI020_GE4'] = ('CodeList',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI026_CTUC'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI026_CTUC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROAD_S']['ZI026_CTUL'] = ('integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI026_CTUU'] = ('integer',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI026_SUR'] = ('Enumeration',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI026_SUR'] = {}
    field_information['GGDM 3.0']['ROAD_S']['EnumeratedIndexValues']['ZI026_SUR']['AP030']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ROAD_S']['ZI031S_URI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZI039S_UFI'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZSAX_RS0'] = ('CodeList',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZSAX_RX0'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZSAX_RX3'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROAD_S']['ZSAX_RX4'] = ('StructuredText',('AP030'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ADR'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['AOO'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ARA'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['BEN'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['CAA'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['CAA']['AQ135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['CIW'] = ('Boolean',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['CNCP'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['COS'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['COS']['AQ135']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['FFN'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['FFN2'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['FFN3'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['FUFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['FURL'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['GDBV'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['GDBV']['AQ135']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['HGT'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['LMC'] = ('Boolean',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['LZN'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['OTH'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['PCF'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['WID'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI001_SDV'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI001_SRT'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI002_UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI004_RCG'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI005_FNA'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI005_GNT'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI005_NFN'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI006_MEM'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI016_ROC'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI020_GE4'] = ('CodeList',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI026_CTUC'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI026_CTUL'] = ('integer',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI026_CTUU'] = ('integer',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI031S_URI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZI039S_UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZSAX_RS0'] = ('CodeList',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZSAX_RX0'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZSAX_RX3'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZSAX_RX4'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_P']['ZVH'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ADR'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['AOO'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ARA'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['BEN'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['CAA'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['CAA']['AQ135']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['CIW'] = ('Boolean',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['CNCP'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['COS'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['COS']['AQ135']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['FFN'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['FFN2'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['FFN3'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['FUFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['FURL'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['GDBV'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['GDBV']['AQ135']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['HGT'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['LMC'] = ('Boolean',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['LZN'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['OTH'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['PCF'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['WID'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI001_SDV'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI001_SRT'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ135']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI002_UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI004_RCG'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI005_FNA'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI005_GNT'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI005_NFN'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI006_MEM'] = ('String',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI016_ROC'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI020_GE4'] = ('CodeList',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI026_CTUC'] = ('Enumeration',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ135']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI026_CTUL'] = ('integer',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI026_CTUU'] = ('integer',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI031S_URI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZI039S_UFI'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZSAX_RS0'] = ('CodeList',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZSAX_RX0'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZSAX_RX3'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZSAX_RX4'] = ('StructuredText',('AQ135'))
    field_information['GGDM 3.0']['ROADSIDE_REST_AREA_S']['ZVH'] = ('Real',('AQ135'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['AOO'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ARA'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['BEN'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['FUFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['FURL'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['GDBV'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['GDBV']['DB160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['HGT'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['LMC'] = ('Boolean',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['LZN'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['OTH'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['PFH'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['RKF'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['RKF'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['WID'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI001_SDV'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI001_SRT'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI001_SRT']['DB160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI002_UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI004_RCG'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI004_RCG']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI005_FNA'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI005_GNT'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI005_GNT']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI005_NFN'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI006_MEM'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI020_GE4'] = ('CodeList',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI026_CTUC'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI026_CTUL'] = ('integer',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI026_CTUU'] = ('integer',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI031S_URI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZI039S_UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZSAX_RS0'] = ('CodeList',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZSAX_RX0'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZSAX_RX3'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZSAX_RX4'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_P']['ZVH'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['AOO'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ARA'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['BEN'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['FUFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['FURL'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['GDBV'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['GDBV']['DB160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['HGT'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['LMC'] = ('Boolean',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['LZN'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['OTH'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['PFH'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['RKF'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['RKF'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['WID'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI001_SDV'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI001_SRT'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI001_SRT']['DB160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI002_UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI004_RCG'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI004_RCG']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI005_FNA'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI005_GNT'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI005_GNT']['DB160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI005_NFN'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI006_MEM'] = ('String',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI020_GE4'] = ('CodeList',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI026_CTUC'] = ('Enumeration',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI026_CTUL'] = ('integer',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI026_CTUU'] = ('integer',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI031S_URI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZI039S_UFI'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZSAX_RS0'] = ('CodeList',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZSAX_RX0'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZSAX_RX3'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZSAX_RX4'] = ('StructuredText',('DB160'))
    field_information['GGDM 3.0']['ROCK_FORMATION_S']['ZVH'] = ('Real',('DB160'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ADR'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['AOO'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ARA'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['AWP'] = ('Boolean',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['BEN'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['CAA'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['CAA']['AN076']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['CNCP'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['COS'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['COS']['AN076']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['FFN'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['FFN2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['FFN3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['FUFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['FURL'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['GDBV'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['GDBV']['AN076']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['HGT'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['LMC'] = ('Boolean',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['LZN'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['OTH'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['PCF'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['SSR'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['SSR2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['SSR3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['VCM'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['VCM2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['VCM3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['VOI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['WID'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI001_SDV'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI001_SRT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI001_SRT']['AN076']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI002_UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI004_RCG'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI004_RCG']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI005_FNA'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI005_GNT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI005_GNT']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI005_NFN'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI006_MEM'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI017_GAW'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI017_RGC'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI017_RRA'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI017_TRT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI020_GE4'] = ('CodeList',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI026_CTUC'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AN076']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI026_CTUL'] = ('integer',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI026_CTUU'] = ('integer',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI031S_URI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZI039S_UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZSAX_RS0'] = ('CodeList',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZSAX_RX0'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZSAX_RX3'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZSAX_RX4'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_P']['ZVH'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ADR'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['AOO'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ARA'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['AWP'] = ('Boolean',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['BEN'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['CAA'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['CAA']['AN076']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['CNCP'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['COS'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['COS']['AN076']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['FFN'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['FFN2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['FFN3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['FUFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['FURL'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['GDBV'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['GDBV']['AN076']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['HGT'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['LMC'] = ('Boolean',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['LZN'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['OTH'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['PCF'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['SSR'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['SSR2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['SSR3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['VCM'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['VCM2'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['VCM3'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['VOI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['WID'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI001_SDV'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI001_SRT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI001_SRT']['AN076']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI002_UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI004_RCG'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI004_RCG']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI005_FNA'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI005_GNT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI005_GNT']['AN076']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI005_NFN'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI006_MEM'] = ('String',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI017_GAW'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI017_RGC'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI017_RRA'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI017_TRT'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI020_GE4'] = ('CodeList',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI026_CTUC'] = ('Enumeration',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AN076']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI026_CTUL'] = ('integer',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI026_CTUU'] = ('integer',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI031S_URI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZI039S_UFI'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZSAX_RS0'] = ('CodeList',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZSAX_RX0'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZSAX_RX3'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZSAX_RX4'] = ('StructuredText',('AN076'))
    field_information['GGDM 3.0']['ROUNDHOUSE_S']['ZVH'] = ('Real',('AN076'))
    field_information['GGDM 3.0']['RUINS_P']['AOO'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ARA'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['BEN'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['FUFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['FURL'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['GDBV'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['GDBV']['AL200']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RUINS_P']['HGT'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['LMC'] = ('Boolean',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['LZN'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['OTH'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['SRL'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RUINS_P']['UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['WID'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI001_SDV'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI001_SRT'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI001_SRT']['AL200']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RUINS_P']['ZI002_UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI004_RCG'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI004_RCG']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RUINS_P']['ZI005_FNA'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI005_GNT'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI005_GNT']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RUINS_P']['ZI005_NFN'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI006_MEM'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI020_GE4'] = ('CodeList',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI025_HDP'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI026_CTUC'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RUINS_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL200']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUINS_P']['ZI026_CTUL'] = ('integer',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI026_CTUU'] = ('integer',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI031S_URI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZI039S_UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZSAX_RS0'] = ('CodeList',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZSAX_RX0'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZSAX_RX3'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZSAX_RX4'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_P']['ZVH'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['AOO'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ARA'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['BEN'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['FUFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['FURL'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['GDBV'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['GDBV']['AL200']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RUINS_S']['HGT'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['LMC'] = ('Boolean',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['LZN'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['OTH'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['SRL'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['RUINS_S']['UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['WID'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI001_SDV'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI001_SRT'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI001_SRT']['AL200']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RUINS_S']['ZI002_UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI004_RCG'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI004_RCG']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RUINS_S']['ZI005_FNA'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI005_GNT'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI005_GNT']['AL200']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RUINS_S']['ZI005_NFN'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI006_MEM'] = ('String',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI020_GE4'] = ('CodeList',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI025_HDP'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI026_CTUC'] = ('Enumeration',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RUINS_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL200']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUINS_S']['ZI026_CTUL'] = ('integer',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI026_CTUU'] = ('integer',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI031S_URI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZI039S_UFI'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZSAX_RS0'] = ('CodeList',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZSAX_RX0'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZSAX_RX3'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZSAX_RX4'] = ('StructuredText',('AL200'))
    field_information['GGDM 3.0']['RUINS_S']['ZVH'] = ('Real',('AL200'))
    field_information['GGDM 3.0']['RUNWAY_S']['ARA'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['AXS'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['AXS']['GB055']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['RUNWAY_S']['BEN'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['CAA'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['CAA']['GB055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['RUNWAY_S']['CNCP'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['COS'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['COS']['GB055']  = (-999999,4,6,8,13,14)
    field_information['GGDM 3.0']['RUNWAY_S']['DEV'] = ('Integer',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['FUFI'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['FURL'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GB052_RIDH'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GB052_RIDL'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GB052_TRHH'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GB052_TRHL'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GDBV'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GDBV']['GB055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCHC'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GSGCHC'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GSGCHC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCHL'] = ('real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCHU'] = ('real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCLC'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GSGCLC'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['GSGCLC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCLL'] = ('real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['GSGCLU'] = ('real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['LZN'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['OTH'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['PCF'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['PCF']['GB055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['RUNWAY_S']['SBB'] = ('Boolean',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['SERP'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['SERP'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['SERP']['GB055']  = (-999999,6,7,8)
    field_information['GGDM 3.0']['RUNWAY_S']['UFI'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['WID'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI001_SDV'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI001_SRT'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI001_SRT']['GB055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI002_UFI'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI004_RCG'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI004_RCG']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI005_FNA'] = ('String',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI005_GNT'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI005_GNT']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI005_NFN'] = ('String',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI006_MEM'] = ('String',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASP'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASP2'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASP3'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASP3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASU'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASU2'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASU3'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASU3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_ASX'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_ASX']['GB055']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI019_SFS'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI019_SFS']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI020_GE4'] = ('CodeList',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI026_CTUC'] = ('Enumeration',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['RUNWAY_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['RUNWAY_S']['ZI026_CTUL'] = ('integer',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI026_CTUU'] = ('integer',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI031S_URI'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZI039S_UFI'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZSAX_RS0'] = ('CodeList',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZSAX_RX0'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZSAX_RX3'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZSAX_RX4'] = ('StructuredText',('GB055'))
    field_information['GGDM 3.0']['RUNWAY_S']['ZVH'] = ('Real',('GB055'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ARA'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['BEN'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['DMF'] = ('Integer',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['FUFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['FURL'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['GDBV'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['GDBV']['NM160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SABKHA_AON_S']['LMC'] = ('Boolean',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['LZN'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['OTH'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['WID'] = ('Real',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI001_SDV'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI001_SRT'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI002_UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI004_RCG'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI005_FNA'] = ('String',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI005_GNT'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NM160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI005_NFN'] = ('String',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI006_MEM'] = ('String',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI020_GE4'] = ('CodeList',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SABKHA_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI026_CTUL'] = ('integer',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI026_CTUU'] = ('integer',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI031S_URI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZSAX_RS0'] = ('CodeList',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM160'))
    field_information['GGDM 3.0']['SABKHA_S']['ARA'] = ('Real',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['BEN'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['FUFI'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['FURL'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['GDBV'] = ('Enumeration',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['GDBV']['BH160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SABKHA_S']['LMC'] = ('Boolean',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['LZN'] = ('Real',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['OTH'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['UFI'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['WID'] = ('Real',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI001_SDV'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI001_SRT'] = ('Enumeration',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI001_SRT']['BH160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SABKHA_S']['ZI002_UFI'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI004_RCG'] = ('Enumeration',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI004_RCG']['BH160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SABKHA_S']['ZI005_FNA'] = ('String',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI005_GNT'] = ('Enumeration',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI005_GNT']['BH160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SABKHA_S']['ZI005_NFN'] = ('String',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI006_MEM'] = ('String',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI020_GE4'] = ('CodeList',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI026_CTUC'] = ('Enumeration',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SABKHA_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SABKHA_S']['ZI026_CTUL'] = ('integer',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI026_CTUU'] = ('integer',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI031S_URI'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZI039S_UFI'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZSAX_RS0'] = ('CodeList',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZSAX_RX0'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZSAX_RX3'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SABKHA_S']['ZSAX_RX4'] = ('StructuredText',('BH160'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ARA'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['AZC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['BEN'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['CNCP'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['COS'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['COS']['BH155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['FUFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['FURL'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['GDBV'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['GDBV']['BH155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['LMC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['LZN'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['OTH'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['PCF'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['WID'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI001_SDV'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI001_SRT'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI001_SRT']['BH155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI002_UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI004_RCG'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI004_RCG']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI005_FNA'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI005_GNT'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI005_GNT']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI005_NFN'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI006_MEM'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI020_GE4'] = ('CodeList',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI026_CTUC'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI026_CTUL'] = ('integer',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI026_CTUU'] = ('integer',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI031S_URI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZI039S_UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZSAX_RS0'] = ('CodeList',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZSAX_RX0'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZSAX_RX3'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_P']['ZSAX_RX4'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ARA'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['AZC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['BEN'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['CNCP'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['COS'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['COS']['BH155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['FUFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['FURL'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['GDBV'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['GDBV']['BH155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['LMC'] = ('Boolean',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['LZN'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['OTH'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['PCF'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['WID'] = ('Real',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI001_SDV'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI001_SRT'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI001_SRT']['BH155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI002_UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI004_RCG'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI004_RCG']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI005_FNA'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI005_GNT'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI005_GNT']['BH155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI005_NFN'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI006_MEM'] = ('String',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI020_GE4'] = ('CodeList',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI026_CTUC'] = ('Enumeration',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI026_CTUL'] = ('integer',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI026_CTUU'] = ('integer',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI031S_URI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZI039S_UFI'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZSAX_RS0'] = ('CodeList',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZSAX_RX0'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZSAX_RX3'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_EVAPORATOR_S']['ZSAX_RX4'] = ('StructuredText',('BH155'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ARA'] = ('Real',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['BEN'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['FUFI'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['FURL'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['GDBV'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['GDBV']['BH150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['LZN'] = ('Real',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['MCC'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['MCC2'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC2']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['MCC3'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['MCC3']['BH150']  = (-999999,88,104,119,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['OTH'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['UFI'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['WID'] = ('Real',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI001_SDV'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI001_SRT'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI001_SRT']['BH150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI002_UFI'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI004_RCG'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI004_RCG']['BH150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI005_FNA'] = ('String',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI005_GNT'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI005_GNT']['BH150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI005_NFN'] = ('String',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI006_MEM'] = ('String',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI020_GE4'] = ('CodeList',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI026_CTUC'] = ('Enumeration',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SALT_FLAT_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI026_CTUL'] = ('integer',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI026_CTUU'] = ('integer',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI031S_URI'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZI039S_UFI'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZSAX_RS0'] = ('CodeList',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZSAX_RX0'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZSAX_RX3'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SALT_FLAT_S']['ZSAX_RX4'] = ('StructuredText',('BH150'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ARA'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['BEN'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['FUFI'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['FURL'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['GDBV'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['GDBV']['DB170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SAND_DUNES_S']['HGT'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['LZN'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['OTH'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['SAD'] = ('Boolean',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['SDO'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['SDT'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['SDT'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['SDT']['DB170']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['SAND_DUNES_S']['UFI'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['WID'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI001_SDV'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI001_SRT'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI001_SRT']['DB170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI002_UFI'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI004_RCG'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI004_RCG']['DB170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI005_FNA'] = ('String',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI005_GNT'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI005_GNT']['DB170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI005_NFN'] = ('String',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI006_MEM'] = ('String',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI020_GE4'] = ('CodeList',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI026_CTUC'] = ('Enumeration',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SAND_DUNES_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI026_CTUL'] = ('integer',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI026_CTUU'] = ('integer',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI031S_URI'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZI039S_UFI'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZSAX_RS0'] = ('CodeList',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZSAX_RX0'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZSAX_RX3'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZSAX_RX4'] = ('StructuredText',('DB170'))
    field_information['GGDM 3.0']['SAND_DUNES_S']['ZVH'] = ('Real',('DB170'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['AOO'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ARA'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['AWP'] = ('Boolean',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['BEN'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['CAA'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['CAA']['AK161']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SCOREBOARD_P']['CNCP'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['COS'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['COS']['AK161']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SCOREBOARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['FUFI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['FURL'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['GDBV'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['GDBV']['AK161']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SCOREBOARD_P']['HEI'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['HGT'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['LMC'] = ('Boolean',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['LZN'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['OTH'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['PCF'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['PCF']['AK161']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SCOREBOARD_P']['UFI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['VOI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI001_SDV'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI001_SRT'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI001_SRT']['AK161']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI002_UFI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI004_RCG'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI004_RCG']['AK161']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI005_FNA'] = ('String',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI005_GNT'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI005_GNT']['AK161']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI005_NFN'] = ('String',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI006_MEM'] = ('String',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI020_GE4'] = ('CodeList',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI026_CTUC'] = ('Enumeration',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SCOREBOARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK161']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI026_CTUL'] = ('integer',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI026_CTUU'] = ('integer',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI031S_URI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZI039S_UFI'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZSAX_RS0'] = ('CodeList',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZSAX_RX0'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZSAX_RX3'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZSAX_RX4'] = ('StructuredText',('AK161'))
    field_information['GGDM 3.0']['SCOREBOARD_P']['ZVH'] = ('Real',('AK161'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['AOO'] = ('Real',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ARA'] = ('Real',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['BEN'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['CAA'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['CAA']['GB070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['CNCP'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['COS'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['COS']['GB070']  = (-999999,8,9,13,14)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['FUFI'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['FURL'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['GDBV'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['GDBV']['GB070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['LZN'] = ('Real',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['OTH'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['PCF'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['PCF']['GB070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['UFI'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['WID'] = ('Real',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI001_SDV'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI001_SRT'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI001_SRT']['GB070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI002_UFI'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI004_RCG'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI004_RCG']['GB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI005_FNA'] = ('String',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI005_GNT'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI005_GNT']['GB070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI005_NFN'] = ('String',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI006_MEM'] = ('String',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI020_GE4'] = ('CodeList',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI026_CTUC'] = ('Enumeration',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI026_CTUL'] = ('integer',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI026_CTUU'] = ('integer',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI031S_URI'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZI039S_UFI'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZSAX_RS0'] = ('CodeList',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZSAX_RX0'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZSAX_RX3'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZSAX_RX4'] = ('StructuredText',('GB070'))
    field_information['GGDM 3.0']['SEAPLANE_RUN_S']['ZVH'] = ('Real',('GB070'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ARA'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['BEN'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['CAA'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['CAA']['AL105']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['CNCP'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['COS'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['COS']['AL105']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SETTLEMENT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['FFN'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['FFN2'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['FFN3'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['FUFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['FURL'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['GDBV'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['GDBV']['AL105']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['HGT'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['HHD'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['LMC'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['LZN'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['OTH'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['PCF'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SETTLEMENT_P']['UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['WID'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI001_SDV'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI001_SRT'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL105']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI002_UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI004_RCG'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI005_FNA'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI005_GNT'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI005_GNT']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI005_NFN'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI006_MEM'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI020_GE4'] = ('CodeList',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI026_CTUC'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL105']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI026_CTUL'] = ('integer',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI026_CTUU'] = ('integer',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI031S_URI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZI039S_UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZSAX_RS0'] = ('CodeList',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZSAX_RX0'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZSAX_RX3'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZSAX_RX4'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_P']['ZVH'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ARA'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['BEN'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['CAA'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['CAA']['AL105']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['CNCP'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['COS'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['COS']['AL105']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SETTLEMENT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['FFN'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['FFN2'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['FFN3'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['FUFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['FURL'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['GDBV'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['GDBV']['AL105']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['HGT'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['HHD'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['LMC'] = ('Boolean',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['LZN'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['OTH'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['PCF'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SETTLEMENT_S']['UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['WID'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI001_SDV'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI001_SRT'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI001_SRT']['AL105']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI002_UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI004_RCG'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI004_RCG']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI005_FNA'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI005_GNT'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI005_GNT']['AL105']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI005_NFN'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI006_MEM'] = ('String',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI020_GE4'] = ('CodeList',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI026_CTUC'] = ('Enumeration',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SETTLEMENT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL105']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI026_CTUL'] = ('integer',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI026_CTUU'] = ('integer',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI031S_URI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZI039S_UFI'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZSAX_RS0'] = ('CodeList',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZSAX_RX0'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZSAX_RX3'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZSAX_RX4'] = ('StructuredText',('AL105'))
    field_information['GGDM 3.0']['SETTLEMENT_S']['ZVH'] = ('Real',('AL105'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ARA'] = ('Real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['BEN'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['CNCP'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['COS'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['COS']['AC030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SETTLING_POND_S']['DZP'] = ('Real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['FUFI'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['FURL'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['GDBV'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['GDBV']['AC030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SETTLING_POND_S']['LMC'] = ('Boolean',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['LZN'] = ('Real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['OTH'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['PCF'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['PCF']['AC030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SETTLING_POND_S']['UFI'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['VLM'] = ('Real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['WDAC'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['WDAC']['AC030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SETTLING_POND_S']['WDAL'] = ('real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['WDAU'] = ('real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['WID'] = ('Real',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI001_SDV'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI001_SRT'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI001_SRT']['AC030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI002_UFI'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI004_RCG'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI004_RCG']['AC030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI005_FNA'] = ('String',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI005_GNT'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI005_GNT']['AC030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI005_NFN'] = ('String',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI006_MEM'] = ('String',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI020_GE4'] = ('CodeList',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI026_CTUC'] = ('Enumeration',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SETTLING_POND_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI026_CTUL'] = ('integer',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI026_CTUU'] = ('integer',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI031S_URI'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZI039S_UFI'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZSAX_RS0'] = ('CodeList',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZSAX_RX0'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZSAX_RX3'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SETTLING_POND_S']['ZSAX_RX4'] = ('StructuredText',('AC030'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ADR'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['AOO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ARA'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['BEN'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['CAA'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['CNCP'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['COS'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['COS']['AC507']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['DCAP'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['DINF'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['DINF']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['FUFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['FURL'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['GDBV'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['GDBV']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['GRD'] = ('Boolean',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['HGT'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['LMC'] = ('Boolean',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['LZN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['OTH'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['PCF'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['PPO'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['PPO2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO2']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['PPO3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['PPO3']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['VCM'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['VCM2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM2']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['VCM3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['VCM3']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['WDST'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['WDST']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['WID'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI001_SDV'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI001_SRT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI001_SRT']['AC507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI002_UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI004_RCG'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI004_RCG']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_FNA'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_FNA2'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_FNA3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_GNT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_GNT2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_GNT3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI005_GNT3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_NFN'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_NFN2'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI005_NFN3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI006_MEM'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI014_PBY'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI014_PBY2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY2']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI014_PBY3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI014_PBY3']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI020_GE4'] = ('CodeList',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_ASE'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_AWO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_AWOI'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_AWOX'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_CFR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_CLO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_CYN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_DRL'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_DRL']['AC507']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_DVPT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_DVPT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_FMR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_FRR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_HAR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_MGN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PHW'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PMP'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PMP']['AC507']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PUR'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PUR2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PUR3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PUR4'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_PUR5'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_PUR5']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_SCC'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_SCC']['AC507']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_SUL'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_TDS'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_TEP'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_TUR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WAC'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WTNO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WUR'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WUR2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WUR3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI024_WUR4'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI024_WUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI026_CTUC'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AC507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI026_CTUL'] = ('integer',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI026_CTUU'] = ('integer',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI031S_URI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZI039S_UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZSAX_RS0'] = ('CodeList',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZSAX_RX0'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZSAX_RX3'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZSAX_RX4'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_P']['ZVH'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ADR'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['AOO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ARA'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['BEN'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['CAA'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['CNCP'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['COS'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['COS']['AC507']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['DCAP'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['DINF'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['DINF']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['FUFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['FURL'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['GDBV'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['GDBV']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['GRD'] = ('Boolean',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['HGT'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['LMC'] = ('Boolean',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['LZN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['OTH'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['PCF'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['PPO'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['PPO2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO2']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['PPO3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['PPO3']['AC507']  = (-999999,16,45,46,61,62,83,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['VCM'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['VCM2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM2']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['VCM3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['VCM3']['AC507']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['WDST'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['WDST']['AC507']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['WID'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI001_SDV'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI001_SRT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI001_SRT']['AC507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI002_UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI004_RCG'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI004_RCG']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_FNA'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_FNA2'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_FNA3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_GNT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_GNT2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_GNT3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI005_GNT3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_NFN'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_NFN2'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI005_NFN3'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI006_MEM'] = ('String',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI014_PBY'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI014_PBY2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY2']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI014_PBY3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI014_PBY3']['AC507']  = (-999999,1,2,6,7,8,12,15,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI020_GE4'] = ('CodeList',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_ASE'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_AWO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_AWOI'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_AWOX'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_CFR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_CLO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_CYN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_DRL'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_DRL']['AC507']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_DVPT'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_DVPT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_FMR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_FRR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_HAR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_MGN'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PHW'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PMP'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PMP']['AC507']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PUR'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PUR2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PUR3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PUR4'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_PUR5'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_PUR5']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_SCC'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_SCC']['AC507']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_SUL'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_TDS'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_TEP'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_TUR'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WAC'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WTNO'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WUR'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WUR2'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR2']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WUR3'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR3']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI024_WUR4'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI024_WUR4']['AC507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI026_CTUC'] = ('Enumeration',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AC507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI026_CTUL'] = ('integer',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI026_CTUU'] = ('integer',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI031S_URI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZI039S_UFI'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZSAX_RS0'] = ('CodeList',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZSAX_RX0'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZSAX_RX3'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZSAX_RX4'] = ('StructuredText',('AC507'))
    field_information['GGDM 3.0']['SEWAGE_TREATMENT_PLANT_S']['ZVH'] = ('Real',('AC507'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ARA'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['BEN'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['CNCP'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['COS'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['COS']['AL208']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['FUFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['FURL'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['GDBV'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['GDBV']['AL208']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['HGT'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['LMC'] = ('Boolean',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['LZN'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['OTH'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['PCF'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['WID'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI001_SDV'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI001_SRT'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI001_SRT']['AL208']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI002_UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI004_RCG'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI004_RCG']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI005_FNA'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI005_GNT'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI005_GNT']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI005_NFN'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI006_MEM'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI020_GE4'] = ('CodeList',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI026_CTUC'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL208']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI026_CTUL'] = ('integer',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI026_CTUU'] = ('integer',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI031S_URI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZI039S_UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZSAX_RS0'] = ('CodeList',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZSAX_RX0'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZSAX_RX3'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZSAX_RX4'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_P']['ZVH'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ARA'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['BEN'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['CNCP'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['COS'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['COS']['AL208']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['FUFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['FURL'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['GDBV'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['GDBV']['AL208']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['HGT'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['LMC'] = ('Boolean',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['LZN'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['OTH'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['PCF'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['WID'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI001_SDV'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI001_SRT'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI001_SRT']['AL208']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI002_UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI004_RCG'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI004_RCG']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI005_FNA'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI005_GNT'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI005_GNT']['AL208']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI005_NFN'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI006_MEM'] = ('String',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI020_GE4'] = ('CodeList',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI026_CTUC'] = ('Enumeration',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL208']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI026_CTUL'] = ('integer',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI026_CTUU'] = ('integer',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI031S_URI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZI039S_UFI'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZSAX_RS0'] = ('CodeList',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZSAX_RX0'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZSAX_RX3'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZSAX_RX4'] = ('StructuredText',('AL208'))
    field_information['GGDM 3.0']['SHANTY_TOWN_S']['ZVH'] = ('Real',('AL208'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['BEN'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['FUFI'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['FURL'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['GDBV'] = ('Enumeration',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['GDBV']['AQ118']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHARP_CURVE_P']['LMC'] = ('Boolean',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['LZN'] = ('Real',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['OTH'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['RAD'] = ('Real',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['UFI'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI001_SDV'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI001_SRT'] = ('Enumeration',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ118']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI002_UFI'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI004_RCG'] = ('Enumeration',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ118']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI006_MEM'] = ('String',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI020_GE4'] = ('CodeList',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI026_CTUC'] = ('Enumeration',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHARP_CURVE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ118']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI026_CTUL'] = ('integer',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI026_CTUU'] = ('integer',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI031S_URI'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZI039S_UFI'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZSAX_RS0'] = ('CodeList',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZSAX_RX0'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZSAX_RX3'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHARP_CURVE_P']['ZSAX_RX4'] = ('StructuredText',('AQ118'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['BEN'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['DZP'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['F_CODE'] = ('CONSTRAINED_STRING',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['FUFI'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['FURL'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['GDBV'] = ('Enumeration',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['GDBV']['AA011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHEAR_WALL_C']['HGT'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['LZN'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['OTH'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['PFH'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['UFI'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI001_SDV'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI001_SRT'] = ('Enumeration',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI001_SRT']['AA011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI002_UFI'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI004_RCG'] = ('Enumeration',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI004_RCG']['AA011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI005_FNA'] = ('String',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI005_GNT'] = ('Enumeration',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI005_GNT']['AA011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI005_NFN'] = ('String',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI006_MEM'] = ('String',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI020_GE4'] = ('CodeList',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI026_CTUC'] = ('Enumeration',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHEAR_WALL_C']['EnumeratedIndexValues']['ZI026_CTUC']['AA011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI026_CTUL'] = ('integer',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI026_CTUU'] = ('integer',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI031S_URI'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZI039S_UFI'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZSAX_RS0'] = ('CodeList',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZSAX_RX0'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZSAX_RX3'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZSAX_RX4'] = ('StructuredText',('AA011'))
    field_information['GGDM 3.0']['SHEAR_WALL_C']['ZVH'] = ('Real',('AA011'))
    field_information['GGDM 3.0']['SHED_P']['ADR'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['AOO'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ARA'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['BEN'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['BNF'] = ('Integer',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['CAA'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['CAA']['AL019']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHED_P']['CNCP'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['COS'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['COS']['AL019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHED_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['FFN'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_P']['FFN2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_P']['FFN3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_P']['FUFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['FURL'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['GDBV'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['GDBV']['AL019']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHED_P']['HGT'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['LMC'] = ('Boolean',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['LZN'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['OTH'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['PCF'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHED_P']['SSR'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_P']['SSR2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_P']['SSR3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_P']['UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['VCM'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_P']['VCM2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_P']['VCM3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_P']['WID'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI001_SDV'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI001_SRT'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI001_SRT']['AL019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHED_P']['ZI002_UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI004_RCG'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI004_RCG']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHED_P']['ZI005_FNA'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI005_GNT'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI005_GNT']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHED_P']['ZI005_NFN'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI006_MEM'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI014_PBY'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PBY2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PBY3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PPO'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PPO2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PPO3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PRW'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PRW2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_P']['ZI014_PRW3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_P']['ZI020_GE4'] = ('CodeList',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI026_CTUC'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHED_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHED_P']['ZI026_CTUL'] = ('integer',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI026_CTUU'] = ('integer',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI031S_URI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZI039S_UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZSAX_RS0'] = ('CodeList',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZSAX_RX0'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZSAX_RX3'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZSAX_RX4'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_P']['ZVH'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ADR'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['AOO'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ARA'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['BEN'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['BNF'] = ('Integer',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['CAA'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['CAA']['AL019']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHED_S']['CNCP'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['COS'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['COS']['AL019']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHED_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['FFN'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_S']['FFN2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_S']['FFN3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['GGDM 3.0']['SHED_S']['FUFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['FURL'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['GDBV'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['GDBV']['AL019']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHED_S']['HGT'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['LMC'] = ('Boolean',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['LZN'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['OTH'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['PCF'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHED_S']['SSR'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_S']['SSR2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_S']['SSR3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['SHED_S']['UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['VCM'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_S']['VCM2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_S']['VCM3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['GGDM 3.0']['SHED_S']['WID'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI001_SDV'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI001_SRT'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI001_SRT']['AL019']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHED_S']['ZI002_UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI004_RCG'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI004_RCG']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHED_S']['ZI005_FNA'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI005_GNT'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI005_GNT']['AL019']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHED_S']['ZI005_NFN'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI006_MEM'] = ('String',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI014_PBY'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PBY2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PBY3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,89,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PPO'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PPO2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PPO3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,200,214,279,325,435,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PRW'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PRW2'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_S']['ZI014_PRW3'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,30,33,38,39,41,45,46,48,50,52,54,57,60,64,66,68,70,75,78,79,83,84,85,87,90,93,94,96,97,99,118,119,999)
    field_information['GGDM 3.0']['SHED_S']['ZI020_GE4'] = ('CodeList',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI026_CTUC'] = ('Enumeration',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHED_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL019']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHED_S']['ZI026_CTUL'] = ('integer',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI026_CTUU'] = ('integer',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI031S_URI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZI039S_UFI'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZSAX_RS0'] = ('CodeList',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZSAX_RX0'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZSAX_RX3'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZSAX_RX4'] = ('StructuredText',('AL019'))
    field_information['GGDM 3.0']['SHED_S']['ZVH'] = ('Real',('AL019'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['AOO'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ARA'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['AWP'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['BEN'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['CAA'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['CNCP'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['COS'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['DZP'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['FUFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['FURL'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['GDBV'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['HGT'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['LMC'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['LNU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['LZN'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['MCC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['MCC2'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['MCC3'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['MWD'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['OTH'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['PCF'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['VOI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['WDU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['WID'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI001_SDV'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI001_SRT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI002_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI004_RCG'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI005_FNA'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI005_GNT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI005_NFN'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI006_MEM'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI020_GE4'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI026_CTUC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI026_CTUL'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI026_CTUU'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI031S_URI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZI039S_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZSAX_RS0'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZSAX_RX0'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZSAX_RX3'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZSAX_RX4'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_C']['ZVH'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['AOO'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ARA'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['AWP'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['BEN'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['CAA'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['CNCP'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['COS'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['DZP'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['FUFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['FURL'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['GDBV'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['HGT'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['LMC'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['LNU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['LZN'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['MCC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['MCC2'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['MCC3'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['MWD'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['OTH'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['PCF'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['VOI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['WDU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['WID'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI001_SDV'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI001_SRT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI002_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI004_RCG'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI005_FNA'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI005_GNT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI005_NFN'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI006_MEM'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI020_GE4'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI026_CTUC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI026_CTUL'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI026_CTUU'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI031S_URI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZI039S_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZSAX_RS0'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZSAX_RX0'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZSAX_RX3'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZSAX_RX4'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_P']['ZVH'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['AOO'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ARA'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['AWP'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['BEN'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['CAA'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['CNCP'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['COS'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['COS']['BI006']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['DZP'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['FUFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['FURL'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['GDBV'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['GDBV']['BI006']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['HGT'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['LMC'] = ('Boolean',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['LNU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['LZN'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['MCC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['MCC2'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['MCC3'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['MWD'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['OTH'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['PCF'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['VOI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['WDU'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['WID'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI001_SDV'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI001_SRT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI001_SRT']['BI006']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI002_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI004_RCG'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI004_RCG']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI005_FNA'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI005_GNT'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI005_GNT']['BI006']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI005_NFN'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI006_MEM'] = ('String',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI020_GE4'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI026_CTUC'] = ('Enumeration',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI006']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI026_CTUL'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI026_CTUU'] = ('integer',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI031S_URI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZI039S_UFI'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZSAX_RS0'] = ('CodeList',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZSAX_RX0'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZSAX_RX3'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZSAX_RX4'] = ('StructuredText',('BI006'))
    field_information['GGDM 3.0']['SHIP_ELEVATOR_S']['ZVH'] = ('Real',('BI006'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['AOO'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ARA'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['BEN'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['CAA'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['CAA']['AM011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['CNCP'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['COS'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['COS']['AM011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['FFN'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['FFN2'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['FFN3'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['FUFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['FURL'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['GDBV'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['GDBV']['AM011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['HGT'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['LMC'] = ('Boolean',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['LZN'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['OTH'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['PCF'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['SHT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['SHT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['SPT'] = ('Boolean',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['VCM'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['VCM2'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['VCM3'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['WID'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI001_SDV'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI001_SRT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI001_SRT']['AM011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI002_UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI004_RCG'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI004_RCG']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI005_FNA'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI005_GNT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI005_GNT']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI005_NFN'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI006_MEM'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI020_GE4'] = ('CodeList',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI026_CTUC'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI026_CTUL'] = ('integer',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI026_CTUU'] = ('integer',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI031S_URI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZI039S_UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZSAX_RS0'] = ('CodeList',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZSAX_RX0'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZSAX_RX3'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZSAX_RX4'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_P']['ZVH'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['AOO'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ARA'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['BEN'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['CAA'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['CAA']['AM011']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['CNCP'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['COS'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['COS']['AM011']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['FFN'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['FFN2'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['FFN3'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['FUFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['FURL'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['GDBV'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['GDBV']['AM011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['HGT'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['LMC'] = ('Boolean',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['LZN'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['OTH'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['PCF'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['SHT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['SHT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['SPT'] = ('Boolean',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['VCM'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['VCM2'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['VCM3'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['WID'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI001_SDV'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI001_SRT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI001_SRT']['AM011']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI002_UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI004_RCG'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI004_RCG']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI005_FNA'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI005_GNT'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI005_GNT']['AM011']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI005_NFN'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI006_MEM'] = ('String',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI020_GE4'] = ('CodeList',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI026_CTUC'] = ('Enumeration',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM011']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI026_CTUL'] = ('integer',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI026_CTUU'] = ('integer',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI031S_URI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZI039S_UFI'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZSAX_RS0'] = ('CodeList',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZSAX_RX0'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZSAX_RX3'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZSAX_RX4'] = ('StructuredText',('AM011'))
    field_information['GGDM 3.0']['SHIPPING_CONTAINER_S']['ZVH'] = ('Real',('AM011'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ADR'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['AOO'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ARA'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['BEN'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['CAA'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['CNCP'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['COS'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['COS']['BB241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIPYARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['FFN'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['FFN2'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['FFN3'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['FUFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['FURL'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['GDBV'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['GDBV']['BB241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['HGT'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['LMC'] = ('Boolean',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['LZN'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['OTH'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['PCF'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIPYARD_P']['UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['WID'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['YSU'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI001_SDV'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI001_SRT'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI001_SRT']['BB241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI002_UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI004_RCG'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI004_RCG']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI005_FNA'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI005_GNT'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI005_GNT']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI005_NFN'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI006_MEM'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI020_GE4'] = ('CodeList',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI026_CTUC'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIPYARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI026_CTUL'] = ('integer',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI026_CTUU'] = ('integer',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI031S_URI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZI039S_UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZSAX_RS0'] = ('CodeList',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZSAX_RX0'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZSAX_RX3'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZSAX_RX4'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_P']['ZVH'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ADR'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['AOO'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ARA'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['BEN'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['CAA'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['CNCP'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['COS'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['COS']['BB241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHIPYARD_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['FFN'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['FFN2'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['FFN3'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['FUFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['FURL'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['GDBV'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['GDBV']['BB241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['HGT'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['LMC'] = ('Boolean',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['LZN'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['OTH'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['PCF'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHIPYARD_S']['UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['WID'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['YSU'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI001_SDV'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI001_SRT'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI001_SRT']['BB241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI002_UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI004_RCG'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI004_RCG']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI005_FNA'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI005_GNT'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI005_GNT']['BB241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI005_NFN'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI006_MEM'] = ('String',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI020_GE4'] = ('CodeList',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI026_CTUC'] = ('Enumeration',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHIPYARD_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI026_CTUL'] = ('integer',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI026_CTUU'] = ('integer',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI031S_URI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZI039S_UFI'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZSAX_RS0'] = ('CodeList',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZSAX_RX0'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZSAX_RX3'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZSAX_RX4'] = ('StructuredText',('BB241'))
    field_information['GGDM 3.0']['SHIPYARD_S']['ZVH'] = ('Real',('BB241'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ADR'] = ('String',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['AOO'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ARA'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['BEN'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['CAA'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['CAA']['AG030']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['CNCP'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['COS'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['COS']['AG030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['F_CODE'] = ('CONSTRAINED_STRING',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['FFN'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['FFN2'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN2']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['FFN3'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['FFN3']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['FUFI'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['FURL'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['GDBV'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['GDBV']['AG030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['HGT'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['LMC'] = ('Boolean',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['LZN'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['OTH'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['PCF'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['PCF']['AG030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['UFI'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['WID'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI001_SDV'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI001_SRT'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI001_SRT']['AG030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI002_UFI'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI004_RCG'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI004_RCG']['AG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI005_FNA'] = ('String',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI005_GNT'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI005_GNT']['AG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI005_NFN'] = ('String',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI006_MEM'] = ('String',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI020_GE4'] = ('CodeList',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI026_CTUC'] = ('Enumeration',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['EnumeratedIndexValues']['ZI026_CTUC']['AG030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI026_CTUL'] = ('integer',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI026_CTUU'] = ('integer',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI031S_URI'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZI039S_UFI'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZSAX_RS0'] = ('CodeList',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZSAX_RX0'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZSAX_RX3'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZSAX_RX4'] = ('StructuredText',('AG030'))
    field_information['GGDM 3.0']['SHOPPING_COMPLEX_S']['ZVH'] = ('Real',('AG030'))
    field_information['GGDM 3.0']['SHORELINE_C']['AZC'] = ('Boolean',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['BEN'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['FUFI'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['FURL'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['GDBV'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['GDBV']['BA024']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHORELINE_C']['OTH'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['SLT'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['SLT'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['SLT']['BA024']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['GGDM 3.0']['SHORELINE_C']['UFI'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI001_SDV'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI001_SRT'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI001_SRT']['BA024']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHORELINE_C']['ZI002_UFI'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI004_RCG'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI004_RCG']['BA024']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHORELINE_C']['ZI006_MEM'] = ('String',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI020_GE4'] = ('CodeList',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI026_CTUC'] = ('Enumeration',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHORELINE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BA024']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_C']['ZI026_CTUL'] = ('integer',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI026_CTUU'] = ('integer',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI031S_URI'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZI039S_UFI'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZSAX_RS0'] = ('CodeList',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZSAX_RX0'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZSAX_RX3'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_C']['ZSAX_RX4'] = ('StructuredText',('BA024'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['AOO'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ARA'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['BEN'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['CAA'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['CNCP'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['COS'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['COS']['BB081']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['F_CODE'] = ('CONSTRAINED_STRING',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FAC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FFN'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FFN2'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FFN3'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FLO'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FUFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['FURL'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['GDBV'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['GDBV']['BB081']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['HGT'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['LMC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['LZN'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['MCC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['MCC2'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['MCC3'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['OTH'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['PCF'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['PWC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['PWC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['WID'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['WLE'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI001_SDV'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI001_SRT'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI001_SRT']['BB081']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI002_UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI004_RCG'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI004_RCG']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI005_FNA'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI005_GNT'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI005_GNT']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI005_NFN'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI006_MEM'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI020_GE4'] = ('CodeList',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI026_CTUC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['EnumeratedIndexValues']['ZI026_CTUC']['BB081']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI026_CTUL'] = ('integer',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI026_CTUU'] = ('integer',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI031S_URI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZI039S_UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZSAX_RS0'] = ('CodeList',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZSAX_RX0'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZSAX_RX3'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZSAX_RX4'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_C']['ZVH'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['AOO'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ARA'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['BEN'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['CAA'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['CNCP'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['COS'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['COS']['BB081']  = (-999999,2,4,6,9,13,14)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FAC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FFN'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FFN2'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FFN3'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FLO'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FUFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['FURL'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['GDBV'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['GDBV']['BB081']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['HGT'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['LMC'] = ('Boolean',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['LZN'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['MCC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['MCC2'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['MCC3'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['OTH'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['PCF'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['PWC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['PWC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['WID'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['WLE'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI001_SDV'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI001_SRT'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI001_SRT']['BB081']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI002_UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI004_RCG'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI004_RCG']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI005_FNA'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI005_GNT'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI005_GNT']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI005_NFN'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI006_MEM'] = ('String',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI020_GE4'] = ('CodeList',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI026_CTUC'] = ('Enumeration',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB081']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI026_CTUL'] = ('integer',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI026_CTUU'] = ('integer',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI031S_URI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZI039S_UFI'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZSAX_RS0'] = ('CodeList',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZSAX_RX0'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZSAX_RX3'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZSAX_RX4'] = ('StructuredText',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_CONSTRUCTION_S']['ZVH'] = ('Real',('BB081'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ARA'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['BEN'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['CNCP'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['COS'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['COS']['BB082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['F_CODE'] = ('CONSTRAINED_STRING',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['FUFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['FURL'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['GDBV'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['GDBV']['BB082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['HGT'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['LZN'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['MCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['MCC2'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['MCC3'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['OTH'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['PCF'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['SGCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['SGCL'] = ('real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['SGCU'] = ('real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['SLR'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['SLR'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['WID'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['WLE'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI001_SDV'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI001_SRT'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI001_SRT']['BB082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI002_UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI004_RCG'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI004_RCG']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI005_FNA'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI005_GNT'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI005_GNT']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI005_NFN'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI006_MEM'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI020_GE4'] = ('CodeList',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI026_CTUC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['EnumeratedIndexValues']['ZI026_CTUC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI026_CTUL'] = ('integer',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI026_CTUU'] = ('integer',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI031S_URI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZI039S_UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZSAX_RS0'] = ('CodeList',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZSAX_RX0'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZSAX_RX3'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZSAX_RX4'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_C']['ZVH'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ARA'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['BEN'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['CNCP'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['COS'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['COS']['BB082']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['FUFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['FURL'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['GDBV'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['GDBV']['BB082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['HGT'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['LZN'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['MCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['MCC2'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['MCC3'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,62,88,104,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['OTH'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['PCF'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['SGCC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['SGCL'] = ('real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['SGCU'] = ('real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['SLR'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['SLR'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['WID'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['WLE'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['WLE'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI001_SDV'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI001_SRT'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI001_SRT']['BB082']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI002_UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI004_RCG'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI004_RCG']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI005_FNA'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI005_GNT'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI005_GNT']['BB082']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI005_NFN'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI006_MEM'] = ('String',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI020_GE4'] = ('CodeList',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI026_CTUC'] = ('Enumeration',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI026_CTUL'] = ('integer',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI026_CTUU'] = ('integer',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI031S_URI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZI039S_UFI'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZSAX_RS0'] = ('CodeList',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZSAX_RX0'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZSAX_RX3'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZSAX_RX4'] = ('StructuredText',('BB082'))
    field_information['GGDM 3.0']['SHORELINE_RAMP_S']['ZVH'] = ('Real',('BB082'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ARA'] = ('Real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['BEN'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['CIW'] = ('Boolean',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['CNCP'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['COS'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['COS']['AQ035']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SIDEWALK_C']['CWT'] = ('Boolean',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['FUFI'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['FURL'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['GDBV'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['GDBV']['AQ035']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['LMC'] = ('Boolean',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['LZN'] = ('Real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['OTH'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['PCF'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['PCF']['AQ035']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SIDEWALK_C']['SBB'] = ('Boolean',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['SGCC'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['SGCC']['AQ035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SIDEWALK_C']['SGCL'] = ('real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['SGCU'] = ('real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['UFI'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['WID'] = ('Real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI001_SDV'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI001_SRT'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI002_UFI'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI004_RCG'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI005_FNA'] = ('String',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI005_GNT'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI005_NFN'] = ('String',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI006_MEM'] = ('String',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI016_ROC'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI016_ROC']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI016_WD1'] = ('Real',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI016_WTC'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI016_WTC']['AQ035']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI020_GE4'] = ('CodeList',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI026_CTUC'] = ('Enumeration',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SIDEWALK_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI026_CTUL'] = ('integer',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI026_CTUU'] = ('integer',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI031S_URI'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZI039S_UFI'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZSAX_RS0'] = ('CodeList',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZSAX_RX0'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZSAX_RX3'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZSAX_RX4'] = ('StructuredText',('AQ035'))
    field_information['GGDM 3.0']['SIDEWALK_C']['ZVH'] = ('Real',('AQ035'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['AOO'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ARA'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['AWP'] = ('Boolean',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['BEN'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['CAA'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['CAA']['AK150']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SKI_JUMP_C']['CNCP'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['COS'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['COS']['AK150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SKI_JUMP_C']['F_CODE'] = ('CONSTRAINED_STRING',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['FUFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['FURL'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['GDBV'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['GDBV']['AK150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SKI_JUMP_C']['HGT'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['LMC'] = ('Boolean',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['LZN'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['OTH'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['PCF'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SKI_JUMP_C']['UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['VOI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['WID'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI001_SDV'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI001_SRT'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI001_SRT']['AK150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI002_UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI004_RCG'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI004_RCG']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI005_FNA'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI005_GNT'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI005_GNT']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI005_NFN'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI006_MEM'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI020_GE4'] = ('CodeList',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI026_CTUC'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_C']['EnumeratedIndexValues']['ZI026_CTUC']['AK150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI026_CTUL'] = ('integer',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI026_CTUU'] = ('integer',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI031S_URI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZI039S_UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZSAX_RS0'] = ('CodeList',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZSAX_RX0'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZSAX_RX3'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZSAX_RX4'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_C']['ZVH'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['AOO'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ARA'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['AWP'] = ('Boolean',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['BEN'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['CAA'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['CAA']['AK150']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SKI_JUMP_P']['CNCP'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['COS'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['COS']['AK150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SKI_JUMP_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['FUFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['FURL'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['GDBV'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['GDBV']['AK150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SKI_JUMP_P']['HGT'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['LMC'] = ('Boolean',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['LZN'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['OTH'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['PCF'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SKI_JUMP_P']['UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['VOI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['WID'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI001_SDV'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI001_SRT'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI001_SRT']['AK150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI002_UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI004_RCG'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI004_RCG']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI005_FNA'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI005_GNT'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI005_GNT']['AK150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI005_NFN'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI006_MEM'] = ('String',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI020_GE4'] = ('CodeList',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI026_CTUC'] = ('Enumeration',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SKI_JUMP_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI026_CTUL'] = ('integer',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI026_CTUU'] = ('integer',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI031S_URI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZI039S_UFI'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZSAX_RS0'] = ('CodeList',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZSAX_RX0'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZSAX_RX3'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZSAX_RX4'] = ('StructuredText',('AK150'))
    field_information['GGDM 3.0']['SKI_JUMP_P']['ZVH'] = ('Real',('AK150'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ARA'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['BEN'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['CNCP'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['COS'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['COS']['AK155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SKI_RUN_C']['F_CODE'] = ('CONSTRAINED_STRING',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['FUFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['FURL'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['GDBV'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['GDBV']['AK155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SKI_RUN_C']['HGT'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['LMC'] = ('Boolean',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['LZN'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['OTH'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['PCF'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SKI_RUN_C']['UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['WID'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI001_SDV'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI001_SRT'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI001_SRT']['AK155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI002_UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI004_RCG'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI004_RCG']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI005_FNA'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI005_GNT'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI005_GNT']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI005_NFN'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI006_MEM'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI020_GE4'] = ('CodeList',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI026_CTUC'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SKI_RUN_C']['EnumeratedIndexValues']['ZI026_CTUC']['AK155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI026_CTUL'] = ('integer',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI026_CTUU'] = ('integer',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI031S_URI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZI039S_UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZSAX_RS0'] = ('CodeList',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZSAX_RX0'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZSAX_RX3'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZSAX_RX4'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_C']['ZVH'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ARA'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['BEN'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['CNCP'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['COS'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['COS']['AK155']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SKI_RUN_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['FUFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['FURL'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['GDBV'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['GDBV']['AK155']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SKI_RUN_S']['HGT'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['LMC'] = ('Boolean',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['LZN'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['OTH'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['PCF'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SKI_RUN_S']['UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['WID'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI001_SDV'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI001_SRT'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI001_SRT']['AK155']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI002_UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI004_RCG'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI004_RCG']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI005_FNA'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI005_GNT'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI005_GNT']['AK155']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI005_NFN'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI006_MEM'] = ('String',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI020_GE4'] = ('CodeList',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI026_CTUC'] = ('Enumeration',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SKI_RUN_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK155']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI026_CTUL'] = ('integer',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI026_CTUU'] = ('integer',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI031S_URI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZI039S_UFI'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZSAX_RS0'] = ('CodeList',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZSAX_RX0'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZSAX_RX3'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZSAX_RX4'] = ('StructuredText',('AK155'))
    field_information['GGDM 3.0']['SKI_RUN_S']['ZVH'] = ('Real',('AK155'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['BEN'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['F_CODE'] = ('CONSTRAINED_STRING',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['FUFI'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['FURL'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['GDBV'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['GDBV']['SA050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SLOPE_REGION_S']['OTH'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['SGCC'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['SGCC']['SA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SLOPE_REGION_S']['SGCL'] = ('real',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['SGCU'] = ('real',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['UFI'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI001_SDV'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI001_SRT'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI001_SRT']['SA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI002_UFI'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI004_RCG'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI004_RCG']['SA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI006_MEM'] = ('String',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI020_GE4'] = ('CodeList',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI026_CTUC'] = ('Enumeration',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SLOPE_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC']['SA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI026_CTUL'] = ('integer',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI026_CTUU'] = ('integer',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI031S_URI'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZI039S_UFI'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZSAX_RS0'] = ('CodeList',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZSAX_RX0'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZSAX_RX3'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLOPE_REGION_S']['ZSAX_RX4'] = ('StructuredText',('SA050'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['AOO'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['BEN'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['CNCP'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['COS'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['COS']['BI040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['FUFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['FURL'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['GDBV'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['GDBV']['BI040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['LMC'] = ('Boolean',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['LZN'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['MCC'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['MCC2'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['MCC3'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['OTH'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['PCF'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['THI'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI001_SDV'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI001_SRT'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI001_SRT']['BI040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI002_UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI004_RCG'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI004_RCG']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI006_MEM'] = ('String',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI020_GE4'] = ('CodeList',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI026_CTUC'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BI040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI026_CTUL'] = ('integer',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI026_CTUU'] = ('integer',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI031S_URI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZI039S_UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZSAX_RS0'] = ('CodeList',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZSAX_RX0'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZSAX_RX3'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_C']['ZSAX_RX4'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['AOO'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['BEN'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['CNCP'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['COS'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['COS']['BI040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['FUFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['FURL'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['GDBV'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['GDBV']['BI040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['LMC'] = ('Boolean',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['LZN'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['MCC'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['MCC2'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['MCC3'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['OTH'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['PCF'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['THI'] = ('Real',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI001_SDV'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI001_SRT'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI001_SRT']['BI040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI002_UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI004_RCG'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI004_RCG']['BI040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI006_MEM'] = ('String',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI020_GE4'] = ('CodeList',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI026_CTUC'] = ('Enumeration',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SLUICE_GATE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI026_CTUL'] = ('integer',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI026_CTUU'] = ('integer',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI031S_URI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZI039S_UFI'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZSAX_RS0'] = ('CodeList',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZSAX_RX0'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZSAX_RX3'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SLUICE_GATE_P']['ZSAX_RX4'] = ('StructuredText',('BI040'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ADR'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['AOO'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ARA'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['BEN'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['CAA'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['CNCP'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['COS'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['COS']['BB201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['FFN'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['FFN2'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['FFN3'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['FUFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['FURL'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['GDBV'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['GDBV']['BB201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['HGT'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['LMC'] = ('Boolean',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['LZN'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['OTH'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['PCF'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['WID'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['BB201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI005_FNA'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI005_NFN'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI006_MEM'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI020_GE4'] = ('CodeList',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['BB201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI026_CTUL'] = ('integer',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI026_CTUU'] = ('integer',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_P']['ZVH'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ADR'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['AOO'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ARA'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['BEN'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['CAA'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['CNCP'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['COS'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['COS']['BB201']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['FFN'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['FFN2'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['FFN3'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['FUFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['FURL'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['GDBV'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['GDBV']['BB201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['HGT'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['LMC'] = ('Boolean',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['LZN'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['OTH'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['PCF'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['WID'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['BB201']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI005_FNA'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['BB201']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI005_NFN'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI006_MEM'] = ('String',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI020_GE4'] = ('CodeList',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['BB201']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI026_CTUL'] = ('integer',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI026_CTUU'] = ('integer',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('BB201'))
    field_information['GGDM 3.0']['SMALL_CRAFT_FACILITY_S']['ZVH'] = ('Real',('BB201'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['AOO'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['AWP'] = ('Boolean',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['BEN'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['CAA'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['CAA']['AF010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['CNCP'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['COS'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['COS']['AF010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SMOKESTACK_P']['DIM'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['F_CODE'] = ('CONSTRAINED_STRING',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['FUFI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['FURL'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['GDBV'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['GDBV']['AF010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['HEI'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['HGT'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['LMC'] = ('Boolean',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['OTH'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['PCF'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['PCF']['AF010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SMOKESTACK_P']['UFI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['VCM'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['VCM2'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM2']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['VCM3'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['VCM3']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['VOI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI001_SDV'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI001_SRT'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI001_SRT']['AF010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI002_UFI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI004_RCG'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI004_RCG']['AF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI005_FNA'] = ('String',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI005_GNT'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI005_GNT']['AF010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI005_NFN'] = ('String',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI006_MEM'] = ('String',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI020_GE4'] = ('CodeList',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI026_CTUC'] = ('Enumeration',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SMOKESTACK_P']['EnumeratedIndexValues']['ZI026_CTUC']['AF010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI026_CTUL'] = ('integer',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI026_CTUU'] = ('integer',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI031S_URI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZI039S_UFI'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZSAX_RS0'] = ('CodeList',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZSAX_RX0'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZSAX_RX3'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZSAX_RX4'] = ('StructuredText',('AF010'))
    field_information['GGDM 3.0']['SMOKESTACK_P']['ZVH'] = ('Real',('AF010'))
    field_information['GGDM 3.0']['SNAG_P']['ARA'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['BEN'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['FUFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['FURL'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['GDBV'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['GDBV']['BD140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SNAG_P']['LZN'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['OTH'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['WID'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI001_SDV'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI001_SRT'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI001_SRT']['BD140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SNAG_P']['ZI002_UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI004_RCG'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI004_RCG']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SNAG_P']['ZI005_FNA'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI005_GNT'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI005_GNT']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SNAG_P']['ZI005_NFN'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI006_MEM'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI020_GE4'] = ('CodeList',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI025_HDP'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI026_CTUC'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SNAG_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SNAG_P']['ZI026_CTUL'] = ('integer',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI026_CTUU'] = ('integer',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI031S_URI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZI039S_UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZSAX_RS0'] = ('CodeList',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZSAX_RX0'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZSAX_RX3'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_P']['ZSAX_RX4'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ARA'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['BEN'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['FUFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['FURL'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['GDBV'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['GDBV']['BD140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SNAG_S']['LZN'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['OTH'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['WID'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI001_SDV'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI001_SRT'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI001_SRT']['BD140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SNAG_S']['ZI002_UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI004_RCG'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI004_RCG']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SNAG_S']['ZI005_FNA'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI005_GNT'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI005_GNT']['BD140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SNAG_S']['ZI005_NFN'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI006_MEM'] = ('String',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI020_GE4'] = ('CodeList',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI025_HDP'] = ('Real',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI026_CTUC'] = ('Enumeration',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SNAG_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SNAG_S']['ZI026_CTUL'] = ('integer',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI026_CTUU'] = ('integer',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI031S_URI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZI039S_UFI'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZSAX_RS0'] = ('CodeList',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZSAX_RX0'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZSAX_RX3'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNAG_S']['ZSAX_RX4'] = ('StructuredText',('BD140'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ARA'] = ('Real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['BEN'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['FUFI'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['FURL'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['GDBV'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['GDBV']['BJ100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['LZN'] = ('Real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['OTH'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SDCC'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SDCC'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SDCC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SDCL'] = ('real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SDCU'] = ('real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SIC'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SIC'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SIC']['BJ100']  = (-999999,1,2)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SNDC'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SNDC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SNDL'] = ('real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SNDU'] = ('real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['SRD'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SRD'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['SRD']['BJ100']  = (-999999,1,2,11,12,16,17,18,35,36,43,52,53,55,56,57,70,81,999)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['UFI'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['WID'] = ('Real',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI001_SDV'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI001_SRT'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI002_UFI'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI004_RCG'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI005_FNA'] = ('String',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI005_GNT'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI005_NFN'] = ('String',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI006_MEM'] = ('String',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI020_GE4'] = ('CodeList',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI026_CTUC'] = ('Enumeration',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI026_CTUL'] = ('integer',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI026_CTUU'] = ('integer',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI031S_URI'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZI039S_UFI'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZSAX_RS0'] = ('CodeList',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZSAX_RX0'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZSAX_RX3'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SNOW_ICE_FIELD_S']['ZSAX_RX4'] = ('StructuredText',('BJ100'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ARA'] = ('Real',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['BEN'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['F_CODE'] = ('CONSTRAINED_STRING',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['FUFI'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['FURL'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['GDBV'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['GDBV']['DA010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['LZN'] = ('Real',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['OTH'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['SDCC'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SDCC'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SDCC']['DA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['SDCL'] = ('real',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['SDCU'] = ('real',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['SRD'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SRD'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SRD']['DA010']  = (-999999,1,2,11,12,13,14,15,16,17,18,19,20,31,32,33,34,35,36,37,43,51,52,53,54,55,56,57,58,59,60,61,63,64,65,66,67,69,70,81,86,88,89,90,91,92,93,94,95,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['STP'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['STP'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['STP']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['SWC'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SWC'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['SWC']['DA010']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['TSM'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['TSM2'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM2'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM2']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['TSM3'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM3'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['TSM3']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['UFI'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['WID'] = ('Real',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI001_SDV'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI001_SRT'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI001_SRT']['DA010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI002_UFI'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI004_RCG'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI004_RCG']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI005_FNA'] = ('String',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI005_GNT'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI005_GNT']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI005_NFN'] = ('String',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI006_MEM'] = ('String',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI020_GE4'] = ('CodeList',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI026_CTUC'] = ('Enumeration',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['EnumeratedIndexValues']['ZI026_CTUC']['DA010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI026_CTUL'] = ('integer',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI026_CTUU'] = ('integer',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI031S_URI'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZI039S_UFI'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZSAX_RS0'] = ('CodeList',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZSAX_RX0'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZSAX_RX3'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOIL_SURFACE_REGION_S']['ZSAX_RX4'] = ('StructuredText',('DA010'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ADR'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['AOO'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ARA'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['BEN'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['CAA'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['CAA']['AD025']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['CNCP'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['COS'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['COS']['AD025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['FUFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['FURL'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['GDBV'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['GDBV']['AD025']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['HGT'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['LMC'] = ('Boolean',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['LZN'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['OTH'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['PCF'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['PPO'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['PPO2'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['PPO3'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['VCM'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['VCM2'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['VCM3'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['WID'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI001_SDV'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI001_SRT'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI001_SRT']['AD025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI002_UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI004_RCG'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI004_RCG']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI005_FNA'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI005_GNT'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI005_GNT']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI005_NFN'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI006_MEM'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI020_GE4'] = ('CodeList',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI026_CTUC'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI026_CTUL'] = ('integer',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI026_CTUU'] = ('integer',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI031S_URI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZI039S_UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZSAX_RS0'] = ('CodeList',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZSAX_RX0'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZSAX_RX3'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZSAX_RX4'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_P']['ZVH'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ADR'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['AOO'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ARA'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['BEN'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['CAA'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['CAA']['AD025']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['CNCP'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['COS'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['COS']['AD025']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['FUFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['FURL'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['GDBV'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['GDBV']['AD025']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['HGT'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['LMC'] = ('Boolean',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['LZN'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['OTH'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['PCF'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['PPO'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['PPO2'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['PPO3'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['VCM'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['VCM2'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['VCM3'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['WID'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI001_SDV'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI001_SRT'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI001_SRT']['AD025']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI002_UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI004_RCG'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI004_RCG']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI005_FNA'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI005_GNT'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI005_GNT']['AD025']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI005_NFN'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI006_MEM'] = ('String',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI020_GE4'] = ('CodeList',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI026_CTUC'] = ('Enumeration',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOLAR_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD025']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI026_CTUL'] = ('integer',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI026_CTUU'] = ('integer',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI031S_URI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZI039S_UFI'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZSAX_RS0'] = ('CodeList',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZSAX_RX0'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZSAX_RX3'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZSAX_RX4'] = ('StructuredText',('AD025'))
    field_information['GGDM 3.0']['SOLAR_FARM_S']['ZVH'] = ('Real',('AD025'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['AOO'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ARA'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['BEN'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['CNCP'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['COS'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['COS']['AD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['FUFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['FURL'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['GDBV'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['GDBV']['AD020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['HGT'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['LMC'] = ('Boolean',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['LZN'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['OTH'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['PCF'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['PPO'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['PPO2'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['PPO3'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['WID'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI001_SDV'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI001_SRT'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI001_SRT']['AD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI002_UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI004_RCG'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI004_RCG']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI005_FNA'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI005_GNT'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI005_GNT']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI005_NFN'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI006_MEM'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI020_GE4'] = ('CodeList',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI026_CTUC'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI026_CTUL'] = ('integer',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI026_CTUU'] = ('integer',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI031S_URI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZI039S_UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZSAX_RS0'] = ('CodeList',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZSAX_RX0'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZSAX_RX3'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZSAX_RX4'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_P']['ZVH'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['AOO'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ARA'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['BEN'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['CNCP'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['COS'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['COS']['AD020']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['FUFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['FURL'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['GDBV'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['GDBV']['AD020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['HGT'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['LMC'] = ('Boolean',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['LZN'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['OTH'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['PCF'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['PPO'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['PPO2'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['PPO3'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['WID'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI001_SDV'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI001_SRT'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI001_SRT']['AD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI002_UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI004_RCG'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI004_RCG']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI005_FNA'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI005_GNT'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI005_GNT']['AD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI005_NFN'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI006_MEM'] = ('String',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI020_GE4'] = ('CodeList',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI026_CTUC'] = ('Enumeration',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI026_CTUL'] = ('integer',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI026_CTUU'] = ('integer',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI031S_URI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZI039S_UFI'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZSAX_RS0'] = ('CodeList',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZSAX_RX0'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZSAX_RX3'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZSAX_RX4'] = ('StructuredText',('AD020'))
    field_information['GGDM 3.0']['SOLAR_PANEL_S']['ZVH'] = ('Real',('AD020'))
    field_information['GGDM 3.0']['SOUNDING_P']['BEN'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['F_CODE'] = ('CONSTRAINED_STRING',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['FUFI'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['FURL'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['GDBV'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['GDBV']['BE020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SOUNDING_P']['HDH'] = ('Real',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['HDP'] = ('Real',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['OTH'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['UFI'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_SVC'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_SVC']['BE020']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_TEC'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_TEC2'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC2']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_TEC3'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_TEC3']['BE020']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_VDC'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZHDP_VDC']['BE020']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZHDP_VDR'] = ('String',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI001_SDV'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI001_SRT'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI001_SRT']['BE020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZI002_UFI'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI004_RCG'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI004_RCG']['BE020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SOUNDING_P']['ZI006_MEM'] = ('String',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI020_GE4'] = ('CodeList',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI026_CTUC'] = ('Enumeration',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SOUNDING_P']['EnumeratedIndexValues']['ZI026_CTUC']['BE020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SOUNDING_P']['ZI026_CTUL'] = ('integer',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI026_CTUU'] = ('integer',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI031S_URI'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZI039S_UFI'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZSAX_RS0'] = ('CodeList',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZSAX_RX0'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZSAX_RX3'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SOUNDING_P']['ZSAX_RX4'] = ('StructuredText',('BE020'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ADR'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['AOO'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ARA'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['BEN'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['CAA'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['CNCP'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['COS'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['COS']['AL351']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['FFN'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['FFN2'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['FFN3'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['FUFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['FURL'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['GDBV'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['GDBV']['AL351']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['HGT'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['LMC'] = ('Boolean',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['LZN'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['OTH'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['PCF'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['WID'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI001_SDV'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI001_SRT'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI001_SRT']['AL351']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI002_UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI004_RCG'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI004_RCG']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI005_FNA'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI005_GNT'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI005_GNT']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI005_NFN'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI006_MEM'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI020_GE4'] = ('CodeList',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI026_CTUC'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL351']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI026_CTUL'] = ('integer',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI026_CTUU'] = ('integer',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI031S_URI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZI039S_UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZSAX_RS0'] = ('CodeList',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZSAX_RX0'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZSAX_RX3'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZSAX_RX4'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_P']['ZVH'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ADR'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['AOO'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ARA'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['BEN'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['CAA'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['CNCP'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['COS'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['COS']['AL351']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['FFN'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['FFN2'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['FFN3'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['FUFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['FURL'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['GDBV'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['GDBV']['AL351']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['HGT'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['LMC'] = ('Boolean',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['LZN'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['OTH'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['PCF'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['WID'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI001_SDV'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI001_SRT'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI001_SRT']['AL351']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI002_UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI004_RCG'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI004_RCG']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI005_FNA'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI005_GNT'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI005_GNT']['AL351']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI005_NFN'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI006_MEM'] = ('String',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI020_GE4'] = ('CodeList',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI026_CTUC'] = ('Enumeration',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL351']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI026_CTUL'] = ('integer',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI026_CTUU'] = ('integer',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI031S_URI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZI039S_UFI'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZSAX_RS0'] = ('CodeList',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZSAX_RX0'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZSAX_RX3'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZSAX_RX4'] = ('StructuredText',('AL351'))
    field_information['GGDM 3.0']['SPACE_FACILITY_S']['ZVH'] = ('Real',('AL351'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ARA'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['BEN'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['CNCP'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['COS'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['COS']['BH165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPILLWAY_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['FUFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['FURL'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['GDBV'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['GDBV']['BH165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['LZN'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['MCC'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['MCC2'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['MCC3'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['OTH'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['PCF'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPILLWAY_C']['UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['WID'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI001_SDV'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI001_SRT'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI001_SRT']['BH165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI002_UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI004_RCG'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI004_RCG']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI005_FNA'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI005_GNT'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI005_GNT']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI005_NFN'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI006_MEM'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI020_GE4'] = ('CodeList',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI026_CTUC'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPILLWAY_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI026_CTUL'] = ('integer',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI026_CTUU'] = ('integer',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI031S_URI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZI039S_UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZSAX_RS0'] = ('CodeList',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZSAX_RX0'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZSAX_RX3'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_C']['ZSAX_RX4'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ARA'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['BEN'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['CNCP'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['COS'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['COS']['BH165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPILLWAY_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['FUFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['FURL'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['GDBV'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['GDBV']['BH165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['LZN'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['MCC'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['MCC2'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['MCC3'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['OTH'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['PCF'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPILLWAY_S']['UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['WID'] = ('Real',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI001_SDV'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI001_SRT'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI001_SRT']['BH165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI002_UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI004_RCG'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI004_RCG']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI005_FNA'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI005_GNT'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI005_GNT']['BH165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI005_NFN'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI006_MEM'] = ('String',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI020_GE4'] = ('CodeList',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI026_CTUC'] = ('Enumeration',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPILLWAY_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI026_CTUL'] = ('integer',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI026_CTUU'] = ('integer',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI031S_URI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZI039S_UFI'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZSAX_RS0'] = ('CodeList',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZSAX_RX0'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZSAX_RX3'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPILLWAY_S']['ZSAX_RX4'] = ('StructuredText',('BH165'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ARA'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['BEN'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['CNCP'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['COS'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['COS']['AK040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['FUFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['FURL'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['GDBV'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['GDBV']['AK040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['HGT'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['LMC'] = ('Boolean',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['LZN'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['OTH'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['PCF'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['WID'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI001_SDV'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI001_SRT'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI001_SRT']['AK040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI002_UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI004_RCG'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI004_RCG']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI005_FNA'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI005_GNT'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI005_GNT']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI005_NFN'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI006_MEM'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI020_GE4'] = ('CodeList',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI026_CTUC'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI026_CTUL'] = ('integer',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI026_CTUU'] = ('integer',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI031S_URI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZI039S_UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZSAX_RS0'] = ('CodeList',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZSAX_RX0'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZSAX_RX3'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZSAX_RX4'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_P']['ZVH'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ARA'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['BEN'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['CNCP'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['COS'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['COS']['AK040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['FUFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['FURL'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['GDBV'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['GDBV']['AK040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['HGT'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['LMC'] = ('Boolean',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['LZN'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['OTH'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['PCF'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['WID'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI001_SDV'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI001_SRT'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI001_SRT']['AK040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI002_UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI004_RCG'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI004_RCG']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI005_FNA'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI005_GNT'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI005_GNT']['AK040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI005_NFN'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI006_MEM'] = ('String',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI020_GE4'] = ('CodeList',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI026_CTUC'] = ('Enumeration',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI026_CTUL'] = ('integer',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI026_CTUU'] = ('integer',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI031S_URI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZI039S_UFI'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZSAX_RS0'] = ('CodeList',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZSAX_RX0'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZSAX_RX3'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZSAX_RX4'] = ('StructuredText',('AK040'))
    field_information['GGDM 3.0']['SPORTS_GROUND_S']['ZVH'] = ('Real',('AK040'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['BEN'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ESC'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ESC'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ESC']['CA030']  = (-999999,1,2,4,5,6)
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['FUFI'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['FURL'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['GDBV'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['GDBV']['CA030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['OTH'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['UFI'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI001_SDV'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI001_SRT'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI001_SRT']['CA030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI002_UFI'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI004_RCG'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI004_RCG']['CA030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI006_MEM'] = ('String',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI020_GE4'] = ('CodeList',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI026_CTUC'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['CA030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI026_CTUL'] = ('integer',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI026_CTUU'] = ('integer',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI031S_URI'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZI039S_UFI'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZSAX_RS0'] = ('CodeList',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZSAX_RX0'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZSAX_RX3'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZSAX_RX4'] = ('StructuredText',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZVH'] = ('Real',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZVH_AVA'] = ('Real',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['ZVH_VDT'] = ('Enumeration',('CA030'))
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZVH_VDT'] = {}
    field_information['GGDM 3.0']['SPOT_ELEVATION_P']['EnumeratedIndexValues']['ZVH_VDT']['CA030']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['STABLE_P']['ADR'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['AOO'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ARA'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['BEN'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['CAA'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STABLE_P']['CNCP'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['COS'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['COS']['AJ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STABLE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['FFN'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_P']['FFN2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_P']['FFN3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_P']['FUFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['FURL'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['GDBV'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['GDBV']['AJ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STABLE_P']['HGT'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['LMC'] = ('Boolean',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['LZN'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['OTH'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['PCF'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STABLE_P']['SSR'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_P']['SSR2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_P']['SSR3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_P']['UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['VCM'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_P']['VCM2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_P']['VCM3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_P']['WID'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI001_SDV'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI001_SRT'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STABLE_P']['ZI002_UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI004_RCG'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STABLE_P']['ZI005_FNA'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI005_GNT'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STABLE_P']['ZI005_NFN'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI006_MEM'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI020_GE4'] = ('CodeList',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI026_CTUC'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STABLE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STABLE_P']['ZI026_CTUL'] = ('integer',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI026_CTUU'] = ('integer',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI031S_URI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZI039S_UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZSAX_RS0'] = ('CodeList',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZSAX_RX0'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZSAX_RX3'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZSAX_RX4'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_P']['ZVH'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ADR'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['AOO'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ARA'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['BEN'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['CAA'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STABLE_S']['CNCP'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['COS'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['COS']['AJ080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STABLE_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['FFN'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_S']['FFN2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_S']['FFN3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['GGDM 3.0']['STABLE_S']['FUFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['FURL'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['GDBV'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['GDBV']['AJ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STABLE_S']['HGT'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['LMC'] = ('Boolean',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['LZN'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['OTH'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['PCF'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STABLE_S']['SSR'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_S']['SSR2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_S']['SSR3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STABLE_S']['UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['VCM'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_S']['VCM2'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_S']['VCM3'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['GGDM 3.0']['STABLE_S']['WID'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI001_SDV'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI001_SRT'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STABLE_S']['ZI002_UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI004_RCG'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STABLE_S']['ZI005_FNA'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI005_GNT'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STABLE_S']['ZI005_NFN'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI006_MEM'] = ('String',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI020_GE4'] = ('CodeList',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI026_CTUC'] = ('Enumeration',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STABLE_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STABLE_S']['ZI026_CTUL'] = ('integer',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI026_CTUU'] = ('integer',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI031S_URI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZI039S_UFI'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZSAX_RS0'] = ('CodeList',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZSAX_RX0'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZSAX_RX3'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZSAX_RX4'] = ('StructuredText',('AJ080'))
    field_information['GGDM 3.0']['STABLE_S']['ZVH'] = ('Real',('AJ080'))
    field_information['GGDM 3.0']['STADIUM_P']['ADR'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['AOO'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ARA'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['AWP'] = ('Boolean',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['BEN'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['CAA'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['CAA']['AK160']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STADIUM_P']['CCT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['CCT'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['STADIUM_P']['CNCP'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['COS'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['COS']['AK160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STADIUM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['FFN'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_P']['FFN2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_P']['FFN3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_P']['FUFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['FURL'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['GDBV'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['GDBV']['AK160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STADIUM_P']['HGT'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['LMC'] = ('Boolean',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['LZN'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['OTH'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['PCF'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STADIUM_P']['SSR'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_P']['SSR2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_P']['SSR3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_P']['UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['VOI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['WID'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI001_SDV'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI001_SRT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI001_SRT']['AK160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STADIUM_P']['ZI002_UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI004_RCG'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI004_RCG']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STADIUM_P']['ZI005_FNA'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI005_GNT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI005_GNT']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STADIUM_P']['ZI005_NFN'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI006_MEM'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI020_GE4'] = ('CodeList',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI026_CTUC'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STADIUM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STADIUM_P']['ZI026_CTUL'] = ('integer',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI026_CTUU'] = ('integer',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI031S_URI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZI039S_UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZSAX_RS0'] = ('CodeList',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZSAX_RX0'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZSAX_RX3'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZSAX_RX4'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_P']['ZVH'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ADR'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['AOO'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ARA'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['AWP'] = ('Boolean',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['BEN'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['CAA'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['CAA']['AK160']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STADIUM_S']['CCT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['CCT'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['STADIUM_S']['CNCP'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['COS'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['COS']['AK160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STADIUM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['FFN'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_S']['FFN2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_S']['FFN3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,572,900,912,921,930,954,999)
    field_information['GGDM 3.0']['STADIUM_S']['FUFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['FURL'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['GDBV'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['GDBV']['AK160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STADIUM_S']['HGT'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['LMC'] = ('Boolean',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['LZN'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['OTH'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['PCF'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STADIUM_S']['SSR'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_S']['SSR2'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_S']['SSR3'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['STADIUM_S']['UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['VOI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['WID'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI001_SDV'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI001_SRT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI001_SRT']['AK160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STADIUM_S']['ZI002_UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI004_RCG'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI004_RCG']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STADIUM_S']['ZI005_FNA'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI005_GNT'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI005_GNT']['AK160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STADIUM_S']['ZI005_NFN'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI006_MEM'] = ('String',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI020_GE4'] = ('CodeList',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI026_CTUC'] = ('Enumeration',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STADIUM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STADIUM_S']['ZI026_CTUL'] = ('integer',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI026_CTUU'] = ('integer',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI031S_URI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZI039S_UFI'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZSAX_RS0'] = ('CodeList',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZSAX_RX0'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZSAX_RX3'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZSAX_RX4'] = ('StructuredText',('AK160'))
    field_information['GGDM 3.0']['STADIUM_S']['ZVH'] = ('Real',('AK160'))
    field_information['GGDM 3.0']['STAIR_C']['ARA'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['BEN'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['CNCP'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['COS'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['COS']['AQ150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STAIR_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['FUFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['FURL'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['GDBV'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['GDBV']['AQ150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STAIR_C']['HGT'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['LZN'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['OTH'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['PCF'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STAIR_C']['UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['WID'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI001_SDV'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI001_SRT'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STAIR_C']['ZI002_UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI004_RCG'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STAIR_C']['ZI005_FNA'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI005_GNT'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STAIR_C']['ZI005_NFN'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI006_MEM'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI020_GE4'] = ('CodeList',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI026_CTUC'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STAIR_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STAIR_C']['ZI026_CTUL'] = ('integer',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI026_CTUU'] = ('integer',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI031S_URI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZI039S_UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZSAX_RS0'] = ('CodeList',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZSAX_RX0'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZSAX_RX3'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZSAX_RX4'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_C']['ZVH'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ARA'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['BEN'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['CNCP'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['COS'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['COS']['AQ150']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STAIR_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['FUFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['FURL'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['GDBV'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['GDBV']['AQ150']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STAIR_S']['HGT'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['LZN'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['OTH'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['PCF'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STAIR_S']['UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['WID'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI001_SDV'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI001_SRT'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ150']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STAIR_S']['ZI002_UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI004_RCG'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STAIR_S']['ZI005_FNA'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI005_GNT'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ150']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STAIR_S']['ZI005_NFN'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI006_MEM'] = ('String',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI020_GE4'] = ('CodeList',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI026_CTUC'] = ('Enumeration',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STAIR_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ150']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STAIR_S']['ZI026_CTUL'] = ('integer',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI026_CTUU'] = ('integer',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI031S_URI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZI039S_UFI'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZSAX_RS0'] = ('CodeList',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZSAX_RX0'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZSAX_RX3'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZSAX_RX4'] = ('StructuredText',('AQ150'))
    field_information['GGDM 3.0']['STAIR_S']['ZVH'] = ('Real',('AQ150'))
    field_information['GGDM 3.0']['STANDPIPE_P']['BEN'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['CAA'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['CAA']['STDPP']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['CNCP'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['COS'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['COS']['STDPP']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STANDPIPE_P']['F_CODE'] = ('CONSTRAINED_STRING',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['FUFI'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['FURL'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['GDBV'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['GDBV']['STDPP']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['HGT'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['HSCD'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['LMC'] = ('Boolean',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['LZN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['OTH'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['PCF'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['PCF']['STDPP']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STANDPIPE_P']['UFI'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI001_SDV'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI001_SRT'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI001_SRT']['STDPP']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI002_UFI'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI004_RCG'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI004_RCG']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI005_FNA'] = ('String',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI005_GNT'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI005_GNT']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI005_NFN'] = ('String',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI006_MEM'] = ('String',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI020_GE4'] = ('CodeList',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_ASE'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_CFR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_CLO'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_CYN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_FMR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_FRR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_HAR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_MGN'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_PHW'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_SCC'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_SCC']['STDPP']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_SUL'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_TDS'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_TEP'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_TUR'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_WAC'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_WTNO'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_WUR'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_WUR']['STDPP']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI024_YWQ'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI024_YWQ']['STDPP']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI026_CTUC'] = ('Enumeration',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STANDPIPE_P']['EnumeratedIndexValues']['ZI026_CTUC']['STDPP']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI026_CTUL'] = ('integer',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI026_CTUU'] = ('integer',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI031S_URI'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZI039S_UFI'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZSAX_RS0'] = ('CodeList',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZSAX_RX0'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZSAX_RX3'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZSAX_RX4'] = ('StructuredText',('STDPP'))
    field_information['GGDM 3.0']['STANDPIPE_P']['ZVH'] = ('Real',('STDPP'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['BEN'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['FUFI'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['FURL'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['GDBV'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['GDBV']['AQ120']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['LMC'] = ('Boolean',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['LOG'] = ('Real',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['LZN'] = ('Real',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['OTH'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['SGCC'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['SGCC']['AQ120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['SGCL'] = ('real',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['SGCU'] = ('real',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['TRS'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['TRS2'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS2']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['TRS3'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['TRS3']['AQ120']  = (-999999,9,12,13,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['UFI'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI001_SDV'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI001_SRT'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ120']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI002_UFI'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI004_RCG'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI006_MEM'] = ('String',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI020_GE4'] = ('CodeList',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI026_CTUC'] = ('Enumeration',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STEEP_GRADE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ120']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI026_CTUL'] = ('integer',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI026_CTUU'] = ('integer',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI031S_URI'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZI039S_UFI'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZSAX_RS0'] = ('CodeList',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZSAX_RX0'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZSAX_RX3'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_GRADE_C']['ZSAX_RX4'] = ('StructuredText',('AQ120'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ARA'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['BEN'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['FUFI'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['FURL'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['GDBV'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['GDBV']['DB010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['HGT'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['LZN'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['MCC'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['MCC']['DB010']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['MCC2'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['MCC2']['DB010']  = (-999999,84,104,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['OTH'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['PFH'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['SGCC'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['SGCC']['DB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['SGCL'] = ('real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['SGCU'] = ('real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['UFI'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['WID'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI001_SDV'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI001_SRT'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI001_SRT']['DB010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI002_UFI'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI004_RCG'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI004_RCG']['DB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI005_FNA'] = ('String',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI005_GNT'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI005_GNT']['DB010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI005_NFN'] = ('String',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI006_MEM'] = ('String',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI020_GE4'] = ('CodeList',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI026_CTUC'] = ('Enumeration',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI026_CTUL'] = ('integer',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI026_CTUU'] = ('integer',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI031S_URI'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZI039S_UFI'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZSAX_RS0'] = ('CodeList',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZSAX_RX0'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZSAX_RX3'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZSAX_RX4'] = ('StructuredText',('DB010'))
    field_information['GGDM 3.0']['STEEP_TERRAIN_FACE_C']['ZVH'] = ('Real',('DB010'))
    field_information['GGDM 3.0']['STOPWAY_S']['ARA'] = ('Real',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ASU'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['STOPWAY_S']['ASU2'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU2'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU2']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['STOPWAY_S']['ASU3'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU3'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ASU3']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['STOPWAY_S']['BEN'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['CNCP'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['COS'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['COS']['GB045']  = (-999999,4,6,8,9,13,14)
    field_information['GGDM 3.0']['STOPWAY_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['FUFI'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['FURL'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['GDBV'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['GDBV']['GB045']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STOPWAY_S']['LZN'] = ('Real',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['OTH'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['PCF'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['PCF']['GB045']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STOPWAY_S']['UFI'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['WID'] = ('Real',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI001_SDV'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI001_SRT'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI001_SRT']['GB045']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STOPWAY_S']['ZI002_UFI'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI004_RCG'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI004_RCG']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STOPWAY_S']['ZI005_FNA'] = ('String',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI005_GNT'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI005_GNT']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STOPWAY_S']['ZI005_NFN'] = ('String',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI006_MEM'] = ('String',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI020_GE4'] = ('CodeList',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI026_CTUC'] = ('Enumeration',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STOPWAY_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB045']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STOPWAY_S']['ZI026_CTUL'] = ('integer',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI026_CTUU'] = ('integer',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI031S_URI'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZI039S_UFI'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZSAX_RS0'] = ('CodeList',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZSAX_RX0'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZSAX_RX3'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZSAX_RX4'] = ('StructuredText',('GB045'))
    field_information['GGDM 3.0']['STOPWAY_S']['ZVH'] = ('Real',('GB045'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ADR'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['AOO'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ARA'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['BEN'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['CAA'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['CNCP'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['COS'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['COS']['AM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['FFN'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['FFN2'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['FFN3'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['FUFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['FURL'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['GDBV'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['GDBV']['AM010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['HGT'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['LMC'] = ('Boolean',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['LUN'] = ('Boolean',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['LZN'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['OTH'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['PCF'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['PPO'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['PPO2'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['PPO3'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['VOI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['WID'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI001_SDV'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI001_SRT'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI001_SRT']['AM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI002_UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI004_RCG'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI004_RCG']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI005_FNA'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI005_GNT'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI005_GNT']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI005_NFN'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI006_MEM'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI020_GE4'] = ('CodeList',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI026_CTUC'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI026_CTUL'] = ('integer',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI026_CTUU'] = ('integer',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI031S_URI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZI039S_UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZSAX_RS0'] = ('CodeList',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZSAX_RX0'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZSAX_RX3'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZSAX_RX4'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_P']['ZVH'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ADR'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['AOO'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ARA'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['BEN'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['CAA'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['CNCP'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['COS'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['COS']['AM010']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['FFN'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['FFN2'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['FFN3'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['FUFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['FURL'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['GDBV'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['GDBV']['AM010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['HGT'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['LMC'] = ('Boolean',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['LUN'] = ('Boolean',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['LZN'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['OTH'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['PCF'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['PPO'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['PPO2'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['PPO3'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['VOI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['WID'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI001_SDV'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI001_SRT'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI001_SRT']['AM010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI002_UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI004_RCG'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI004_RCG']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI005_FNA'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI005_GNT'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI005_GNT']['AM010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI005_NFN'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI006_MEM'] = ('String',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI020_GE4'] = ('CodeList',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI026_CTUC'] = ('Enumeration',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI026_CTUL'] = ('integer',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI026_CTUU'] = ('integer',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI031S_URI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZI039S_UFI'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZSAX_RS0'] = ('CodeList',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZSAX_RX0'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZSAX_RX3'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZSAX_RX4'] = ('StructuredText',('AM010'))
    field_information['GGDM 3.0']['STORAGE_DEPOT_S']['ZVH'] = ('Real',('AM010'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ARA'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['AWP'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['BEN'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['CAA'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['CAA']['NU070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['CBP'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['CNCP'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['COS'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['COS']['NU070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['DMF'] = ('Integer',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['FUFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['FURL'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['GDBV'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['GDBV']['NU070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['HEI'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['HGT'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['LMC'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['LUN'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['LZN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['OTH'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['PCF'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PCF']['NU070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['PPO'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['PPO2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO2']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['PPO3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['PPO3']['NU070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['SPT'] = ('Boolean',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['SSC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['SSC']['NU070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['VCM'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['VCM2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM2']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['VCM3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['VCM3']['NU070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['VLM'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['VOI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['WID'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['YWQ'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['YWQ']['NU070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI001_SDV'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI001_SRT'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NU070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI002_UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI004_RCG'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_FNA'] = ('String',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_FNA2'] = ('String',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_GNT'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_GNT2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_NFN'] = ('String',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI005_NFN2'] = ('String',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI006_MEM'] = ('String',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI020_GE4'] = ('CodeList',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_ASE'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_CFR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_CLO'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_CYN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_FMR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_FRR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_HAR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_MGN'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_PHW'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_SCC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NU070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_SUL'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_TDS'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_TEP'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_TUR'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WAC'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WTNO'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WUR'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WUR2'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WUR3'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI024_WUR4'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NU070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI026_CTUC'] = ('Enumeration',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NU070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI026_CTUL'] = ('integer',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI026_CTUU'] = ('integer',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI031S_URI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZI039S_UFI'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZSAX_RS0'] = ('CodeList',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZSAX_RX0'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZSAX_RX3'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZSAX_RX4'] = ('StructuredText',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_AON_S']['ZVH'] = ('Real',('NU070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['AOO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ARA'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['AWP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['BEN'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['CAA'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['CAA']['AM070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['CBP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['CNCP'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['COS'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['COS']['AM070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['FUFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['FURL'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['GDBV'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['GDBV']['AM070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['HEI'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['HGT'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['LMC'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['LOC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['LOC']['AM070']  = (-999999,40,44,45,48)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['LUN'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['LZN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['OTH'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['PCF'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['PMPR'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['PPO'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['PPO2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['PPO3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['SPT'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['SSC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['VCM'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['VCM2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['VCM3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['VLM'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['VOI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['WID'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['YWQ'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI001_SDV'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI001_SRT'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI001_SRT']['AM070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI002_UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI004_RCG'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI004_RCG']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_FNA'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_FNA2'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_GNT'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI005_GNT']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_GNT2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI005_GNT2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_NFN'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI005_NFN2'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI006_MEM'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI020_GE4'] = ('CodeList',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_ASE'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_CFR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_CLO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_CYN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_FMR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_FRR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_HAR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_MGN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_PHW'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_SCC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_SCC']['AM070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_SUL'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_TDS'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_TEP'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_TUR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WAC'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WTNO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WUR'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WUR2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WUR3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR3']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI024_WUR4'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI024_WUR4']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI026_CTUC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI026_CTUL'] = ('integer',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI026_CTUU'] = ('integer',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI031S_URI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZI039S_UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZSAX_RS0'] = ('CodeList',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZSAX_RX0'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZSAX_RX3'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZSAX_RX4'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_P']['ZVH'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['AOO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ARA'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['AWP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['BEN'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['CAA'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['CAA']['AM070']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['CBP'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['CNCP'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['COS'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['COS']['AM070']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['FUFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['FURL'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['GDBV'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['GDBV']['AM070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['HEI'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['HGT'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['LMC'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['LOC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['LOC']['AM070']  = (-999999,40,44,45,48)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['LUN'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['LZN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['OTH'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['PCF'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['PMPR'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['PPO'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['PPO2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['PPO3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,170,214,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['SPT'] = ('Boolean',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['SSC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['VCM'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['VCM2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['VCM3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['VLM'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['VOI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['WID'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['YWQ'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI001_SDV'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI001_SRT'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI001_SRT']['AM070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI002_UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI004_RCG'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI004_RCG']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_FNA'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_FNA2'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_GNT'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI005_GNT']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_GNT2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI005_GNT2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_NFN'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI005_NFN2'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI006_MEM'] = ('String',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI020_GE4'] = ('CodeList',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_ASE'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_CFR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_CLO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_CYN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_FMR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_FRR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_HAR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_MGN'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_PHW'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_SCC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_SCC']['AM070']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_SUL'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_TDS'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_TEP'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_TUR'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WAC'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WTNO'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WUR'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WUR2'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR2']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WUR3'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR3']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI024_WUR4'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI024_WUR4']['AM070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI026_CTUC'] = ('Enumeration',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORAGE_TANK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI026_CTUL'] = ('integer',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI026_CTUU'] = ('integer',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI031S_URI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZI039S_UFI'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZSAX_RS0'] = ('CodeList',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZSAX_RX0'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZSAX_RX3'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZSAX_RX4'] = ('StructuredText',('AM070'))
    field_information['GGDM 3.0']['STORAGE_TANK_S']['ZVH'] = ('Real',('AM070'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ARA'] = ('Real',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['BEN'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['CNCP'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['COS'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['COS']['AQ114']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['FUFI'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['FURL'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['GDBV'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['GDBV']['AQ114']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['LZN'] = ('Real',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['MCC'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['MCC2'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC2']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['MCC3'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['MCC3']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['OTH'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['PCF'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['PCF']['AQ114']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['UFI'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['WID'] = ('Real',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI001_SDV'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI001_SRT'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ114']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI002_UFI'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI004_RCG'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ114']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI005_FNA'] = ('String',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI005_GNT'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ114']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI005_NFN'] = ('String',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI006_MEM'] = ('String',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI020_GE4'] = ('CodeList',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI026_CTUC'] = ('Enumeration',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STORM_DRAIN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ114']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI026_CTUL'] = ('integer',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI026_CTUU'] = ('integer',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI031S_URI'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZI039S_UFI'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZSAX_RS0'] = ('CodeList',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZSAX_RX0'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZSAX_RX3'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STORM_DRAIN_P']['ZSAX_RX4'] = ('StructuredText',('AQ114'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['BEN'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['CNCP'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['COS'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['COS']['AQ161']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STREET_LAMP_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['FUFI'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['FURL'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['GDBV'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['GDBV']['AQ161']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STREET_LAMP_P']['HGT'] = ('Real',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['LZN'] = ('Real',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['OTH'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['PCF'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['PCF']['AQ161']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STREET_LAMP_P']['UFI'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI001_SDV'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI001_SRT'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ161']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI002_UFI'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI004_RCG'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ161']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI005_FNA'] = ('String',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI005_GNT'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ161']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI005_NFN'] = ('String',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI006_MEM'] = ('String',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI020_GE4'] = ('CodeList',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI026_CTUC'] = ('Enumeration',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STREET_LAMP_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ161']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI026_CTUL'] = ('integer',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI026_CTUU'] = ('integer',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI031S_URI'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZI039S_UFI'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZSAX_RS0'] = ('CodeList',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZSAX_RX0'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZSAX_RX3'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZSAX_RX4'] = ('StructuredText',('AQ161'))
    field_information['GGDM 3.0']['STREET_LAMP_P']['ZVH'] = ('Real',('AQ161'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ADI'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ADI'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ADI']['AQ162']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['AOO'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['BEN'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['CAA'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['CAA']['AQ162']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['CNCP'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['COS'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['COS']['AQ162']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['STREET_SIGN_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['FUFI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['FURL'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['GDBV'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['GDBV']['AQ162']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['HEI'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['HGT'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['LZN'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['MCC'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['MCC2'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC2']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['MCC3'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['MCC3']['AQ162']  = (-999999,64,74,117,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['OTH'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['PCF'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['PCF']['AQ162']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STREET_SIGN_P']['SSG'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['SSG'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['SSG']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['UFI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['VOI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI001_SDV'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI001_SRT'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ162']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI002_UFI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI004_RCG'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI005_FNA'] = ('String',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI005_GNT'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI005_NFN'] = ('String',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI006_MEM'] = ('String',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI020_GE4'] = ('CodeList',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI026_CTUC'] = ('Enumeration',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STREET_SIGN_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ162']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI026_CTUL'] = ('integer',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI026_CTUU'] = ('integer',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI031S_URI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZI039S_UFI'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZSAX_RS0'] = ('CodeList',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZSAX_RX0'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZSAX_RX3'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZSAX_RX4'] = ('StructuredText',('AQ162'))
    field_information['GGDM 3.0']['STREET_SIGN_P']['ZVH'] = ('Real',('AQ162'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ARA'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['BEN'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['FUFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['FURL'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['GDBV'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['GDBV']['BD100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['HGT'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['LMC'] = ('Boolean',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['LZN'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['MCC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['MCC2'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['MCC3'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['OTH'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['PCF'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['PLC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['PLC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['PLC']['BD100']  = (-999999,1,3,4,5,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['WID'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI001_SDV'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI001_SRT'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI001_SRT']['BD100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI002_UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI004_RCG'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI004_RCG']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI005_FNA'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI005_GNT'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI005_GNT']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI005_NFN'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI006_MEM'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI020_GE4'] = ('CodeList',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI025_HDP'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI026_CTUC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI026_CTUL'] = ('integer',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI026_CTUU'] = ('integer',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI031S_URI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZI039S_UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZSAX_RS0'] = ('CodeList',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZSAX_RX0'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZSAX_RX3'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZSAX_RX4'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_P']['ZVH'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ARA'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['BEN'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['FUFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['FURL'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['GDBV'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['GDBV']['BD100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['HGT'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['LMC'] = ('Boolean',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['LZN'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['MCC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['MCC2'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['MCC3'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['OTH'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['PCF'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['PLC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['PLC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['PLC']['BD100']  = (-999999,1,3,4,5,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['WID'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI001_SDV'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI001_SRT'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI001_SRT']['BD100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI002_UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI004_RCG'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI004_RCG']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI005_FNA'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI005_GNT'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI005_GNT']['BD100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI005_NFN'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI006_MEM'] = ('String',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI020_GE4'] = ('CodeList',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI025_HDP'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI026_CTUC'] = ('Enumeration',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI026_CTUL'] = ('integer',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI026_CTUU'] = ('integer',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI031S_URI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZI039S_UFI'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZSAX_RS0'] = ('CodeList',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZSAX_RX0'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZSAX_RX3'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZSAX_RX4'] = ('StructuredText',('BD100'))
    field_information['GGDM 3.0']['STRUCTURAL_PILE_S']['ZVH'] = ('Real',('BD100'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ADR'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['AOO'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ARA'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['BEN'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['CAA'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['CNCP'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['COS'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['COS']['AM060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['FUFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['FURL'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['GDBV'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['GDBV']['AM060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['HGT'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['HST'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['HST2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['HST3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['LZN'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['OTH'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['PCF'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['PPO'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['PPO2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['PPO3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['WID'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI001_SDV'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI001_SRT'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI001_SRT']['AM060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI002_UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI004_RCG'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI004_RCG']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI005_FNA'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI005_GNT'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI005_GNT']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI005_NFN'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI006_MEM'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI020_GE4'] = ('CodeList',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI026_CTUC'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI026_CTUL'] = ('integer',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI026_CTUU'] = ('integer',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI031S_URI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZI039S_UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZSAX_RS0'] = ('CodeList',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZSAX_RX0'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZSAX_RX3'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZSAX_RX4'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_P']['ZVH'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ADR'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['AOO'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ARA'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['BEN'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['CAA'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['CNCP'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['COS'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['COS']['AM060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['FUFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['FURL'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['GDBV'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['GDBV']['AM060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['HGT'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['HST'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['HST2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['HST3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['LZN'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['OTH'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['PCF'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['PPO'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['PPO2'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['PPO3'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['WID'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI001_SDV'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI001_SRT'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI001_SRT']['AM060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI002_UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI004_RCG'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI004_RCG']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI005_FNA'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI005_GNT'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI005_GNT']['AM060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI005_NFN'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI006_MEM'] = ('String',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI020_GE4'] = ('CodeList',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI026_CTUC'] = ('Enumeration',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI026_CTUL'] = ('integer',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI026_CTUU'] = ('integer',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI031S_URI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZI039S_UFI'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZSAX_RS0'] = ('CodeList',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZSAX_RX0'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZSAX_RX3'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZSAX_RX4'] = ('StructuredText',('AM060'))
    field_information['GGDM 3.0']['SURFACE_BUNKER_S']['ZVH'] = ('Real',('AM060'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['BEL'] = ('Real',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['BEN'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['CAA'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['CAA']['ZB050']  = (-999999,3,5,7,17,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['FUFI'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['FURL'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['GDBV'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['GDBV']['ZB050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['OTH'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['PCF'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['PCF']['ZB050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['SUY'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['SUY'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['SUY']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['UFI'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI001_SDV'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI001_SRT'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['ZB050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI002_UFI'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI004_RCG'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI005_FNA'] = ('String',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI005_GNT'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['ZB050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI005_NFN'] = ('String',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI006_MEM'] = ('String',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI020_GE4'] = ('CodeList',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI026_CTUC'] = ('Enumeration',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SURVEY_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZB050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI026_CTUL'] = ('integer',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI026_CTUU'] = ('integer',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI031S_URI'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZI039S_UFI'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZSAX_RS0'] = ('CodeList',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZSAX_RX0'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZSAX_RX3'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZSAX_RX4'] = ('StructuredText',('ZB050'))
    field_information['GGDM 3.0']['SURVEY_POINT_P']['ZVH'] = ('Real',('ZB050'))
    field_information['GGDM 3.0']['SWAMP_S']['ARA'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['BEN'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['BMC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['SWAMP_S']['BMC2'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC2']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['SWAMP_S']['BMC3'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['BMC3']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['GGDM 3.0']['SWAMP_S']['CAA'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['CAA']['ED020']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SWAMP_S']['DMBC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['DMBC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWAMP_S']['DMBL'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['DMBU'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['DMT'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['DZP'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['F_CODE'] = ('CONSTRAINED_STRING',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['FUFI'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['FURL'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['GDBV'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['GDBV']['ED020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SWAMP_S']['HDP'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['HGT'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['LZN'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['OTH'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['PVH'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['SDSC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['SDSC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWAMP_S']['SDSL'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['SDSU'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['TID'] = ('Boolean',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['TRE'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['TRE']['ED020']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['SWAMP_S']['TSCC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['TSCC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWAMP_S']['TSCL'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['TSCU'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['UFI'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['VSP'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['SWAMP_S']['VSP2'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP2']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['SWAMP_S']['VSP3'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['VSP3']['ED020']  = (-999999,19,22,64,999)
    field_information['GGDM 3.0']['SWAMP_S']['WDAC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['WDAC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWAMP_S']['WDAL'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['WDAU'] = ('real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['WID'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI001_SDV'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI001_SRT'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI001_SRT']['ED020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI002_UFI'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI004_RCG'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI004_RCG']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI005_FNA'] = ('String',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI005_GNT'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI005_GNT']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI005_NFN'] = ('String',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI006_MEM'] = ('String',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI020_GE4'] = ('CodeList',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_ASE'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_CFR'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_CLO'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_CYN'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_FMR'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_FRR'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_HAR'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_HYP'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_HYP']['ED020']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_MGN'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_PHW'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_SCC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_SCC']['ED020']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_SUL'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_TDS'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_TEP'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_TUR'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_WAC'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_WTNO'] = ('Real',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_WUR'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_WUR']['ED020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI024_YWQ'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI024_YWQ']['ED020']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['SWAMP_S']['ZI026_CTUC'] = ('Enumeration',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SWAMP_S']['EnumeratedIndexValues']['ZI026_CTUC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWAMP_S']['ZI026_CTUL'] = ('integer',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI026_CTUU'] = ('integer',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI031S_URI'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZI039S_UFI'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZSAX_RS0'] = ('CodeList',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZSAX_RX0'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZSAX_RX3'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWAMP_S']['ZSAX_RX4'] = ('StructuredText',('ED020'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ARA'] = ('Real',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['BEN'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['FUFI'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['FURL'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['GDBV'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['GDBV']['FC177']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['HDP'] = ('Real',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['LZN'] = ('Real',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['OTH'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['UFI'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['WID'] = ('Real',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_DCR'] = ('Boolean',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_DKC'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_DKC2'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC2']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_DKC3'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_DKC3']['FC177']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_SVC'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_SVC']['FC177']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_TEC'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_TEC2'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC2']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_TEC3'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_TEC3']['FC177']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_VDC'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZHDP_VDC']['FC177']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZHDP_VDR'] = ('String',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI001_SDV'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI001_SRT'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['FC177']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI002_UFI'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI004_RCG'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['FC177']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI005_FNA'] = ('String',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI005_GNT'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI005_GNT']['FC177']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI005_NFN'] = ('String',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI006_MEM'] = ('String',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI020_GE4'] = ('CodeList',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI026_CTUC'] = ('Enumeration',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SWEPT_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC177']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI026_CTUL'] = ('integer',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI026_CTUU'] = ('integer',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI031S_URI'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZI039S_UFI'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZSAX_RS0'] = ('CodeList',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZSAX_RX0'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZSAX_RX3'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWEPT_AREA_S']['ZSAX_RX4'] = ('StructuredText',('FC177'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ARA'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['BEN'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['CAA'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['CAA']['NU170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['CNCP'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['COS'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['COS']['NU170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['DMF'] = ('Integer',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['DZP'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['FUFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['FURL'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['GDBV'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['GDBV']['NU170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['HGT'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['LMC'] = ('Boolean',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['LOC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['LOC']['NU170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['LZN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['OTH'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['PCF'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['PCF']['NU170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['VLM'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['WID'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI001_SDV'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI001_SRT'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NU170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI002_UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI004_RCG'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI005_FNA'] = ('String',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI005_GNT'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI005_NFN'] = ('String',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI006_MEM'] = ('String',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI020_GE4'] = ('CodeList',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_ASE'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_CFR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_CLO'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_CYN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_FMR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_FRR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_HAR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_HYP'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NU170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_MGN'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_PHW'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_SCC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NU170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_SUL'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_TDS'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_TEP'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_TUR'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WAC'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WTNO'] = ('Real',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WUR'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WUR2'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WUR3'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI024_WUR4'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NU170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI026_CTUC'] = ('Enumeration',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NU170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI026_CTUL'] = ('integer',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI026_CTUU'] = ('integer',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI031S_URI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZI039S_UFI'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZSAX_RS0'] = ('CodeList',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZSAX_RX0'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZSAX_RX3'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_AON_S']['ZSAX_RX4'] = ('StructuredText',('NU170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ADR'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ARA'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['BEN'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['CAA'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['CAA']['AK170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['CNCP'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['COS'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['COS']['AK170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['DZP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['FUFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['FURL'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['GDBV'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['GDBV']['AK170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['HGT'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['LMC'] = ('Boolean',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['LOC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['LOC']['AK170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['LZN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['OTH'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['PCF'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['VLM'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['WID'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI001_SDV'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI001_SRT'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI001_SRT']['AK170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI002_UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI004_RCG'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI004_RCG']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI005_FNA'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI005_GNT'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI005_GNT']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI005_NFN'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI006_MEM'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI020_GE4'] = ('CodeList',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_ASE'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_CFR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_CLO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_CYN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_FMR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_FRR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_HAR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_HYP'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_HYP']['AK170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_MGN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_PHW'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_SCC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_SCC']['AK170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_SUL'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_TDS'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_TEP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_TUR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WAC'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WTNO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WUR'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WUR2'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR2']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WUR3'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR3']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI024_WUR4'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI024_WUR4']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI026_CTUC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI026_CTUL'] = ('integer',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI026_CTUU'] = ('integer',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI031S_URI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZI039S_UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZSAX_RS0'] = ('CodeList',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZSAX_RX0'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZSAX_RX3'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_P']['ZSAX_RX4'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ADR'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ARA'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['BEN'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['CAA'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['CAA']['AK170']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['CNCP'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['COS'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['COS']['AK170']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['DZP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['FUFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['FURL'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['GDBV'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['GDBV']['AK170']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['HGT'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['LMC'] = ('Boolean',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['LOC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['LOC']['AK170']  = (-999999,17,23,40,44,45,46,47)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['LZN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['OTH'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['PCF'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['VLM'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['WID'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI001_SDV'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI001_SRT'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI001_SRT']['AK170']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI002_UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI004_RCG'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI004_RCG']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI005_FNA'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI005_GNT'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI005_GNT']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI005_NFN'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI006_MEM'] = ('String',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI020_GE4'] = ('CodeList',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_ASE'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_CFR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_CLO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_CYN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_FMR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_FRR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_HAR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_HYP'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_HYP']['AK170']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_MGN'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_PHW'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_SCC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_SCC']['AK170']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_SUL'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_TDS'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_TEP'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_TUR'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WAC'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WTNO'] = ('Real',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WUR'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WUR2'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR2']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WUR3'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR3']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI024_WUR4'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI024_WUR4']['AK170']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI026_CTUC'] = ('Enumeration',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK170']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI026_CTUL'] = ('integer',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI026_CTUU'] = ('integer',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI031S_URI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZI039S_UFI'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZSAX_RS0'] = ('CodeList',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZSAX_RX0'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZSAX_RX3'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['SWIMMING_POOL_S']['ZSAX_RX4'] = ('StructuredText',('AK170'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ARA'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['BEN'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['CSC'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['CSC2'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC2']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['CSC3'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['CSC3']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['FUFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['FURL'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['GDBV'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['GDBV']['AP056']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['LZN'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['OTH'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['PCF'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['PCF']['AP056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['TRS'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['TRS2'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS2']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['TRS3'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['TRS3']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['WID'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI001_SDV'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI001_SRT'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI001_SRT']['AP056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI002_UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI004_RCG'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI004_RCG']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI005_FNA'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI005_NFN'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI006_MEM'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI020_GE4'] = ('CodeList',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI026_CTUC'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AP056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI026_CTUL'] = ('integer',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI026_CTUU'] = ('integer',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI031S_URI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZI039S_UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZSAX_RS0'] = ('CodeList',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZSAX_RX0'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZSAX_RX3'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_P']['ZSAX_RX4'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ARA'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['BEN'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['CSC'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['CSC2'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC2']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['CSC3'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['CSC3']['AP056']  = (-999999,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['F_CODE'] = ('CONSTRAINED_STRING',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['FUFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['FURL'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['GDBV'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['GDBV']['AP056']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['LZN'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['OTH'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['PCF'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['PCF']['AP056']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['TRS'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['TRS2'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS2']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['TRS3'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['TRS3']['AP056']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['WID'] = ('Real',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI001_SDV'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI001_SRT'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI001_SRT']['AP056']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI002_UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI004_RCG'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI004_RCG']['AP056']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI005_FNA'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI005_NFN'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI006_MEM'] = ('String',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI020_GE4'] = ('CodeList',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI026_CTUC'] = ('Enumeration',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_CROSSING_S']['EnumeratedIndexValues']['ZI026_CTUC']['AP056']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI026_CTUL'] = ('integer',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI026_CTUU'] = ('integer',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI031S_URI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZI039S_UFI'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZSAX_RS0'] = ('CodeList',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZSAX_RX0'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZSAX_RX3'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_CROSSING_S']['ZSAX_RX4'] = ('StructuredText',('AP056'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ADR'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['AOO'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ARA'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['BEN'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['CAA'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['CNCP'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['COS'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['COS']['AM071']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TANK_FARM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['FFN'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['FFN2'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['FFN3'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['FUFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['FURL'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['GDBV'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['GDBV']['AM071']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['HGT'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['LMC'] = ('Boolean',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['LZN'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['OTH'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['PCF'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_FARM_P']['PPO'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['PPO2'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['PPO3'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['WID'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI001_SDV'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI001_SRT'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI001_SRT']['AM071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI002_UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI004_RCG'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI004_RCG']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI005_FNA'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI005_GNT'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI005_GNT']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI005_NFN'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI006_MEM'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI020_GE4'] = ('CodeList',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI026_CTUC'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI026_CTUL'] = ('integer',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI026_CTUU'] = ('integer',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI031S_URI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZI039S_UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZSAX_RS0'] = ('CodeList',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZSAX_RX0'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZSAX_RX3'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZSAX_RX4'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_P']['ZVH'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ADR'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['AOO'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ARA'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['BEN'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['CAA'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['CNCP'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['COS'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['COS']['AM071']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TANK_FARM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['FFN'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['FFN2'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['FFN3'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['FUFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['FURL'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['GDBV'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['GDBV']['AM071']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['HGT'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['LMC'] = ('Boolean',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['LZN'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['OTH'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['PCF'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_FARM_S']['PPO'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['PPO2'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['PPO3'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['WID'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI001_SDV'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI001_SRT'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI001_SRT']['AM071']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI002_UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI004_RCG'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI004_RCG']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI005_FNA'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI005_GNT'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI005_GNT']['AM071']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI005_NFN'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI006_MEM'] = ('String',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI020_GE4'] = ('CodeList',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI026_CTUC'] = ('Enumeration',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM071']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI026_CTUL'] = ('integer',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI026_CTUU'] = ('integer',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI031S_URI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZI039S_UFI'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZSAX_RS0'] = ('CodeList',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZSAX_RX0'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZSAX_RX3'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZSAX_RX4'] = ('StructuredText',('AM071'))
    field_information['GGDM 3.0']['TANK_FARM_S']['ZVH'] = ('Real',('AM071'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ARA'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['BEN'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['CIW'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['CWT'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['FUFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['FURL'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['GDBV'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['GDBV']['AP055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['LZN'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['OTH'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['PCF'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['PCF']['AP055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['PSN'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['RLE'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['RLE']['AP055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['RTN'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['RTN2'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['RTN3'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['SBB'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['SPD'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['SPM'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['WID'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI001_SDV'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI001_SRT'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI001_SRT']['AP055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI002_UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI004_RCG'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI004_RCG']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI005_FNA'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI005_NFN'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI006_MEM'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI016_ROC'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI016_ROC']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI020_GE4'] = ('CodeList',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI026_CTUC'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI026_CTUL'] = ('integer',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI026_CTUU'] = ('integer',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI031S_URI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZI039S_UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZSAX_RS0'] = ('CodeList',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZSAX_RX0'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZSAX_RX3'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_C']['ZSAX_RX4'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ARA'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['BEN'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['CIW'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['CWT'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['FUFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['FURL'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['GDBV'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['GDBV']['AP055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['LZN'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['OTH'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['PCF'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['PCF']['AP055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['PSN'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['RLE'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['RLE']['AP055']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['RTN'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['RTN2'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['RTN3'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['SBB'] = ('Boolean',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['SPD'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['SPM'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['WID'] = ('Real',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI001_SDV'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI001_SRT'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI001_SRT']['AP055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI002_UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI004_RCG'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI004_RCG']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI005_FNA'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI005_NFN'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI006_MEM'] = ('String',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI016_ROC'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI016_ROC']['AP055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI020_GE4'] = ('CodeList',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI026_CTUC'] = ('Enumeration',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TANK_TRAIL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AP055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI026_CTUL'] = ('integer',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI026_CTUU'] = ('integer',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI031S_URI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZI039S_UFI'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZSAX_RS0'] = ('CodeList',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZSAX_RX0'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZSAX_RX3'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TANK_TRAIL_S']['ZSAX_RX4'] = ('StructuredText',('AP055'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ARA'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['AXS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['TAXIWAY_C']['BEN'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['CNCP'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['COS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['COS']['GB075']  = (-999999,4,6,13,14)
    field_information['GGDM 3.0']['TAXIWAY_C']['DEV'] = ('Integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['F_CODE'] = ('CONSTRAINED_STRING',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['FUFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['FURL'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['GDBV'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['GDBV']['GB075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['LZN'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['OTH'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['PCF'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TAXIWAY_C']['SBB'] = ('Boolean',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['TXP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['TXP'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['WID'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI001_SDV'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI001_SRT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI001_SRT']['GB075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI002_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI004_RCG'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI004_RCG']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI005_FNA'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI005_GNT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI005_GNT']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI005_NFN'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI006_MEM'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASP2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASP3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASU'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASU2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASU3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_ASX'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI019_SFS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI020_GE4'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI026_CTUC'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TAXIWAY_C']['EnumeratedIndexValues']['ZI026_CTUC']['GB075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI026_CTUL'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI026_CTUU'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI031S_URI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZI039S_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZSAX_RS0'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZSAX_RX0'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZSAX_RX3'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZSAX_RX4'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_C']['ZVH'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ARA'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['AXS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['AXS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['TAXIWAY_S']['BEN'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['CNCP'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['COS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['COS']['GB075']  = (-999999,4,6,13,14)
    field_information['GGDM 3.0']['TAXIWAY_S']['DEV'] = ('Integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['FUFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['FURL'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['GDBV'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['GDBV']['GB075']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['LZN'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['OTH'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['PCF'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TAXIWAY_S']['SBB'] = ('Boolean',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['TXP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['TXP'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['WID'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI001_SDV'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI001_SRT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI001_SRT']['GB075']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI002_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI004_RCG'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI004_RCG']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI005_FNA'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI005_GNT'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI005_GNT']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI005_NFN'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI006_MEM'] = ('String',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASP'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASP2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASP3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASU'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASU2'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASU3'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20,21,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_ASX'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI019_SFS'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI020_GE4'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI026_CTUC'] = ('Enumeration',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TAXIWAY_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB075']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI026_CTUL'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI026_CTUU'] = ('integer',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI031S_URI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZI039S_UFI'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZSAX_RS0'] = ('CodeList',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZSAX_RX0'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZSAX_RX3'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZSAX_RX4'] = ('StructuredText',('GB075'))
    field_information['GGDM 3.0']['TAXIWAY_S']['ZVH'] = ('Real',('GB075'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ARA'] = ('Real',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['BEN'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['CNCP'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['COS'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['COS']['FA100']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TEST_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['FUFI'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['FURL'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['GDBV'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['GDBV']['FA100']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TEST_SITE_S']['LZN'] = ('Real',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['OTH'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['PCF'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['PCF']['FA100']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TEST_SITE_S']['UFI'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['WID'] = ('Real',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI001_SDV'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI001_SRT'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['FA100']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI002_UFI'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI004_RCG'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['FA100']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI005_FNA'] = ('String',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI005_GNT'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['FA100']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI005_NFN'] = ('String',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI006_MEM'] = ('String',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI020_GE4'] = ('CodeList',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI026_CTUC'] = ('Enumeration',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TEST_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA100']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI026_CTUL'] = ('integer',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI026_CTUU'] = ('integer',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI031S_URI'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZI039S_UFI'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZSAX_RS0'] = ('CodeList',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZSAX_RX0'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZSAX_RX3'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TEST_SITE_S']['ZSAX_RX4'] = ('StructuredText',('FA100'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['AOO'] = ('Real',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['AWP'] = ('Boolean',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['BEN'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['CNCP'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['COS'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['COS']['AL510']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['FUFI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['FURL'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['GDBV'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['GDBV']['AL510']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['HGT'] = ('Real',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['LMC'] = ('Boolean',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['OTH'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['UFI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['VOI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI001_SDV'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI001_SRT'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI001_SRT']['AL510']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI002_UFI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI004_RCG'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI004_RCG']['AL510']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI005_FNA'] = ('String',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI005_GNT'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI005_GNT']['AL510']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI005_NFN'] = ('String',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI006_MEM'] = ('String',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI020_GE4'] = ('CodeList',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI026_CTUC'] = ('Enumeration',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL510']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI026_CTUL'] = ('integer',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI026_CTUU'] = ('integer',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI031S_URI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZI039S_UFI'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZSAX_RS0'] = ('CodeList',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZSAX_RX0'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZSAX_RX3'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZSAX_RX4'] = ('StructuredText',('AL510'))
    field_information['GGDM 3.0']['TETHERED_BALLOON_P']['ZVH'] = ('Real',('AL510'))
    field_information['GGDM 3.0']['THICKET_S']['ARA'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['BEN'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['DMBC'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['DMBC']['EB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['THICKET_S']['DMBL'] = ('real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['DMBU'] = ('real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['F_CODE'] = ('CONSTRAINED_STRING',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['FUFI'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['FURL'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['GDBV'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['GDBV']['EB020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['THICKET_S']['HGT'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['LZN'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['OTH'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['PVH'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['UFI'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['VTI'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['WID'] = ('Real',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI001_SDV'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI001_SRT'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI001_SRT']['EB020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['THICKET_S']['ZI002_UFI'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI004_RCG'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI004_RCG']['EB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['THICKET_S']['ZI005_FNA'] = ('String',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI005_GNT'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI005_GNT']['EB020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['THICKET_S']['ZI005_NFN'] = ('String',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI006_MEM'] = ('String',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI020_GE4'] = ('CodeList',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI026_CTUC'] = ('Enumeration',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['THICKET_S']['EnumeratedIndexValues']['ZI026_CTUC']['EB020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['THICKET_S']['ZI026_CTUL'] = ('integer',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI026_CTUU'] = ('integer',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI031S_URI'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZI039S_UFI'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZSAX_RS0'] = ('CodeList',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZSAX_RX0'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZSAX_RX3'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['THICKET_S']['ZSAX_RX4'] = ('StructuredText',('EB020'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['BEN'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C35'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C36'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C37'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C38'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C39'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C40'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C41'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C42'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C43'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C44'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C45'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['C46'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['CNCP'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['COS'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['COS']['BG030']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D35'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D36'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D37'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D38'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D39'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D40'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D41'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D42'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D43'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D44'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D45'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['D46'] = ('Real',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['FUFI'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['FURL'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['GDBV'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['GDBV']['BG030']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['OTH'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['PCF'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['PCF']['BG030']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['REW'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['REW'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['REW']['BG030']  = (-999999,1,2)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['UFI'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI001_SDV'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI001_SRT'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['BG030']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI002_UFI'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI004_RCG'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['BG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI005_FNA'] = ('String',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI005_GNT'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['BG030']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI005_NFN'] = ('String',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI006_MEM'] = ('String',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI020_GE4'] = ('CodeList',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI026_CTUC'] = ('Enumeration',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BG030']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI026_CTUL'] = ('integer',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI026_CTUU'] = ('integer',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI031S_URI'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZI039S_UFI'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZSAX_RS0'] = ('CodeList',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZSAX_RX0'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZSAX_RX3'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_STREAM_OBSERVE_STATION_P']['ZSAX_RX4'] = ('StructuredText',('BG030'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ARA'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['BEN'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['BMC'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['BMC2'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC2']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['BMC3'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['BMC3']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,11,14,15,16,17,18,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['DOXY'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['FUFI'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['FURL'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['GDBV'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['GDBV']['BA040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['LZN'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['OTH'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['UFI'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['WID'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI001_SDV'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI001_SRT'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI001_SRT']['BA040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI002_UFI'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI004_RCG'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI004_RCG']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI005_FNA'] = ('String',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI005_GNT'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI005_GNT']['BA040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI005_NFN'] = ('String',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI006_MEM'] = ('String',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI020_GE4'] = ('CodeList',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_ASE'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_CFR'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_CLO'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_CYN'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_FMR'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_FRR'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_HAR'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_MGN'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_PHW'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_SCC'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI024_SCC']['BA040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_SUL'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_TDS'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_TEP'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_TUR'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_WAC'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI024_WTNO'] = ('Real',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI026_CTUC'] = ('Enumeration',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TIDAL_WATER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BA040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI026_CTUL'] = ('integer',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI026_CTUU'] = ('integer',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI031S_URI'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZI039S_UFI'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZSAX_RS0'] = ('CodeList',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZSAX_RX0'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZSAX_RX3'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TIDAL_WATER_S']['ZSAX_RX4'] = ('StructuredText',('BA040'))
    field_information['GGDM 3.0']['TOMB_P']['AOO'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ARA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['BEN'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['CAA'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['CAA']['AL036']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TOMB_P']['DZP'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['FUFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['FURL'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['GDBV'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['GDBV']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOMB_P']['HEI'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['HGT'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['LEA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['LMC'] = ('Boolean',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['LZN'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['OTH'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['PCF'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TOMB_P']['SSC'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['TOMB_P']['TTY'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['TTY'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOMB_P']['UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['WID'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI001_SDV'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI001_SRT'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI001_SRT']['AL036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TOMB_P']['ZI002_UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI004_RCG'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI004_RCG']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TOMB_P']['ZI005_FNA'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI005_GNT'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI005_GNT']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TOMB_P']['ZI005_NFN'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI006_MEM'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI020_GE4'] = ('CodeList',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI026_CTUC'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TOMB_P']['ZI026_CTUL'] = ('integer',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI026_CTUU'] = ('integer',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI031S_URI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZI037_REL'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['TOMB_P']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['TOMB_P']['ZI039S_UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZSAX_RS0'] = ('CodeList',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZSAX_RX0'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZSAX_RX3'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZSAX_RX4'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_P']['ZVH'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['AOO'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ARA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['BEN'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['CAA'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['CAA']['AL036']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TOMB_S']['DZP'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['FUFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['FURL'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['GDBV'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['GDBV']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOMB_S']['HEI'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['HGT'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['LEA'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['LMC'] = ('Boolean',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['LZN'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['OTH'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['PCF'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TOMB_S']['SSC'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['GGDM 3.0']['TOMB_S']['TTY'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['TTY'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOMB_S']['UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['WID'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI001_SDV'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI001_SRT'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI001_SRT']['AL036']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TOMB_S']['ZI002_UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI004_RCG'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI004_RCG']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TOMB_S']['ZI005_FNA'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI005_GNT'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI005_GNT']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TOMB_S']['ZI005_NFN'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI006_MEM'] = ('String',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI020_GE4'] = ('CodeList',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI026_CTUC'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL036']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TOMB_S']['ZI026_CTUL'] = ('integer',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI026_CTUU'] = ('integer',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI031S_URI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZI037_REL'] = ('Enumeration',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['GGDM 3.0']['TOMB_S']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['GGDM 3.0']['TOMB_S']['ZI039S_UFI'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZSAX_RS0'] = ('CodeList',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZSAX_RX0'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZSAX_RX3'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZSAX_RX4'] = ('StructuredText',('AL036'))
    field_information['GGDM 3.0']['TOMB_S']['ZVH'] = ('Real',('AL036'))
    field_information['GGDM 3.0']['TOWER_P']['AOO'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ARA'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['AWP'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['BEN'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['CAA'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['CAA']['AL241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TOWER_P']['CNCP'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['COS'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['COS']['AL241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['FUFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['FURL'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['GDBV'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['GDBV']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOWER_P']['GUG'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['HEI'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['HGT'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['LMC'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['LZN'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['OTH'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['PCF'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TOWER_P']['PYC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PYC'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TOWER_P']['PYM'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['TOWER_P']['SPT'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['SSR'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_P']['SSR2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_P']['SSR3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_P']['TOS'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['TOWER_P']['TTC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_P']['TTC2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_P']['TTC3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_P']['UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['VOI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['WID'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI001_SDV'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI001_SRT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['AL241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TOWER_P']['ZI002_UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI004_RCG'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TOWER_P']['ZI005_FNA'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI005_GNT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI005_GNT']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TOWER_P']['ZI005_NFN'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI006_MEM'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI018_WIT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOWER_P']['ZI020_GE4'] = ('CodeList',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI026_CTUC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TOWER_P']['ZI026_CTUL'] = ('integer',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI026_CTUU'] = ('integer',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI031S_URI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZI039S_UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZSAX_RS0'] = ('CodeList',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZSAX_RX0'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZSAX_RX3'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZSAX_RX4'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_P']['ZVH'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['AOO'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ARA'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['AWP'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['BEN'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['CAA'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['CAA']['AL241']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TOWER_S']['CNCP'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['COS'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['COS']['AL241']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TOWER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['FUFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['FURL'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['GDBV'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['GDBV']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOWER_S']['GUG'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['HEI'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['HGT'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['LMC'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['LZN'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['OTH'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['PCF'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TOWER_S']['PYC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PYC'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TOWER_S']['PYM'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PYM'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['GGDM 3.0']['TOWER_S']['SPT'] = ('Boolean',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['SSR'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_S']['SSR2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_S']['SSR3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,999)
    field_information['GGDM 3.0']['TOWER_S']['TOS'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['GGDM 3.0']['TOWER_S']['TTC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_S']['TTC2'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_S']['TTC3'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['GGDM 3.0']['TOWER_S']['UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['VOI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['WID'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI001_SDV'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI001_SRT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI001_SRT']['AL241']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TOWER_S']['ZI002_UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI004_RCG'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI004_RCG']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TOWER_S']['ZI005_FNA'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI005_GNT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI005_GNT']['AL241']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TOWER_S']['ZI005_NFN'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI006_MEM'] = ('String',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI018_WIT'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TOWER_S']['ZI020_GE4'] = ('CodeList',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI026_CTUC'] = ('Enumeration',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL241']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TOWER_S']['ZI026_CTUL'] = ('integer',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI026_CTUU'] = ('integer',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI031S_URI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZI039S_UFI'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZSAX_RS0'] = ('CodeList',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZSAX_RX0'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZSAX_RX3'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZSAX_RX4'] = ('StructuredText',('AL241'))
    field_information['GGDM 3.0']['TOWER_S']['ZVH'] = ('Real',('AL241'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['BEN'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['CNCP'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['COS'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['COS']['AQ160']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['FUFI'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['FURL'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['GDBV'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['GDBV']['AQ160']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['HGT'] = ('Real',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['LZN'] = ('Real',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['OTH'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['PCF'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['PCF']['AQ160']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['UFI'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI001_SDV'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI001_SRT'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ160']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI002_UFI'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI004_RCG'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ160']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI005_FNA'] = ('String',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI005_GNT'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ160']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI005_NFN'] = ('String',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI006_MEM'] = ('String',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI020_GE4'] = ('CodeList',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI026_CTUC'] = ('Enumeration',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ160']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI026_CTUL'] = ('integer',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI026_CTUU'] = ('integer',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI031S_URI'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZI039S_UFI'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZSAX_RS0'] = ('CodeList',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZSAX_RX0'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZSAX_RX3'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZSAX_RX4'] = ('StructuredText',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_LIGHT_P']['ZVH'] = ('Real',('AQ160'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['BEN'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['CAA'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['DOF'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['F_CODE'] = ('CONSTRAINED_STRING',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['FUFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['FURL'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['GDBV'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['LZN'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['MAN'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['OTH'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['WID'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI001_SDV'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI001_SRT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI002_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI004_RCG'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI005_FNA'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI005_GNT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI005_NFN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI006_MEM'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI020_GE4'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI026_CTUC'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI026_CTUL'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI026_CTUU'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI031S_URI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZI039S_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZSAX_RS0'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZSAX_RX0'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZSAX_RX3'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_C']['ZSAX_RX4'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['BEN'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['CAA'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['DOF'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['F_CODE'] = ('CONSTRAINED_STRING',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['FUFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['FURL'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['GDBV'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['LZN'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['MAN'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['OTH'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['WID'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI001_SDV'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI001_SRT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI002_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI004_RCG'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI005_FNA'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI005_GNT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI005_NFN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI006_MEM'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI020_GE4'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI026_CTUC'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI026_CTUL'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI026_CTUU'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI031S_URI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZI039S_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZSAX_RS0'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZSAX_RX0'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZSAX_RX3'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_P']['ZSAX_RX4'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['BEN'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['CAA'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['CAA']['FC041']  = (-999999,1,8,16,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['DOF'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['FUFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['FURL'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['GDBV'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['GDBV']['FC041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['IAS'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['LZN'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['MAN'] = ('Boolean',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['OTH'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['TAN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['TSP'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['TSP'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['TSP']['FC041']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['WID'] = ('Real',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI001_SDV'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI001_SRT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI001_SRT']['FC041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI002_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI004_RCG'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI004_RCG']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI005_FNA'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI005_GNT'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI005_GNT']['FC041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI005_NFN'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI006_MEM'] = ('String',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI020_GE4'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI026_CTUC'] = ('Enumeration',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI026_CTUL'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI026_CTUU'] = ('integer',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI031S_URI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZI039S_UFI'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZSAX_RS0'] = ('CodeList',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZSAX_RX0'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZSAX_RX3'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAFFIC_SEPARATION_SCHEME_S']['ZSAX_RX4'] = ('StructuredText',('FC041'))
    field_information['GGDM 3.0']['TRAIL_C']['ARA'] = ('Real',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['BEN'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['CAA'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['CAA']['AP050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TRAIL_C']['CIW'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['CNCP'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['COS'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['COS']['AP050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRAIL_C']['CWT'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['DEV'] = ('Integer',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['FUFI'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['FURL'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['GDBV'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['GDBV']['AP050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAIL_C']['LMC'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['LOC'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['LOC']['AP050']  = (-999999,17,40,44)
    field_information['GGDM 3.0']['TRAIL_C']['LZN'] = ('Real',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['OTH'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['PCF'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['PCF']['AP050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRAIL_C']['PTG'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['RLE'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['RLE']['AP050']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TRAIL_C']['SBB'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['THR'] = ('Boolean',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['TRS'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['TRS']['AP050']  = (-999999,9,18,23,999)
    field_information['GGDM 3.0']['TRAIL_C']['UFI'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['WID'] = ('Real',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI001_SDV'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI001_SRT'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI001_SRT']['AP050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAIL_C']['ZI002_UFI'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI004_RCG'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI004_RCG']['AP050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAIL_C']['ZI005_FNA'] = ('String',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI005_GNT'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI005_GNT']['AP050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAIL_C']['ZI005_NFN'] = ('String',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI006_MEM'] = ('String',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI016_WTC'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI016_WTC']['AP050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TRAIL_C']['ZI020_GE4'] = ('CodeList',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI026_CTUC'] = ('Enumeration',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAIL_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAIL_C']['ZI026_CTUL'] = ('integer',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI026_CTUU'] = ('integer',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI031S_URI'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZI039S_UFI'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZSAX_RS0'] = ('CodeList',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZSAX_RX0'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZSAX_RX3'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAIL_C']['ZSAX_RX4'] = ('StructuredText',('AP050'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ADR'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['AOO'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ARA'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['BEN'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['CAA'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['CNCP'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['COS'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['COS']['FA165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['F_CODE'] = ('CONSTRAINED_STRING',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['FFN'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['FFN2'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['FFN3'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['FUFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['FURL'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['GDBV'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['GDBV']['FA165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['HGT'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['LMC'] = ('Boolean',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['LZN'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['OTH'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['PCF'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['WID'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI001_SDV'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI001_SRT'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI001_SRT']['FA165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI002_UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI004_RCG'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI004_RCG']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI005_FNA'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI005_GNT'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI005_GNT']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI005_NFN'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI006_MEM'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI020_GE4'] = ('CodeList',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI026_CTUC'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_P']['EnumeratedIndexValues']['ZI026_CTUC']['FA165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI026_CTUL'] = ('integer',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI026_CTUU'] = ('integer',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI031S_URI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZI039S_UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZSAX_RS0'] = ('CodeList',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZSAX_RX0'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZSAX_RX3'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZSAX_RX4'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_P']['ZVH'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ADR'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['AOO'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ARA'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['BEN'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['CAA'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['CNCP'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['COS'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['COS']['FA165']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['F_CODE'] = ('CONSTRAINED_STRING',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['FFN'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['FFN2'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['FFN3'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['FUFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['FURL'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['GDBV'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['GDBV']['FA165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['HGT'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['LMC'] = ('Boolean',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['LZN'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['OTH'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['PCF'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['WID'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI001_SDV'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI001_SRT'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI001_SRT']['FA165']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI002_UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI004_RCG'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI004_RCG']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI005_FNA'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI005_GNT'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI005_GNT']['FA165']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI005_NFN'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI006_MEM'] = ('String',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI020_GE4'] = ('CodeList',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI026_CTUC'] = ('Enumeration',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRAINING_SITE_S']['EnumeratedIndexValues']['ZI026_CTUC']['FA165']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI026_CTUL'] = ('integer',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI026_CTUU'] = ('integer',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI031S_URI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZI039S_UFI'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZSAX_RS0'] = ('CodeList',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZSAX_RX0'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZSAX_RX3'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZSAX_RX4'] = ('StructuredText',('FA165'))
    field_information['GGDM 3.0']['TRAINING_SITE_S']['ZVH'] = ('Real',('FA165'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['BCC'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['BEN'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['CON'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['CON'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EXP'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['EXP'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['FUFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['FURL'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['GDBV'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['GDBV']['AQ059']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['HCA'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['LZN'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['OTH'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['SHC'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['SRE'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['SRE'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,8,9,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['TRS'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['TRS2'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['TRS3'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['WD1'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI001_SDV'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI001_SRT'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ059']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI002_UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI004_RCG'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI006_MEM'] = ('String',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI020_GE4'] = ('CodeList',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI026_CTUC'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ059']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI026_CTUL'] = ('integer',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI026_CTUU'] = ('integer',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI031S_URI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZI039S_UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZSAX_RS0'] = ('CodeList',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZSAX_RX0'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZSAX_RX3'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_C']['ZSAX_RX4'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['BCC'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['BEN'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['CON'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['CON'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EXP'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['EXP'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['FUFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['FURL'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['GDBV'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['GDBV']['AQ059']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['HCA'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['LZN'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['OTH'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['SHC'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['SRE'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['SRE'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,8,9,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['TRS'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['TRS2'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['TRS3'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['WD1'] = ('Real',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI001_SDV'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI001_SRT'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ059']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI002_UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI004_RCG'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI006_MEM'] = ('String',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI020_GE4'] = ('CodeList',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI026_CTUC'] = ('Enumeration',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ059']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI026_CTUL'] = ('integer',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI026_CTUU'] = ('integer',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI031S_URI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZI039S_UFI'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZSAX_RS0'] = ('CodeList',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZSAX_RX0'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZSAX_RX3'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_CHARACTER_CHANGE_P']['ZSAX_RX4'] = ('StructuredText',('AQ059'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['AOO'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ARA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['BEN'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['CAA'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['CNCP'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['COS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['FUFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['FURL'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['GDBV'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['HCA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['HGT'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['LMC'] = ('Boolean',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['LZN'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['OHC'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['OTH'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['PCF'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['TRS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['TRS2'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['TRS3'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['WID'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI001_SDV'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI001_SRT'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI002_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI004_RCG'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI006_MEM'] = ('String',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI020_GE4'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI026_CTUC'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI026_CTUL'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI026_CTUU'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI031S_URI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZI039S_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZSAX_RS0'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZSAX_RX0'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZSAX_RX3'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZSAX_RX4'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_C']['ZVH'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['AOO'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ARA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['BEN'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['CAA'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['CNCP'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['COS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['FUFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['FURL'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['GDBV'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['HCA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['HGT'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['LMC'] = ('Boolean',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['LZN'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['OHC'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['OTH'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['PCF'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['TRS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['TRS2'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['TRS3'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['WID'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI001_SDV'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI001_SRT'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI002_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI004_RCG'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI006_MEM'] = ('String',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI020_GE4'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI026_CTUC'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI026_CTUL'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI026_CTUU'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI031S_URI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZI039S_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZSAX_RS0'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZSAX_RX0'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZSAX_RX3'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZSAX_RX4'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_P']['ZVH'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['AOO'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ARA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['BEN'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['CAA'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['CAA']['AL211']  = (-999999,3,17,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['CNCP'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['COS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['COS']['AL211']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['FUFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['FURL'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['GDBV'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['GDBV']['AL211']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['HCA'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['HGT'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['LMC'] = ('Boolean',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['LZN'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['OHC'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['OTH'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['PCF'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['TRP'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRP'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['TRS'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['TRS2'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['TRS3'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['WID'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI001_SDV'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI001_SRT'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI001_SRT']['AL211']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI002_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI004_RCG'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI004_RCG']['AL211']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI006_MEM'] = ('String',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI020_GE4'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI026_CTUC'] = ('Enumeration',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AL211']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI026_CTUL'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI026_CTUU'] = ('integer',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI031S_URI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZI039S_UFI'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZSAX_RS0'] = ('CodeList',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZSAX_RX0'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZSAX_RX3'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZSAX_RX4'] = ('StructuredText',('AL211'))
    field_information['GGDM 3.0']['TRANS_ROUTE_PROTECT_STRUCT_S']['ZVH'] = ('Real',('AL211'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['AOO'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ARA'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['BEN'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['CNCP'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['COS'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['COS']['AQ068']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['DGC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['DGC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['FUFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['FURL'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['GDBV'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['GDBV']['AQ068']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['LZN'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['OTH'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['PCF'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['TRS'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['TRS2'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['TRS3'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['WID'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI001_SDV'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI001_SRT'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ068']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI002_UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI004_RCG'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI006_MEM'] = ('String',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI020_GE4'] = ('CodeList',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI026_CTUC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ068']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI026_CTUL'] = ('integer',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI026_CTUU'] = ('integer',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI031S_URI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZI039S_UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZSAX_RS0'] = ('CodeList',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZSAX_RX0'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZSAX_RX3'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_P']['ZSAX_RX4'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['AOO'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ARA'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['BEN'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['CNCP'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['COS'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['COS']['AQ068']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['DGC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['DGC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['FUFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['FURL'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['GDBV'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['GDBV']['AQ068']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['LZN'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['OTH'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['PCF'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['TRS'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['TRS2'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['TRS3'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['WID'] = ('Real',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI001_SDV'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI001_SRT'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ068']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI002_UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI004_RCG'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ068']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI006_MEM'] = ('String',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI020_GE4'] = ('CodeList',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI026_CTUC'] = ('Enumeration',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ068']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI026_CTUL'] = ('integer',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI026_CTUU'] = ('integer',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI031S_URI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZI039S_UFI'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZSAX_RS0'] = ('CodeList',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZSAX_RX0'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZSAX_RX3'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_BLOCK_S']['ZSAX_RX4'] = ('StructuredText',('AQ068'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ADR'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['AOO'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ARA'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ATB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['BEN'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['CAA'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['CAA']['AQ125']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['CNCP'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['COS'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['COS']['AQ125']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['FFN'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['FFN2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['FFN3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['FUFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['FURL'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['GDBV'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['GDBV']['AQ125']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['HGT'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['HST'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['HST2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['HST3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['LMC'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['LUN'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['LZN'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['MUB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['OTH'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['PCF'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['SPT'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['SSR'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['SSR2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['SSR3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['TRS'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['TRS2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['TRS3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['WID'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI001_SDV'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI001_SRT'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ125']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI002_UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI004_RCG'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI005_FNA'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI005_GNT'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI005_NFN'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI006_MEM'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI020_GE4'] = ('CodeList',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI026_CTUC'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ125']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI026_CTUL'] = ('integer',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI026_CTUU'] = ('integer',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI031S_URI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZI039S_UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZSAX_RS0'] = ('CodeList',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZSAX_RX0'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZSAX_RX3'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZSAX_RX4'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_P']['ZVH'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ADR'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['AOO'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ARA'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ATB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['BEN'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['CAA'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['CAA']['AQ125']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['CNCP'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['COS'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['COS']['AQ125']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['FFN'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['FFN2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['FFN3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,525,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['FUFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['FURL'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['GDBV'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['GDBV']['AQ125']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['HGT'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['HST'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['HST2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['HST3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['LMC'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['LUN'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['LZN'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['MUB'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['OTH'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['PCF'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['SPT'] = ('Boolean',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['SSR'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['SSR2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['SSR3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,55,64,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['TRS'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['TRS2'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['TRS3'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['WID'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI001_SDV'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI001_SRT'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ125']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI002_UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI004_RCG'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI005_FNA'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI005_GNT'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ125']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI005_NFN'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI006_MEM'] = ('String',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI020_GE4'] = ('CodeList',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI026_CTUC'] = ('Enumeration',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ125']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI026_CTUL'] = ('integer',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI026_CTUU'] = ('integer',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI031S_URI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZI039S_UFI'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZSAX_RS0'] = ('CodeList',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZSAX_RX0'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZSAX_RX3'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZSAX_RX4'] = ('StructuredText',('AQ125'))
    field_information['GGDM 3.0']['TRANSPORTATION_STATION_S']['ZVH'] = ('Real',('AQ125'))
    field_information['GGDM 3.0']['TREE_P']['BEN'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['F_CODE'] = ('CONSTRAINED_STRING',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['FUFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['FURL'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['GDBV'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['GDBV']['EC005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TREE_P']['HGT'] = ('Real',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['LMC'] = ('Boolean',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['OTH'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['SDSC'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['SDSC']['EC005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TREE_P']['SDSL'] = ('real',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['SDSU'] = ('real',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['TRE'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['TRE'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['TRE']['EC005']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['TREE_P']['UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['VSP'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['VSP'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['VSP']['EC005']  = (-999999,8,19,22,25,999)
    field_information['GGDM 3.0']['TREE_P']['ZI001_SDV'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI001_SRT'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI001_SRT']['EC005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TREE_P']['ZI002_UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI004_RCG'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI004_RCG']['EC005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TREE_P']['ZI005_FNA'] = ('String',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI005_GNT'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI005_GNT']['EC005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TREE_P']['ZI005_NFN'] = ('String',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI006_MEM'] = ('String',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI020_GE4'] = ('CodeList',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI026_CTUC'] = ('Enumeration',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TREE_P']['EnumeratedIndexValues']['ZI026_CTUC']['EC005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TREE_P']['ZI026_CTUL'] = ('integer',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI026_CTUU'] = ('integer',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI031S_URI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZI039S_UFI'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZSAX_RS0'] = ('CodeList',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZSAX_RX0'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZSAX_RX3'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZSAX_RX4'] = ('StructuredText',('EC005'))
    field_information['GGDM 3.0']['TREE_P']['ZVH'] = ('Real',('EC005'))
    field_information['GGDM 3.0']['TUNDRA_S']['ARA'] = ('Real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['BEN'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['F_CODE'] = ('CONSTRAINED_STRING',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['FUFI'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['FURL'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['GDBV'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['GDBV']['BJ110']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TUNDRA_S']['LZN'] = ('Real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['OTH'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['SNDC'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['SNDC'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['SNDC']['BJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TUNDRA_S']['SNDL'] = ('real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['SNDU'] = ('real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['UFI'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['VTI'] = ('Real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['WID'] = ('Real',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI001_SDV'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI001_SRT'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI001_SRT']['BJ110']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TUNDRA_S']['ZI002_UFI'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI004_RCG'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI004_RCG']['BJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TUNDRA_S']['ZI005_FNA'] = ('String',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI005_GNT'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI005_GNT']['BJ110']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TUNDRA_S']['ZI005_NFN'] = ('String',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI006_MEM'] = ('String',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI020_GE4'] = ('CodeList',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI026_CTUC'] = ('Enumeration',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TUNDRA_S']['EnumeratedIndexValues']['ZI026_CTUC']['BJ110']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TUNDRA_S']['ZI026_CTUL'] = ('integer',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI026_CTUU'] = ('integer',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI031S_URI'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZI039S_UFI'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZSAX_RS0'] = ('CodeList',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZSAX_RX0'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZSAX_RX3'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNDRA_S']['ZSAX_RX4'] = ('StructuredText',('BJ110'))
    field_information['GGDM 3.0']['TUNNEL_C']['AOO'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ARA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['BCC'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TUNNEL_C']['BEN'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['CAA'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['CAA']['AQ130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TUNNEL_C']['CIW'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['CNCP'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['COS'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['COS']['AQ130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TUNNEL_C']['DZC'] = ('Integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['DZP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['F_CODE'] = ('CONSTRAINED_STRING',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['FUFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['FURL'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['GDBV'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['GDBV']['AQ130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TUNNEL_C']['HCA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['HGT'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['HST'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_C']['HST2'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_C']['HST3'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_C']['LEA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['LZN'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['OHC'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['OTH'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['PCF'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TUNNEL_C']['TRA'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['TRS'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_C']['TRS2'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_C']['TRS3'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_C']['UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['WD2'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['WID'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI001_SDV'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI001_SRT'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI001_SRT']['AQ130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TUNNEL_C']['ZI002_UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI004_RCG'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI004_RCG']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TUNNEL_C']['ZI005_FNA'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI005_GNT'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI005_GNT']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TUNNEL_C']['ZI005_NFN'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI006_MEM'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI020_GE4'] = ('CodeList',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI025_HDP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI026_CTUC'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TUNNEL_C']['EnumeratedIndexValues']['ZI026_CTUC']['AQ130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TUNNEL_C']['ZI026_CTUL'] = ('integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI026_CTUU'] = ('integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI031S_URI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZI039S_UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZSAX_RS0'] = ('CodeList',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZSAX_RX0'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZSAX_RX3'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_C']['ZSAX_RX4'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['AOO'] = ('Real',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['BEN'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['CAA'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['CAA']['AQ095']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['CNCP'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['COS'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['COS']['AQ095']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['FUFI'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['FURL'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['GDBV'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['GDBV']['AQ095']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['HCA'] = ('Real',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['LZN'] = ('Real',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['OHC'] = ('Real',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['OTH'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['PCF'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['PCF']['AQ095']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['TRS'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['TRS2'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS2']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['TRS3'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['TRS3']['AQ095']  = (-999999,2,5,7,8,9,12,13,17,20,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['UFI'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI001_SDV'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI001_SRT'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ095']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI002_UFI'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI004_RCG'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ095']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI005_FNA'] = ('String',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI005_GNT'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ095']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI005_NFN'] = ('String',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI006_MEM'] = ('String',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI020_GE4'] = ('CodeList',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI026_CTUC'] = ('Enumeration',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ095']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI026_CTUL'] = ('integer',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI026_CTUU'] = ('integer',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI031S_URI'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZI039S_UFI'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZSAX_RS0'] = ('CodeList',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZSAX_RX0'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZSAX_RX3'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZSAX_RX4'] = ('StructuredText',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_MOUTH_P']['ZVH'] = ('Real',('AQ095'))
    field_information['GGDM 3.0']['TUNNEL_S']['AOO'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ARA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['BCC'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['BCC'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['TUNNEL_S']['BEN'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['CAA'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['CAA']['AQ130']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['TUNNEL_S']['CIW'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['CNCP'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['COS'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['COS']['AQ130']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['TUNNEL_S']['DZC'] = ('Integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['DZP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['FUFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['FURL'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['GDBV'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['GDBV']['AQ130']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['TUNNEL_S']['HCA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['HGT'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['HST'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_S']['HST2'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_S']['HST3'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['TUNNEL_S']['LEA'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['LZN'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['OHC'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['OTH'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['PCF'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['TUNNEL_S']['TRA'] = ('Boolean',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['TRS'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_S']['TRS2'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_S']['TRS3'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,10,12,13,16,20,999)
    field_information['GGDM 3.0']['TUNNEL_S']['UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['WD2'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['WID'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI001_SDV'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI001_SRT'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ130']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['TUNNEL_S']['ZI002_UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI004_RCG'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['TUNNEL_S']['ZI005_FNA'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI005_GNT'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ130']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['TUNNEL_S']['ZI005_NFN'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI006_MEM'] = ('String',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI020_GE4'] = ('CodeList',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI025_HDP'] = ('Real',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI026_CTUC'] = ('Enumeration',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['TUNNEL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ130']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['TUNNEL_S']['ZI026_CTUL'] = ('integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI026_CTUU'] = ('integer',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI031S_URI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZI039S_UFI'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZSAX_RS0'] = ('CodeList',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZSAX_RX0'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZSAX_RX3'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['TUNNEL_S']['ZSAX_RX4'] = ('StructuredText',('AQ130'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ARA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['BEN'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['CAA'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['CNCP'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['COS'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['COS']['AH060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['DZP'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['FUFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['FURL'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['GDBV'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['GDBV']['AH060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['HST'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['HST2'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['HST3'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['LEA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['LZN'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['MCC'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['MCC2'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['MCC3'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['OTH'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['PCF'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['PRM'] = ('Boolean',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['WID'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['YSU'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI001_SDV'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI001_SRT'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI001_SRT']['AH060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI002_UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI004_RCG'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI004_RCG']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI005_FNA'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI005_GNT'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI005_GNT']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI005_NFN'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI006_MEM'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI020_GE4'] = ('CodeList',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI026_CTUC'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AH060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI026_CTUL'] = ('integer',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI026_CTUU'] = ('integer',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI031S_URI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZI039S_UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZSAX_RS0'] = ('CodeList',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZSAX_RX0'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZSAX_RX3'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_P']['ZSAX_RX4'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ARA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['BEN'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['CAA'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['CNCP'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['COS'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['COS']['AH060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['DZP'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['FUFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['FURL'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['GDBV'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['GDBV']['AH060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['HST'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['HST2'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['HST3'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['LEA'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['LZN'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['MCC'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['MCC2'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['MCC3'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['OTH'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['PCF'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['PRM'] = ('Boolean',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['WID'] = ('Real',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['YSU'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['YSU'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI001_SDV'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI001_SRT'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI001_SRT']['AH060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI002_UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI004_RCG'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI004_RCG']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI005_FNA'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI005_GNT'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI005_GNT']['AH060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI005_NFN'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI006_MEM'] = ('String',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI020_GE4'] = ('CodeList',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI026_CTUC'] = ('Enumeration',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AH060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI026_CTUL'] = ('integer',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI026_CTUU'] = ('integer',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI031S_URI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZI039S_UFI'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZSAX_RS0'] = ('CodeList',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZSAX_RX0'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZSAX_RX3'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_BUNKER_S']['ZSAX_RX4'] = ('StructuredText',('AH060'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ADR'] = ('String',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ARA'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['BEN'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['CNCP'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['COS'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['COS']['AL250']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['DZP'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['F_CODE'] = ('CONSTRAINED_STRING',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['FUFI'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['FURL'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['GDBV'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['GDBV']['AL250']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['HST'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['HST2'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST2'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST2']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['HST3'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST3'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['HST3']['AL250']  = (-999999,1,2,3,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['LEA'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['LMC'] = ('Boolean',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['LZN'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['OTH'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['PCF'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['PCF']['AL250']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['UFI'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['WID'] = ('Real',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI001_SDV'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI001_SRT'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI001_SRT']['AL250']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI002_UFI'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI004_RCG'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI004_RCG']['AL250']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI005_FNA'] = ('String',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI005_GNT'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI005_GNT']['AL250']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI005_NFN'] = ('String',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI006_MEM'] = ('String',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI020_GE4'] = ('CodeList',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI026_CTUC'] = ('Enumeration',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['EnumeratedIndexValues']['ZI026_CTUC']['AL250']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI026_CTUL'] = ('integer',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI026_CTUU'] = ('integer',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI031S_URI'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZI039S_UFI'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZSAX_RS0'] = ('CodeList',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZSAX_RX0'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZSAX_RX3'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UNDERGROUND_DWELLING_P']['ZSAX_RX4'] = ('StructuredText',('AL250'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ARA'] = ('Real',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['BEN'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['FUFI'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['FURL'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['GDBV'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['GDBV']['AQ115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['LZN'] = ('Real',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['MCC'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['MCC2'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC2']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['MCC3'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['MCC3']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['OTH'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['UFI'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['UTY'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['UTY2'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY2'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY2']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['UTY3'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY3'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['UTY3']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['WID'] = ('Real',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI001_SDV'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI001_SRT'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['AQ115']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI002_UFI'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI004_RCG'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI005_FNA'] = ('String',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI005_GNT'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI005_NFN'] = ('String',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI006_MEM'] = ('String',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI020_GE4'] = ('CodeList',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI026_CTUC'] = ('Enumeration',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['AQ115']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI026_CTUL'] = ('integer',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI026_CTUU'] = ('integer',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI031S_URI'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZI039S_UFI'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZSAX_RS0'] = ('CodeList',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZSAX_RX0'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZSAX_RX3'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['UTILITY_ACCESS_POINT_P']['ZSAX_RX4'] = ('StructuredText',('AQ115'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['BEN'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['DOF'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['FUFI'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['FURL'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['GDBV'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['GDBV']['BH145']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['OTH'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['PWAC'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['PWAC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['PWAL'] = ('real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['PWAU'] = ('real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['UFI'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WDAC'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['WDAC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WDAL'] = ('real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WDAU'] = ('real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WDH'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WST'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['WST'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['WST']['BH145']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WVA'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['WVH'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI001_SDV'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI001_SRT'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI001_SRT']['BH145']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI002_UFI'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI004_RCG'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI004_RCG']['BH145']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI005_FNA'] = ('String',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI005_GNT'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI005_GNT']['BH145']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI005_NFN'] = ('String',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI006_MEM'] = ('String',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI020_GE4'] = ('CodeList',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_ASE'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_CFR'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_CLO'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_CYN'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_FMR'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_FRR'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_HAR'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_MGN'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_PHW'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_SCC'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI024_SCC']['BH145']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_SUL'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_TDS'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_TEP'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_TUR'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_WAC'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_WTNO'] = ('Real',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI024_YWQ'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH145']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI026_CTUC'] = ('Enumeration',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VANISHING_POINT_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH145']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI026_CTUL'] = ('integer',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI026_CTUU'] = ('integer',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI031S_URI'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZI039S_UFI'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZSAX_RS0'] = ('CodeList',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZSAX_RX0'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZSAX_RX3'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VANISHING_POINT_P']['ZSAX_RX4'] = ('StructuredText',('BH145'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['AOO'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ARA'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['BEN'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['CNCP'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['COS'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['COS']['AP041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['F_CODE'] = ('CONSTRAINED_STRING',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['FUFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['FURL'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['GDBV'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['GDBV']['AP041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['HGT'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['LZN'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['MCC'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['MCC2'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['MCC3'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['OTH'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['PCF'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['TRS'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['TRS2'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['TRS3'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['WID'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI001_SDV'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI001_SRT'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI001_SRT']['AP041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI002_UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI004_RCG'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI004_RCG']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI005_FNA'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI005_GNT'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI005_GNT']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI005_NFN'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI006_MEM'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI020_GE4'] = ('CodeList',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI026_CTUC'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['EnumeratedIndexValues']['ZI026_CTUC']['AP041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI026_CTUL'] = ('integer',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI026_CTUU'] = ('integer',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI031S_URI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZI039S_UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZSAX_RS0'] = ('CodeList',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZSAX_RX0'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZSAX_RX3'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZSAX_RX4'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_C']['ZVH'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['AOO'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ARA'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['BEN'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['CNCP'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['COS'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['COS']['AP041']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['FUFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['FURL'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['GDBV'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['GDBV']['AP041']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['HGT'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['LZN'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['MCC'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['MCC2'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['MCC3'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['OTH'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['PCF'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['TRS'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['TRS2'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['TRS3'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,5,9,12,13,16,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['WID'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI001_SDV'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI001_SRT'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI001_SRT']['AP041']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI002_UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI004_RCG'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI004_RCG']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI005_FNA'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI005_GNT'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI005_GNT']['AP041']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI005_NFN'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI006_MEM'] = ('String',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI020_GE4'] = ('CodeList',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI026_CTUC'] = ('Enumeration',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AP041']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI026_CTUL'] = ('integer',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI026_CTUU'] = ('integer',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI031S_URI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZI039S_UFI'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZSAX_RS0'] = ('CodeList',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZSAX_RX0'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZSAX_RX3'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZSAX_RX4'] = ('StructuredText',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_BARRIER_P']['ZVH'] = ('Real',('AP041'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ADR'] = ('String',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ARA'] = ('Real',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['BEN'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['CAA'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['CAA']['AQ140']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['CIW'] = ('Boolean',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['CNCP'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['COS'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['COS']['AQ140']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['F_CODE'] = ('CONSTRAINED_STRING',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['FUFI'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['FURL'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['GDBV'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['GDBV']['AQ140']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['LMC'] = ('Boolean',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['LZN'] = ('Real',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['OTH'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['PCF'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['PCF']['AQ140']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['UFI'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['VET'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['VET'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['VET']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['WID'] = ('Real',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI001_SDV'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI001_SRT'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI001_SRT']['AQ140']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI002_UFI'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI004_RCG'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI004_RCG']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI005_FNA'] = ('String',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI005_GNT'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI005_GNT']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI005_NFN'] = ('String',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI006_MEM'] = ('String',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI016_ROC'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI016_ROC']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI020_GE4'] = ('CodeList',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI026_CTUC'] = ('Enumeration',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['EnumeratedIndexValues']['ZI026_CTUC']['AQ140']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI026_CTUL'] = ('integer',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI026_CTUU'] = ('integer',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI031S_URI'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZI039S_UFI'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZSAX_RS0'] = ('CodeList',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZSAX_RX0'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZSAX_RX3'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VEHICLE_LOT_S']['ZSAX_RX4'] = ('StructuredText',('AQ140'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['AOO'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ARA'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['BEN'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['CAA'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['CAA']['BI005']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['CNCP'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['COS'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['COS']['BI005']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['FUFI'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['FURL'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['GDBV'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['GDBV']['BI005']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['HGT'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['LCA'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['LMC'] = ('Boolean',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['LZN'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['OTH'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['PCF'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['PCF']['BI005']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['UFI'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['WID'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI001_SDV'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI001_SRT'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI001_SRT']['BI005']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI002_UFI'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI004_RCG'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI004_RCG']['BI005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI005_FNA'] = ('String',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI005_GNT'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI005_GNT']['BI005']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI005_NFN'] = ('String',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI006_MEM'] = ('String',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI020_GE4'] = ('CodeList',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI026_CTUC'] = ('Enumeration',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI005']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI026_CTUL'] = ('integer',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI026_CTUU'] = ('integer',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI031S_URI'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZI039S_UFI'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZSAX_RS0'] = ('CodeList',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZSAX_RX0'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZSAX_RX3'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZSAX_RX4'] = ('StructuredText',('BI005'))
    field_information['GGDM 3.0']['VESSEL_LIFT_S']['ZVH'] = ('Real',('BI005'))
    field_information['GGDM 3.0']['VINEYARD_P']['ARA'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['BEN'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['F_CODE'] = ('CONSTRAINED_STRING',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['FUFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['FURL'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['GDBV'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['GDBV']['EA050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VINEYARD_P']['HGT'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['LMC'] = ('Boolean',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['LZN'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['OTH'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['VTI'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['WID'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI001_SDV'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI001_SRT'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI001_SRT']['EA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI002_UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI004_RCG'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI004_RCG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI005_FNA'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI005_GNT'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI005_GNT']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI005_NFN'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI006_MEM'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI013_CSP'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_CSP']['EA050']  = (16,)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI013_FFP'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI013_FFP2'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP2']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI013_FFP3'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_FFP3']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI013_IRG'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI013_IRG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI020_GE4'] = ('CodeList',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI026_CTUC'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VINEYARD_P']['EnumeratedIndexValues']['ZI026_CTUC']['EA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VINEYARD_P']['ZI026_CTUL'] = ('integer',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI026_CTUU'] = ('integer',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI031S_URI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZI039S_UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZSAX_RS0'] = ('CodeList',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZSAX_RX0'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZSAX_RX3'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZSAX_RX4'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_P']['ZVH'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ARA'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['BEN'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['F_CODE'] = ('CONSTRAINED_STRING',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['FUFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['FURL'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['GDBV'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['GDBV']['EA050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VINEYARD_S']['HGT'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['LMC'] = ('Boolean',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['LZN'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['OTH'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['VTI'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['WID'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI001_SDV'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI001_SRT'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI001_SRT']['EA050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI002_UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI004_RCG'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI004_RCG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI005_FNA'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI005_GNT'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI005_GNT']['EA050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI005_NFN'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI006_MEM'] = ('String',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI013_CSP'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_CSP']['EA050']  = (16,)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI013_FFP'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI013_FFP2'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP2']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI013_FFP3'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_FFP3']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI013_IRG'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI013_IRG']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI020_GE4'] = ('CodeList',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI026_CTUC'] = ('Enumeration',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VINEYARD_S']['EnumeratedIndexValues']['ZI026_CTUC']['EA050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VINEYARD_S']['ZI026_CTUL'] = ('integer',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI026_CTUU'] = ('integer',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI031S_URI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZI039S_UFI'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZSAX_RS0'] = ('CodeList',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZSAX_RX0'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZSAX_RX3'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZSAX_RX4'] = ('StructuredText',('EA050'))
    field_information['GGDM 3.0']['VINEYARD_S']['ZVH'] = ('Real',('EA050'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ARA'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['BEN'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['FUFI'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['FURL'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['GDBV'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['GDBV']['ZD020']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['LZN'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['OTH'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['UFI'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCA'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCA2'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA2'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA2']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCA3'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA3'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCA3']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCT'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCT2'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT2'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT2']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['VCT3'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT3'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['VCT3']['ZD020']  = (-999999,1,3,4,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['WID'] = ('Real',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI001_SDV'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI001_SRT'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI001_SRT']['ZD020']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI002_UFI'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI004_RCG'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI004_RCG']['ZD020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI006_MEM'] = ('String',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI020_GE4'] = ('CodeList',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI026_CTUC'] = ('Enumeration',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZD020']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI026_CTUL'] = ('integer',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI026_CTUU'] = ('integer',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI031S_URI'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZI039S_UFI'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZSAX_RS0'] = ('CodeList',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZSAX_RX0'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZSAX_RX3'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOID_COLLECTION_AREA_S']['ZSAX_RX4'] = ('StructuredText',('ZD020'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ARA'] = ('Real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['BEN'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['F_CODE'] = ('CONSTRAINED_STRING',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['FUFI'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['FURL'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['GDBV'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['GDBV']['DB190']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['HGT'] = ('Real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['LZN'] = ('Real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['OTH'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['SGCC'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['SGCC']['DB190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['SGCL'] = ('real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['SGCU'] = ('real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['UFI'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['WID'] = ('Real',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI001_SDV'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI001_SRT'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI001_SRT']['DB190']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI002_UFI'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI004_RCG'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI004_RCG']['DB190']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI005_FNA'] = ('String',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI005_GNT'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI005_GNT']['DB190']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI005_NFN'] = ('String',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI006_MEM'] = ('String',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI020_GE4'] = ('CodeList',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI026_CTUC'] = ('Enumeration',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['EnumeratedIndexValues']['ZI026_CTUC']['DB190']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI026_CTUL'] = ('integer',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI026_CTUU'] = ('integer',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI031S_URI'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZI039S_UFI'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZSAX_RS0'] = ('CodeList',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZSAX_RX0'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZSAX_RX3'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZSAX_RX4'] = ('StructuredText',('DB190'))
    field_information['GGDM 3.0']['VOLCANIC_DYKE_C']['ZVH'] = ('Real',('DB190'))
    field_information['GGDM 3.0']['VOLCANO_P']['ARA'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['BEN'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['F_CODE'] = ('CONSTRAINED_STRING',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['FUFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['FURL'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['GDBV'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['GDBV']['DB180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VOLCANO_P']['HGT'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['LMC'] = ('Boolean',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['LZN'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['OTH'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['VGT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['VGT'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['VGT']['DB180']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['VOLCANO_P']['VOA'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['VOA'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['VOA']['DB180']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['VOLCANO_P']['WID'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI001_SDV'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI001_SRT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI001_SRT']['DB180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VOLCANO_P']['ZI002_UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI004_RCG'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI004_RCG']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VOLCANO_P']['ZI005_FNA'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI005_GNT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI005_GNT']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VOLCANO_P']['ZI005_NFN'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI006_MEM'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI020_GE4'] = ('CodeList',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI026_CTUC'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VOLCANO_P']['EnumeratedIndexValues']['ZI026_CTUC']['DB180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VOLCANO_P']['ZI026_CTUL'] = ('integer',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI026_CTUU'] = ('integer',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI031S_URI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZI039S_UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZSAX_RS0'] = ('CodeList',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZSAX_RX0'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZSAX_RX3'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZSAX_RX4'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_P']['ZVH'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ARA'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['BEN'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['F_CODE'] = ('CONSTRAINED_STRING',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['FUFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['FURL'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['GDBV'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['GDBV']['DB180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['VOLCANO_S']['HGT'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['LMC'] = ('Boolean',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['LZN'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['OTH'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['VGT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['VGT'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['VGT']['DB180']  = (-999999,1,2,3,4,5)
    field_information['GGDM 3.0']['VOLCANO_S']['VOA'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['VOA'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['VOA']['DB180']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['VOLCANO_S']['WID'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI001_SDV'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI001_SRT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI001_SRT']['DB180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['VOLCANO_S']['ZI002_UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI004_RCG'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI004_RCG']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['VOLCANO_S']['ZI005_FNA'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI005_GNT'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI005_GNT']['DB180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['VOLCANO_S']['ZI005_NFN'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI006_MEM'] = ('String',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI020_GE4'] = ('CodeList',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI026_CTUC'] = ('Enumeration',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['VOLCANO_S']['EnumeratedIndexValues']['ZI026_CTUC']['DB180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['VOLCANO_S']['ZI026_CTUL'] = ('integer',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI026_CTUU'] = ('integer',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI031S_URI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZI039S_UFI'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZSAX_RS0'] = ('CodeList',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZSAX_RX0'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZSAX_RX3'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZSAX_RX4'] = ('StructuredText',('DB180'))
    field_information['GGDM 3.0']['VOLCANO_S']['ZVH'] = ('Real',('DB180'))
    field_information['GGDM 3.0']['WALL_C']['BAT'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['BAT'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['BAT']['AL260']  = (-999999,1,2,3,4,5,999)
    field_information['GGDM 3.0']['WALL_C']['BEN'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['CAA'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['CAA']['AL260']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WALL_C']['F_CODE'] = ('CONSTRAINED_STRING',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['FUFI'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['FURL'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['GDBV'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['GDBV']['AL260']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WALL_C']['HGT'] = ('Real',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['LMC'] = ('Boolean',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['LZN'] = ('Real',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['MCC'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['WALL_C']['MCC2'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC2']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['WALL_C']['MCC3'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['MCC3']['AL260']  = (-999999,8,9,21,62,64,77,83,107,108,117,150,999)
    field_information['GGDM 3.0']['WALL_C']['OTH'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['PCF'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['PCF']['AL260']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WALL_C']['PFHC'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['PFHC'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['PFHC']['AL260']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WALL_C']['PFHL'] = ('real',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['PFHU'] = ('real',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['THI'] = ('Real',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['UFI'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['WTI'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['WTI'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['WTI']['AL260']  = (-999999,1,2,999)
    field_information['GGDM 3.0']['WALL_C']['ZI001_SDV'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI001_SRT'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI001_SRT']['AL260']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WALL_C']['ZI002_UFI'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI004_RCG'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI004_RCG']['AL260']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WALL_C']['ZI005_FNA'] = ('String',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI005_GNT'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI005_GNT']['AL260']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WALL_C']['ZI005_NFN'] = ('String',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI006_MEM'] = ('String',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI020_GE4'] = ('CodeList',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI026_CTUC'] = ('Enumeration',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WALL_C']['EnumeratedIndexValues']['ZI026_CTUC']['AL260']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WALL_C']['ZI026_CTUL'] = ('integer',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI026_CTUU'] = ('integer',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI031S_URI'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZI039S_UFI'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZSAX_RS0'] = ('CodeList',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZSAX_RX0'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZSAX_RX3'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZSAX_RX4'] = ('StructuredText',('AL260'))
    field_information['GGDM 3.0']['WALL_C']['ZVH'] = ('Real',('AL260'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ARA'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['BEN'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['F_CODE'] = ('CONSTRAINED_STRING',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['FUFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['FURL'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['GDBV'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['GDBV']['AB507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WASTE_HEAP_P']['HGT'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['LMC'] = ('Boolean',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['LZN'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['OTH'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['VOI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['WID'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI001_SDV'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI001_SRT'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI001_SRT']['AB507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI002_UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI004_RCG'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI004_RCG']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI005_FNA'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI005_GNT'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI005_GNT']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI005_NFN'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI006_MEM'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI020_GE4'] = ('CodeList',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI026_CTUC'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_P']['EnumeratedIndexValues']['ZI026_CTUC']['AB507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI026_CTUL'] = ('integer',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI026_CTUU'] = ('integer',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI031S_URI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZI039S_UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZSAX_RS0'] = ('CodeList',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZSAX_RX0'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZSAX_RX3'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZSAX_RX4'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_P']['ZVH'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ARA'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['BEN'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['F_CODE'] = ('CONSTRAINED_STRING',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['FUFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['FURL'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['GDBV'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['GDBV']['AB507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WASTE_HEAP_S']['HGT'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['LMC'] = ('Boolean',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['LZN'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['OTH'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['VOI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['WID'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI001_SDV'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI001_SRT'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI001_SRT']['AB507']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI002_UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI004_RCG'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI004_RCG']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI005_FNA'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI005_GNT'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI005_GNT']['AB507']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI005_NFN'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI006_MEM'] = ('String',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI020_GE4'] = ('CodeList',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI026_CTUC'] = ('Enumeration',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WASTE_HEAP_S']['EnumeratedIndexValues']['ZI026_CTUC']['AB507']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI026_CTUL'] = ('integer',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI026_CTUU'] = ('integer',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI031S_URI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZI039S_UFI'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZSAX_RS0'] = ('CodeList',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZSAX_RX0'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZSAX_RX3'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZSAX_RX4'] = ('StructuredText',('AB507'))
    field_information['GGDM 3.0']['WASTE_HEAP_S']['ZVH'] = ('Real',('AB507'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ARA'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ASY'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['BEN'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['CAA'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['CNCP'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['COS'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['F_CODE'] = ('CONSTRAINED_STRING',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['FUFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['FURL'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['GDBV'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['GDBV']['GB065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['IKO'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['LASZ'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['LZN'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['MAG'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['NA8'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['NAO'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['OTH'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['PCF'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['PEC'] = ('Boolean',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['WID'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI001_SDV'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI001_SRT'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI001_SRT']['GB065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI002_UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI004_RCG'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI004_RCG']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI005_FNA'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI005_GNT'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI005_GNT']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI005_NFN'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI006_MEM'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI020_GE4'] = ('CodeList',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI026_CTUC'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_P']['EnumeratedIndexValues']['ZI026_CTUC']['GB065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI026_CTUL'] = ('integer',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI026_CTUU'] = ('integer',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI031S_URI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI039S_UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZI103_MVD'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZSAX_RS0'] = ('CodeList',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZSAX_RX0'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZSAX_RX3'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZSAX_RX4'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZVA'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_P']['ZVH'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ARA'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ASY'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ASY'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['BEN'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['CAA'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['CNCP'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['COS'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['F_CODE'] = ('CONSTRAINED_STRING',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['FUFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['FURL'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['GDBV'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['GDBV']['GB065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['IKO'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['LASZ'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['LZN'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['MAG'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['NA8'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['NAO'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['OTH'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['PCF'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['PEC'] = ('Boolean',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['WID'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI001_SDV'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI001_SRT'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI001_SRT']['GB065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI002_UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI004_RCG'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI004_RCG']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI005_FNA'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI005_GNT'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI005_GNT']['GB065']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI005_NFN'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI006_MEM'] = ('String',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI020_GE4'] = ('CodeList',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI026_CTUC'] = ('Enumeration',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_AERODROME_S']['EnumeratedIndexValues']['ZI026_CTUC']['GB065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI026_CTUL'] = ('integer',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI026_CTUU'] = ('integer',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI031S_URI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI039S_UFI'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZI103_MVD'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZSAX_RS0'] = ('CodeList',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZSAX_RX0'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZSAX_RX3'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZSAX_RX4'] = ('StructuredText',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZVA'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_AERODROME_S']['ZVH'] = ('Real',('GB065'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['AOO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ARA'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['AWP'] = ('Boolean',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['BEN'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['CAA'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['CAA']['BI050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['CNCP'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['COS'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['COS']['BI050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['FUFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['FURL'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['GDBV'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['GDBV']['BI050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['HGT'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['LMC'] = ('Boolean',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['LZN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['OTH'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['PCF'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['VCM'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['VCM2'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['VCM3'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['VOI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['WID'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI001_SDV'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI001_SRT'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['BI050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI002_UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI004_RCG'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI005_FNA'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI005_GNT'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI005_NFN'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI006_MEM'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI020_GE4'] = ('CodeList',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_ASE'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_CFR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_CLO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_CYN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_FMR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_FRR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_HAR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_HYP'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_HYP']['BI050']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_MGN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_PHW'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_SCC'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_SCC']['BI050']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_SUL'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_TDS'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_TEP'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_TUR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_WAC'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_WTNO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI024_YWQ'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI024_YWQ']['BI050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI026_CTUC'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['BI050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI026_CTUL'] = ('integer',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI026_CTUU'] = ('integer',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI031S_URI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZI039S_UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZSAX_RS0'] = ('CodeList',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZSAX_RX0'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZSAX_RX3'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZSAX_RX4'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_P']['ZVH'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['AOO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ARA'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['AWP'] = ('Boolean',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['BEN'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['CAA'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['CAA']['BI050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['CNCP'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['COS'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['COS']['BI050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['F_CODE'] = ('CONSTRAINED_STRING',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['FUFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['FURL'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['GDBV'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['GDBV']['BI050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['HGT'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['LMC'] = ('Boolean',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['LZN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['OTH'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['PCF'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['VCM'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['VCM2'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['VCM3'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['VOI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['WID'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI001_SDV'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI001_SRT'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT']['BI050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI002_UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI004_RCG'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI005_FNA'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI005_GNT'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT']['BI050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI005_NFN'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI006_MEM'] = ('String',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI020_GE4'] = ('CodeList',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_ASE'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_CFR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_CLO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_CYN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_FMR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_FRR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_HAR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_HYP'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_HYP']['BI050']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_MGN'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_PHW'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_SCC'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_SCC']['BI050']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_SUL'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_TDS'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_TEP'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_TUR'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_WAC'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_WTNO'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI024_YWQ'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI024_YWQ']['BI050']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI026_CTUC'] = ('Enumeration',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC']['BI050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI026_CTUL'] = ('integer',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI026_CTUU'] = ('integer',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI031S_URI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZI039S_UFI'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZSAX_RS0'] = ('CodeList',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZSAX_RX0'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZSAX_RX3'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZSAX_RX4'] = ('StructuredText',('BI050'))
    field_information['GGDM 3.0']['WATER_INTAKE_TOWER_S']['ZVH'] = ('Real',('BI050'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['BEN'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['DOXY'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['FUFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['FURL'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['GDBV'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['GDBV']['ZD070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['LEA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['OTH'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['PWAC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['PWAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['PWAL'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['PWAU'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['SCOG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['SCOG'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['SCOG']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['TSTE'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['TSTE'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['TSTE']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WCAC'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WDAC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WDAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WDAL'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WDAU'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WDH'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WDL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WHCO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WODR'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WODR'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WODR']['ZD070']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTBB'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTCA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTCL'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTFE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTKK'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTMN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTNA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTPO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTSI'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WTST'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WTST'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['WTST']['ZD070']  = (-999999,1,2,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WVA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WVH'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['WVL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI001_SDV'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI001_SRT'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT']['ZD070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI002_UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI004_RCG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_FNA'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_FNA2'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_FNA3'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_GNT'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_GNT2'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT2']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_GNT3'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT3']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_NFN'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_NFN2'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI005_NFN3'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI006_MEM'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI020_GE4'] = ('CodeList',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_ASE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_CFR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_CLO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_CYN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_FMR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_FRR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_HAR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_HYP'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_HYP']['ZD070']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_MGN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_PHW'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_SCC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_SCC']['ZD070']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_SUL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_TDS'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_TEP'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_TUR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_WAC'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI024_YWQ'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI024_YWQ']['ZD070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI026_CTUC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI026_CTUL'] = ('integer',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI026_CTUU'] = ('integer',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI031S_URI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZI039S_UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZSAX_RS0'] = ('CodeList',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZSAX_RX0'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZSAX_RX3'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_P']['ZSAX_RX4'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['BEN'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['DOXY'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['F_CODE'] = ('CONSTRAINED_STRING',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['FUFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['FURL'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['GDBV'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['GDBV']['ZD070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['LEA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['OTH'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['PWAC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['PWAC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['PWAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['PWAL'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['PWAU'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['SCOG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['SCOG'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['SCOG']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['TSTE'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['TSTE'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['TSTE']['ZD070']  = (-999999,1,2,3,4,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WCAC'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WDAC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WDAC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WDAC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WDAL'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WDAU'] = ('real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WDH'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WDL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WHCO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WODR'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WODR'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WODR']['ZD070']  = (-999999,1,2,3,4,5,6,7,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTBB'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTCA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTCL'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTFE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTKK'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTMN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTNA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTPO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTSI'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WTST'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WTST'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['WTST']['ZD070']  = (-999999,1,2,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WVA'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WVH'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['WVL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI001_SDV'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI001_SRT'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI001_SRT']['ZD070']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI002_UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI004_RCG'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI004_RCG']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_FNA'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_FNA2'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_FNA3'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_GNT'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_GNT2'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT2']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_GNT3'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI005_GNT3']['ZD070']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_NFN'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_NFN2'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI005_NFN3'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI006_MEM'] = ('String',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI020_GE4'] = ('CodeList',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_ASE'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_CFR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_CLO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_CYN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_FMR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_FRR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_HAR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_HYP'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_HYP']['ZD070']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_MGN'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_PHW'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_SCC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_SCC']['ZD070']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_SUL'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_TDS'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_TEP'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_TUR'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_WAC'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_WTNO'] = ('Real',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI024_YWQ'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI024_YWQ']['ZD070']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI026_CTUC'] = ('Enumeration',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['EnumeratedIndexValues']['ZI026_CTUC']['ZD070']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI026_CTUL'] = ('integer',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI026_CTUU'] = ('integer',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI031S_URI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZI039S_UFI'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZSAX_RS0'] = ('CodeList',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZSAX_RX0'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZSAX_RX3'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MEASUREMENT_LOCATION_S']['ZSAX_RX4'] = ('StructuredText',('ZD070'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ADR'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['AOO'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ARA'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['AWP'] = ('Boolean',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['BEN'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['BNF'] = ('Integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['CAA'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['CAA']['AJ055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['CNCP'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['COS'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['COS']['AJ055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_MILL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['FFN'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['FFN2'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['FFN3'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['FUFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['FURL'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['GDBV'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['GDBV']['AJ055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['HGT'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['LMC'] = ('Boolean',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['LZN'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['OTH'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['PCF'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_MILL_P']['UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['VOI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['WID'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI001_SDV'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI001_SRT'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI002_UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI004_RCG'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI005_FNA'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI005_GNT'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI005_NFN'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI006_MEM'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI014_PPO'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI014_PPO2'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI014_PPO3'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI020_GE4'] = ('CodeList',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI026_CTUC'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_MILL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI026_CTUL'] = ('integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI026_CTUU'] = ('integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI031S_URI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZI039S_UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZSAX_RS0'] = ('CodeList',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZSAX_RX0'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZSAX_RX3'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZSAX_RX4'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_P']['ZVH'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ADR'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['AOO'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ARA'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['AWP'] = ('Boolean',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['BEN'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['BNF'] = ('Integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['CAA'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['CAA']['AJ055']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['CNCP'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['COS'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['COS']['AJ055']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_MILL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['FFN'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['FFN2'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['FFN3'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,351,501,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['FUFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['FURL'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['GDBV'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['GDBV']['AJ055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['HGT'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['LMC'] = ('Boolean',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['LZN'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['OTH'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['PCF'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_MILL_S']['UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['VOI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['WID'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI001_SDV'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI001_SRT'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ055']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI002_UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI004_RCG'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI005_FNA'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI005_GNT'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ055']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI005_NFN'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI006_MEM'] = ('String',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI014_PPO'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI014_PPO2'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI014_PPO3'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI020_GE4'] = ('CodeList',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI026_CTUC'] = ('Enumeration',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_MILL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ055']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI026_CTUL'] = ('integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI026_CTUU'] = ('integer',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI031S_URI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZI039S_UFI'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZSAX_RS0'] = ('CodeList',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZSAX_RX0'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZSAX_RX3'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZSAX_RX4'] = ('StructuredText',('AJ055'))
    field_information['GGDM 3.0']['WATER_MILL_S']['ZVH'] = ('Real',('AJ055'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['BEN'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C35'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C36'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C37'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C38'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C39'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C40'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C41'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C42'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C43'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C44'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C45'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['C46'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['CRN'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['CRS'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['CRX'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['CUR'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['CUR'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['CUR']['BG010']  = (-999999,1,2,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D35'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D36'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D37'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D38'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D39'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D40'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D41'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D42'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D43'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D44'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D45'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['D46'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['DOF'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['DZP'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['F_CODE'] = ('CONSTRAINED_STRING',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['FUFI'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['FURL'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['GDBV'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['GDBV']['BG010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['HDP'] = ('Real',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['HSE'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['OTH'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['REW'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['REW'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['REW']['BG010']  = (-999999,1,2)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['UFI'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_DCR'] = ('Boolean',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_DKC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_DKC2'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC2'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC2']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_DKC3'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC3'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_DKC3']['BG010']  = (-999999,1,3,4,5,6,7,8,9,10,11,12,998,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_SVC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_SVC'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_SVC']['BG010']  = (-999999,1,2,3,4,5,998,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_TEC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_TEC2'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC2'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC2']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_TEC3'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC3'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_TEC3']['BG010']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_VDC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_VDC'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZHDP_VDC']['BG010']  = (-999999,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,24,28,30,90,91,92,93,94,95,96,97,98,99,100,101,102,103,104,105,107,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZHDP_VDR'] = ('String',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI001_SDV'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI001_SRT'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI001_SRT']['BG010']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI002_UFI'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI004_RCG'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI004_RCG']['BG010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI005_FNA'] = ('String',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI005_GNT'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI005_GNT']['BG010']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI005_NFN'] = ('String',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI006_MEM'] = ('String',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI020_GE4'] = ('CodeList',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI026_CTUC'] = ('Enumeration',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['EnumeratedIndexValues']['ZI026_CTUC']['BG010']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI026_CTUL'] = ('integer',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI026_CTUU'] = ('integer',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI031S_URI'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZI039S_UFI'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZSAX_RS0'] = ('CodeList',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZSAX_RX0'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZSAX_RX3'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_MOVEMENT_DATA_LOCATION_P']['ZSAX_RX4'] = ('StructuredText',('BG010'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ARA'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['BEN'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['CAA'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['CAA']['BH065']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['CNCP'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['COS'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['COS']['BH065']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_RACE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['FUFI'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['FURL'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['GDBV'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['GDBV']['BH065']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['HGT'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['LMC'] = ('Boolean',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['LOC'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['LOC'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['LOC']['BH065']  = (-999999,40,44,45)
    field_information['GGDM 3.0']['WATER_RACE_C']['LZN'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['OTH'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['PCF'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['PCF']['BH065']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_RACE_C']['RLE'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['RLE'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['RLE']['BH065']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['WATER_RACE_C']['SPT'] = ('Boolean',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['UFI'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['WID'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['WRT'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['WRT'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['WRT']['BH065']  = (-999999,1,2,3,4)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI001_SDV'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI001_SRT'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI001_SRT']['BH065']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI002_UFI'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI004_RCG'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI004_RCG']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI006_MEM'] = ('String',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI020_GE4'] = ('CodeList',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_ASE'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_CFR'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_CLO'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_CYN'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_FMR'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_FRR'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_HAR'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_HYP'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_HYP']['BH065']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_MGN'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_PHW'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_SCC'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_SCC']['BH065']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_SUL'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_TDS'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_TEP'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_TUR'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WAC'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WTNO'] = ('Real',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WUR'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WUR2'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR2']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WUR3'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR3']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_WUR4'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_WUR4']['BH065']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI024_YWQ'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI024_YWQ']['BH065']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI026_CTUC'] = ('Enumeration',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_RACE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH065']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI026_CTUL'] = ('integer',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI026_CTUU'] = ('integer',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI031S_URI'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZI039S_UFI'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZSAX_RS0'] = ('CodeList',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZSAX_RX0'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZSAX_RX3'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_RACE_C']['ZSAX_RX4'] = ('StructuredText',('BH065'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['AOO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ARA'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['AWP'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['BEN'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['CAA'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['CAA']['AM080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['CNCP'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['COS'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['COS']['AM080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_TOWER_P']['F_CODE'] = ('CONSTRAINED_STRING',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['FUFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['FURL'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['GDBV'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['GDBV']['AM080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['HGT'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['LMC'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['LZN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['OTH'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['PCF'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_TOWER_P']['PMPR'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['SPT'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['SSC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,92,94,100,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['VLM'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['VOI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['WDST'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['WDST']['AM080']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['WID'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['YWQ'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI001_SDV'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI001_SRT'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI001_SRT']['AM080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI002_UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI004_RCG'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI004_RCG']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_FNA'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_FNA2'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_GNT'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_GNT2'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI005_GNT2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_NFN'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI005_NFN2'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI006_MEM'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI020_GE4'] = ('CodeList',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_ASE'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_CFR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_CLO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_CYN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_FMR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_FRR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_HAR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_HYP'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_HYP']['AM080']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_MGN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_PHW'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_SCC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_SCC']['AM080']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_SUL'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_TDS'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_TEP'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_TUR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WAC'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WTNO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WUR'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WUR2'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WUR3'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR3']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI024_WUR4'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI024_WUR4']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI026_CTUC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_P']['EnumeratedIndexValues']['ZI026_CTUC']['AM080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI026_CTUL'] = ('integer',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI026_CTUU'] = ('integer',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI031S_URI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZI039S_UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZSAX_RS0'] = ('CodeList',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZSAX_RX0'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZSAX_RX3'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZSAX_RX4'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_P']['ZVH'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['AOO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ARA'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['AWP'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['BEN'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['CAA'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['CAA']['AM080']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['CNCP'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['COS'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['COS']['AM080']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_TOWER_S']['F_CODE'] = ('CONSTRAINED_STRING',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['FUFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['FURL'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['GDBV'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['GDBV']['AM080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['HGT'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['LMC'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['LZN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['OTH'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['PCF'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_TOWER_S']['PMPR'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['SPT'] = ('Boolean',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['SSC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['SSC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,92,94,100,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['VLM'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['VOI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['WDST'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['WDST']['AM080']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['WID'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['YWQ'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI001_SDV'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI001_SRT'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI001_SRT']['AM080']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI002_UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI004_RCG'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI004_RCG']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_FNA'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_FNA2'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_GNT'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_GNT2'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI005_GNT2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_NFN'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI005_NFN2'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI006_MEM'] = ('String',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI020_GE4'] = ('CodeList',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_ASE'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_CFR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_CLO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_CYN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_FMR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_FRR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_HAR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_HYP'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_HYP']['AM080']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_MGN'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_PHW'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_SCC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_SCC']['AM080']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_SUL'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_TDS'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_TEP'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_TUR'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WAC'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WTNO'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WUR'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WUR2'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR2']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WUR3'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR3']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI024_WUR4'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI024_WUR4']['AM080']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI026_CTUC'] = ('Enumeration',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TOWER_S']['EnumeratedIndexValues']['ZI026_CTUC']['AM080']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI026_CTUL'] = ('integer',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI026_CTUU'] = ('integer',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI031S_URI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZI039S_UFI'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZSAX_RS0'] = ('CodeList',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZSAX_RX0'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZSAX_RX3'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZSAX_RX4'] = ('StructuredText',('AM080'))
    field_information['GGDM 3.0']['WATER_TOWER_S']['ZVH'] = ('Real',('AM080'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ARA'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['BEN'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['CNCP'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['COS'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['COS']['BH040']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['DZP'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['FUFI'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['FURL'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['GDBV'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['GDBV']['BH040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['LMC'] = ('Boolean',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['LZN'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['OTH'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['PCF'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['PCF']['BH040']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['UFI'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['VLM'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['WID'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI001_SDV'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI001_SRT'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI001_SRT']['BH040']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI002_UFI'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI004_RCG'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI004_RCG']['BH040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI005_FNA'] = ('String',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI005_GNT'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI005_GNT']['BH040']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI005_NFN'] = ('String',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI006_MEM'] = ('String',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI020_GE4'] = ('CodeList',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_ASE'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_CFR'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_CLO'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_CYN'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_FMR'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_FRR'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_HAR'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_MGN'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_PHW'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_SCC'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI024_SCC']['BH040']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_SUL'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_TDS'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_TEP'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_TUR'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_WAC'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI024_WTNO'] = ('Real',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI026_CTUC'] = ('Enumeration',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH040']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI026_CTUL'] = ('integer',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI026_CTUU'] = ('integer',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI031S_URI'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZI039S_UFI'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZSAX_RS0'] = ('CodeList',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZSAX_RX0'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZSAX_RX3'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TREATMENT_BED_S']['ZSAX_RX4'] = ('StructuredText',('BH040'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['BEN'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['F_CODE'] = ('CONSTRAINED_STRING',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['FUFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['FURL'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['GDBV'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['OTH'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI001_SDV'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI001_SRT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI002_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI004_RCG'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI005_FNA'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI005_GNT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI005_NFN'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI006_MEM'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI020_GE4'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI026_CTUC'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI026_CTUL'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI026_CTUU'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI031S_URI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZI039S_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZSAX_RS0'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZSAX_RX0'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZSAX_RX3'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_C']['ZSAX_RX4'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['BEN'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['F_CODE'] = ('CONSTRAINED_STRING',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['FUFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['FURL'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['GDBV'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['OTH'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI001_SDV'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI001_SRT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI002_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI004_RCG'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI005_FNA'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI005_GNT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI005_NFN'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI006_MEM'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI020_GE4'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI026_CTUC'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI026_CTUL'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI026_CTUU'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI031S_URI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZI039S_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZSAX_RS0'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZSAX_RX0'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZSAX_RX3'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_P']['ZSAX_RX4'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['BEN'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['F_CODE'] = ('CONSTRAINED_STRING',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['FUFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['FURL'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['GDBV'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['GDBV']['BG012']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['OTH'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['WTT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['WTT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['WTT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI001_SDV'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI001_SRT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI001_SRT']['BG012']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI002_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI004_RCG'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI004_RCG']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI005_FNA'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI005_GNT'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI005_GNT']['BG012']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI005_NFN'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI006_MEM'] = ('String',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI020_GE4'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI026_CTUC'] = ('Enumeration',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['EnumeratedIndexValues']['ZI026_CTUC']['BG012']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI026_CTUL'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI026_CTUU'] = ('integer',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI031S_URI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZI039S_UFI'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZSAX_RS0'] = ('CodeList',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZSAX_RX0'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZSAX_RX3'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_TURBULENCE_S']['ZSAX_RX4'] = ('StructuredText',('BG012'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['AQN'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ARA'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['BEN'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['CAA'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['CAA']['NM230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['CNCP'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['COS'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['COS']['NM230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['DMF'] = ('Integer',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['F_CODE'] = ('CONSTRAINED_STRING',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['FUFI'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['FURL'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['GDBV'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['GDBV']['NM230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['LMC'] = ('Boolean',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['OTH'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['PCF'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['PCF']['NM230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['SWW'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['TSSM'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['TSSM2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['TSSM3'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['TSSM3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['UFI'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WAD'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WDST'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WDST']['NM230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WFT'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WFT']['NM230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WWM'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WWM2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['WWM3'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['WWM3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI001_SDV'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI001_SRT'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI001_SRT']['NM230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI002_UFI'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI004_RCG'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI004_RCG']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_FNA'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_FNA2'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_GNT'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI005_GNT']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_GNT2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI005_GNT2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_NFN'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI005_NFN2'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI006_MEM'] = ('String',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI020_GE4'] = ('CodeList',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_ASE'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_AWO'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_AWOI'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_AWOX'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_CFR'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_CLO'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_CYN'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_DRL'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_DRL']['NM230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_FMR'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_FRR'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_HAR'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_HYP'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_HYP']['NM230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_MGN'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_PHW'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_PMP'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_PMP']['NM230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_SCC'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_SCC']['NM230']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_SUL'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_TDS'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_TEP'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_TUR'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WAC'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WTNO'] = ('Real',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WUR'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WUR2'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR2']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WUR3'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR3']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_WUR4'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_WUR4']['NM230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI024_YWQ'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI024_YWQ']['NM230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI026_CTUC'] = ('Enumeration',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['EnumeratedIndexValues']['ZI026_CTUC']['NM230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI026_CTUL'] = ('integer',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI026_CTUU'] = ('integer',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI031S_URI'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZI039S_UFI'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZSAX_RS0'] = ('CodeList',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZSAX_RX0'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZSAX_RX3'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_AON_S']['ZSAX_RX4'] = ('StructuredText',('NM230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['AQN'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ARA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['BEN'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['CAA'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['CAA']['BH230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['CDI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['CNCP'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['COS'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['COS']['BH230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_WELL_P']['DWL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['DZP'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['FUFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['FURL'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['GDBV'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['GDBV']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['HGT'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['LMC'] = ('Boolean',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['LZN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['OTH'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['PCF'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_WELL_P']['PUD'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['SWW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['TSSM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['TSSM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['TSSM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['TSSM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['WAD'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['WCAC'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['WDST'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WDST']['BH230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['WFT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['WHCO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['WID'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['WWM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['WWM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['WWM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['WWM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI001_SDV'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI001_SRT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI001_SRT']['BH230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI002_UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI004_RCG'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI004_RCG']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_FNA'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_FNA2'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_GNT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_GNT2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI005_GNT2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_NFN'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI005_NFN2'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI006_MEM'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI020_GE4'] = ('CodeList',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_ASE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_AWO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_AWOI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_AWOX'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_CFR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_CLO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_CYN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_DRL'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_DRL']['BH230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_DVPT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_DVPT']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_FMR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_FRR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_HAR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_HYP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_MGN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_PHW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_PMP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_PMP']['BH230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_SCC'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_SUL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_TDS'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_TEP'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_TUR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WAC'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTBB'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTCA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTFE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTKK'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTMN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTNA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTNO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTPO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WTSI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WUR'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WUR2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WUR3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_WUR4'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI024_YWQ'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI026_CTUC'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI026_CTUL'] = ('integer',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI026_CTUU'] = ('integer',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI031S_URI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZI039S_UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZSAX_RS0'] = ('CodeList',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZSAX_RX0'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZSAX_RX3'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZSAX_RX4'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_P']['ZVH'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['AQN'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ARA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['BEN'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['CAA'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['CAA']['BH230']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['CDI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['CNCP'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['COS'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['COS']['BH230']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATER_WELL_S']['DWL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['DZP'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['FUFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['FURL'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['GDBV'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['GDBV']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['HGT'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['LMC'] = ('Boolean',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['LZN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['OTH'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['PCF'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATER_WELL_S']['PUD'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['SWW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['TSSM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['TSSM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['TSSM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['TSSM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['WAD'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['WCAC'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['WDST'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WDST']['BH230']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['WFT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WFT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['WHCO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['WID'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['WWM'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['WWM2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['WWM3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['WWM3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI001_SDV'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI001_SRT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI001_SRT']['BH230']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI002_UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI004_RCG'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI004_RCG']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_FNA'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_FNA2'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_GNT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI005_GNT']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_GNT2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_NFN'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI005_NFN2'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI006_MEM'] = ('String',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI020_GE4'] = ('CodeList',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_ASE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_AWO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_AWOI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_AWOX'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_CFR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_CLO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_CYN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_DRL'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_DRL']['BH230']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_DVPT'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_DVPT']['BH230']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_FMR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_FRR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_HAR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_HYP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_MGN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_PHW'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_PMP'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_PMP']['BH230']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_SCC'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_SUL'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_TDS'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_TEP'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_TUR'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WAC'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTBB'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTCA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTFE'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTKK'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTMN'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTNA'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTNO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTPO'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WTSI'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WUR'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WUR2'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WUR3'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_WUR4'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH230']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI024_YWQ'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI026_CTUC'] = ('Enumeration',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATER_WELL_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH230']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI026_CTUL'] = ('integer',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI026_CTUU'] = ('integer',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI031S_URI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZI039S_UFI'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZSAX_RS0'] = ('CodeList',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZSAX_RX0'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZSAX_RX3'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZSAX_RX4'] = ('StructuredText',('BH230'))
    field_information['GGDM 3.0']['WATER_WELL_S']['ZVH'] = ('Real',('BH230'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ARA'] = ('Real',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['BEN'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['F_CODE'] = ('CONSTRAINED_STRING',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['FUFI'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['FURL'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['GDBV'] = ('Enumeration',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['GDBV']['FC035']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['LZN'] = ('Real',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['OTH'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['UFI'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['WID'] = ('Real',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI001_SDV'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI001_SRT'] = ('Enumeration',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI001_SRT']['FC035']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI002_UFI'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI004_RCG'] = ('Enumeration',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI004_RCG']['FC035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI005_FNA'] = ('String',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI005_GNT'] = ('Enumeration',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI005_GNT']['FC035']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI005_NFN'] = ('String',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI006_MEM'] = ('String',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI020_GE4'] = ('CodeList',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI026_CTUC'] = ('Enumeration',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['EnumeratedIndexValues']['ZI026_CTUC']['FC035']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI026_CTUL'] = ('integer',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI026_CTUU'] = ('integer',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI031S_URI'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZI039S_UFI'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZSAX_RS0'] = ('CodeList',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZSAX_RX0'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZSAX_RX3'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERBODY_DIVIDER_S']['ZSAX_RX4'] = ('StructuredText',('FC035'))
    field_information['GGDM 3.0']['WATERFALL_C']['AOO'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ARA'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['BEN'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['F_CODE'] = ('CONSTRAINED_STRING',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['FUFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['FURL'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['GDBV'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['GDBV']['BH180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERFALL_C']['HGT'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['LMC'] = ('Boolean',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['LZN'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['OTH'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['WID'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI001_SDV'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI001_SRT'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI001_SRT']['BH180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATERFALL_C']['ZI002_UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI004_RCG'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI004_RCG']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATERFALL_C']['ZI005_FNA'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI005_GNT'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI005_GNT']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERFALL_C']['ZI005_NFN'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI006_MEM'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI020_GE4'] = ('CodeList',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI026_CTUC'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATERFALL_C']['EnumeratedIndexValues']['ZI026_CTUC']['BH180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATERFALL_C']['ZI026_CTUL'] = ('integer',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI026_CTUU'] = ('integer',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI031S_URI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZI039S_UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZSAX_RS0'] = ('CodeList',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZSAX_RX0'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZSAX_RX3'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZSAX_RX4'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_C']['ZVH'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['AOO'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ARA'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['BEN'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['FUFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['FURL'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['GDBV'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['GDBV']['BH180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERFALL_P']['HGT'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['LMC'] = ('Boolean',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['LZN'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['OTH'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['WID'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI001_SDV'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI001_SRT'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI001_SRT']['BH180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATERFALL_P']['ZI002_UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI004_RCG'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI004_RCG']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATERFALL_P']['ZI005_FNA'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI005_GNT'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI005_GNT']['BH180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERFALL_P']['ZI005_NFN'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI006_MEM'] = ('String',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI020_GE4'] = ('CodeList',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI026_CTUC'] = ('Enumeration',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATERFALL_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATERFALL_P']['ZI026_CTUL'] = ('integer',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI026_CTUU'] = ('integer',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI031S_URI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZI039S_UFI'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZSAX_RS0'] = ('CodeList',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZSAX_RX0'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZSAX_RX3'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZSAX_RX4'] = ('StructuredText',('BH180'))
    field_information['GGDM 3.0']['WATERFALL_P']['ZVH'] = ('Real',('BH180'))
    field_information['GGDM 3.0']['WATERWORK_P']['ADR'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ADUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ANFL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['AOO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ARA'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['BEN'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['CAA'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATERWORK_P']['CNCP'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['COS'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['COS']['BH220']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATERWORK_P']['DCAP'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['DINF'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['DINF']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATERWORK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['FUFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['FURL'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['GDBV'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['GDBV']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERWORK_P']['GRD'] = ('Boolean',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['HGT'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['LMC'] = ('Boolean',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['LZN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['OTH'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['PCF'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATERWORK_P']['UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['WDST'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['WDST']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATERWORK_P']['WID'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['WLSS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI001_SDV'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI001_SRT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI001_SRT']['BH220']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI002_UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI004_RCG'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI004_RCG']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_FNA'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_FNA2'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_GNT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI005_GNT']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_GNT2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI005_GNT2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_NFN'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI005_NFN2'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI006_MEM'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI020_GE4'] = ('CodeList',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_ASE'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_AWO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_AWOI'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_AWOX'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_CFR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_CLO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_CYN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_DRL'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_DRL']['BH220']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_DVPT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_DVPT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_FMR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_FRR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_HAR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_MGN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PHW'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PMP'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PMP']['BH220']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PUR'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PUR2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PUR3'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PUR4'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_PUR5'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_PUR5']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_SCC'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_SCC']['BH220']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_SUL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_TDS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_TEP'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_TUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WAC'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WTNO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WUR'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WUR2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WUR3'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_WUR4'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_WUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI024_YWQ'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI024_YWQ']['BH220']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI026_CTUC'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATERWORK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BH220']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATERWORK_P']['ZI026_CTUL'] = ('integer',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI026_CTUU'] = ('integer',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI031S_URI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZI039S_UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZSAX_RS0'] = ('CodeList',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZSAX_RX0'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZSAX_RX3'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZSAX_RX4'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_P']['ZVH'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ADR'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ADUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ANFL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['AOO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ARA'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['BEN'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['CAA'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WATERWORK_S']['CNCP'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['COS'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['COS']['BH220']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WATERWORK_S']['DCAP'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['DINF'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['DINF'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['DINF']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATERWORK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['FUFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['FURL'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['GDBV'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['GDBV']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERWORK_S']['GRD'] = ('Boolean',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['HGT'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['LMC'] = ('Boolean',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['LZN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['OTH'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['PCF'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WATERWORK_S']['UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['WDST'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['WDST'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['WDST']['BH220']  = (-999999,1,2,3,4,5,6,7,8,998,999)
    field_information['GGDM 3.0']['WATERWORK_S']['WID'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['WLSS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI001_SDV'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI001_SRT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI001_SRT']['BH220']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI002_UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI004_RCG'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI004_RCG']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_FNA'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_FNA2'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_GNT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI005_GNT']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_GNT2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI005_GNT2'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI005_GNT2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_NFN'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI005_NFN2'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI006_MEM'] = ('String',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI020_GE4'] = ('CodeList',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_ASE'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_AWO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_AWOI'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_AWOX'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_CFR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_CLO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_CYN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_DRL'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_DRL'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_DRL']['BH220']  = (-999999,17,40,44,45,50,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_DVPT'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_DVPT'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_DVPT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_FMR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_FRR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_HAR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_MGN'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PHW'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PMP'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PMP'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PMP']['BH220']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PUR'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PUR2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR2'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PUR3'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR3'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PUR4'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR4'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_PUR5'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR5'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_PUR5']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_SCC'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_SCC']['BH220']  = (-999999,1,4,10,11,12,13,14,998,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_SUL'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_TDS'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_TEP'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_TUR'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WAC'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WTNO'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WUR'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WUR2'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR2'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR2']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WUR3'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR3'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR3']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_WUR4'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR4'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_WUR4']['BH220']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI024_YWQ'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI024_YWQ']['BH220']  = (-999999,1,2,3,4,999)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI026_CTUC'] = ('Enumeration',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WATERWORK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BH220']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WATERWORK_S']['ZI026_CTUL'] = ('integer',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI026_CTUU'] = ('integer',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI031S_URI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZI039S_UFI'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZSAX_RS0'] = ('CodeList',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZSAX_RX0'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZSAX_RX3'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZSAX_RX4'] = ('StructuredText',('BH220'))
    field_information['GGDM 3.0']['WATERWORK_S']['ZVH'] = ('Real',('BH220'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ADR'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['AOO'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ARA'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['BEN'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['CAA'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['CAA']['AD060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WIND_FARM_P']['CNCP'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['COS'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['COS']['AD060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WIND_FARM_P']['F_CODE'] = ('CONSTRAINED_STRING',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['FUFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['FURL'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['GDBV'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['GDBV']['AD060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WIND_FARM_P']['HGT'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['LMC'] = ('Boolean',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['LZN'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['OTH'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['PCF'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WIND_FARM_P']['UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['WID'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI001_SDV'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI001_SRT'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI001_SRT']['AD060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI002_UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI004_RCG'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI004_RCG']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI005_FNA'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI005_GNT'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI005_GNT']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI005_NFN'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI006_MEM'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI020_GE4'] = ('CodeList',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI026_CTUC'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WIND_FARM_P']['EnumeratedIndexValues']['ZI026_CTUC']['AD060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI026_CTUL'] = ('integer',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI026_CTUU'] = ('integer',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI031S_URI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZI039S_UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZSAX_RS0'] = ('CodeList',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZSAX_RX0'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZSAX_RX3'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZSAX_RX4'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_P']['ZVH'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ADR'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['AOO'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ARA'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['BEN'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['CAA'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['CAA']['AD060']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WIND_FARM_S']['CNCP'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['COS'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['COS']['AD060']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WIND_FARM_S']['F_CODE'] = ('CONSTRAINED_STRING',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['FUFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['FURL'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['GDBV'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['GDBV']['AD060']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WIND_FARM_S']['HGT'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['LMC'] = ('Boolean',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['LZN'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['OTH'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['PCF'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WIND_FARM_S']['UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['WID'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI001_SDV'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI001_SRT'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI001_SRT']['AD060']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI002_UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI004_RCG'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI004_RCG']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI005_FNA'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI005_GNT'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI005_GNT']['AD060']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI005_NFN'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI006_MEM'] = ('String',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI020_GE4'] = ('CodeList',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI026_CTUC'] = ('Enumeration',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WIND_FARM_S']['EnumeratedIndexValues']['ZI026_CTUC']['AD060']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI026_CTUL'] = ('integer',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI026_CTUU'] = ('integer',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI031S_URI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZI039S_UFI'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZSAX_RS0'] = ('CodeList',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZSAX_RX0'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZSAX_RX3'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZSAX_RX4'] = ('StructuredText',('AD060'))
    field_information['GGDM 3.0']['WIND_FARM_S']['ZVH'] = ('Real',('AD060'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['AOO'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ARA'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['AWP'] = ('Boolean',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['BEN'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['CAA'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['CAA']['AJ051']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['CNCP'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['COS'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['COS']['AJ051']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['FUFI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['FURL'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['GDBV'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['GDBV']['AJ051']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['GUG'] = ('Boolean',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['HGT'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['LMC'] = ('Boolean',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['LZN'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['OTH'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['PCF'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['PCF']['AJ051']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['SRL'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['SRL'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['SRL']['AJ051']  = (-999999,1,2,3)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['TOS'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['TOS']['AJ051']  = (-999999,6,11,12,13,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['UFI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['VCM'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['VCM2'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM2']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['VCM3'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['VCM3']['AJ051']  = (-999999,2,4,5,7,9,15,18,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['VOI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['WID'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI001_SDV'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI001_SRT'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ051']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI002_UFI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI004_RCG'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ051']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI005_FNA'] = ('String',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI005_GNT'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ051']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI005_NFN'] = ('String',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI006_MEM'] = ('String',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI020_GE4'] = ('CodeList',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI026_CTUC'] = ('Enumeration',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WIND_TURBINE_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ051']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI026_CTUL'] = ('integer',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI026_CTUU'] = ('integer',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI031S_URI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZI039S_UFI'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZSAX_RS0'] = ('CodeList',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZSAX_RX0'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZSAX_RX3'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZSAX_RX4'] = ('StructuredText',('AJ051'))
    field_information['GGDM 3.0']['WIND_TURBINE_P']['ZVH'] = ('Real',('AJ051'))
    field_information['GGDM 3.0']['WINDMILL_P']['AOO'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ARA'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['AWP'] = ('Boolean',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['BEN'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['CAA'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['CAA']['AJ050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WINDMILL_P']['CNCP'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['COS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['COS']['AJ050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WINDMILL_P']['F_CODE'] = ('CONSTRAINED_STRING',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['FUFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['FURL'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['GDBV'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['GDBV']['AJ050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WINDMILL_P']['HGT'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['LMC'] = ('Boolean',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['LZN'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['OTH'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['PCF'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WINDMILL_P']['PPO'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_P']['PPO2'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_P']['PPO3'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_P']['TOS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['GGDM 3.0']['WINDMILL_P']['UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['VCM'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_P']['VCM2'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_P']['VCM3'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_P']['VOI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['WID'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI001_SDV'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI001_SRT'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI001_SRT']['AJ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WINDMILL_P']['ZI002_UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI004_RCG'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI004_RCG']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WINDMILL_P']['ZI005_FNA'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI005_GNT'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI005_GNT']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WINDMILL_P']['ZI005_NFN'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI006_MEM'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI020_GE4'] = ('CodeList',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI026_CTUC'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WINDMILL_P']['EnumeratedIndexValues']['ZI026_CTUC']['AJ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WINDMILL_P']['ZI026_CTUL'] = ('integer',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI026_CTUU'] = ('integer',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI031S_URI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZI039S_UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZSAX_RS0'] = ('CodeList',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZSAX_RX0'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZSAX_RX3'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZSAX_RX4'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_P']['ZVH'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['AOO'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ARA'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['AWP'] = ('Boolean',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['BEN'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['CAA'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['CAA']['AJ050']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['WINDMILL_S']['CNCP'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['COS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['COS']['AJ050']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['WINDMILL_S']['F_CODE'] = ('CONSTRAINED_STRING',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['FUFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['FURL'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['GDBV'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['GDBV']['AJ050']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WINDMILL_S']['HGT'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['LMC'] = ('Boolean',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['LZN'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['OTH'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['PCF'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['WINDMILL_S']['PPO'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_S']['PPO2'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_S']['PPO3'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['GGDM 3.0']['WINDMILL_S']['TOS'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['TOS'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['GGDM 3.0']['WINDMILL_S']['UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['VCM'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_S']['VCM2'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_S']['VCM3'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['GGDM 3.0']['WINDMILL_S']['VOI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['WID'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI001_SDV'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI001_SRT'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI001_SRT']['AJ050']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WINDMILL_S']['ZI002_UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI004_RCG'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI004_RCG']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WINDMILL_S']['ZI005_FNA'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI005_GNT'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI005_GNT']['AJ050']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WINDMILL_S']['ZI005_NFN'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI006_MEM'] = ('String',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI020_GE4'] = ('CodeList',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI026_CTUC'] = ('Enumeration',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WINDMILL_S']['EnumeratedIndexValues']['ZI026_CTUC']['AJ050']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WINDMILL_S']['ZI026_CTUL'] = ('integer',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI026_CTUU'] = ('integer',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI031S_URI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZI039S_UFI'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZSAX_RS0'] = ('CodeList',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZSAX_RX0'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZSAX_RX3'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZSAX_RX4'] = ('StructuredText',('AJ050'))
    field_information['GGDM 3.0']['WINDMILL_S']['ZVH'] = ('Real',('AJ050'))
    field_information['GGDM 3.0']['WRECK_P']['ARA'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['BEN'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['DKC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_P']['DKC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC2'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC2']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_P']['DKC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC3'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['DKC3']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_P']['DTN'] = ('Boolean',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['F_CODE'] = ('CONSTRAINED_STRING',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['FUFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['FURL'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['GDBV'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['GDBV']['BD180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WRECK_P']['LZN'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['OTH'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['WLO'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['WLO'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['WLO']['BD180']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['WRECK_P']['ZHBH_TEC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_P']['ZHBH_TEC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC2']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_P']['ZHBH_TEC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZHBH_TEC3']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_P']['ZI001_SDV'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI001_SRT'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI001_SRT']['BD180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WRECK_P']['ZI002_UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI004_RCG'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI004_RCG']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WRECK_P']['ZI005_FNA'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI005_GNT'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI005_GNT']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WRECK_P']['ZI005_NFN'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI006_MEM'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI020_GE4'] = ('CodeList',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI025_HDP'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI025_WLE'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI025_WLE']['BD180']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['WRECK_P']['ZI026_CTUC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WRECK_P']['EnumeratedIndexValues']['ZI026_CTUC']['BD180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WRECK_P']['ZI026_CTUL'] = ('integer',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI026_CTUU'] = ('integer',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI031S_URI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZI039S_UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZSAX_RS0'] = ('CodeList',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZSAX_RX0'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZSAX_RX3'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_P']['ZSAX_RX4'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ARA'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['BEN'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['DKC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_S']['DKC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC2'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC2']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_S']['DKC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC3'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['DKC3']['BD180']  = (-999999,1,3,4,5,6,8,9,998,999)
    field_information['GGDM 3.0']['WRECK_S']['DTN'] = ('Boolean',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['F_CODE'] = ('CONSTRAINED_STRING',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['FUFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['FURL'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['GDBV'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['GDBV']['BD180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['WRECK_S']['LZN'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['OTH'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['WLO'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['WLO'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['WLO']['BD180']  = (-999999,1,2,3,4,5,6,999)
    field_information['GGDM 3.0']['WRECK_S']['ZHBH_TEC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_S']['ZHBH_TEC2'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC2'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC2']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_S']['ZHBH_TEC3'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC3'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZHBH_TEC3']['BD180']  = (-999999,1,2,3,4,5,6,8,9,10,11,12,13,14,15,17,18,999)
    field_information['GGDM 3.0']['WRECK_S']['ZI001_SDV'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI001_SRT'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI001_SRT']['BD180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['WRECK_S']['ZI002_UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI004_RCG'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI004_RCG']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['WRECK_S']['ZI005_FNA'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI005_GNT'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI005_GNT']['BD180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['WRECK_S']['ZI005_NFN'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI006_MEM'] = ('String',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI020_GE4'] = ('CodeList',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI025_HDP'] = ('Real',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI025_WLE'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI025_WLE']['BD180']  = (-999999,1,2,3,4,5,9,999)
    field_information['GGDM 3.0']['WRECK_S']['ZI026_CTUC'] = ('Enumeration',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['WRECK_S']['EnumeratedIndexValues']['ZI026_CTUC']['BD180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['WRECK_S']['ZI026_CTUL'] = ('integer',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI026_CTUU'] = ('integer',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI031S_URI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZI039S_UFI'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZSAX_RS0'] = ('CodeList',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZSAX_RX0'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZSAX_RX3'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['WRECK_S']['ZSAX_RX4'] = ('StructuredText',('BD180'))
    field_information['GGDM 3.0']['ZOO_P']['ADR'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['AOO'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ARA'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['BEN'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['CAA'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['CAA']['AK180']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ZOO_P']['CNCP'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['COS'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['COS']['AK180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ZOO_P']['F_CODE'] = ('CONSTRAINED_STRING',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['FUFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['FURL'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['GDBV'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['GDBV']['AK180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ZOO_P']['HGT'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['LMC'] = ('Boolean',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['LZN'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['OTH'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['PCF'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ZOO_P']['UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['WID'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI001_SDV'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI001_SRT'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI001_SRT']['AK180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ZOO_P']['ZI002_UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI004_RCG'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI004_RCG']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ZOO_P']['ZI005_FNA'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI005_GNT'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI005_GNT']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ZOO_P']['ZI005_NFN'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI006_MEM'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI020_GE4'] = ('CodeList',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI026_CTUC'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ZOO_P']['EnumeratedIndexValues']['ZI026_CTUC']['AK180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ZOO_P']['ZI026_CTUL'] = ('integer',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI026_CTUU'] = ('integer',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI031S_URI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZI039S_UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZSAX_RS0'] = ('CodeList',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZSAX_RX0'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZSAX_RX3'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZSAX_RX4'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_P']['ZVH'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ADR'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['AOO'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ARA'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['BEN'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['CAA'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['CAA'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['CAA']['AK180']  = (-999999,3,5,7,16,17,999)
    field_information['GGDM 3.0']['ZOO_S']['CNCP'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['COS'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['COS'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['COS']['AK180']  = (-999999,4,6,9,13,14)
    field_information['GGDM 3.0']['ZOO_S']['F_CODE'] = ('CONSTRAINED_STRING',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['FUFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['FURL'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['GDBV'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['GDBV'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['GDBV']['AK180']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['GGDM 3.0']['ZOO_S']['HGT'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['LMC'] = ('Boolean',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['LZN'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['OTH'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['PCF'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['PCF'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['GGDM 3.0']['ZOO_S']['UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['WID'] = ('Real',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI001_SDV'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI001_SRT'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI001_SRT'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI001_SRT']['AK180']  = (-999999,2,7,9,10,21,22,25,26,28,29,30,31,32,43,60,61,64,108,159,160,165,166,167,168,169,170,171,999)
    field_information['GGDM 3.0']['ZOO_S']['ZI002_UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI004_RCG'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI004_RCG'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI004_RCG']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,998,999)
    field_information['GGDM 3.0']['ZOO_S']['ZI005_FNA'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI005_GNT'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI005_GNT'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI005_GNT']['AK180']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['GGDM 3.0']['ZOO_S']['ZI005_NFN'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI006_MEM'] = ('String',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI020_GE4'] = ('CodeList',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI026_CTUC'] = ('Enumeration',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI026_CTUC'] = {}
    field_information['GGDM 3.0']['ZOO_S']['EnumeratedIndexValues']['ZI026_CTUC']['AK180']  = (2,3,4,5,6,7,8,9)
    field_information['GGDM 3.0']['ZOO_S']['ZI026_CTUL'] = ('integer',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI026_CTUU'] = ('integer',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI031S_URI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZI039S_UFI'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZSAX_RS0'] = ('CodeList',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZSAX_RX0'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZSAX_RX3'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZSAX_RX4'] = ('StructuredText',('AK180'))
    field_information['GGDM 3.0']['ZOO_S']['ZVH'] = ('Real',('AK180'))


## Default values and summary domain values and levels are the same as standard GGDM 3.0
