﻿

""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: TDS4_2_GGDM30_TranslateFeaturesandFields.py                                       **
 **  Copyright (c) May 2015 by Leidos                                                          **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class / feature / and field specific            **
 **             mappings and where a translation is involved, that is listed as well.          **
 **             The information in this file is specific to translations from:                 **
 **                 TDS 4.0 Composite to GGDM 3.0 Composite                                    **
 **             Notes:                                                                         **
 **                 Be sure MEM and OTH transforms are done last in each feature class.        **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                   **
 **                                                                                            **
 **  Development History:                                                                      **
 **  May 2015 / Annette Janett Filer                                                           **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os
import copy



current_include_source = "TDS 4.0"
current_include_target = "GGDM 3.0"



common_fields = [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None)  
]

common_geom_fields =  [
    ('FCSubtype', 'FCSubtype', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None), 
    ('SHAPE@', 'SHAPE@', None)
    ]

common_Pnt_fields = []

common_Crv_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None)
    ]

common_Srf_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None)
    ]


common_Tbl_fields = []

# ('GLOBALID', 'GLOBALID', None)
common_fields_ignore = ['shape@', 'shape@length', 'shape@area', 'fcsubtype', 'objectid', 'globalid']



# A dictionary of fields and values for default restriction information item
RestrictionInfoTargetDefaultFieldValues = {
    'CCN':'No Information',
    'CDR':'No Information',
    'F_CODE':'ZI002',
    'SAX_RY2':'noInformation',
    'SAX_RS1':'No Information',
    'SAX_RS2':'No Information',
    'SAX_RX9':'No Information',
    'SAX_RS4':'noInformation',
    'SAX_RS5':'No Information',
    'SAX_RS6':'noInformation',
    'SAX_RS8':'No Information',
    'SAX_RS9':'No Information',
    'SAX_RY0':'No Information',
    'SAX_RX1':'noInformation',
    'SAX_RX2':'noInformation',
    'SAX_RY1':'noInformation',
    'SAX_RX5':'noInformation',
    'SAX_RX7':'noInformation',
    'SAX_RX6':'noInformation',
    'UFI':'A9593791-4AE9-4180-8E1E-9CB3D239DEE5'
}

RestrictionInfoTblFields = [
    ('CCN','CCN',None),
    ('CDR','CDR',None),
    ('SAX_RS1','SAX_RS1',None),
    ('SAX_RS2','SAX_RS2',None),
    ('SAX_RS4','SAX_RS4',None),
    ('SAX_RS5','SAX_RS5',None),
    ('SAX_RS6','SAX_RS6',None),
    ('SAX_RS8','SAX_RS8',None),
    ('SAX_RS9','SAX_RS9',None),
    ('SAX_RX1','SAX_RX1',None),
    ('SAX_RX2','SAX_RX2',None),
    ('SAX_RX5','SAX_RX5',None),
    ('SAX_RX6','SAX_RX6',None),
    ('SAX_RX7','SAX_RX7',None),
    ('SAX_RX9','SAX_RX9',None),
    ('SAX_RY0','SAX_RY0',None),
    ('SAX_RY1','SAX_RY1',None),
    ('SAX_RY2','SAX_RY2',None),
    (None,'UFI','transform_placeholder_return_None'),
    (None,'F_CODE','transform_placeholder_return_None'),
    ('SAX_RX8',None,None),
    ('SAX_RS3',None,None)
]


# This is basically to get the CCN and CDR from dataset into Restriction Information.
# Other fields from dataset will be mapped to dataset.
XformDatasetToRestrictionInfoFields = [
    ('ZI002_CCN','CCN',None),
    ('ZI002_CDR','CDR',None),
    (None,'F_CODE','transform_set_to_default'),
    (None,'SAX_RS1',None),
    (None,'SAX_RS2',None),
    (None,'SAX_RS4',None),
    (None,'SAX_RS5',None),
    (None,'SAX_RS6',None),
    (None,'SAX_RS8',None),
    (None,'SAX_RS9',None),
    (None,'SAX_RX1',None),
    (None,'SAX_RX2',None),
    (None,'SAX_RX5',None),
    (None,'SAX_RX6',None),
    (None,'SAX_RX7',None),
    (None,'SAX_RX9',None),
    (None,'SAX_RY0',None),
    (None,'SAX_RY1',None),
    (None,'SAX_RY2',None),
    ('AHA',None,None),
    ('AVA',None,None),
    ('CID',None,None),
    ('CPS',None,None),
    ('DQS',None,None),
    ('EQC',None,None),
    ('ETS',None,None),
    ('ETZ',None,None),
    ('EVA',None,None),
    ('HVA',None,None),
    ('HZD',None,None),
    ('IC2',None,None),
    ('MDE',None,None),
    ('MEM',None,None),
    ('OTH',None,None),
    ('RCG',None,None),
    ('URI',None,None),
    ('VDT',None,None),
    ('ZSAX_RS0',None,None),
    ('ZSAX_RX3',None,None),
    ('ZSAX_RX4',None,None),
    (None,'UFI','transform_set_UFI') \
     ]


RestrictionInfoMetaConvertSubsetFields = [
    ('ZI002_CCN','CCN',None),
    ('ZI002_CDR','CDR',None)
    ]

RestrictionInfoFCSubsetFields = [
    ]



# It is critical that the target fields match the destination AND if
# the source is not actually present, the default value is set. We must
# have a value or the metadata processing code will fail. This can be very
# subtle. For instance ZI004_PRE is only in the MetadataSrf feature class.
# but we need to operate based on each feature and ZI004_PRE is not
# on individual features. The source should then be the source fields
# that are present on each feature, not the metadata entity itself.
# To process the metadata entity directly, use MetadataSrfFields.
EntityCollectionFields = [
    ('SHAPE@','SHAPE@', None),
    ('SHAPE@Length','SHAPE@Length',None),
    ('SHAPE@Area','SHAPE@Area',None),
    (None, 'ZI001_SRT', 'transform_ZI001_SRT'),
    (None, 'ZI001_SDV', 'transform_ZI001_SDV'),
    (None, 'ZI001_SDP', 'transform_ZI001_SDP'),
    (None,'ZI001_SPS','transform_ZI001_SPS'),
    ('F_CODE','F_CODE','transform_CollectionSrfMetadataSrf_F_CODE'),
    ('FCSubtype','FCSubType','transform_FCSubtype'),
    (None,'AHA','transform_set_EntityCollection_field_to_default'),
    (None,'AVA','transform_set_EntityCollection_field_to_default'),
    (None,'DQS','transform_set_EntityCollection_field_to_default'),
    (None,'EVA','transform_set_EntityCollection_field_to_default'),
    (None,'HVA','transform_set_EntityCollection_field_to_default'),
    (None,'MDE','transform_set_EntityCollection_field_to_default'),
    (None,'RCG','transform_set_EntityCollection_field_to_default'),
    (None,'SCVN','transform_set_schemaversion'),
    ('ZI001_NSD',None,None),
    ('ZI001_NSN',None,None),
    ('ZI001_NSP',None,None),
    ('ZI001_SSD',None,None),
    ('ZI001_SSN',None,None),
    ('ZI001_SSY',None,None),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    (None,'EQS','transform_set_EntityCollection_field_to_default'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromcodelisttoenum'),
    ('OTH','OTH','transform_OTH')
    ]



EntityCollectionTargetDefaultFieldValues = {
    'FCSubtype':132721,
    'AHA':-999999,
    'AVA':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'EVA':-999999,
    'F_CODE':'ZI039',
    'HVA':-999999,
    'MDE':'noInformation',
    'OTH':'noInformation',
    'RCG':-999999,
    'SCVN':'No Information',
    'UFI':'noInformation',
    'ZI001_SDP':'No Information',
    'ZI001_SPS':-999999,
    'ZI001_VSC':-999999,
    'ZI001_VSD':'noInformation',
    'ZI001_VSN':'No Information',
    'ZI004_PRE':'No Information'
    }

# These fields are examined in each source feature instance
# and they are used to extend the information in the
# Entity Collection Metadata records found in MetadataSrf
EntityCollectionMetaConvertSubsetFields = [
    ]

# These fields may be in each feature class instance and should
# be matched to a record in Entity Collection Metadata (MetadataSrf)
# if possible. Where there is no destination in each feature class
# in GGDM, the target is none.
EntityCollectionFCSubsetFields = [
    ]



# DatasetSrfResourceSrf field translations
DatasetSrfResourceSrfFields = [ \
    ('SHAPE@','SHAPE@', None),
    ('SHAPE@Length','SHAPE@Length',None),
    ('SHAPE@Area','SHAPE@Area',None),
    ('FCSubtype','FCSubType',None),
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('IC2',None,None),
    ('MDE','MDE',None),
    (None,'FURL',None),
    (None,'RTL',None),
    (None,'SCVN','transform_set_schemaversion'),
    (None,'ZI020_GE42',None),
    (None,'ZI020_GE43',None),
    (None,'ZI020_GE44',None),
    ('URI','URI',None),
    ('ZSAX_RS0','ZSAX_RS0',None), 
    ('ZSAX_RX3','ZSAX_RX3',None), 
    ('ZSAX_RX4','ZSAX_RX4',None),
    ('ZI002_CCN',None,'transform_put_source_to_OTH'),
    ('ZI002_CDR',None,'transform_put_source_to_OTH'),
    ('CPS','CPS','transformCPScodelist2CPSenumvalue'),
    ('EQC','EQS','transformEQCtoEQS'),
    ('ETS','ETS','transformETScodelist2ETSenumvalue'),
    ('HZD','HZD','transformHZDcodelist2HZDenumvalue'),
    (None,'ZI020_GE4','transform_GE4_from_IC2'),
    ('RCG','RCG','transformRCGcodelist2RCGenumvalue'),
    ('VDT','VDT','transformVDTcodelist2VDTenumvalue'),
    ('MEM','MEM','transform_MEM'),
    (None, 'ZI002_UFI', 'find_matchrestrictioninfoCCNCDR'),
    ('OTH','OTH','transform_OTH')
     ]


DatasetTargetDefaultFieldValues = {
    'FCSubType':121591,
    'AHA':-999999,
    'AVA':-999999,
    'CID':'No Information',
    'CPS':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'ETS':-999999,
    'ETZ':'No Information',
    'EVA':-999999,
    'F_CODE':'ZI031',
    'FURL':'noInformation',
    'HVA':-999999,
    'HZD':-999999,
    'MDE':'noInformation',
    'MEM':'No Information',
    'OTH':'noInformation',
    'RCG':-999999,
    'RTL':'No Information',
    'SCVN':'noInformation',
    'URI':'noInformation',
    'VDT':-999999,
    'ZI002_UFI':'noInformation',
    'ZI020_GE4':'noInformation',
    'ZI020_GE42':'noInformation',
    'ZI020_GE43':'noInformation',
    'ZI020_GE44':'noInformation',
    'ZSAX_RS0':'U',
    'ZSAX_RX0':'noInformation',
    'ZSAX_RX3':'noInformation',
    'ZSAX_RX4':'noInformation'
    }




#  group translations - CommonMetadata
commonMetadata = [
]

#  group translations - CommonTranslationGroup
CommonTranslationGroup = [ 
    (None,'ZI002_UFI','transform_find_restriction_info_id'), 
    (None,'ZI031S_URI','transform_find_entity_collection_id_by_shape'), 
    (None,'ZI039S_UFI','transform_find_dataset_id'),
    (None,'ZI026_CTUC',None), 
    (None,'ZI026_CTUL',None), 
    (None,'ZI026_CTUU',None),
    (None,'ZSAX_RX0',None),
    ('ZI004_RCG','ZI004_RCG','transformZI004_RCGfromcodelisttoenum'), 
    ('ZSAX_RS0','ZSAX_RS0',None), 
    ('ZSAX_RX3','ZSAX_RX3',None), 
    ('ZSAX_RX4','ZSAX_RX4',None),
    ('ZI006_MEM','ZI006_MEM','transform_MEM'), 
    ('OTH','OTH','transform_OTH')
]

#  group translations - EntityCollectionOnFeature
EntityCollectionOnFeature = [ 
    (None,'ZI001_SDV','transform_ZI001_SDV'), 
    (None,'ZI001_SRT','transform_ZI001_SRT')
]

#  group translations - RestrictionInfoMoveToTbl
RestrictionInfoMoveToTbl = [ 
    (None,'CCN',None), 
    (None,'CDR',None)
]


common_metadata_translate_fields = copy.deepcopy(EntityCollectionOnFeature) + copy.deepcopy(CommonTranslationGroup)


# CollectionSrfMetadataSrf field translations
CollectionMetadataSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('F_CODE','F_CODE','transform_CollectionSrfMetadataSrf_F_CODE'),
    (None,'AHA',None),
    (None,'AVA',None),
    (None,'DQS',None),
    (None,'EVA',None),
    (None,'HVA',None),
    (None,'MDE',None),
    (None,'SCVN','transform_set_schemaversion'),
    ('ZI001_NSD',None,None),
    ('ZI001_NSN','ZI001_SDP',None),
    ('ZI001_NSP',None,None),
    ('ZI001_SSD',None,None),
    ('ZI001_SSN','ZI001_SDP',None),
    ('ZI001_SSY',None,None),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    (None,'EQS',None),
    (None,'RCG',None),
    (None,'ZI001_SDP','transform_ZI001_SDP'),
    (None,'ZI001_SPS','transform_ZI001_SPS'),
    ('UFI','UFI',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromcodelisttoenum')
     ]

# ConstraintTbl field translations
ConstraintTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    (None,'F_CODE',None),
    (None,'SAX_RS1',None),
    (None,'SAX_RS2',None),
    (None,'SAX_RS4',None),
    (None,'SAX_RS5',None),
    (None,'SAX_RS6',None),
    (None,'SAX_RS8',None),
    (None,'SAX_RS9',None),
    (None,'SAX_RX1',None),
    (None,'SAX_RX2',None),
    (None,'SAX_RX5',None),
    (None,'SAX_RX6',None),
    (None,'SAX_RX7',None),
    (None,'SAX_RX9',None),
    (None,'SAX_RY0',None),
    (None,'SAX_RY1',None),
    (None,'SAX_RY2',None),
    (None,'UFI','transform_set_UFI') \
     ]


# ---------------- Generated data


# AeronauticCrv field translations
AeronauticCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AXS','AXS',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'SBB',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('TXP','TXP',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPnt field translations
AeronauticPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FPT','FPT',None),
    ('GUG','GUG',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ','LASZ',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('PYM','PYM',None),
    ('TOS','TOS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI103_MVD','ZI103_MVD',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPntExt field translations
AeronauticPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('ART','ART',None),
    ('ASO','ASO',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CHA','CHA',None),
    ('CMS','CMS',None),
    ('COL','COL',None),
    ('DIA','DIA',None),
    ('DIR','DIR',None),
    ('F_CODE','F_CODE',None),
    ('GA032_NSX','GA032_NSX',None),
    ('GB001_AID','GB001_AID',None),
    ('HGT','HGT',None),
    ('LCN','LCN',None),
    ('LZN','LZN',None),
    ('MCA','MCA',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PER','PER',None),
    ('PRM','PRM',None),
    ('PWR','PWR',None),
    ('RAC','RAC',None),
    ('RSI','RSI',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('VIS','VIS',None),
    ('VIS2','VIS2',None),
    ('VIS3','VIS3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COC','COC','transform_missing_enum_index_with_warnings'),
    ('COS','COS','transform_COS'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrf field translations
AeronauticSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('APY','APY',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('CAA','CAA',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FPT','FPT',None),
    ('GB052_RIDH','GB052_RIDH',None),
    ('GB052_RIDL','GB052_RIDL',None),
    ('GB052_TRHH','GB052_TRHH',None),
    ('GB052_TRHL','GB052_TRHL',None),
    ('GSGCHC','GSGCHC',None),
    ('GSGCHL','GSGCHL',None),
    ('GSGCHU','GSGCHU',None),
    ('GSGCLC','GSGCLC',None),
    ('GSGCLL','GSGCLL',None),
    ('GSGCLU','GSGCLU',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LASZ','LASZ',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    (None,'APU',None),
    (None,'APU2',None),
    (None,'APU3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'SBB',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('SERP','SERP',None),
    ('TXP','TXP',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI103_MVD','ZI103_MVD',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('ASU','ASU','transform_ASU'),
    ('ASU2','ASU2','transform_ASU'),
    ('ASU3','ASU3','transform_ASU'),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrfExt field translations
AeronauticSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePnt field translations
AgriculturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI018_WIT',None,None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI013_PIG','transform_ZI013_PIG'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePntExt field translations
AgriculturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZVH','ZVH',None),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgricultureSrf field translations
AgricultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI018_WIT',None,None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI013_PIG','transform_ZI013_PIG'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryCrvExt field translations
BoundaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('BAL','FA003_BAL',None),
    ('BST','BST',None),
    ('CAA','CAA',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('LSP','LSP',None),
    ('LZN','LZN',None),
    ('MGL','MGL',None),
    ('MGL2','MGL2',None),
    ('MGL3','MGL3',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNTA',None),
    (None,'ZI005_GNTB',None),
    (None,'ZI020_FI2A',None),
    (None,'ZI020_FI2B',None),
    (None,'ZI020_GE4A',None),
    (None,'ZI020_GE4B',None),
    ('RPC','RPC',None),
    ('ZI005_FNAA','ZI005_FNAA',None),
    ('ZI005_FNAB','ZI005_FNAB',None),
    ('ZI005_NFNA','ZI005_NFNA',None),
    ('ZI005_NFNB','ZI005_NFNB',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryPnt field translations
BoundaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA',None,None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrf field translations
BoundarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('LGDR','CDM',None),
    ('LGID','CSI',None),
    (None,'BEN',None),
    (None,'CDY',None),
    (None,'CSY',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrfExt field translations
BoundarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('GEC','GEC',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'PPL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI020_IC4',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)


# CultureCrv field translations
CultureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('SSC','SSC',None),
    ('TOS','TOS',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePnt field translations
CulturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CCG','CCG',None),
    ('CSO','CSO',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'SDQ',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePntExt field translations
CulturePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('CUL','CUL',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrf field translations
CultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CAM','CAM',None),
    ('CCG','CCG',None),
    ('CSO','CSO',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'SDQ',None),
    (None,'TRE',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrfIndustrySrf field translations
CultureSrfIndustrySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE','transform_Industry_F_CODE'),
    ('ADI',None,None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CAM',None,None),
    ('CCG',None,None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('CSO',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HEI',None,None),
    ('HGT','HGT',None),
    ('HSS',None,None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    (None,'AZC',None),
    (None,'BEN',None),
    (None,'BNF',None),
    (None,'CNCP',None),
    (None,'CRA',None),
    (None,'CRM',None),
    (None,'FURL',None),
    (None,'HST',None),
    (None,'HST2',None),
    (None,'HST3',None),
    (None,'LCA',None),
    (None,'PBY',None),
    (None,'PBY2',None),
    (None,'PBY3',None),
    (None,'PPO',None),
    (None,'PPO2',None),
    (None,'PPO3',None),
    (None,'PRW',None),
    (None,'PRW2',None),
    (None,'PRW3',None),
    (None,'UMA',None),
    (None,'VCM',None),
    (None,'VCM2',None),
    (None,'VCM3',None),
    (None,'WDAC',None),
    (None,'WDAL',None),
    (None,'WDAU',None),
    (None,'ZI005_GNT',None),
    (None,'ZI014_PPO',None),
    (None,'ZI014_PPO2',None),
    (None,'ZI014_PPO3',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('SRL','SRL',None),
    ('SSC',None,None),
    ('SSR',None,None),
    ('SSR2',None,None),
    ('SSR3',None,None),
    ('TOS',None,None),
    ('TTY',None,None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_YWQ',None,None),
    ('ZI037_REL',None,None),
    ('ZI037_RFA',None,None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    ('MZN','MZN','transform_MZN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'MZN','transform_MZN'),
    (None,'TRS','transform_TRS'),
    (None,'TRS2','transform_TRS'),
    (None,'TRS3','transform_TRS'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrfExt field translations
CultureSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('CUL','CUL',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)


# FacilityPnt field translations
FacilityPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'ADUR',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'WLSS',None),
    (None,'WSRC',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAC',None,None),
    ('RAS','RAS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilitySrf field translations
FacilitySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'ADUR',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'WLSS',None),
    (None,'WSRC',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAC',None,None),
    ('RAS','RAS',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationCrvExt field translations
HydroAidNavigationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('BRR','BRR',None),
    ('F_CODE','F_CODE',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPnt field translations
HydroAidNavigationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC034_BRF','BC034_BRF',None),
    ('BC034_BRF2','BC034_BRF2',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC040_COL','BC040_COL',None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_MLR','BC040_MLR',None),
    ('BC040_PER','BC040_PER',None),
    ('BC101_SST','BC101_SST',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('REF','REF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('BC040_LVN','BC040_LVN','transform_LVN'),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPntExt field translations
HydroAidNavigationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('BC010_REF','BC010_REF',None),
    ('BC010_TZP','BC010_TZP',None),
    ('BC034_BRF','BC034_BRF',None),
    ('BC034_BRF2','BC034_BRF2',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC040_CAA','BC040_CAA',None),
    ('BC040_COL','BC040_COL',None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_MLR','BC040_MLR',None),
    ('BC040_ZVH','BC040_ZVH',None),
    ('BC101_SST','BC101_SST',None),
    ('BRF','BRF',None),
    ('BRF2','BRF2',None),
    ('BUS','BUS',None),
    ('BUT','BUT',None),
    ('CAA','CAA',None),
    ('CCR','CCR',None),
    ('COL','COL',None),
    ('CPT','CPT',None),
    ('CSS','CSS',None),
    ('DKS','DKS',None),
    ('EOL','EOL',None),
    ('F_CODE','F_CODE',None),
    ('FLT','FLT',None),
    ('GUG','GUG',None),
    ('HBH','HBH',None),
    ('HGT','HGT',None),
    ('IAA','IAA',None),
    ('IAS','IAS',None),
    ('LFC','LFC',None),
    ('LFC2','LFC2',None),
    ('LFC3','LFC3',None),
    ('LSA','LSA',None),
    ('LSI','LSI',None),
    ('LST','LST',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLR','MLR',None),
    ('MRP','MRP',None),
    ('MRT','MRT',None),
    ('NMC','NMC',None),
    ('NMC2','NMC2',None),
    ('NMC3','NMC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'VOI',None),
    (None,'ZI005_GNT',None),
    ('NSC','NSC',None),
    ('ORC','ORC',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('REF','REF',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('STA','STA',None),
    ('STA2','STA2',None),
    ('STA3','STA3',None),
    ('TOS','TOS',None),
    ('WID','WID',None),
    ('ZHBH_DCR','ZHBH_DCR',None),
    ('ZHBH_DKC','ZHBH_DKC',None),
    ('ZHBH_DKC2','ZHBH_DKC2',None),
    ('ZHBH_DKC3','ZHBH_DKC3',None),
    ('ZHBH_SVC','ZHBH_SVC',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHBH_VDC','ZHBH_VDC',None),
    ('ZHBH_VDR','ZHBH_VDR',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_BRF','ZI018_BRF',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZVH','ZVH',None),
    ('BC040_LVN','BC040_LVN','transform_LVN'),
    ('BET','BET','transform_missing_enum_index_with_warnings'),
    ('COC','COC','transform_missing_enum_index_with_warnings'),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    ('LVN','LVN','transform_LVN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TZP','TZP','transform_missing_enum_index_with_warnings'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationSrf field translations
HydroAidNavigationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_PER','BC040_PER',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyAONExt field translations
HydrographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'AQN',None),
    (None,'ARA',None),
    (None,'ATC',None),
    (None,'AZC',None),
    (None,'BBMCA',None),
    (None,'BBMCA2',None),
    (None,'BBMCA3',None),
    (None,'BBMCB',None),
    (None,'BBMCB2',None),
    (None,'BBMCB3',None),
    (None,'BEN',None),
    (None,'BH141_AWBA',None),
    (None,'BH141_AWBB',None),
    (None,'BH141_IBOA',None),
    (None,'BH141_IBOB',None),
    (None,'BH141_SHDA',None),
    (None,'BH141_SHDB',None),
    (None,'BH141_SLTA',None),
    (None,'BH141_SLTB',None),
    (None,'BH141_WBHA',None),
    (None,'BH141_WBHB',None),
    (None,'BMC',None),
    (None,'BMC2',None),
    (None,'BMC3',None),
    (None,'BPWHAC',None),
    (None,'BPWHAL',None),
    (None,'BPWHAU',None),
    (None,'BPWHBC',None),
    (None,'BPWHBL',None),
    (None,'BPWHBU',None),
    (None,'BPWSAC',None),
    (None,'BPWSAL',None),
    (None,'BPWSAU',None),
    (None,'BPWSBC',None),
    (None,'BPWSBL',None),
    (None,'BPWSBU',None),
    (None,'BWVCAC',None),
    (None,'BWVCAL',None),
    (None,'BWVCAU',None),
    (None,'BWVCBC',None),
    (None,'BWVCBL',None),
    (None,'BWVCBU',None),
    (None,'CAA',None),
    (None,'CDA',None),
    (None,'CDL',None),
    (None,'CNCP',None),
    (None,'CWT',None),
    (None,'DEV',None),
    (None,'DIT',None),
    (None,'DMD',None),
    (None,'DMF',None),
    (None,'DOF',None),
    (None,'DOXY',None),
    (None,'DZP',None),
    (None,'F_CODE',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'HGT',None),
    (None,'IWT',None),
    (None,'LZN',None),
    (None,'MNS',None),
    (None,'MWD',None),
    (None,'NVS',None),
    (None,'PCF',None),
    (None,'PWA',None),
    (None,'PWAC',None),
    (None,'PWAL',None),
    (None,'PWAU',None),
    (None,'RLE',None),
    (None,'SBB',None),
    (None,'SWT',None),
    (None,'SWW',None),
    (None,'TID',None),
    (None,'TSSM',None),
    (None,'TSSM2',None),
    (None,'TSSM3',None),
    (None,'VCM',None),
    (None,'VCM2',None),
    (None,'VCM3',None),
    (None,'WAD',None),
    (None,'WD3',None),
    (None,'WDAC',None),
    (None,'WDAL',None),
    (None,'WDAU',None),
    (None,'WDH',None),
    (None,'WDL',None),
    (None,'WDST',None),
    (None,'WFT',None),
    (None,'WID',None),
    (None,'WMT',None),
    (None,'WVA',None),
    (None,'WVH',None),
    (None,'WVL',None),
    (None,'WWM',None),
    (None,'WWM2',None),
    (None,'WWM3',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_AWO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_DRL',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_RTP',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SQN',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WPAC',None),
    (None,'ZI024_WSG',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI024_YWQ',None),
    (None,'ZI025_HDP',None),
    (None,'ZVH',None),
    (None,'COS','transform_COS'),
    (None,'FFN','transform_FFN_932_and_TRS'),
    (None,'FFN2','transform_FFN_932_and_TRS'),
    (None,'FFN3','transform_FFN_932_and_TRS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LOC','transform_LOC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'PMPR','transform_PMPR'),
    (None,'UFI','transform_set_UFI'),
    (None,'VLM','transform_VLM_fromInterval'),
    (None,'WCC','transform_missing_enum_index_with_warnings'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_HYP','transform_ZI024_HYP'),
    (None,'ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrv field translations
HydrographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DIM','DIM',None),
    ('DSD','DSD',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DFU2',None),
    (None,'DFU3',None),
    (None,'DIT',None),
    (None,'DOXY',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'STNB',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('TRA',None,None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WD5',None,None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WRT','WRT',None),
    ('WST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PAC','ZI024_WPAC',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('DWT','DFU','transformDWT_to_DFU'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LDC','transform_LDC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('WCC','WCC','transform_missing_enum_index_with_warnings'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrvExt field translations
HydrographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('BDS','BDS',None),
    ('BRG','BRG',None),
    ('BRR','BRR',None),
    ('BRS','BRS',None),
    ('CAA','CAA',None),
    ('CFT','CFT',None),
    ('CRV','CRV',None),
    ('DAN','DAN',None),
    ('DMC','DMC',None),
    ('DOF','DOF',None),
    ('DPG','DPG',None),
    ('DPG2','DPG2',None),
    ('DPG3','DPG3',None),
    ('DRP','DRP',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('IAS','IAS',None),
    ('LAF','LAF',None),
    ('LOR','LOR',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MAS','MAS',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCY','MCY',None),
    ('MCY2','MCY2',None),
    ('MCY3','MCY3',None),
    ('MLO','MLO',None),
    ('MNR','MNR',None),
    ('MNR2','MNR2',None),
    ('MNR3','MNR3',None),
    ('MRR','MRR',None),
    ('MRR2','MRR2',None),
    ('MRR3','MRR3',None),
    ('NFP','NFP',None),
    ('NFP2','NFP2',None),
    ('NFP3','NFP3',None),
    ('NOA','NOA',None),
    ('NOA2','NOA2',None),
    ('NOA3','NOA3',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('RTT','RTT',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('WID','WID',None),
    ('WTT','WTT',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI012_DCR','ZI012_DCR',None),
    ('ZI012_DKC','ZI012_DKC',None),
    ('ZI012_DKC2','ZI012_DKC2',None),
    ('ZI012_DKC3','ZI012_DKC3',None),
    ('ZI012_SVC','ZI012_SVC',None),
    ('ZI012_TEC','ZI012_TEC',None),
    ('ZI012_TEC2','ZI012_TEC2',None),
    ('ZI012_TEC3','ZI012_TEC3',None),
    ('ZI012_VDR','ZI012_VDR',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI012_VDC','ZI012_VDC','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPnt field translations
HydrographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC101_SST','BC101_SST',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('DFT','DFT',None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DSD','DSD',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('IWT','IWT',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    (None,'BEN',None),
    (None,'BH010_CAA',None),
    (None,'CDI',None),
    (None,'CNCP',None),
    (None,'DFU2',None),
    (None,'DFU3',None),
    (None,'DOXY',None),
    (None,'DWL',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'PUD',None),
    (None,'SCOG',None),
    (None,'TSSM',None),
    (None,'TSSM2',None),
    (None,'TSSM3',None),
    (None,'TSTE',None),
    (None,'WCAC',None),
    (None,'WDST',None),
    (None,'WHCO',None),
    (None,'WODR',None),
    (None,'WTBB',None),
    (None,'WTCA',None),
    (None,'WTCL',None),
    (None,'WTFE',None),
    (None,'WTKK',None),
    (None,'WTMN',None),
    (None,'WTNA',None),
    (None,'WTNO',None),
    (None,'WTPO',None),
    (None,'WTSI',None),
    (None,'WTST',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTBB',None),
    (None,'ZI024_WTCA',None),
    (None,'ZI024_WTFE',None),
    (None,'ZI024_WTKK',None),
    (None,'ZI024_WTMN',None),
    (None,'ZI024_WTNA',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WTPO',None),
    (None,'ZI024_WTSI',None),
    (None,'ZI024_WUR4',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WD5',None,None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WFT','WFT',None),
    ('WID','WID',None),
    ('WOC','WOC',None),
    ('WST','WST',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('WWM','WWM',None),
    ('WWM2','WWM2',None),
    ('WWM3','WWM3',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVT','ZI024_DVPT',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PAC','ZI024_WPAC',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_RTP','ZI024_RTP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('DWT','DFU','transformDWT_to_DFU'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LDC','transform_LDC'),
    (None,'PMPR','transform_PMPR'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP'),
    ('ZI024_PMP','ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPntExt field translations
HydrographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('C35','C35',None),
    ('C36','C36',None),
    ('C37','C37',None),
    ('C38','C38',None),
    ('C39','C39',None),
    ('C40','C40',None),
    ('C41','C41',None),
    ('C42','C42',None),
    ('C43','C43',None),
    ('C44','C44',None),
    ('C45','C45',None),
    ('C46','C46',None),
    ('CAA','CAA',None),
    ('CRN','CRN',None),
    ('CRS','CRS',None),
    ('CRX','CRX',None),
    ('CUR','CUR',None),
    ('D35','D35',None),
    ('D36','D36',None),
    ('D37','D37',None),
    ('D38','D38',None),
    ('D39','D39',None),
    ('D40','D40',None),
    ('D41','D41',None),
    ('D42','D42',None),
    ('D43','D43',None),
    ('D44','D44',None),
    ('D45','D45',None),
    ('D46','D46',None),
    ('DKC','DKC',None),
    ('DKC2','DKC2',None),
    ('DKC3','DKC3',None),
    ('DOF','DOF',None),
    ('DTN','DTN',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('HDH','HDH',None),
    ('HDP','HDP',None),
    ('HSE','HSE',None),
    ('IAS','IAS',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('REW','REW',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WID','WID',None),
    ('WLO','WLO',None),
    ('WTT','WTT',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_UHS','ZI025_UHS',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('COS','COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrf field translations
HydrographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC034_MRT2','BC034_MRT2',None),
    ('BC034_MRT3','BC034_MRT3',None),
    ('BC101_SST','BC101_SST',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CNS',None,None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DSD','DSD',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('HDP','HDP',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('INU','INU',None),
    ('IWT','IWT',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('MWD','MWD',None),
    (None,'BEN',None),
    (None,'CDI',None),
    (None,'CNCP',None),
    (None,'DFU2',None),
    (None,'DFU3',None),
    (None,'DIT',None),
    (None,'DOXY',None),
    (None,'DWL',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'PUD',None),
    (None,'SCOG',None),
    (None,'STNB',None),
    (None,'TSSM',None),
    (None,'TSSM2',None),
    (None,'TSSM3',None),
    (None,'TSTE',None),
    (None,'WCAC',None),
    (None,'WDST',None),
    (None,'WHCO',None),
    (None,'WODR',None),
    (None,'WTBB',None),
    (None,'WTCA',None),
    (None,'WTCL',None),
    (None,'WTFE',None),
    (None,'WTKK',None),
    (None,'WTMN',None),
    (None,'WTNA',None),
    (None,'WTNO',None),
    (None,'WTPO',None),
    (None,'WTSI',None),
    (None,'WTST',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTBB',None),
    (None,'ZI024_WTCA',None),
    (None,'ZI024_WTFE',None),
    (None,'ZI024_WTKK',None),
    (None,'ZI024_WTMN',None),
    (None,'ZI024_WTNA',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WTPO',None),
    (None,'ZI024_WTSI',None),
    (None,'ZI024_WUR4',None),
    ('NVS','NVS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('TID','TID',None),
    ('TRA',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WD3','WD3',None),
    ('WD5',None,None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WFT','WFT',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WST',None,None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('WWM','WWM',None),
    ('WWM2','WWM2',None),
    ('WWM3','WWM3',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVT','ZI024_DVPT',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PAC','ZI024_WPAC',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_RTP','ZI024_RTP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('DWT','DFU','transformDWT_to_DFU'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LDC','transform_LDC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('WCC','WCC','transform_missing_enum_index_with_warnings'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP'),
    ('ZI024_PMP','ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrfSubterraneanSrf field translations
HydrographySrfSubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO',None,None),
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('ATC',None,None),
    ('AWP',None,None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('AZC',None,None),
    ('BA000_VDC',None,None),
    ('BA000_VDR',None,None),
    ('BH141_AWBA',None,None),
    ('BH141_AWBB',None,None),
    ('BH141_IBOA',None,None),
    ('BH141_IBOB',None,None),
    ('BH141_SHDA',None,None),
    ('BH141_SHDB',None,None),
    ('BH141_SLTA',None,None),
    ('BH141_SLTB',None,None),
    ('BH141_WBHA',None,None),
    ('BH141_WBHB',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BPWHAC',None,None),
    ('BPWHAL',None,None),
    ('BPWHAU',None,None),
    ('BPWHBC',None,None),
    ('BPWHBL',None,None),
    ('BPWHBU',None,None),
    ('BPWSAC',None,None),
    ('BPWSAL',None,None),
    ('BPWSAU',None,None),
    ('BPWSBC',None,None),
    ('BPWSBL',None,None),
    ('BPWSBU',None,None),
    ('BWVCAC',None,None),
    ('BWVCAL',None,None),
    ('BWVCAU',None,None),
    ('BWVCBC',None,None),
    ('BWVCBL',None,None),
    ('BWVCBU',None,None),
    ('CAA','CAA',None),
    ('CDA',None,None),
    ('CET',None,None),
    ('CNS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DMD',None,None),
    ('DOF',None,None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DWT',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FIC',None,None),
    ('GOT',None,None),
    ('HGT',None,None),
    ('IWT',None,None),
    ('LEA','LEA',None),
    ('LMC',None,None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MNS',None,None),
    (None,'AQP2',None),
    (None,'AQP3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'CNF',None),
    (None,'FURL',None),
    (None,'GWTR',None),
    (None,'HYCD',None),
    (None,'SWCP',None),
    (None,'WRCC',None),
    (None,'WRCL',None),
    (None,'WRCU',None),
    (None,'WWRC',None),
    (None,'WWRL',None),
    (None,'WWRU',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI071_CTX',None),
    (None,'ZI071_FFN',None),
    (None,'ZI071_FFN2',None),
    (None,'ZI071_FFN3',None),
    (None,'ZI071_UAO',None),
    ('NVS',None,None),
    ('OCS',None,None),
    ('PCF','PCF',None),
    ('PFD',None,None),
    ('PFH',None,None),
    ('PWA',None,None),
    ('RKF',None,None),
    ('RLE',None,None),
    ('SAD',None,None),
    ('SBB',None,None),
    ('SDCC',None,None),
    ('SDCL',None,None),
    ('SDCU',None,None),
    ('SDO',None,None),
    ('SDT',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('SHD',None,None),
    ('SIC',None,None),
    ('SLT',None,None),
    ('SRD',None,None),
    ('SSE',None,None),
    ('STP',None,None),
    ('SWC',None,None),
    ('SWT',None,None),
    ('SWW',None,None),
    ('TID',None,None),
    ('TRA',None,None),
    ('TRS',None,None),
    ('TRS2',None,None),
    ('TRS3',None,None),
    ('TSM',None,None),
    ('TSM2',None,None),
    ('TSM3',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('VLM',None,None),
    ('VOI',None,None),
    ('WAD',None,None),
    ('WCC',None,None),
    ('WD3',None,None),
    ('WD5',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WFT',None,None),
    ('WID','WID',None),
    ('WLE',None,None),
    ('WMT',None,None),
    ('WST',None,None),
    ('WVA',None,None),
    ('WVH',None,None),
    ('WVL',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH',None,None),
    ('COS','COS','transform_COS'),
    ('GWS','GWS','transform_GWS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrfExt field translations
HydrographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AQF','AQF',None),
    ('ARA','ARA',None),
    ('BDS','BDS',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BRR','BRR',None),
    ('BRS','BRS',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('COG','COG',None),
    ('DAN','DAN',None),
    ('DKC','DKC',None),
    ('DKC2','DKC2',None),
    ('DKC3','DKC3',None),
    ('DOF','DOF',None),
    ('DRP','DRP',None),
    ('DTN','DTN',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('HDP','HDP',None),
    ('IAS','IAS',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('MAS','MAS',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCY','MCY',None),
    ('MCY2','MCY2',None),
    ('MCY3','MCY3',None),
    ('MFE','MFE',None),
    ('MLO','MLO',None),
    ('MNR','MNR',None),
    ('MNR2','MNR2',None),
    ('MNR3','MNR3',None),
    ('MRR','MRR',None),
    ('MRR2','MRR2',None),
    ('MRR3','MRR3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DOXY',None),
    (None,'FURL',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    ('OPT','OPT',None),
    ('ORS','ORS',None),
    ('ORS2','ORS2',None),
    ('ORS3','ORS3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RTT','RTT',None),
    ('TAN','TAN',None),
    ('TSP','TSP',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WLO','WLO',None),
    ('WPC','WPC',None),
    ('WPC2','WPC2',None),
    ('WPC3','WPC3',None),
    ('WTT','WTT',None),
    ('ZHBH_TEC','ZHBH_TEC',None),
    ('ZHBH_TEC2','ZHBH_TEC2',None),
    ('ZHBH_TEC3','ZHBH_TEC3',None),
    ('ZHDP_DCR','ZHDP_DCR',None),
    ('ZHDP_DKC','ZHDP_DKC',None),
    ('ZHDP_DKC2','ZHDP_DKC2',None),
    ('ZHDP_DKC3','ZHDP_DKC3',None),
    ('ZHDP_SVC','ZHDP_SVC',None),
    ('ZHDP_TEC','ZHDP_TEC',None),
    ('ZHDP_TEC2','ZHDP_TEC2',None),
    ('ZHDP_TEC3','ZHDP_TEC3',None),
    ('ZHDP_VDC','ZHDP_VDC',None),
    ('ZHDP_VDR','ZHDP_VDR',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('COA','COA','transform_missing_enum_index_with_warnings'),
    ('COC','COC','transform_missing_enum_index_with_warnings'),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyCrv field translations
HypsographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('HQC','HQC',None),
    (None,'BEN',None),
    (None,'FURL',None),
    ('ZVH','ZVH',None),
    ('ESC','ESC','transform_ESC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPnt field translations
HypsographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE','transform_Hypsography_F_CODE'),
    ('BEL','BEL',None),
    ('CPA',None,None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('ZVH_AVA','ZVH_AVA',None),
    ('ESC','ESC','transform_ESC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'SUY','transform_SUYfromCPA'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZVH_VDT','ZVH_VDT','transformVDTcodelist2VDTenumvalue') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPntExt field translations
HypsographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('CPA','CPA',None),
    ('F_CODE','F_CODE',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryCrv field translations
IndustryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'CVT2',None),
    (None,'CVT3',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'CVT','transform_CVT'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPnt field translations
IndustryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE','transform_Industry_F_CODE'),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('GUG','GUG',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'CVT2',None),
    (None,'CVT3',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('RIP','RIP',None),
    ('SRL','SRL',None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WEQ','WEQ',None),
    ('WEQ2','WEQ2',None),
    ('WEQ3','WEQ3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    ('MZN','MZN','transform_MZN'),
    (None,'CVT','transform_CVT'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPntExt field translations
IndustryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustrySrf field translations
IndustrySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE','transform_Industry_F_CODE'),
    ('ADI',None,None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('CAM',None,None),
    ('CCG',None,None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('CSO',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HEI',None,None),
    ('HGT','HGT',None),
    ('HSS',None,None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    (None,'AZC',None),
    (None,'BEN',None),
    (None,'BNF',None),
    (None,'CNCP',None),
    (None,'CRA',None),
    (None,'CRM',None),
    (None,'FURL',None),
    (None,'HST',None),
    (None,'HST2',None),
    (None,'HST3',None),
    (None,'LCA',None),
    (None,'PBY',None),
    (None,'PBY2',None),
    (None,'PBY3',None),
    (None,'PPO',None),
    (None,'PPO2',None),
    (None,'PPO3',None),
    (None,'PRW',None),
    (None,'PRW2',None),
    (None,'PRW3',None),
    (None,'UMA',None),
    (None,'VCM',None),
    (None,'VCM2',None),
    (None,'VCM3',None),
    (None,'WDAC',None),
    (None,'WDAL',None),
    (None,'WDAU',None),
    (None,'ZI005_GNT',None),
    (None,'ZI014_PPO',None),
    (None,'ZI014_PPO2',None),
    (None,'ZI014_PPO3',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('SRL','SRL',None),
    ('SSC',None,None),
    ('SSR',None,None),
    ('SSR2',None,None),
    ('SSR3',None,None),
    ('TOS',None,None),
    ('TTY',None,None),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_YWQ',None,None),
    ('ZI037_REL',None,None),
    ('ZI037_RFA',None,None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    ('MZN','MZN','transform_MZN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'MZN','transform_MZN'),
    (None,'TRS','transform_TRS'),
    (None,'TRS2','transform_TRS'),
    (None,'TRS3','transform_TRS'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrv field translations
InformationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNR',None),
    (None,'ZI005_GNR2',None),
    (None,'ZI005_GNR3',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI015_GCUC',None),
    (None,'ZI015_GCUL',None),
    (None,'ZI015_GCUU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrvExt field translations
InformationCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('NLT','NLT',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNR',None),
    (None,'ZI005_GNR2',None),
    (None,'ZI005_GNR3',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI015_GCUC',None),
    (None,'ZI015_GCUL',None),
    (None,'ZI015_GCUU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationPnt field translations
InformationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('NLT','NLT',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNR',None),
    (None,'ZI005_GNR2',None),
    (None,'ZI005_GNR3',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI015_GCUC',None),
    (None,'ZI015_GCUL',None),
    (None,'ZI015_GCUU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrf field translations
InformationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNR',None),
    (None,'ZI005_GNR2',None),
    (None,'ZI005_GNR3',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI015_GCUC',None),
    (None,'ZI015_GCUL',None),
    (None,'ZI015_GCUU',None),
    ('VCA','VCA',None),
    ('VCA2','VCA2',None),
    ('VCA3','VCA3',None),
    ('VCT','VCT',None),
    ('VCT2','VCT2',None),
    ('VCT3','VCT3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrfExt field translations
InformationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('NLT','NLT',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNR',None),
    (None,'ZI005_GNR2',None),
    (None,'ZI005_GNR3',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI015_GCUC',None),
    (None,'ZI015_GCUL',None),
    (None,'ZI015_GCUU',None),
    ('VAVC','VAVC',None),
    ('VAVL','VAVL',None),
    ('VAVU','VAVU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MetadataTbl field translations
MetadataTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    (None,'AHA',None),
    (None,'AVA',None),
    (None,'DQS',None),
    (None,'EVA',None),
    (None,'F_CODE',None),
    (None,'HVA',None),
    (None,'MDE',None),
    (None,'SCVN',None),
    (None,'ZI001_VSD',None),
    (None,'ZI001_VSN',None),
    (None,'ZI004_PRE',None),
    (None,'EQS','transformEQCtoEQS'),
    (None,'RCG','transformRCGcodelist2RCGenumvalue'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI001_SDP','transform_ZI001_SDP'),
    (None,'ZI001_SPS','transform_ZI001_SPS'),
    (None,'ZI001_VSC','transformZI001_VSCfromcodelisttoenum') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrv field translations
MilitaryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'VOI',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryCrvExt field translations
MilitaryCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('CAA','CAA',None),
    ('DSP','DSP',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    ('MLUS','MLUS',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNTA',None),
    (None,'ZI005_GNTB',None),
    (None,'ZI020_FI2A',None),
    (None,'ZI020_FI2B',None),
    (None,'ZI020_GE4A',None),
    (None,'ZI020_GE4B',None),
    ('ZI005_FNAA','ZI005_FNAA',None),
    ('ZI005_FNAB','ZI005_FNAB',None),
    ('ZI005_NFNA','ZI005_NFNA',None),
    ('ZI005_NFNB','ZI005_NFNB',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPnt field translations
MilitaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FZR','FZR',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP','MLOP',None),
    ('MLUS','MLUS',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPntExt field translations
MilitaryPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    ('PCF','PCF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrf field translations
MilitarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FZR','FZR',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MLOP','MLOP',None),
    ('MLUS','MLUS',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrfExt field translations
MilitarySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    ('PCF','PCF',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyAONExt field translations
PhysiographyAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'BEN',None),
    (None,'DMF',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'LZN',None),
    (None,'WID',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrv field translations
PhysiographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('CET','CET',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('GFT','GFT',None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FDI',None),
    (None,'FURL',None),
    (None,'GFY',None),
    (None,'SDI',None),
    (None,'SHO',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrvExt field translations
PhysiographyCrvExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AZC','AZC',None),
    ('F_CODE','F_CODE',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_NFN',None),
    ('SLT','SLT',None),
    ('SSE','SSE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPnt field translations
PhysiographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('DOF','DOF',None),
    ('F_CODE','F_CODE',None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'FURL',None),
    (None,'ZI024_AWO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('OHC','OHC',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    ('ZVH','ZVH',None),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPntExt field translations
PhysiographyPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PFD','PFD',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrf field translations
PhysiographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('CET','CET',None),
    ('DOF','DOF',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LND','LND',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI024_AWO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SAD','SAD',None),
    ('SDCC','SDCC',None),
    ('SDCL','SDCL',None),
    ('SDCU','SDCU',None),
    ('SDO','SDO',None),
    ('SDT','SDT',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SIC','SIC',None),
    ('SLT','SLT',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('SRD','SRD',None),
    ('SSE','SSE',None),
    ('STP','STP',None),
    ('SWC','SWC',None),
    ('TSM','TSM',None),
    ('TSM2','TSM2',None),
    ('TSM3','TSM3',None),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrfSubterraneanSrf field translations
PhysiographySrfSubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO',None,None),
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('ATC',None,None),
    ('AWP',None,None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('AZC',None,None),
    ('BA000_VDC',None,None),
    ('BA000_VDR',None,None),
    ('BH141_AWBA',None,None),
    ('BH141_AWBB',None,None),
    ('BH141_IBOA',None,None),
    ('BH141_IBOB',None,None),
    ('BH141_SHDA',None,None),
    ('BH141_SHDB',None,None),
    ('BH141_SLTA',None,None),
    ('BH141_SLTB',None,None),
    ('BH141_WBHA',None,None),
    ('BH141_WBHB',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BPWHAC',None,None),
    ('BPWHAL',None,None),
    ('BPWHAU',None,None),
    ('BPWHBC',None,None),
    ('BPWHBL',None,None),
    ('BPWHBU',None,None),
    ('BPWSAC',None,None),
    ('BPWSAL',None,None),
    ('BPWSAU',None,None),
    ('BPWSBC',None,None),
    ('BPWSBL',None,None),
    ('BPWSBU',None,None),
    ('BWVCAC',None,None),
    ('BWVCAL',None,None),
    ('BWVCAU',None,None),
    ('BWVCBC',None,None),
    ('BWVCBL',None,None),
    ('BWVCBU',None,None),
    ('CAA','CAA',None),
    ('CDA',None,None),
    ('CET',None,None),
    ('CNS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DMD',None,None),
    ('DOF',None,None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DWT',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FIC',None,None),
    ('GOT',None,None),
    ('HGT',None,None),
    ('IWT',None,None),
    ('LEA','LEA',None),
    ('LMC',None,None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MNS',None,None),
    (None,'AQP2',None),
    (None,'AQP3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'CNF',None),
    (None,'FURL',None),
    (None,'GWTR',None),
    (None,'HYCD',None),
    (None,'SWCP',None),
    (None,'WRCC',None),
    (None,'WRCL',None),
    (None,'WRCU',None),
    (None,'WWRC',None),
    (None,'WWRL',None),
    (None,'WWRU',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI071_CTX',None),
    (None,'ZI071_FFN',None),
    (None,'ZI071_FFN2',None),
    (None,'ZI071_FFN3',None),
    (None,'ZI071_UAO',None),
    ('NVS',None,None),
    ('OCS',None,None),
    ('PCF','PCF',None),
    ('PFD',None,None),
    ('PFH',None,None),
    ('PWA',None,None),
    ('RKF',None,None),
    ('RLE',None,None),
    ('SAD',None,None),
    ('SBB',None,None),
    ('SDCC',None,None),
    ('SDCL',None,None),
    ('SDCU',None,None),
    ('SDO',None,None),
    ('SDT',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('SHD',None,None),
    ('SIC',None,None),
    ('SLT',None,None),
    ('SRD',None,None),
    ('SSE',None,None),
    ('STP',None,None),
    ('SWC',None,None),
    ('SWT',None,None),
    ('SWW',None,None),
    ('TID',None,None),
    ('TRA',None,None),
    ('TRS',None,None),
    ('TRS2',None,None),
    ('TRS3',None,None),
    ('TSM',None,None),
    ('TSM2',None,None),
    ('TSM3',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('VLM',None,None),
    ('VOI',None,None),
    ('WAD',None,None),
    ('WCC',None,None),
    ('WD3',None,None),
    ('WD5',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WFT',None,None),
    ('WID','WID',None),
    ('WLE',None,None),
    ('WMT',None,None),
    ('WST',None,None),
    ('WVA',None,None),
    ('WVH',None,None),
    ('WVL',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH',None,None),
    ('COS','COS','transform_COS'),
    ('GWS','GWS','transform_GWS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrfExt field translations
PhysiographySrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('MBC_MCC1','MBC_MCC1',None),
    ('MBC_MCC2','MBC_MCC2',None),
    ('MBC_PSC1','MBC_PSC1',None),
    ('MBC_PSC2','MBC_PSC2',None),
    ('MBC_SCO1','MBC_SCO1',None),
    ('MBC_SCO2','MBC_SCO2',None),
    (None,'ARA',None),
    (None,'BEN',None),
    (None,'DZP',None),
    (None,'FURL',None),
    (None,'LZN',None),
    (None,'PCF',None),
    (None,'PRVR',None),
    (None,'STP',None),
    (None,'SWC',None),
    (None,'WID',None),
    (None,'ZI005_GNT',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SSE','SSE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourCrv field translations
PortHarbourCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPnt field translations
PortHarbourPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'PLC',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('TID','TID',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT',None,None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPntExt field translations
PortHarbourPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('BER','BER',None),
    ('DF1','DF1',None),
    ('DF2','DF2',None),
    ('DF3','DF3',None),
    ('DF4','DF4',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('LZN','LZN',None),
    (None,'ACH',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrf field translations
PortHarbourSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FHC','FHC',None),
    ('FHC2','FHC2',None),
    ('FHC3','FHC3',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('LCA','LCA',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'PLC',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('TID','TID',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT',None,None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrfExt field translations
PortHarbourSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'ACH',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationAONExt field translations
RecreationAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'DMF',None),
    (None,'DZP',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'HGT',None),
    (None,'LZN',None),
    (None,'PCF',None),
    (None,'WID',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_NFN',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    (None,'COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LOC','transform_LOC'),
    (None,'UFI','transform_set_UFI'),
    (None,'VLM','transform_VLM_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationCrv field translations
RecreationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'RAY',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('THI','THI',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationPnt field translations
RecreationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('THI','THI',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationSrf field translations
RecreationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'RAY',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# ReferenceTblExt field translations
ReferenceTblExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    (None,'RS6',None),
    (None,'RX0',None),
    (None,'RX1',None),
    (None,'RX2',None),
    (None,'RX3',None),
    (None,'RX4',None),
    (None,'RX5',None),
    (None,'RX6',None),
    (None,'RX7',None),
    (None,'RY1',None),
    (None,'RY2',None)
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# ResourceTbl field translations
ResourceTblFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Tbl_fields) + [ \
    (None,'AHA',None),
    (None,'AVA',None),
    (None,'CID',None),
    (None,'DQS',None),
    (None,'ETZ',None),
    (None,'EVA',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'HVA',None),
    (None,'MDE',None),
    (None,'RTL',None),
    (None,'SCVN',None),
    (None,'URI',None),
    (None,'ZI020_GE42',None),
    (None,'ZI020_GE43',None),
    (None,'ZI020_GE44',None),
    (None,'CPS','transformCPScodelist2CPSenumvalue'),
    (None,'EQS','transformEQCtoEQS'),
    (None,'ETS','transformETScodelist2ETSenumvalue'),
    (None,'HZD','transformHZDcodelist2HZDenumvalue'),
    (None,'MEM','transform_MEM'),
    (None,'RCG','transformRCGcodelist2RCGenumvalue'),
    (None,'VDT','transformVDTcodelist2VDTenumvalue'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementPnt field translations
SettlementPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'BNF',None),
    (None,'CNCP',None),
    (None,'DNE',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA1',None,None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN1',None,None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrf field translations
SettlementSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'BNF',None),
    (None,'CNCP',None),
    (None,'DNE',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA1',None,None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN1',None,None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrfExt field translations
SettlementSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'BEN',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'NDX',None),
    (None,'NDX2',None),
    (None,'NDX3',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_NFN',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageAONExt field translations
StorageAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'AWP',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CBP',None),
    (None,'CNCP',None),
    (None,'DMF',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'HEI',None),
    (None,'HGT',None),
    (None,'LZN',None),
    (None,'PCF',None),
    (None,'PPO',None),
    (None,'PPO2',None),
    (None,'PPO3',None),
    (None,'SPT',None),
    (None,'SSC',None),
    (None,'VCM',None),
    (None,'VCM2',None),
    (None,'VCM3',None),
    (None,'VOI',None),
    (None,'WID',None),
    (None,'YWQ',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_NFN',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    (None,'ZVH',None),
    (None,'COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'UFI','transform_set_UFI'),
    (None,'VLM','transform_VLM_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StoragePnt field translations
StoragePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'HEI',None),
    (None,'WDST',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI018_WIT',None,None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'PMPR','transform_PMPR'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageSrf field translations
StorageSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'HEI',None),
    (None,'WDST',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI018_WIT',None,None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_LOC'),
    (None,'PMPR','transform_PMPR'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM','transform_VLM_fromInterval'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureCrv field translations
StructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BAT','BAT',None),
    ('BSU','BSU',None),
    ('CRM','CRM',None),
    ('F_CODE','F_CODE',None),
    ('FTI','FTI',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FEF',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI018_WIT',None),
    ('PCF','PCF',None),
    ('PFHC','PFHC',None),
    ('PFHL','PFHL',None),
    ('PFHU','PFHU',None),
    ('THI','THI',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WTI','WTI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePnt field translations
StructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC','HSC',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MFB','MFB',None),
    ('MKSZ','MKSZ',None),
    ('MUB','MUB',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'RLE',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('ROOM','NOR',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('STAF','STAF',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC','VEC',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'MEL','transform_MEL'),
    (None,'MFY','transform_MFY'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePntExt field translations
StructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureSrf field translations
StructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSC','HSC',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LZN','LZN',None),
    ('MFB','MFB',None),
    ('MKSZ','MKSZ',None),
    ('MUB','MUB',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'RLE',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('ROOM','NOR',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('STAF','STAF',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VEC','VEC',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WPST','WPST',None),
    ('WTYP','WTYP',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI014_PRW','ZI014_PRW',None),
    ('ZI014_PRW2','ZI014_PRW2',None),
    ('ZI014_PRW3','ZI014_PRW3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'MEL','transform_MEL'),
    (None,'MFY','transform_MFY'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('ZI037_RFA','ZI037_RFA','transform_missing_enum_index_with_warnings') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SubterraneanSrf field translations
SubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO',None,None),
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('ATC',None,None),
    ('AWP',None,None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('AZC',None,None),
    ('BA000_VDC',None,None),
    ('BA000_VDR',None,None),
    ('BH141_AWBA',None,None),
    ('BH141_AWBB',None,None),
    ('BH141_IBOA',None,None),
    ('BH141_IBOB',None,None),
    ('BH141_SHDA',None,None),
    ('BH141_SHDB',None,None),
    ('BH141_SLTA',None,None),
    ('BH141_SLTB',None,None),
    ('BH141_WBHA',None,None),
    ('BH141_WBHB',None,None),
    ('BMC',None,None),
    ('BMC2',None,None),
    ('BMC3',None,None),
    ('BPWHAC',None,None),
    ('BPWHAL',None,None),
    ('BPWHAU',None,None),
    ('BPWHBC',None,None),
    ('BPWHBL',None,None),
    ('BPWHBU',None,None),
    ('BPWSAC',None,None),
    ('BPWSAL',None,None),
    ('BPWSAU',None,None),
    ('BPWSBC',None,None),
    ('BPWSBL',None,None),
    ('BPWSBU',None,None),
    ('BWVCAC',None,None),
    ('BWVCAL',None,None),
    ('BWVCAU',None,None),
    ('BWVCBC',None,None),
    ('BWVCBL',None,None),
    ('BWVCBU',None,None),
    ('CAA','CAA',None),
    ('CDA',None,None),
    ('CET',None,None),
    ('CNS',None,None),
    ('CWT',None,None),
    ('DEV',None,None),
    ('DMD',None,None),
    ('DOF',None,None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DWT',None,None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCS',None,None),
    ('FFN',None,None),
    ('FFN2',None,None),
    ('FFN3',None,None),
    ('FIC',None,None),
    ('GOT',None,None),
    ('HGT',None,None),
    ('IWT',None,None),
    ('LEA','LEA',None),
    ('LMC',None,None),
    ('LZN','LZN',None),
    ('MCC',None,None),
    ('MCC2',None,None),
    ('MCC3',None,None),
    ('MNS',None,None),
    (None,'AQP2',None),
    (None,'AQP3',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'CNF',None),
    (None,'FURL',None),
    (None,'GWTR',None),
    (None,'HYCD',None),
    (None,'SWCP',None),
    (None,'WRCC',None),
    (None,'WRCL',None),
    (None,'WRCU',None),
    (None,'WWRC',None),
    (None,'WWRL',None),
    (None,'WWRU',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI071_CTX',None),
    (None,'ZI071_FFN',None),
    (None,'ZI071_FFN2',None),
    (None,'ZI071_FFN3',None),
    (None,'ZI071_UAO',None),
    ('NVS',None,None),
    ('OCS',None,None),
    ('PCF','PCF',None),
    ('PFD',None,None),
    ('PFH',None,None),
    ('PWA',None,None),
    ('RKF',None,None),
    ('RLE',None,None),
    ('SAD',None,None),
    ('SBB',None,None),
    ('SDCC',None,None),
    ('SDCL',None,None),
    ('SDCU',None,None),
    ('SDO',None,None),
    ('SDT',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('SHD',None,None),
    ('SIC',None,None),
    ('SLT',None,None),
    ('SRD',None,None),
    ('SSE',None,None),
    ('STP',None,None),
    ('SWC',None,None),
    ('SWT',None,None),
    ('SWW',None,None),
    ('TID',None,None),
    ('TRA',None,None),
    ('TRS',None,None),
    ('TRS2',None,None),
    ('TRS3',None,None),
    ('TSM',None,None),
    ('TSM2',None,None),
    ('TSM3',None,None),
    ('VCM',None,None),
    ('VCM2',None,None),
    ('VCM3',None,None),
    ('VLM',None,None),
    ('VOI',None,None),
    ('WAD',None,None),
    ('WCC',None,None),
    ('WD3',None,None),
    ('WD5',None,None),
    ('WDH',None,None),
    ('WDL',None,None),
    ('WFT',None,None),
    ('WID','WID',None),
    ('WLE',None,None),
    ('WMT',None,None),
    ('WST',None,None),
    ('WVA',None,None),
    ('WVH',None,None),
    ('WVL',None,None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_HYP',None,None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH',None,None),
    ('COS','COS','transform_COS'),
    ('GWS','GWS','transform_GWS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundCrv field translations
TransportationGroundCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CAT','CAT',None),
    ('CON','CON',None),
    ('CTC','CTC',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZC','DZC',None),
    ('DZP','DZP',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FSC','FSC',None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA','LEA',None),
    ('LOG','LOG',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MWG','MWG',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'PSN',None),
    (None,'RIN_RTN',None),
    (None,'RIN_RTN2',None),
    (None,'RIN_RTN3',None),
    (None,'RTY',None),
    (None,'SPD',None),
    (None,'SPM',None),
    (None,'VCO',None),
    (None,'VCS_VCD',None),
    (None,'VCS_VCR',None),
    (None,'ZI005_GNT',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('OOC','OOC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RFD','RFD',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RRC','RRC',None),
    ('RRC2','RRC2',None),
    ('RRC3','RRC3',None),
    ('RSA','RSA',None),
    ('RTA','RTA',None),
    ('RTN','RTN',None),
    ('RTN_ROI',None,None),
    ('RTN_ROI2',None,None),
    ('RTN_ROI3',None,None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RWC','RWC',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHC','SHC',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('TST','TST',None),
    ('TYP',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA','WVA',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RIR','ZI017_RIR',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZVH','ZVH',None),
    ('BOT','BOT','transform_BOT'),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PTG','transform_TRS_to_PTG'),
    (None,'RIN_ROI','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI2','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI3','transform_RIN_ROI_from_RTN_ROI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SRE','SRE','transform_SRE'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UBC','UBC','transform_UBC_from_BSC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPnt field translations
TransportationGroundPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BNF','BNF',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CON','CON',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTC','CTC',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LOC',None,None),
    ('LTN',None,None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MFB',None,None),
    ('MUB','MUB',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'MES',None),
    (None,'RIN_RTN',None),
    (None,'RIN_RTN2',None),
    (None,'RIN_RTN3',None),
    (None,'VCO',None),
    (None,'VCS_VCD',None),
    (None,'VCS_VCR',None),
    (None,'ZI005_GNT',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('OOC','OOC',None),
    ('PCF','PCF',None),
    ('PYM','PYM',None),
    ('RAD','RAD',None),
    ('RFD','RFD',None),
    ('RIT','RIT',None),
    ('RLE',None,None),
    ('RTN',None,None),
    ('RTN_ROI',None,None),
    ('RTN_ROI2',None,None),
    ('RTN_ROI3',None,None),
    ('RTN2',None,None),
    ('RTN3',None,None),
    ('SBB',None,None),
    ('SGCC',None,None),
    ('SGCL',None,None),
    ('SGCU',None,None),
    ('SHC','SHC',None),
    ('SPT','SPT',None),
    ('SSG','SSG',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('THR',None,None),
    ('TRP','TRP',None),
    ('TYP',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VOI','VOI',None),
    ('VST',None,None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1',None,None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZVH','ZVH',None),
    ('BOT','BOT','transform_BOT'),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'RIN_ROI','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI2','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI3','transform_RIN_ROI_from_RTN_ROI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SRE','SRE','transform_SRE'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UBC','UBC','transform_UBC_from_BSC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPntExt field translations
TransportationGroundPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('CTL','CTL',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundSrf field translations
TransportationGroundSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BNF','BNF',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FSC','FSC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LEA','LEA',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MFB',None,None),
    ('MUB','MUB',None),
    ('MWG','MWG',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'CSC',None),
    (None,'CSC2',None),
    (None,'CSC3',None),
    (None,'FURL',None),
    (None,'PSN',None),
    (None,'RIN_RTN',None),
    (None,'RIN_RTN2',None),
    (None,'RIN_RTN3',None),
    (None,'RTY',None),
    (None,'SPD',None),
    (None,'SPM',None),
    (None,'VCO',None),
    (None,'VCS_VCD',None),
    (None,'VCS_VCR',None),
    (None,'ZI005_GNT',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('PCF','PCF',None),
    ('RFD','RFD',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RTN','RTN',None),
    ('RTN_ROI',None,None),
    ('RTN_ROI2',None,None),
    ('RTN_ROI3',None,None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SPT','SPT',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('TYP',None,None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VET','VET',None),
    ('VOI','VOI',None),
    ('VST',None,None),
    ('WBD','WBD',None),
    ('WD2','WD2',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WT2','WT2',None),
    ('WVA','WVA',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZVH','ZVH',None),
    ('BOT','BOT','transform_BOT'),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PTG','transform_TRS_to_PTG'),
    (None,'RIN_ROI','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI2','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI3','transform_RIN_ROI_from_RTN_ROI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UBC','UBC','transform_UBC_from_BSC'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterAONExt field translations
TransportationWaterAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'BBMCA',None),
    (None,'BBMCA2',None),
    (None,'BBMCA3',None),
    (None,'BBMCB',None),
    (None,'BBMCB2',None),
    (None,'BBMCB3',None),
    (None,'BEN',None),
    (None,'BH141_AWBA',None),
    (None,'BH141_AWBB',None),
    (None,'BH141_IBOA',None),
    (None,'BH141_IBOB',None),
    (None,'BH141_SHDA',None),
    (None,'BH141_SHDB',None),
    (None,'BH141_SLTA',None),
    (None,'BH141_SLTB',None),
    (None,'BH141_WBHA',None),
    (None,'BH141_WBHB',None),
    (None,'BMC',None),
    (None,'BMC2',None),
    (None,'BMC3',None),
    (None,'BPWHAC',None),
    (None,'BPWHAL',None),
    (None,'BPWHAU',None),
    (None,'BPWHBC',None),
    (None,'BPWHBL',None),
    (None,'BPWHBU',None),
    (None,'BPWSAC',None),
    (None,'BPWSAL',None),
    (None,'BPWSAU',None),
    (None,'BPWSBC',None),
    (None,'BPWSBL',None),
    (None,'BPWSBU',None),
    (None,'BWVCAC',None),
    (None,'BWVCAL',None),
    (None,'BWVCAU',None),
    (None,'BWVCBC',None),
    (None,'BWVCBL',None),
    (None,'BWVCBU',None),
    (None,'CAA',None),
    (None,'CDA',None),
    (None,'CDL',None),
    (None,'CNCP',None),
    (None,'CWT',None),
    (None,'DEV',None),
    (None,'DMF',None),
    (None,'DOXY',None),
    (None,'DZP',None),
    (None,'F_CODE',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'HDP',None),
    (None,'HGT',None),
    (None,'LEA',None),
    (None,'LZN',None),
    (None,'MWD',None),
    (None,'NVS',None),
    (None,'PCF',None),
    (None,'PWA',None),
    (None,'RLE',None),
    (None,'SBB',None),
    (None,'WD3',None),
    (None,'WDAC',None),
    (None,'WDAL',None),
    (None,'WDAU',None),
    (None,'WDH',None),
    (None,'WDL',None),
    (None,'WID',None),
    (None,'WVA',None),
    (None,'WVH',None),
    (None,'WVL',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_AWO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SQN',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WPAC',None),
    (None,'ZI024_WSG',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI024_YWQ',None),
    (None,'ZVH',None),
    (None,'COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LOC','transform_LOC'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterCrv field translations
TransportationWaterCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BGT','BGT',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('HDP','HDP',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCX','MCX',None),
    ('MWD','MWD',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DOXY',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'PSN',None),
    (None,'RIN_RTN',None),
    (None,'RIN_RTN2',None),
    (None,'RIN_RTN3',None),
    (None,'SPD',None),
    (None,'SPM',None),
    (None,'TID',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('NVS','NVS',None),
    ('OPT','OPT',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('THI','THI',None),
    ('TRA',None,None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PAC','ZI024_WPAC',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'RIN_ROI','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI2','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI3','transform_RIN_ROI_from_RTN_ROI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPnt field translations
TransportationWaterPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BGT','BGT',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PCF','PCF',None),
    ('THI','THI',None),
    ('VOI','VOI',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPntExt field translations
TransportationWaterPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('LZN','LZN',None),
    ('MCX','MCX',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'PSN',None),
    (None,'RIN_RTN',None),
    (None,'RIN_RTN2',None),
    (None,'RIN_RTN3',None),
    (None,'SPD',None),
    (None,'SPM',None),
    (None,'ZI005_GNT',None),
    ('OPT','OPT',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'RIN_ROI','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI2','transform_RIN_ROI_from_RTN_ROI'),
    (None,'RIN_ROI3','transform_RIN_ROI_from_RTN_ROI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterSrf field translations
TransportationWaterSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BBMCA','BBMCA',None),
    ('BBMCA2','BBMCA2',None),
    ('BBMCA3','BBMCA3',None),
    ('BBMCB','BBMCB',None),
    ('BBMCB2','BBMCB2',None),
    ('BBMCB3','BBMCB3',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DOXY',None),
    (None,'FRZ',None),
    (None,'FURL',None),
    (None,'TID',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('TRA',None,None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PAC','ZI024_WPAC',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SQN','ZI024_SQN',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WSG','ZI024_WSG',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_HYP','ZI024_HYP','transform_ZI024_HYP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureAONExt field translations
UtilityInfrastructureAONExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'ARA',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'CWT',None),
    (None,'DEV',None),
    (None,'DIM',None),
    (None,'DMF',None),
    (None,'DZP',None),
    (None,'F_CODE',None),
    (None,'FLO',None),
    (None,'FURL',None),
    (None,'HGT',None),
    (None,'LEA',None),
    (None,'LZN',None),
    (None,'MCC',None),
    (None,'MCC2',None),
    (None,'MCC3',None),
    (None,'NPL',None),
    (None,'OWO',None),
    (None,'PCF',None),
    (None,'PLT',None),
    (None,'PLT2',None),
    (None,'PLT3',None),
    (None,'PPO',None),
    (None,'PPO2',None),
    (None,'PPO3',None),
    (None,'RLE',None),
    (None,'RTA',None),
    (None,'SBB',None),
    (None,'SPT',None),
    (None,'VCM',None),
    (None,'VCM2',None),
    (None,'VCM3',None),
    (None,'WDAC',None),
    (None,'WDAL',None),
    (None,'WDAU',None),
    (None,'WDH',None),
    (None,'WDL',None),
    (None,'WID',None),
    (None,'WVA',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_FNA2',None),
    (None,'ZI005_FNA3',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_GNT2',None),
    (None,'ZI005_GNT3',None),
    (None,'ZI005_NFN',None),
    (None,'ZI005_NFN2',None),
    (None,'ZI005_NFN3',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_AWO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_DRL',None),
    (None,'ZI024_DVPT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_WUR2',None),
    (None,'ZI024_WUR3',None),
    (None,'ZI024_WUR4',None),
    (None,'ZI024_YWQ',None),
    (None,'ZI025_HDP',None),
    (None,'ZVH',None),
    (None,'COS','transform_COS'),
    (None,'FFN','transform_FFN_932_and_TRS'),
    (None,'FFN2','transform_FFN_932_and_TRS'),
    (None,'FFN3','transform_FFN_932_and_TRS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LOC','transform_LOC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'PMPR','transform_PMPR'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureCrv field translations
UtilityInfrastructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('CAB2','CAB2',None),
    ('CAB3','CAB3',None),
    ('CST','CST',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIM','DIM',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('KVA','KVA',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'FURL',None),
    (None,'PLT2',None),
    (None,'PLT3',None),
    (None,'VCO',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('NPL','NPL',None),
    ('OHC','OHC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PLT','PLT',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RLE','RLE',None),
    ('RTA','RTA',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('TST','TST',None),
    ('VOI','VOI',None),
    ('WVA','WVA',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_HDP','ZI025_HDP',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('LMC','LMC','transform_LMC'),
    ('LOC','LOC','transform_LOC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PMPR','transform_PMPR'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePnt field translations
UtilityInfrastructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AT005_CAB','AT005_CAB',None),
    ('AT005_CAB2','AT005_CAB2',None),
    ('AT005_CAB3','AT005_CAB3',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    (None,'ADUR',None),
    (None,'ANFL',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DCAP',None),
    (None,'DIM',None),
    (None,'DINF',None),
    (None,'EPW',None),
    (None,'FURL',None),
    (None,'GRD',None),
    (None,'RAC',None),
    (None,'WDST',None),
    (None,'WLSS',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('TOS','TOS',None),
    ('UTY','UTY',None),
    ('UTY2','UTY2',None),
    ('UTY3','UTY3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVT','ZI024_DVPT',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PUR','ZI024_PUR',None),
    ('ZI024_PUR2','ZI024_PUR2',None),
    ('ZI024_PUR3','ZI024_PUR3',None),
    ('ZI024_PUR4','ZI024_PUR4',None),
    ('ZI024_PUR5','ZI024_PUR5',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI032_GUG','ZI032_GUG',None),
    ('ZI032_PYC','ZI032_PYC',None),
    ('ZI032_PYM','ZI032_PYM',None),
    ('ZI032_TOS','ZI032_TOS',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_PMP','ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePntExt field translations
UtilityInfrastructurePntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'CNCP',None),
    (None,'DZP',None),
    (None,'F_CODE',None),
    (None,'FURL',None),
    (None,'HGT',None),
    (None,'HSCD',None),
    (None,'LZN',None),
    (None,'PCF',None),
    (None,'SPT',None),
    (None,'ZI005_FNA',None),
    (None,'ZI005_GNT',None),
    (None,'ZI005_NFN',None),
    (None,'ZI024_ASE',None),
    (None,'ZI024_CFR',None),
    (None,'ZI024_CLO',None),
    (None,'ZI024_CYN',None),
    (None,'ZI024_DRL',None),
    (None,'ZI024_DVPT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_HAR',None),
    (None,'ZI024_MGN',None),
    (None,'ZI024_PHW',None),
    (None,'ZI024_SCC',None),
    (None,'ZI024_SUL',None),
    (None,'ZI024_TDS',None),
    (None,'ZI024_TEP',None),
    (None,'ZI024_TUR',None),
    (None,'ZI024_WAC',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR',None),
    (None,'ZI024_YWQ',None),
    (None,'ZVH',None),
    (None,'COS','transform_COS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'LUN','transform_TRS_to_LUN'),
    (None,'UFI','transform_set_UFI'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureSrf field translations
UtilityInfrastructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ADR','ADR',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    (None,'ADUR',None),
    (None,'ANFL',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CNCP',None),
    (None,'DCAP',None),
    (None,'DINF',None),
    (None,'EPW',None),
    (None,'FURL',None),
    (None,'GRD',None),
    (None,'WDST',None),
    (None,'WLSS',None),
    (None,'ZI024_AWOI',None),
    (None,'ZI024_AWOX',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    (None,'ZI024_WUR4',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_GNT','ZI005_GNT',None),
    ('ZI005_GNT2','ZI005_GNT2',None),
    ('ZI005_GNT3','ZI005_GNT3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT',None,None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_AWO','ZI024_AWO',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_DRL','ZI024_DRL',None),
    ('ZI024_DVT','ZI024_DVPT',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_PUR','ZI024_PUR',None),
    ('ZI024_PUR2','ZI024_PUR2',None),
    ('ZI024_PUR3','ZI024_PUR3',None),
    ('ZI024_PUR4','ZI024_PUR4',None),
    ('ZI024_PUR5','ZI024_PUR5',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_WUR2','ZI024_WUR2',None),
    ('ZI024_WUR3','ZI024_WUR3',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SSR','SSR','transform_SSR'),
    ('SSR2','SSR2','transform_SSR'),
    ('SSR3','SSR3','transform_SSR'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI024_PMP','ZI024_PMP','transform_PMP') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationCrv field translations
VegetationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPnt field translations
VegetationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('VSP','VSP',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPntExt field translations
VegetationPntExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('COG','COG',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FEO','FEO',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('STR','STR',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WCL','WCL',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COA','COA','transform_missing_enum_index_with_warnings'),
    ('COC','COC','transform_missing_enum_index_with_warnings'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrf field translations
VegetationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BOC','BOC',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('HDP','HDP',None),
    ('HGT','HGT',None),
    ('HYP',None,None),
    ('LZN','LZN',None),
    (None,'AOO',None),
    (None,'BEN',None),
    (None,'CAA',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    (None,'ZI024_FMR',None),
    (None,'ZI024_FRR',None),
    (None,'ZI024_WTNO',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('SNDC','SNDC',None),
    ('SNDL','SNDL',None),
    ('SNDU','SNDU',None),
    ('TID','TID',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI024_ASE','ZI024_ASE',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_CLO','ZI024_CLO',None),
    ('ZI024_CYN','ZI024_CYN',None),
    ('ZI024_HAR','ZI024_HAR',None),
    ('ZI024_MGN','ZI024_MGN',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_SUL','ZI024_SUL',None),
    ('ZI024_TDS','ZI024_TDS',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_WUR','ZI024_WUR',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZVH','ZVH',None),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LMC','LMC','transform_LMC'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'TWS','transform_TWS'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    (None,'ZI024_HYP','transform_ZI024_HYP'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI'),
    ('VEG','VEG','transform_VEG') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrfExt field translations
VegetationSrfExtFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + copy.deepcopy(commonMetadata) + [ \
    ('ARA','ARA',None),
    ('COG','COG',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FEO','FEO',None),
    ('HGT','HGT',None),
    ('LZN','LZN',None),
    (None,'BEN',None),
    (None,'FURL',None),
    (None,'ZI005_GNT',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('STR','STR',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('WCL','WCL',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZVH','ZVH',None),
    ('COA','COA','transform_missing_enum_index_with_warnings'),
    ('COC','COC','transform_missing_enum_index_with_warnings'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LMC','transform_LMC'),
    (None,'VTI','transform_VTI_fromInterval'),
    (None,'ZI020_GE4','transform_GE4_from_IC2_Dataset'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('UFI','UFI','transform_set_UFI') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

