﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: TDS4_FCFields.py                                        **
 **  Copyright (c) March 2017 by Leidos                                                      **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 062.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides a schema-like definition for the data model:             **
 **                 TDS 4.0 Composite
 **
 **    A python dictionary structure is used to define the schema fields for this data model
 **    allowing for the look up and retrieval of default value information, assigned feature code
 **    and identification of whether an attribute applies to a feature within a feature class.
 **
 **    This information is specific to the data model listed above.
 **
 **    The information held within this definition consists of:
 **    1) interval_fields: are special case fields that do not have the standard default value
 **    2) feature class lists
 **    3) fields in the feature class, and for each field, the data type and list of feature codes
 **       on which the field is 'allowed'
 **    4) fields that are enumerated values also get a list of the allowed values for that field
 **    5) summary domain values is a listing of the domain value numeric and textual value that may be
 **       useful for lookup or documentation purposes
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                                  **
 **                                                                                            **
 **  Development History:                                                                      **
 **  March 2017 / Annette Janett Filer (Annette.J.Filer@leidos.com) Regenerated this file
 **   and corrected InformationCrv and InformationSrf Ext issues from the auto-generated file.            **
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""





def TDS40AddSchemaInfoFeaturesSubtypes(field_information):
    field_information['TDS 4.0']['interval_fields'] = {'AQTC','AYRC','BPWHAC','BPWHBC','BPWSAC','BPWSBC','BWVCAC','BWVCBC','DMBC','DPAC','GSGCHC','GSGCLC','RMWC','SDCC','SDSC','SGCC','TSCC'}
    field_information['TDS 4.0']['AeronauticCrv'] = {}
    field_information['TDS 4.0']['AeronauticPnt'] = {}
    field_information['TDS 4.0']['AeronauticSrf'] = {}
    field_information['TDS 4.0']['AgriculturePnt'] = {}
    field_information['TDS 4.0']['AgricultureSrf'] = {}
    field_information['TDS 4.0']['BoundaryCrvExt'] = {}
    field_information['TDS 4.0']['BoundaryPnt'] = {}
    field_information['TDS 4.0']['CollectionSrf'] = {}
    field_information['TDS 4.0']['CultureCrv'] = {}
    field_information['TDS 4.0']['CulturePnt'] = {}
    field_information['TDS 4.0']['CulturePntExt'] = {}
    field_information['TDS 4.0']['CultureSrf'] = {}
    field_information['TDS 4.0']['CultureSrfExt'] = {}
    field_information['TDS 4.0']['DatasetSrf'] = {}
    field_information['TDS 4.0']['FacilityPnt'] = {}
    field_information['TDS 4.0']['FacilitySrf'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf'] = {}
    field_information['TDS 4.0']['HydrographyCrv'] = {}
    field_information['TDS 4.0']['HydrographyPnt'] = {}
    field_information['TDS 4.0']['HydrographySrf'] = {}
    field_information['TDS 4.0']['HypsographyCrv'] = {}
    field_information['TDS 4.0']['HypsographyPnt'] = {}
    field_information['TDS 4.0']['IndustryCrv'] = {}
    field_information['TDS 4.0']['IndustryPnt'] = {}
    field_information['TDS 4.0']['IndustrySrf'] = {}
    field_information['TDS 4.0']['InformationCrv'] = {}
    field_information['TDS 4.0']['InformationPnt'] = {}
    field_information['TDS 4.0']['InformationSrf'] = {}
    field_information['TDS 4.0']['MilitaryCrv'] = {}
    field_information['TDS 4.0']['MilitaryPnt'] = {}
    field_information['TDS 4.0']['MilitarySrf'] = {}
    field_information['TDS 4.0']['PhysiographyCrv'] = {}
    field_information['TDS 4.0']['PhysiographyPnt'] = {}
    field_information['TDS 4.0']['PhysiographySrf'] = {}
    field_information['TDS 4.0']['PortHarbourCrv'] = {}
    field_information['TDS 4.0']['PortHarbourPnt'] = {}
    field_information['TDS 4.0']['PortHarbourSrf'] = {}
    field_information['TDS 4.0']['RecreationCrv'] = {}
    field_information['TDS 4.0']['RecreationPnt'] = {}
    field_information['TDS 4.0']['RecreationSrf'] = {}
    field_information['TDS 4.0']['SettlementPnt'] = {}
    field_information['TDS 4.0']['SettlementSrf'] = {}
    field_information['TDS 4.0']['StoragePnt'] = {}
    field_information['TDS 4.0']['StorageSrf'] = {}
    field_information['TDS 4.0']['StructureCrv'] = {}
    field_information['TDS 4.0']['StructurePnt'] = {}
    field_information['TDS 4.0']['StructureSrf'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf'] = {}
    field_information['TDS 4.0']['VegetationCrv'] = {}
    field_information['TDS 4.0']['VegetationPnt'] = {}
    field_information['TDS 4.0']['VegetationSrf'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['BoundaryCrvExt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CollectionSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CulturePntExt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['CultureSrfExt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['DatasetSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HypsographyCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['InformationCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['InformationPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['VegetationPnt']['EnumeratedIndexValues'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues'] = {}


    field_information['TDS 4.0']['AeronauticCrv']['ARA'] = ('REAL',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['AXS'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['AXS'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticCrv']['DEV'] = ('Integer',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['F_CODE'] = ('CONSTRAINED_STRING',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['LZN'] = ('REAL',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['OTH'] = ('StructuredText',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['PCF'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticCrv']['TXP'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['TXP'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['AeronauticCrv']['UFI'] = ('StructuredText',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['WID'] = ('REAL',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZI004_RCG'] = ('CodeList',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZI005_FNA'] = ('String',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZI005_NFN'] = ('String',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZI006_MEM'] = ('String',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASP'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASP2'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASP3'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASU'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASU2'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASU3'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_ASX'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticCrv']['ZI019_SFS'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['TDS 4.0']['AeronauticCrv']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticCrv']['ZSAX_RS0'] = ('CodeList',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZSAX_RX3'] = ('StructuredText',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZSAX_RX4'] = ('StructuredText',('GB075'))
    field_information['TDS 4.0']['AeronauticCrv']['ZVH'] = ('REAL',('GB075'))
    field_information['TDS 4.0']['AeronauticPnt']['ADR'] = ('String',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['AOO'] = ('REAL',('GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ARA'] = ('REAL',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ASY'] = ('Enumeration',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['TDS 4.0']['AeronauticPnt']['ATB'] = ('Boolean',('GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['AWP'] = ('Boolean',('AL510','AQ060','AQ110','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['AXS'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['AXS'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticPnt']['CAA'] = ('Enumeration',('AL351','GB005','GB030','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['COS'] = ('Enumeration',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['FFN'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['FFN2'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['FFN3'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticPnt']['FPT'] = ('Enumeration',('GB005','GB035'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AeronauticPnt']['GUG'] = ('Boolean',('AQ110'))
    field_information['TDS 4.0']['AeronauticPnt']['HAF'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HAF'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['TDS 4.0']['AeronauticPnt']['HGT'] = ('REAL',('AL351','AL510','AQ060','AQ110','GB030','GB040','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['HST'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticPnt']['HST2'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticPnt']['HST3'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticPnt']['HTP'] = ('Enumeration',('GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HTP'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7)
    field_information['TDS 4.0']['AeronauticPnt']['IKO'] = ('StructuredText',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['LMC'] = ('Boolean',('AL351','AL510','AQ060','AQ110','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['LZN'] = ('REAL',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['MCC'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticPnt']['MCC2'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticPnt']['MCC3'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticPnt']['MUB'] = ('Boolean',('GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['NA8'] = ('String',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['OTH'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['PCF'] = ('Enumeration',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['AQ110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticPnt']['PEC'] = ('Boolean',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['PYM'] = ('Enumeration',('AQ110'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['PYM']['AQ110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['AeronauticPnt']['SSR'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['SSR2'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['SSR3'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticPnt']['TOS'] = ('Enumeration',('AQ110'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TOS']['AQ110']  = (-999999,6,12,13,999)
    field_information['TDS 4.0']['AeronauticPnt']['TRS'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticPnt']['UFI'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['VCM'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['VCM2'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['VCM3'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticPnt']['VOI'] = ('StructuredText',('AL510','AQ060','AQ110','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['WID'] = ('REAL',('AL351','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZI004_RCG'] = ('CodeList',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZI005_FNA'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['ZI005_NFN'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230'))
    field_information['TDS 4.0']['AeronauticPnt']['ZI006_MEM'] = ('String',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASP'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASP2'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASP3'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASU'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASU2'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASU3'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_ASX'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticPnt']['ZI019_SFS'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['TDS 4.0']['AeronauticPnt']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticPnt']['ZSAX_RS0'] = ('CodeList',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZSAX_RX3'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZSAX_RX4'] = ('StructuredText',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticPnt']['ZVA'] = ('REAL',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticPnt']['ZVH'] = ('REAL',('AL351','AL510','AQ060','AQ110','GB005','GB030','GB035','GB040','GB065','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ADR'] = ('String',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['AOO'] = ('REAL',('GB070','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['APY'] = ('Enumeration',('GB015'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['APY'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['APY']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['ARA'] = ('REAL',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ASU'] = ('Enumeration',('GB045'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ASU2'] = ('Enumeration',('GB045'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU2']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ASU3'] = ('Enumeration',('GB045'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASU3']['GB045']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ASY'] = ('Enumeration',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB005']  = (-999999,1,2,3,4,5,6,7,12)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB035']  = (-999999,8,9,10,11,12,13)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ASY']['GB065']  = (-999999,1,2,3,4,5,7,12)
    field_information['TDS 4.0']['AeronauticSrf']['ATB'] = ('Boolean',('GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['AWP'] = ('Boolean',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['AXS'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB015']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB030']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB055']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['AXS']['GB075']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['AeronauticSrf']['CAA'] = ('Enumeration',('AL351','GB005','GB030','GB035','GB055','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['AL351']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB005']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB035']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB055']  = (-999999,3,5,7,16,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['CAA']['GB065']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['COS'] = ('Enumeration',('GB005','GB035','GB065','GB070'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB005']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB035']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB065']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['COS']['GB070']  = (-999999,8,13,14)
    field_information['TDS 4.0']['AeronauticSrf']['DEV'] = ('Integer',('GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['FFN'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['FFN2'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN2']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['FFN3'] = ('Enumeration',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['AL351']  = (-999999,331,333,334,341,530,550,835,847,970,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['AQ060']  = (-999999,486,490,505,507,508,510,511,513,520,525,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['GB230']  = (-999999,341,520,530,536,847,862,881,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FFN3']['GB250']  = (-999999,341,520,530,536,835,836,847,999)
    field_information['TDS 4.0']['AeronauticSrf']['FPT'] = ('Enumeration',('GB005','GB035'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT']['GB005']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['FPT']['GB035']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AeronauticSrf']['GB052_RIDH'] = ('StructuredText',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['GB052_RIDL'] = ('StructuredText',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['GSGCHC'] = ('Enumeration',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCHC'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCHC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['GSGCHL'] = ('real',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['GSGCHU'] = ('real',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['GSGCLC'] = ('Enumeration',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCLC'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['GSGCLC']['GB055']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['GSGCLL'] = ('real',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['GSGCLU'] = ('real',('GB055'))
    field_information['TDS 4.0']['AeronauticSrf']['HAF'] = ('Enumeration',('GB030'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HAF'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HAF']['GB030']  = (-999999,1,2,3,4,6,9,10,11,999)
    field_information['TDS 4.0']['AeronauticSrf']['HGT'] = ('REAL',('AL351','AQ060','GB030','GB040','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['HST'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticSrf']['HST2'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST2']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticSrf']['HST3'] = ('Enumeration',('GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HST3']['GB250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AeronauticSrf']['HTP'] = ('Enumeration',('GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HTP'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['HTP']['GB230']  = (-999999,1,2,3,4,5,6,7)
    field_information['TDS 4.0']['AeronauticSrf']['IKO'] = ('StructuredText',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['LMC'] = ('Boolean',('AL351','AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['LZN'] = ('REAL',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['MCC'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticSrf']['MCC2'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC2']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticSrf']['MCC3'] = ('Enumeration',('GB040'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['MCC3']['GB040']  = (-999999,5,21,51,64,107,117,999)
    field_information['TDS 4.0']['AeronauticSrf']['MUB'] = ('Boolean',('GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['NA8'] = ('String',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['OTH'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['PCF'] = ('Enumeration',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['AL351']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['AQ060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB005']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB015']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB035']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB230']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['PCF']['GB250']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AeronauticSrf']['PEC'] = ('Boolean',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['SSR'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['SSR2'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR2']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['SSR3'] = ('Enumeration',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['AQ060']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['GB230']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['SSR3']['GB250']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AeronauticSrf']['TRS'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['TRS2'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS2']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['TRS3'] = ('Enumeration',('AQ060'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TRS3']['AQ060']  = (-999999,1,5,7,12,13,17,999)
    field_information['TDS 4.0']['AeronauticSrf']['TXP'] = ('Enumeration',('GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TXP'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['TXP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['AeronauticSrf']['UFI'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['VCM'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['VCM2'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM2']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['VCM3'] = ('Enumeration',('AQ060','GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3']['AQ060']  = (-999999,2,3,4,6,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['VCM3']['GB230']  = (-999999,1,3,4,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AeronauticSrf']['VOI'] = ('StructuredText',('AQ060','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['WID'] = ('REAL',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZI004_RCG'] = ('CodeList',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZI005_FNA'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['ZI005_NFN'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230'))
    field_information['TDS 4.0']['AeronauticSrf']['ZI006_MEM'] = ('String',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASP'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASP2'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASP3'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASP3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASU'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASU2'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU2']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASU3'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASU3']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_ASX'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB015']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB055']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_ASX']['GB075']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AeronauticSrf']['ZI019_SFS'] = ('Enumeration',('GB015','GB030','GB055','GB075'))
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS'] = {}
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB015']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB030']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB055']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['EnumeratedIndexValues']['ZI019_SFS']['GB075']  = (-999999,1,2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AeronauticSrf']['ZSAX_RS0'] = ('CodeList',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZSAX_RX3'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZSAX_RX4'] = ('StructuredText',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AeronauticSrf']['ZVA'] = ('REAL',('GB005','GB035','GB065'))
    field_information['TDS 4.0']['AeronauticSrf']['ZVH'] = ('REAL',('AL351','AQ060','GB005','GB015','GB030','GB035','GB040','GB045','GB055','GB065','GB070','GB075','GB230','GB250'))
    field_information['TDS 4.0']['AgriculturePnt']['ADR'] = ('String',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['AOO'] = ('REAL',('AJ110'))
    field_information['TDS 4.0']['AgriculturePnt']['ARA'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ATB'] = ('Boolean',('AJ110'))
    field_information['TDS 4.0']['AgriculturePnt']['AWP'] = ('Boolean',('AJ050','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['CAA'] = ('Enumeration',('AJ080','AJ085'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AgriculturePnt']['DMBC'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgriculturePnt']['DMBL'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['DMBU'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['DMT'] = ('REAL',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['FFN'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgriculturePnt']['FFN2'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgriculturePnt']['FFN3'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgriculturePnt']['HGT'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['LMC'] = ('Boolean',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['LZN'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['OTH'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['PCF'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgriculturePnt']['PPO'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgriculturePnt']['PPO2'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgriculturePnt']['PPO3'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgriculturePnt']['SDSC'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgriculturePnt']['SDSL'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['SDSU'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['SSR'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgriculturePnt']['SSR2'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgriculturePnt']['SSR3'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgriculturePnt']['TOS'] = ('Enumeration',('AJ050'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['TDS 4.0']['AgriculturePnt']['TRE'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AgriculturePnt']['TSCC'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgriculturePnt']['TSCL'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['TSCU'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['VCM'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['VCM2'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['VCM3'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgriculturePnt']['VLM'] = ('REAL',('BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['VOI'] = ('StructuredText',('AJ050','AM020'))
    field_information['TDS 4.0']['AgriculturePnt']['VSP'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgriculturePnt']['VSP2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgriculturePnt']['VSP3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgriculturePnt']['WID'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZI004_RCG'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZI005_FNA'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZI005_NFN'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZI006_MEM'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_CSP'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_CSP2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_CSP3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FFP'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FFP2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FFP3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FMM'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FMM2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI013_FMM3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZI018_WIT'] = ('Enumeration',('AJ080','AJ085'))
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI018_WIT']['AJ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['AgriculturePnt']['EnumeratedIndexValues']['ZI018_WIT']['AJ085']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['AgriculturePnt']['ZSAX_RS0'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZSAX_RX3'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZSAX_RX4'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgriculturePnt']['ZVH'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['ADR'] = ('String',('AJ080','AJ085','AJ110','AL270','EA030'))
    field_information['TDS 4.0']['AgricultureSrf']['AOO'] = ('REAL',('AJ110'))
    field_information['TDS 4.0']['AgricultureSrf']['ARA'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ATB'] = ('Boolean',('AJ110'))
    field_information['TDS 4.0']['AgricultureSrf']['AWP'] = ('Boolean',('AJ050','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['CAA'] = ('Enumeration',('AJ080','AJ085'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ080']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['CAA']['AJ085']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['AgricultureSrf']['DMBC'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['DMBC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgricultureSrf']['DMBL'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['DMBU'] = ('real',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['DMT'] = ('REAL',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['FFN'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgricultureSrf']['FFN2'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN2']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgricultureSrf']['FFN3'] = ('Enumeration',('AJ080','AJ085','AJ110','AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ080']  = (-999999,9,919,921,923,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ085']  = (-999999,2,3,9,106,530,919,921,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AJ110']  = (-999999,2,3,850,907,922,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['FFN3']['AL270']  = (-999999,3,15,847,970,999)
    field_information['TDS 4.0']['AgricultureSrf']['HGT'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['LMC'] = ('Boolean',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','EA010','EA030','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['LZN'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['OTH'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['PCF'] = ('Enumeration',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ085']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AJ110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AL270']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['AM020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PCF']['BH051']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['AgricultureSrf']['PPO'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgricultureSrf']['PPO2'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO2']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgricultureSrf']['PPO3'] = ('Enumeration',('AJ050','BH051'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3']['AJ050']  = (-999999,122,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['PPO3']['BH051']  = (-999999,11,29,30,39,72,77,999)
    field_information['TDS 4.0']['AgricultureSrf']['PVH'] = ('REAL',('EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['SDSC'] = ('Enumeration',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SDSC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgricultureSrf']['SDSL'] = ('real',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['SDSU'] = ('real',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['SSR'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgricultureSrf']['SSR2'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR2']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgricultureSrf']['SSR3'] = ('Enumeration',('AJ080','AJ085','AJ110','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ085']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AJ110']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['SSR3']['AM020']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['AgricultureSrf']['TOS'] = ('Enumeration',('AJ050'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TOS']['AJ050']  = (-999999,6,11,12,13,14,999)
    field_information['TDS 4.0']['AgricultureSrf']['TRE'] = ('Enumeration',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE']['AL270']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TRE']['EA040']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['AgricultureSrf']['TSCC'] = ('Enumeration',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC']['AL270']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['TSCC']['EA040']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['AgricultureSrf']['TSCL'] = ('real',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['TSCU'] = ('real',('AL270','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['UFI'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['VCM'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['VCM2'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM2']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['VCM3'] = ('Enumeration',('AJ050','AJ080','AJ085','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ050']  = (-999999,2,3,4,7,8,9,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ080']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AJ085']  = (-999999,1,3,4,7,8,9,12,13,14,15,16,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VCM3']['AM020']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['AgricultureSrf']['VLM'] = ('REAL',('BH051'))
    field_information['TDS 4.0']['AgricultureSrf']['VOI'] = ('StructuredText',('AJ050','AM020'))
    field_information['TDS 4.0']['AgricultureSrf']['VSP'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgricultureSrf']['VSP2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP2']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgricultureSrf']['VSP3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['VSP3']['AL270']  = (-999999,8,22,25,34,999)
    field_information['TDS 4.0']['AgricultureSrf']['WID'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZI004_RCG'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZI005_FNA'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZI005_NFN'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZI006_MEM'] = ('String',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_CSP'] = ('Enumeration',('AL270','BH135','EA010','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['BH135']  = (28,)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA050']  = (16,)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP']['EA055']  = (18,)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_CSP2'] = ('Enumeration',('AL270','EA010','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP2']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_CSP3'] = ('Enumeration',('AL270','EA010','EA040'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['AL270']  = (-999999,8,9,10,22,29,33,34,35,41,42,43,44,45,46,48,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['EA010']  = (-999999,3,5,8,10,11,13,14,20,21,22,25,26,27,30,31,32,33,35,36,37,39,45,117,152,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_CSP3']['EA040']  = (-999999,1,2,4,5,6,7,15,17,19,23,24,38,40,43,47,159,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FFP'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FFP2'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP2']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FFP3'] = ('Enumeration',('AL270','BH135','EA010','EA030','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['AL270']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['BH135']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA010']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA030']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA040']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA050']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FFP3']['EA055']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FMM'] = ('Enumeration',('AL270','EA010'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM']['EA010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FMM2'] = ('Enumeration',('AL270','EA010'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM2']['EA010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_FMM3'] = ('Enumeration',('AL270','EA010'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3']['AL270']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_FMM3']['EA010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI013_IRG'] = ('Enumeration',('EA010','EA040','EA050','EA055'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA040']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA050']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI013_IRG']['EA055']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI014_PPO'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI014_PPO2'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI014_PPO3'] = ('Enumeration',('AL270'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL270']  = (-999999,20,25,28,32,39,41,44,63,70,73,92,94,95,111,114,117,121,123,155,160,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZI018_WIT'] = ('Enumeration',('AJ080','AJ085'))
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AJ080']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['AgricultureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AJ085']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['AgricultureSrf']['ZSAX_RS0'] = ('CodeList',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZSAX_RX3'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZSAX_RX4'] = ('StructuredText',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','BH051','BH135','EA010','EA030','EA040','EA050','EA055','EC010'))
    field_information['TDS 4.0']['AgricultureSrf']['ZVH'] = ('REAL',('AJ030','AJ050','AJ080','AJ085','AJ110','AL270','AM020','EA040','EA050','EA055'))
    field_information['TDS 4.0']['BoundaryCrvExt']['F_CODE'] = ('CONSTRAINED_STRING',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['OTH'] = ('StructuredText',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['UFI'] = ('StructuredText',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['ZI004_RCG'] = ('CodeList',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['ZI006_MEM'] = ('String',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['ZSAX_RS0'] = ('CodeList',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['ZSAX_RX3'] = ('StructuredText',('FA110'))
    field_information['TDS 4.0']['BoundaryCrvExt']['ZSAX_RX4'] = ('StructuredText',('FA110'))
    field_information['TDS 4.0']['BoundaryPnt']['ARA'] = ('REAL',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['LZN'] = ('REAL',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['MCC'] = ('Enumeration',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['BoundaryPnt']['MCC2'] = ('Enumeration',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC2']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['BoundaryPnt']['MCC3'] = ('Enumeration',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['MCC3']['ZB030']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['BoundaryPnt']['OTH'] = ('StructuredText',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['PCF'] = ('Enumeration',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['BoundaryPnt']['EnumeratedIndexValues']['PCF']['ZB030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['BoundaryPnt']['UFI'] = ('StructuredText',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['WID'] = ('REAL',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZI004_RCG'] = ('CodeList',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZI005_FNA'] = ('String',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZI005_NFN'] = ('String',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZI006_MEM'] = ('String',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZSAX_RS0'] = ('CodeList',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZSAX_RX3'] = ('StructuredText',('ZB030'))
    field_information['TDS 4.0']['BoundaryPnt']['ZSAX_RX4'] = ('StructuredText',('ZB030'))
    field_information['TDS 4.0']['CollectionSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZI040','ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['OTH'] = ('StructuredText',('ZI040','ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['UFI'] = ('StructuredText',('ZI040','ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_NSD'] = ('StructuredText',('ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_NSN'] = ('String',('ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_NSP'] = ('CodeList',('ZI041'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_SSD'] = ('StructuredText',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_SSN'] = ('String',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_SSY'] = ('CodeList',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_VSC'] = ('CodeList',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_VSD'] = ('StructuredText',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI001_VSN'] = ('String',('ZI040'))
    field_information['TDS 4.0']['CollectionSrf']['ZI004_PRE'] = ('String',('ZI040','ZI041'))
    field_information['TDS 4.0']['CultureCrv']['ARA'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['AWP'] = ('Boolean',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['HEI'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['HGT'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['LMC'] = ('Boolean',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['LZN'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['OTH'] = ('StructuredText',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['PCF'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureCrv']['SSC'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSC'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['TDS 4.0']['CultureCrv']['SSR'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureCrv']['SSR2'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureCrv']['SSR3'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureCrv']['TOS'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['CultureCrv']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['TDS 4.0']['CultureCrv']['UFI'] = ('StructuredText',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['VOI'] = ('StructuredText',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['WID'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZI004_RCG'] = ('CodeList',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZI005_FNA'] = ('String',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZI005_NFN'] = ('String',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZI006_MEM'] = ('String',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZSAX_RS0'] = ('CodeList',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZSAX_RX3'] = ('StructuredText',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZSAX_RX4'] = ('StructuredText',('AL130'))
    field_information['TDS 4.0']['CultureCrv']['ZVH'] = ('REAL',('AL130'))
    field_information['TDS 4.0']['CulturePnt']['ADR'] = ('String',('AL030','AL201'))
    field_information['TDS 4.0']['CulturePnt']['ARA'] = ('REAL',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['AWP'] = ('Boolean',('AL012','AL130'))
    field_information['TDS 4.0']['CulturePnt']['CCG'] = ('Enumeration',('FA012'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['CCG'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['CulturePnt']['CSO'] = ('Enumeration',('FA012'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['CSO'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['CulturePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['HEI'] = ('REAL',('AL036','AL130'))
    field_information['TDS 4.0']['CulturePnt']['HGT'] = ('REAL',('AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['TDS 4.0']['CulturePnt']['HSS'] = ('Enumeration',('AL201'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['HSS'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['CulturePnt']['LMC'] = ('Boolean',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['TDS 4.0']['CulturePnt']['LZN'] = ('REAL',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['OTH'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['PCF'] = ('Enumeration',('AK121','AL012','AL025','AL030','AL036','AL130','AL201','BH075'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL025']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CulturePnt']['SRL'] = ('Enumeration',('AL200'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['TDS 4.0']['CulturePnt']['SSC'] = ('Enumeration',('AL036','AL130'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSC'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['TDS 4.0']['CulturePnt']['SSR'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CulturePnt']['SSR2'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CulturePnt']['SSR3'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CulturePnt']['TOS'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['TDS 4.0']['CulturePnt']['TTY'] = ('Enumeration',('AL036'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['TTY'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['CulturePnt']['UFI'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['VLM'] = ('REAL',('BH075'))
    field_information['TDS 4.0']['CulturePnt']['VOI'] = ('StructuredText',('AL012','AL130'))
    field_information['TDS 4.0']['CulturePnt']['WID'] = ('REAL',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZI004_RCG'] = ('CodeList',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZI005_FNA'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZI005_NFN'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZI006_MEM'] = ('String',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['CulturePnt']['ZI037_REL'] = ('Enumeration',('AL030','AL036','AL201'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CulturePnt']['ZI037_RFA'] = ('Enumeration',('AL201'))
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['CulturePnt']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['CulturePnt']['ZSAX_RS0'] = ('CodeList',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZSAX_RX3'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZSAX_RX4'] = ('StructuredText',('AK121','AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075','FA012'))
    field_information['TDS 4.0']['CulturePnt']['ZVH'] = ('REAL',('AL012','AL025','AL030','AL036','AL130','AL200','AL201','BH075'))
    field_information['TDS 4.0']['CulturePntExt']['ARA'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['CUL'] = ('Enumeration',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['EnumeratedIndexValues']['CUL'] = {}
    field_information['TDS 4.0']['CulturePntExt']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['CulturePntExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['LZN'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['OTH'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['UFI'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['WID'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZI004_RCG'] = ('CodeList',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['CulturePntExt']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CulturePntExt']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CulturePntExt']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CultureSrf']['ADI'] = ('Enumeration',('AK120'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ADI'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ADI']['AK120']  = (-999999,2,3,4,6,999)
    field_information['TDS 4.0']['CultureSrf']['ADR'] = ('String',('AK120','AL030','AL201','EA031'))
    field_information['TDS 4.0']['CultureSrf']['AOO'] = ('REAL',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['ARA'] = ('REAL',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['AWP'] = ('Boolean',('AL012','AL130'))
    field_information['TDS 4.0']['CultureSrf']['CAA'] = ('Enumeration',('AK120','FA210'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['AK120']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CAA']['FA210']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['CultureSrf']['CAM'] = ('Enumeration',('FA210'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CAM'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CAM']['FA210']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['TDS 4.0']['CultureSrf']['CCG'] = ('Enumeration',('FA012'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CCG'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CCG']['FA012']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['CultureSrf']['CSO'] = ('Enumeration',('FA012'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CSO'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['CSO']['FA012']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['CultureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['FFN'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN']['AL180']  = (-999999,460,540,545,570,621,643,999)
    field_information['TDS 4.0']['CultureSrf']['FFN2'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN2']['AL180']  = (-999999,460,540,545,570,621,643,999)
    field_information['TDS 4.0']['CultureSrf']['FFN3'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['FFN3']['AL180']  = (-999999,460,540,545,570,621,643,999)
    field_information['TDS 4.0']['CultureSrf']['HEI'] = ('REAL',('AL036','AL130'))
    field_information['TDS 4.0']['CultureSrf']['HGT'] = ('REAL',('AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075'))
    field_information['TDS 4.0']['CultureSrf']['HSS'] = ('Enumeration',('AL201'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['HSS'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['HSS']['AL201']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['CultureSrf']['LMC'] = ('Boolean',('AK120','AK121','AL012','AL030','AL036','AL130','AL180','AL200','AL201','BH075','EA031'))
    field_information['TDS 4.0']['CultureSrf']['LZN'] = ('REAL',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['MCC'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['TDS 4.0']['CultureSrf']['MCC2'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC2']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['TDS 4.0']['CultureSrf']['MCC3'] = ('Enumeration',('AL180'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['MCC3']['AL180']  = (-999999,9,21,62,64,74,117,999)
    field_information['TDS 4.0']['CultureSrf']['OTH'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['PCF'] = ('Enumeration',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL201','BH075'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AK120']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AK121']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL012']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL036']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL175']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL180']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['AL201']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['PCF']['BH075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['CultureSrf']['SRL'] = ('Enumeration',('AK120','AL200','FA210'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['AK120']  = (-999999,1,2,3)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['AL200']  = (-999999,1,2,3)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SRL']['FA210']  = (-999999,1,2,3)
    field_information['TDS 4.0']['CultureSrf']['SSC'] = ('Enumeration',('AL036','AL130'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSC'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSC']['AL036']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSC']['AL130']  = (-999999,12,17,77,78,95,96,97,98,109,112,999)
    field_information['TDS 4.0']['CultureSrf']['SSR'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureSrf']['SSR2'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR2']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureSrf']['SSR3'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['SSR3']['AL130']  = (-999999,6,38,40,41,42,51,77,78,79,80,82,999)
    field_information['TDS 4.0']['CultureSrf']['TOS'] = ('Enumeration',('AL130'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['TOS']['AL130']  = (-999999,1,2,3,5,6,999)
    field_information['TDS 4.0']['CultureSrf']['TTY'] = ('Enumeration',('AL036'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['TTY'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['TTY']['AL036']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['CultureSrf']['UFI'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['VLM'] = ('REAL',('BH075'))
    field_information['TDS 4.0']['CultureSrf']['VOI'] = ('StructuredText',('AL012','AL130'))
    field_information['TDS 4.0']['CultureSrf']['WID'] = ('REAL',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZI004_RCG'] = ('CodeList',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZI005_FNA'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZI005_NFN'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZI006_MEM'] = ('String',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZI024_YWQ'] = ('Enumeration',('BH075'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH075']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['CultureSrf']['ZI037_REL'] = ('Enumeration',('AL030','AL036','AL175','AL201'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL036']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CultureSrf']['ZI037_RFA'] = ('Enumeration',('AL175','AL201'))
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL175']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['CultureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL201']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['CultureSrf']['ZSAX_RS0'] = ('CodeList',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZSAX_RX3'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZSAX_RX4'] = ('StructuredText',('AK120','AK121','AL012','AL030','AL036','AL130','AL175','AL180','AL200','AL201','BH075','EA031','FA012','FA210'))
    field_information['TDS 4.0']['CultureSrf']['ZVH'] = ('REAL',('AL012','AL030','AL036','AL130','AL180','AL200','AL201','BH075','EA031'))
    field_information['TDS 4.0']['CultureSrfExt']['ARA'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['CUL'] = ('Enumeration',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['EnumeratedIndexValues']['CUL'] = {}
    field_information['TDS 4.0']['CultureSrfExt']['EnumeratedIndexValues']['CUL']['ZD030']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['CultureSrfExt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['LZN'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['OTH'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['UFI'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['WID'] = ('REAL',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZI004_RCG'] = ('CodeList',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZI005_FNA'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZI005_NFN'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZI006_MEM'] = ('String',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZI037_REL'] = ('Enumeration',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['CultureSrfExt']['EnumeratedIndexValues']['ZI037_REL']['ZD030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['CultureSrfExt']['ZSAX_RS0'] = ('CodeList',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZSAX_RX3'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['CultureSrfExt']['ZSAX_RX4'] = ('StructuredText',('ZD030'))
    field_information['TDS 4.0']['DatasetSrf']['AHA'] = ('REAL',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['AVA'] = ('REAL',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['CID'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['CPS'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['DQS'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['EQC'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ETS'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ETZ'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['EVA'] = ('REAL',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['HVA'] = ('REAL',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['HZD'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['IC2'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['MDE'] = ('StructuredText',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['MEM'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['OTH'] = ('StructuredText',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['RCG'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['URI'] = ('StructuredText',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['VDT'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ZI002_CCN'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ZI002_CDR'] = ('String',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ZSAX_RS0'] = ('CodeList',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ZSAX_RX3'] = ('StructuredText',('ZI031'))
    field_information['TDS 4.0']['DatasetSrf']['ZSAX_RX4'] = ('StructuredText',('ZI031'))
    field_information['TDS 4.0']['FacilityPnt']['ADR'] = ('String',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['AOO'] = ('REAL',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['ARA'] = ('REAL',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['CAA'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['FacilityPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['FFN'] = ('Enumeration',('AL010','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilityPnt']['FFN2'] = ('Enumeration',('AL010','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilityPnt']['FFN3'] = ('Enumeration',('AL010','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilityPnt']['HGT'] = ('REAL',('AL010','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['LMC'] = ('Boolean',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['LZN'] = ('REAL',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['OTH'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['PCF'] = ('Enumeration',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilityPnt']['RAC'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['RAC'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['RAC']['AT045']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['FacilityPnt']['RAS'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['RAS'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['FacilityPnt']['UFI'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['VCM'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilityPnt']['VCM2'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilityPnt']['VCM3'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilityPnt']['WID'] = ('REAL',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['YSU'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI004_RCG'] = ('CodeList',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZI005_FNA'] = ('String',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZI005_NFN'] = ('String',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZI006_MEM'] = ('String',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PBY'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PBY2'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PBY3'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PPO'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PPO2'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PPO3'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PRW'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PRW2'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI014_PRW3'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI018_WIT'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI037_REL'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['FacilityPnt']['ZI037_RFA'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['FacilityPnt']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['FacilityPnt']['ZSAX_RS0'] = ('CodeList',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZSAX_RX3'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZSAX_RX4'] = ('StructuredText',('AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilityPnt']['ZVH'] = ('REAL',('AL010','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ADR'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['AOO'] = ('REAL',('AL010'))
    field_information['TDS 4.0']['FacilitySrf']['ARA'] = ('REAL',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['CAA'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AG040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['CAA']['AL010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['FacilitySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['FFN'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AG040']  = (-999999,382,459,466,482,535,550,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilitySrf']['FFN2'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AG040']  = (-999999,382,459,466,482,535,550,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN2']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilitySrf']['FFN3'] = ('Enumeration',('AG030','AG040','AL010','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AG030']  = (-999999,272,330,332,333,382,440,460,464,465,466,470,475,476,477,478,482,535,540,550,570,572,573,578,582,594,610,612,621,640,643,651,680,681,691,696,741,752,760,761,770,775,811,833,838,841,847,857,860,862,863,865,881,885,887,888,890,891,893,895,900,905,906,909,913,921,922,923,930,961,962,966,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AG040']  = (-999999,382,459,466,482,535,550,601,604,610,621,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,741,752,757,760,761,770,775,791,795,801,807,808,809,810,811,812,813,822,828,838,841,847,848,850,857,860,862,863,865,885,887,888,913,930,961,970,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AL010']  = (-999999,2,3,9,14,15,19,20,21,27,30,35,40,50,60,70,83,87,91,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,361,362,363,370,372,382,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['FFN3']['AT045']  = (-999999,520,722,811,829,835,999)
    field_information['TDS 4.0']['FacilitySrf']['HGT'] = ('REAL',('AG030','AG040','AL010','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['LMC'] = ('Boolean',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['LZN'] = ('REAL',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['OTH'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['PCF'] = ('Enumeration',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AG030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AG040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AL010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AL011']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['PCF']['AT045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['FacilitySrf']['RAC'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['RAC'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['RAC']['AT045']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['FacilitySrf']['RAS'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['RAS'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['RAS']['AT045']  = (-999999,1,2,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['FacilitySrf']['UFI'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['VCM'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilitySrf']['VCM2'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM2']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilitySrf']['VCM3'] = ('Enumeration',('AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['VCM3']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['FacilitySrf']['WID'] = ('REAL',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['YSU'] = ('Enumeration',('AT045'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['YSU']['AT045']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI004_RCG'] = ('CodeList',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZI005_FNA'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZI005_NFN'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZI006_MEM'] = ('String',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PBY'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY']['AG040']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PBY2'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AG040']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PBY3'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AG040']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL010']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PPO'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PPO2'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PPO3'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AG040']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL010']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PRW'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PRW2'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI014_PRW3'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AG040']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL010']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI018_WIT'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT']['AG040']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI018_WIT']['AL010']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI037_REL'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_REL']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['FacilitySrf']['ZI037_RFA'] = ('Enumeration',('AG040','AL010'))
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA']['AG040']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['FacilitySrf']['EnumeratedIndexValues']['ZI037_RFA']['AL010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['FacilitySrf']['ZSAX_RS0'] = ('CodeList',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZSAX_RX3'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZSAX_RX4'] = ('StructuredText',('AG030','AG040','AL010','AL011','AT045'))
    field_information['TDS 4.0']['FacilitySrf']['ZVH'] = ('REAL',('AG030','AG040','AL010','AT045'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ADR'] = ('String',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['AOO'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ARA'] = ('REAL',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ATB'] = ('Boolean',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['AWP'] = ('Boolean',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['CAA'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['COS'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['FFN'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['FFN2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['FFN3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['HGT'] = ('REAL',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['LMC'] = ('Boolean',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['LZN'] = ('REAL',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['OTH'] = ('StructuredText',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['PCF'] = ('Enumeration',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['PCF']['BC070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['SSR'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['SSR2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['SSR3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['UFI'] = ('StructuredText',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['VCM'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['VCM2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['VCM3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationPnt']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationPnt']['VOI'] = ('StructuredText',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['WID'] = ('REAL',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZI004_RCG'] = ('CodeList',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZI005_FNA'] = ('String',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZI005_NFN'] = ('String',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZI006_MEM'] = ('String',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZSAX_RS0'] = ('CodeList',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZSAX_RX3'] = ('StructuredText',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZSAX_RX4'] = ('StructuredText',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationPnt']['ZVH'] = ('REAL',('BC050','BC070'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ADR'] = ('String',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['AOO'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ARA'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ATB'] = ('Boolean',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['AWP'] = ('Boolean',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['CAA'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['CAA']['BC050']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['COS'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['COS']['BC050']  = (-999999,4,6,8,9,13,14)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['FFN'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['FFN2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN2']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['FFN3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['FFN3']['BC050']  = (-999999,486,505,507,511,512,846,881,905,923,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['HGT'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['LMC'] = ('Boolean',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['LZN'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['OTH'] = ('StructuredText',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['PCF'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['PCF']['BC050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['SSR'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['SSR2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR2']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['SSR3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['SSR3']['BC050']  = (-999999,6,7,40,41,42,77,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['UFI'] = ('StructuredText',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['VCM'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['VCM2'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM2']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['VCM3'] = ('Enumeration',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['HydroAidNavigationSrf']['EnumeratedIndexValues']['VCM3']['BC050']  = (-999999,3,4,6,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydroAidNavigationSrf']['VOI'] = ('StructuredText',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['WID'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZI004_RCG'] = ('CodeList',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZI005_FNA'] = ('String',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZI005_NFN'] = ('String',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZI006_MEM'] = ('String',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZSAX_RS0'] = ('CodeList',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZSAX_RX3'] = ('StructuredText',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZSAX_RX4'] = ('StructuredText',('BC050'))
    field_information['TDS 4.0']['HydroAidNavigationSrf']['ZVH'] = ('REAL',('BC050'))
    field_information['TDS 4.0']['HydrographyCrv']['AOO'] = ('REAL',('BI020','BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['ARA'] = ('REAL',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ATC'] = ('Enumeration',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ATC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['AWP'] = ('Boolean',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_AWBA'] = ('REAL',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_AWBB'] = ('REAL',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_IBOA'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['BH141_IBOB'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['BH141_SHDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_SHDB'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_SLTA'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['BH141_SLTB'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyCrv']['BH141_WBHA'] = ('REAL',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BH141_WBHB'] = ('REAL',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BMC'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographyCrv']['BMC2'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographyCrv']['BMC3'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographyCrv']['BPWHAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BPWHAL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWHAU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWHBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BPWHBL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWHBU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWSAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BPWSAL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWSAU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWSBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BPWSBL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BPWSBU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BWVCAC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BWVCAL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BWVCAU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BWVCBC'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyCrv']['BWVCBL'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['BWVCBU'] = ('real',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['CAA'] = ('Enumeration',('BH010','BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,17,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydrographyCrv']['CDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['CWT'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['DEV'] = ('Integer',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['DIM'] = ('REAL',('BH110'))
    field_information['TDS 4.0']['HydrographyCrv']['DWT'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['DWT'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['DWT']['BI020']  = (-999999,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['FCS'] = ('Enumeration',('BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['FCS'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographyCrv']['HGT'] = ('REAL',('BH010','BH065','BH110','BH180','BI020','BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['LMC'] = ('Boolean',('BH010','BH030','BH065','BH110','BH120','BH180','BI020','BI040'))
    field_information['TDS 4.0']['HydrographyCrv']['LOC'] = ('Enumeration',('BH065','BH110'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH065']  = (-999999,40,44,45)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['LOC']['BH110']  = (-999999,40,44,45)
    field_information['TDS 4.0']['HydrographyCrv']['LZN'] = ('REAL',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['MCC'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['MCC2'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['MCC3'] = ('Enumeration',('BH165','BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyCrv']['NVS'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['NVS'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographyCrv']['OTH'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['PCF'] = ('Enumeration',('BH010','BH030','BH065','BH100','BH110','BH165','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['PCF']['BI060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyCrv']['PWA'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['RLE'] = ('Enumeration',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['HydrographyCrv']['SBB'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['SPT'] = ('Boolean',('BH065','BH110'))
    field_information['TDS 4.0']['HydrographyCrv']['THI'] = ('REAL',('BI040'))
    field_information['TDS 4.0']['HydrographyCrv']['TID'] = ('Boolean',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['TRA'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographyCrv']['TRS'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyCrv']['TRS2'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyCrv']['TRS3'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyCrv']['UFI'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['VLM'] = ('REAL',('BH100'))
    field_information['TDS 4.0']['HydrographyCrv']['VOI'] = ('StructuredText',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['WCC'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WCC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,6,7,8,999)
    field_information['TDS 4.0']['HydrographyCrv']['WD3'] = ('REAL',('BH010','BH030','BH100','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['WD5'] = ('REAL',('BI020'))
    field_information['TDS 4.0']['HydrographyCrv']['WDH'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['WDL'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['WID'] = ('REAL',('BH010','BH030','BH065','BH100','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['WMT'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WMT'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['TDS 4.0']['HydrographyCrv']['WRT'] = ('Enumeration',('BH065'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WRT'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WRT']['BH065']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['HydrographyCrv']['WST'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WST'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['WST']['BH140']  = (-999999,1,2,999)
    field_information['TDS 4.0']['HydrographyCrv']['WVA'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['WVH'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['WVL'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['ZI004_RCG'] = ('CodeList',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZI005_FNA'] = ('String',('BH010','BH030','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZI005_NFN'] = ('String',('BH010','BH030','BH120','BH140','BH165','BH180','BI020','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZI006_MEM'] = ('String',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZI024_HYP'] = ('Enumeration',('BH010','BH030','BH100','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyCrv']['ZI024_SCC'] = ('Enumeration',('BH010','BH100'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographyCrv']['ZI024_YWQ'] = ('Enumeration',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyCrv']['ZSAX_RS0'] = ('CodeList',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZSAX_RX3'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZSAX_RX4'] = ('StructuredText',('BH010','BH030','BH065','BH100','BH110','BH120','BH140','BH165','BH180','BI020','BI040','BI044','BI060'))
    field_information['TDS 4.0']['HydrographyCrv']['ZVH'] = ('REAL',('BH010','BH030','BH100','BH110','BH140','BH180','BI020','BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['AOO'] = ('REAL',('BD115','BI020','BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['AQN'] = ('String',('BH170','BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['ARA'] = ('REAL',('BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['AWP'] = ('Boolean',('BD115','BD181','BI020','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['AZC'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_AWBA'] = ('REAL',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_AWBB'] = ('REAL',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_IBOA'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['BH141_IBOB'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['BH141_SHDA'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_SHDB'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_SLTA'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyPnt']['BH141_SLTB'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographyPnt']['BH141_WBHA'] = ('REAL',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BH141_WBHB'] = ('REAL',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWHAC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BPWHAL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWHAU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWHBC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BPWHBL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWHBU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWSAC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BPWSAL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWSAU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWSBC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BPWSBL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BPWSBU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BWVCAC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BWVCAL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BWVCAU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BWVCBC'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographyPnt']['BWVCBL'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['BWVCBU'] = ('real',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['CAA'] = ('Enumeration',('BD115','BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['DMD'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['DOF'] = ('REAL',('BH145','BH170'))
    field_information['TDS 4.0']['HydrographyPnt']['DWT'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['DWT'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['DWT']['BI020']  = (-999999,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['FCS'] = ('Enumeration',('BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FCS'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographyPnt']['FFN'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographyPnt']['FFN2'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographyPnt']['FFN3'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographyPnt']['HGT'] = ('REAL',('BD115','BD181','BH012','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['IWT'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['IWT'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['HydrographyPnt']['LMC'] = ('Boolean',('BD115','BD181','BH012','BH082','BH120','BH180','BH230','BI010','BI020','BI040','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['LZN'] = ('REAL',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['MCC'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['MCC2'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['MCC3'] = ('Enumeration',('BI020','BI040','BI044'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI040']  = (-999999,21,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographyPnt']['MNS'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['OCS'] = ('Enumeration',('BD115'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['OCS'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['HydrographyPnt']['OTH'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['PCF'] = ('Enumeration',('BB110','BD115','BD181','BH012','BH082','BH170','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BB110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BD181']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH012']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['PCF']['BI070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographyPnt']['SWT'] = ('Enumeration',('BH170'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['SWT'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['TDS 4.0']['HydrographyPnt']['SWW'] = ('REAL',('BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['THI'] = ('REAL',('BI040'))
    field_information['TDS 4.0']['HydrographyPnt']['TID'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographyPnt']['TRS'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyPnt']['TRS2'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyPnt']['TRS3'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographyPnt']['UFI'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['VCM'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['VCM2'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['VCM3'] = ('Enumeration',('BD115','BI010','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BI010']  = (-999999,3,4,7,8,9,12,13,15,16,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographyPnt']['VLM'] = ('REAL',('BH082','BH170','BI010'))
    field_information['TDS 4.0']['HydrographyPnt']['VOI'] = ('StructuredText',('BD115','BD181','BI020','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['WAD'] = ('String',('BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['WD5'] = ('REAL',('BI020'))
    field_information['TDS 4.0']['HydrographyPnt']['WFT'] = ('Enumeration',('BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['WFT'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['TDS 4.0']['HydrographyPnt']['WID'] = ('REAL',('BD115','BD140','BD181','BH012','BH082','BH120','BH170','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographyPnt']['WST'] = ('Enumeration',('BH145'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['WST'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['WST']['BH145']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['ZI004_RCG'] = ('CodeList',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZI005_FNA'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI020','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZI005_NFN'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI020','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZI006_MEM'] = ('String',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZI024_HYP'] = ('Enumeration',('BH082','BH170','BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographyPnt']['ZI024_SCC'] = ('Enumeration',('BH082','BH170','BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographyPnt']['ZI024_YWQ'] = ('Enumeration',('BH082','BH170','BH230'))
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographyPnt']['ZSAX_RS0'] = ('CodeList',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZSAX_RX3'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZSAX_RX4'] = ('StructuredText',('BB110','BD115','BD140','BD181','BH012','BH082','BH120','BH145','BH170','BH180','BH230','BI010','BI020','BI040','BI044','BI050','BI070'))
    field_information['TDS 4.0']['HydrographyPnt']['ZVH'] = ('REAL',('BD115','BD181','BH012','BH082','BH180','BH230','BI010','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['AOO'] = ('REAL',('BD115','BI020','BI044'))
    field_information['TDS 4.0']['HydrographySrf']['AQN'] = ('String',('BH116','BH170','BH230'))
    field_information['TDS 4.0']['HydrographySrf']['AQO'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['AQO2'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO2']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['AQO3'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQO3']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['AQP'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQP'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQP']['BH116']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['AQTC'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQTC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AQTC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['AQTL'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['AQTU'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['ARA'] = ('REAL',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ATC'] = ('Enumeration',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ATC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ATC']['BH010']  = (-999999,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['AWP'] = ('Boolean',('BD115','BI020','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['AYRC'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AYRC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['AYRC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['AYRL'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['AYRU'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['AZC'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_AWBA'] = ('REAL',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_AWBB'] = ('REAL',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_IBOA'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOA']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['BH141_IBOB'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_IBOB']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['BH141_SHDA'] = ('Boolean',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_SHDB'] = ('Boolean',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_SLTA'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTA']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['BH141_SLTB'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH010']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH030']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH082']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BH141_SLTB']['BH140']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['BH141_WBHA'] = ('REAL',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BH141_WBHB'] = ('REAL',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BMC'] = ('Enumeration',('BA040','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC']['BA040']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographySrf']['BMC2'] = ('Enumeration',('BA040','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2']['BA040']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC2']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographySrf']['BMC3'] = ('Enumeration',('BA040','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3']['BA040']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BMC3']['BH140']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['HydrographySrf']['BPWHAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BPWHAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWHAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWHBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWHBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BPWHBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWHBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWSAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BPWSAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWSAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWSBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BPWSBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BPWSBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BPWSBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BWVCAC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCAC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BWVCAL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BWVCAU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BWVCBC'] = ('Enumeration',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['BWVCBC']['BH140']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['BWVCBL'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['BWVCBU'] = ('real',('BH010','BH030','BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['CAA'] = ('Enumeration',('BD115','BH010','BI020'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BD115']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BH010']  = (-999999,3,17,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['CAA']['BI020']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['HydrographySrf']['CDA'] = ('Boolean',('BH010','BH030','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['CNS'] = ('Boolean',('BH090'))
    field_information['TDS 4.0']['HydrographySrf']['CWT'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['DEV'] = ('Integer',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['DMD'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['DOF'] = ('REAL',('BH170'))
    field_information['TDS 4.0']['HydrographySrf']['DPAC'] = ('Enumeration',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['DPAC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['DPAC']['BH116']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['HydrographySrf']['DPAL'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['DPAU'] = ('real',('BH116'))
    field_information['TDS 4.0']['HydrographySrf']['DWT'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['DWT'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['DWT']['BI020']  = (-999999,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographySrf']['F_CODE'] = ('CONSTRAINED_STRING',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['FCS'] = ('Enumeration',('BI044'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FCS'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FCS']['BI044']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographySrf']['FFN'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographySrf']['FFN2'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN2']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographySrf']['FFN3'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['FFN3']['BH082']  = (-999999,30,35,351,361,440,488,505,921,955,999)
    field_information['TDS 4.0']['HydrographySrf']['HGT'] = ('REAL',('BD115','BH010','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['IWT'] = ('Enumeration',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['IWT'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['IWT']['BH082']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['HydrographySrf']['LMC'] = ('Boolean',('BD115','BH010','BH030','BH082','BH120','BH230','BI020','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['LZN'] = ('REAL',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['MCC'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['MCC2'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC2']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['MCC3'] = ('Enumeration',('BH165','BI020','BI044'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BH165']  = (-999999,5,9,21,62,77,83,84,104,108,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BI020']  = (-999999,9,21,62,64,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['MCC3']['BI044']  = (-999999,9,21,46,62,77,83,84,104,107,117,150,999)
    field_information['TDS 4.0']['HydrographySrf']['MNS'] = ('Boolean',('BH082'))
    field_information['TDS 4.0']['HydrographySrf']['NVS'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['NVS'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['NVS']['BH140']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['HydrographySrf']['OCS'] = ('Enumeration',('BD115'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['OCS'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['OCS']['BD115']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['HydrographySrf']['OTH'] = ('StructuredText',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['PCF'] = ('Enumeration',('BD115','BH010','BH030','BH082','BH100','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BD115']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH082']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH165']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BH230']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI044']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['PCF']['BI050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HydrographySrf']['PWA'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['RLE'] = ('Enumeration',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['RLE']['BH010']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['HydrographySrf']['SBB'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['SWT'] = ('Enumeration',('BH170'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['SWT'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['SWT']['BH170']  = (-999999,4,6,7,999)
    field_information['TDS 4.0']['HydrographySrf']['SWW'] = ('REAL',('BH230'))
    field_information['TDS 4.0']['HydrographySrf']['TID'] = ('Boolean',('BH082','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['TRA'] = ('Boolean',('BH010'))
    field_information['TDS 4.0']['HydrographySrf']['TRS'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographySrf']['TRS2'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS2']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographySrf']['TRS3'] = ('Enumeration',('BI020'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['TRS3']['BI020']  = (-999999,8,9,12,13,999)
    field_information['TDS 4.0']['HydrographySrf']['UFI'] = ('StructuredText',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['VCM'] = ('Enumeration',('BD115','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['VCM2'] = ('Enumeration',('BD115','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM2']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['VCM3'] = ('Enumeration',('BD115','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3']['BD115']  = (-999999,2,4,7,9,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['VCM3']['BI050']  = (-999999,2,3,4,7,8,9,12,13,15,17,999)
    field_information['TDS 4.0']['HydrographySrf']['VLM'] = ('REAL',('BH082','BH100','BH170'))
    field_information['TDS 4.0']['HydrographySrf']['VOI'] = ('StructuredText',('BD115','BI020','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['WAD'] = ('String',('BH230'))
    field_information['TDS 4.0']['HydrographySrf']['WCC'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WCC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WCC']['BH140']  = (-999999,1,2,3,4,6,7,8,999)
    field_information['TDS 4.0']['HydrographySrf']['WD3'] = ('REAL',('BH010','BH030','BH100','BH140'))
    field_information['TDS 4.0']['HydrographySrf']['WD5'] = ('REAL',('BI020'))
    field_information['TDS 4.0']['HydrographySrf']['WDH'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['WDL'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['WFT'] = ('Enumeration',('BH230'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WFT'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WFT']['BH230']  = (-999999,2,3,5,6,7,999)
    field_information['TDS 4.0']['HydrographySrf']['WID'] = ('REAL',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['WMT'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WMT'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WMT']['BH140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,999)
    field_information['TDS 4.0']['HydrographySrf']['WST'] = ('Enumeration',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WST'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['WST']['BH140']  = (-999999,1,2,999)
    field_information['TDS 4.0']['HydrographySrf']['WVA'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['WVH'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['WVL'] = ('REAL',('BH140'))
    field_information['TDS 4.0']['HydrographySrf']['ZI004_RCG'] = ('CodeList',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZI005_FNA'] = ('String',('BA040','BD115','BH010','BH030','BH082','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZI005_NFN'] = ('String',('BA040','BD115','BH010','BH030','BH082','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZI006_MEM'] = ('String',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZI024_HYP'] = ('Enumeration',('BH010','BH030','BH082','BH100','BH140','BH170','BH230'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH010']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH030']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH082']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH100']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH140']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH170']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_HYP']['BH230']  = (-999999,1,2,4)
    field_information['TDS 4.0']['HydrographySrf']['ZI024_SCC'] = ('Enumeration',('BH010','BH082','BH100','BH116','BH170','BH230'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH010']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH082']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH100']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH116']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH170']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_SCC']['BH230']  = (-999999,1,4,10,11,12,13,14,998)
    field_information['TDS 4.0']['HydrographySrf']['ZI024_YWQ'] = ('Enumeration',('BH010','BH030','BH082','BH116','BH140','BH170','BH230'))
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH082']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH116']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH140']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH170']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH230']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['HydrographySrf']['ZSAX_RS0'] = ('CodeList',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZSAX_RX3'] = ('StructuredText',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZSAX_RX4'] = ('StructuredText',('BA040','BD115','BH010','BH030','BH082','BH090','BH100','BH116','BH120','BH140','BH165','BH170','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HydrographySrf']['ZVH'] = ('REAL',('BD115','BH010','BH030','BH082','BH100','BH140','BH230','BI020','BI044','BI050'))
    field_information['TDS 4.0']['HypsographyCrv']['ESC'] = ('Enumeration',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['EnumeratedIndexValues']['ESC'] = {}
    field_information['TDS 4.0']['HypsographyCrv']['EnumeratedIndexValues']['ESC']['CA010']  = (-999999,1,2,3,4,5)
    field_information['TDS 4.0']['HypsographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['HQC'] = ('Enumeration',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['EnumeratedIndexValues']['HQC'] = {}
    field_information['TDS 4.0']['HypsographyCrv']['EnumeratedIndexValues']['HQC']['CA010']  = (-999999,1,2,3,4,5,6,7,8,9,12,13,14,15,16,18,19,20,21,22,23,98,99,999)
    field_information['TDS 4.0']['HypsographyCrv']['OTH'] = ('StructuredText',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['UFI'] = ('StructuredText',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZI004_RCG'] = ('CodeList',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZI006_MEM'] = ('String',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZSAX_RS0'] = ('CodeList',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZSAX_RX3'] = ('StructuredText',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZSAX_RX4'] = ('StructuredText',('CA010'))
    field_information['TDS 4.0']['HypsographyCrv']['ZVH'] = ('REAL',('CA010'))
    field_information['TDS 4.0']['HypsographyPnt']['BEL'] = ('REAL',('ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['CPA'] = ('Enumeration',('ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['CPA'] = {}
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['CPA']['ZB035']  = (-999999,2,3,5)
    field_information['TDS 4.0']['HypsographyPnt']['ESC'] = ('Enumeration',('CA030'))
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['ESC'] = {}
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['ESC']['CA030']  = (-999999,1,2,3,4,5)
    field_information['TDS 4.0']['HypsographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['OTH'] = ('StructuredText',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['PCF'] = ('Enumeration',('ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['HypsographyPnt']['EnumeratedIndexValues']['PCF']['ZB035']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['HypsographyPnt']['UFI'] = ('StructuredText',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZI004_RCG'] = ('CodeList',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZI005_FNA'] = ('String',('ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZI005_NFN'] = ('String',('ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZI006_MEM'] = ('String',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZSAX_RS0'] = ('CodeList',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZSAX_RX3'] = ('StructuredText',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZSAX_RX4'] = ('StructuredText',('CA030','ZB035'))
    field_information['TDS 4.0']['HypsographyPnt']['ZVH'] = ('REAL',('CA030'))
    field_information['TDS 4.0']['IndustryCrv']['ARA'] = ('REAL',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['AWP'] = ('Boolean',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['HGT'] = ('REAL',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['LMC'] = ('Boolean',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['LZN'] = ('REAL',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['OTH'] = ('StructuredText',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['PCF'] = ('Enumeration',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['PCF']['AF020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['PCF']['AF021']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryCrv']['PFH'] = ('REAL',('AA011'))
    field_information['TDS 4.0']['IndustryCrv']['UFI'] = ('StructuredText',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['VCM'] = ('Enumeration',('AF020','AF021'))
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['VCM2'] = ('Enumeration',('AF020','AF021'))
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM2']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM2']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['VCM3'] = ('Enumeration',('AF020','AF021'))
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM3']['AF020']  = (-999999,4,7,8,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['EnumeratedIndexValues']['VCM3']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryCrv']['VOI'] = ('StructuredText',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['WID'] = ('REAL',('AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZI004_RCG'] = ('CodeList',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZI005_FNA'] = ('String',('AA011','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZI005_NFN'] = ('String',('AA011','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZI006_MEM'] = ('String',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZSAX_RS0'] = ('CodeList',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZSAX_RX3'] = ('StructuredText',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZSAX_RX4'] = ('StructuredText',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryCrv']['ZVH'] = ('REAL',('AA011','AF020','AF021','AF050'))
    field_information['TDS 4.0']['IndustryPnt']['ADR'] = ('String',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['ARA'] = ('REAL',('AA010','AA020','AA040','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['AWP'] = ('Boolean',('AA020','AA040','AB000','AC010','AC020','AF021','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['TDS 4.0']['IndustryPnt']['AZC'] = ('Boolean',('BH155'))
    field_information['TDS 4.0']['IndustryPnt']['CAA'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['IndustryPnt']['CRA'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CRA'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,99,999)
    field_information['TDS 4.0']['IndustryPnt']['CRM'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CRM'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['IndustryPnt']['DZP'] = ('REAL',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['FFN'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustryPnt']['FFN2'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustryPnt']['FFN3'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustryPnt']['GUG'] = ('Boolean',('AF070'))
    field_information['TDS 4.0']['IndustryPnt']['HGT'] = ('REAL',('AA010','AA020','AA040','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['TDS 4.0']['IndustryPnt']['HST'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustryPnt']['HST2'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustryPnt']['HST3'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustryPnt']['LCA'] = ('REAL',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['LEA'] = ('REAL',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['LMC'] = ('Boolean',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['LOC'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['TDS 4.0']['IndustryPnt']['LZN'] = ('REAL',('AA010','AA020','AA040','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['MZN'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['MZN'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['IndustryPnt']['OTH'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['PBY'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustryPnt']['PBY2'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustryPnt']['PBY3'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustryPnt']['PCF'] = ('Enumeration',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AA054']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF021']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AF080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustryPnt']['PPO'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustryPnt']['PPO2'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustryPnt']['PPO3'] = ('Enumeration',('AA010','AA020','AA040','AA054','AC060'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AA054']  = (-999999,45,62,83,149,161,162,163,164,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustryPnt']['PRW'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustryPnt']['PRW2'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustryPnt']['PRW3'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustryPnt']['RIP'] = ('Boolean',('AA045','AA054'))
    field_information['TDS 4.0']['IndustryPnt']['SRL'] = ('Enumeration',('AA040','AF040','AF070'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['SRL']['AF070']  = (-999999,1,2,3)
    field_information['TDS 4.0']['IndustryPnt']['TRS'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustryPnt']['TRS2'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustryPnt']['TRS3'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustryPnt']['UFI'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['UMA'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['UMA'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['IndustryPnt']['VCM'] = ('Enumeration',('AA040','AC020','AF021','AF040','AF070'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM']['AF070']  = (-999999,4,8,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['VCM2'] = ('Enumeration',('AA040','AC020','AF021','AF040','AF070'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM2']['AF070']  = (-999999,4,8,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['VCM3'] = ('Enumeration',('AA040','AC020','AF021','AF040','AF070'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF021']  = (-999999,4,7,9,15,18,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['VCM3']['AF070']  = (-999999,4,8,9,15,999)
    field_information['TDS 4.0']['IndustryPnt']['VOI'] = ('StructuredText',('AA020','AA040','AB000','AC010','AC020','AF021','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['TDS 4.0']['IndustryPnt']['WEQ'] = ('Enumeration',('AA054'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['IndustryPnt']['WEQ2'] = ('Enumeration',('AA054'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ2']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['IndustryPnt']['WEQ3'] = ('Enumeration',('AA054'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['WEQ3']['AA054']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['IndustryPnt']['WID'] = ('REAL',('AA010','AA020','AA040','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZI004_RCG'] = ('CodeList',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZI005_FNA'] = ('String',('AA010','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF080','AJ055','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZI005_NFN'] = ('String',('AA010','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF080','AJ055','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZI006_MEM'] = ('String',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZI014_PPO'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustryPnt']['ZI014_PPO2'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustryPnt']['ZI014_PPO3'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustryPnt']['ZSAX_RS0'] = ('CodeList',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZSAX_RX3'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZSAX_RX4'] = ('StructuredText',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040','BH155'))
    field_information['TDS 4.0']['IndustryPnt']['ZVH'] = ('REAL',('AA010','AA020','AA040','AA045','AA054','AB000','AC010','AC020','AC040','AC060','AF021','AF040','AF050','AF070','AF080','AJ055','AM040'))
    field_information['TDS 4.0']['IndustrySrf']['ADR'] = ('String',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['ARA'] = ('REAL',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['AWP'] = ('Boolean',('AA020','AA040','AB000','AC010','AC020','AF040','AJ055','AM040'))
    field_information['TDS 4.0']['IndustrySrf']['AZC'] = ('Boolean',('BH155'))
    field_information['TDS 4.0']['IndustrySrf']['CAA'] = ('Enumeration',('AB010','AM040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AB010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CAA']['AM040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['IndustrySrf']['CRA'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CRA'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CRA']['AF040']  = (-999999,2,3,7,99,999)
    field_information['TDS 4.0']['IndustrySrf']['CRM'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CRM'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['CRM']['AF040']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['IndustrySrf']['DZP'] = ('REAL',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['FFN'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustrySrf']['FFN2'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN2']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustrySrf']['FFN3'] = ('Enumeration',('AA010','AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AA010']  = (-999999,40,50,70,83,84,85,87,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AC040']  = (-999999,91,192,481,484,500,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['FFN3']['AJ055']  = (-999999,105,107,161,501,999)
    field_information['TDS 4.0']['IndustrySrf']['HGT'] = ('REAL',('AA010','AA020','AA040','AB000','AB010','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['TDS 4.0']['IndustrySrf']['HST'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustrySrf']['HST2'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST2']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustrySrf']['HST3'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['HST3']['AA010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['IndustrySrf']['LCA'] = ('REAL',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['LEA'] = ('REAL',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['LMC'] = ('Boolean',('AA010','AA020','AA040','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['LOC'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['LOC']['AA010']  = (-999999,40,44)
    field_information['TDS 4.0']['IndustrySrf']['LZN'] = ('REAL',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['MZN'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['MZN'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['MZN']['AA010']  = (-999999,1,3,4,5,6,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['IndustrySrf']['OTH'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['PBY'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustrySrf']['PBY2'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY2']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustrySrf']['PBY3'] = ('Enumeration',('AB000'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PBY3']['AB000']  = (-999999,8,15,16,17,999)
    field_information['TDS 4.0']['IndustrySrf']['PCF'] = ('Enumeration',('AA010','AA020','AA040','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AA040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB000']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AB040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AC060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AF040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['AJ055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['BH040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PCF']['BH155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['IndustrySrf']['PPO'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AA052']  = (-999999,45,83,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustrySrf']['PPO2'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AA052']  = (-999999,45,83,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO2']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustrySrf']['PPO3'] = ('Enumeration',('AA010','AA020','AA040','AA052','AC060'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA010']  = (-999999,8,9,17,18,26,33,34,35,48,50,53,58,59,65,66,85,88,89,93,95,96,97,105,110,118,120,126,130,151,152,153,173,204,224,283,339,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA020']  = (-999999,18,26,33,48,58,59,65,95,105,120,126,151,152,153,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA040']  = (-999999,45,83,122,149,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AA052']  = (-999999,45,83,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PPO3']['AC060']  = (-999999,13,15,60,63,158,159,999)
    field_information['TDS 4.0']['IndustrySrf']['PRW'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustrySrf']['PRW2'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW2']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustrySrf']['PRW3'] = ('Enumeration',('AM040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['PRW3']['AM040']  = (-999999,12,14,34,54,67,68,84,154,999)
    field_information['TDS 4.0']['IndustrySrf']['SRL'] = ('Enumeration',('AA040','AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['SRL']['AA040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['SRL']['AF040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['IndustrySrf']['TRS'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustrySrf']['TRS2'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS2']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustrySrf']['TRS3'] = ('Enumeration',('AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['TRS3']['AF040']  = (-999999,7,8,12,13,999)
    field_information['TDS 4.0']['IndustrySrf']['UFI'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['UMA'] = ('Enumeration',('AA010'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['UMA'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['UMA']['AA010']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['IndustrySrf']['VCM'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustrySrf']['VCM2'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM2']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustrySrf']['VCM3'] = ('Enumeration',('AA040','AC020','AF040'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AA040']  = (-999999,2,7,9,15,18,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AC020']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['VCM3']['AF040']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['IndustrySrf']['VLM'] = ('REAL',('AB040','AC030','BH040'))
    field_information['TDS 4.0']['IndustrySrf']['VOI'] = ('StructuredText',('AA020','AA040','AB000','AC010','AC020','AF040','AJ055','AM040'))
    field_information['TDS 4.0']['IndustrySrf']['WID'] = ('REAL',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZI004_RCG'] = ('CodeList',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZI005_FNA'] = ('String',('AA010','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZI005_NFN'] = ('String',('AA010','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZI006_MEM'] = ('String',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZI014_PPO'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustrySrf']['ZI014_PPO2'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustrySrf']['ZI014_PPO3'] = ('Enumeration',('AC040','AJ055'))
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AC040']  = (-999999,4,16,45,46,61,62,74,83,84,137,150,157,214,999)
    field_information['TDS 4.0']['IndustrySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AJ055']  = (-999999,20,28,63,73,111,155,160,999)
    field_information['TDS 4.0']['IndustrySrf']['ZSAX_RS0'] = ('CodeList',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZSAX_RX3'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZSAX_RX4'] = ('StructuredText',('AA010','AA020','AA040','AA052','AB000','AB010','AB040','AC010','AC020','AC030','AC040','AC060','AF040','AJ055','AM040','BH040','BH155'))
    field_information['TDS 4.0']['IndustrySrf']['ZVH'] = ('REAL',('AA010','AA020','AA040','AB000','AB010','AC010','AC020','AC040','AC060','AF040','AJ055','AM040'))
    field_information['TDS 4.0']['InformationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['NLT'] = ('Enumeration',('ZD040'))
    field_information['TDS 4.0']['InformationCrv']['EnumeratedIndexValues']['NLT'] = {}
    field_information['TDS 4.0']['InformationCrv']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['InformationCrv']['OTH'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['UFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['ZI004_RCG'] = ('CodeList',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationCrv']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationCrv']['ZI006_MEM'] = ('String',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['ZSAX_RS0'] = ('CodeList',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['ZSAX_RX3'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationCrv']['ZSAX_RX4'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['NLT'] = ('Enumeration',('ZD040'))
    field_information['TDS 4.0']['InformationPnt']['EnumeratedIndexValues']['NLT'] = {}
    field_information['TDS 4.0']['InformationPnt']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['InformationPnt']['OTH'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['UFI'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['ZI004_RCG'] = ('CodeList',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationPnt']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationPnt']['ZI006_MEM'] = ('String',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['ZSAX_RS0'] = ('CodeList',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['ZSAX_RX3'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationPnt']['ZSAX_RX4'] = ('StructuredText',('ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['ARA'] = ('REAL',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['LZN'] = ('REAL',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['NLT'] = ('Enumeration',('ZD040'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['NLT'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['NLT']['ZD040']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['InformationSrf']['OTH'] = ('StructuredText',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['UFI'] = ('StructuredText',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['VCA'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['TDS 4.0']['InformationSrf']['VCA2'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA2'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA2']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['TDS 4.0']['InformationSrf']['VCA3'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA3'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCA3']['ZD020']  = (-999999,1,2,3,6,7,8,9,10,11,12,13,16,999)
    field_information['TDS 4.0']['InformationSrf']['VCT'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT']['ZD020']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['InformationSrf']['VCT2'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT2'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT2']['ZD020']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['InformationSrf']['VCT3'] = ('Enumeration',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT3'] = {}
    field_information['TDS 4.0']['InformationSrf']['EnumeratedIndexValues']['VCT3']['ZD020']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['InformationSrf']['WID'] = ('REAL',('ZD020'))
    field_information['TDS 4.0']['InformationSrf']['ZI005_FNA'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationSrf']['ZI005_NFN'] = ('String',('ZD040'))
    field_information['TDS 4.0']['InformationSrf']['ZI004_RCG'] = ('CodeList',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['ZI006_MEM'] = ('String',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['ZSAX_RS0'] = ('CodeList',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['ZSAX_RX3'] = ('StructuredText',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['InformationSrf']['ZSAX_RX4'] = ('StructuredText',('ZD020','ZD040','ZD045'))
    field_information['TDS 4.0']['MilitaryCrv']['ARA'] = ('REAL',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['EET'] = ('Enumeration',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['EET'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['MilitaryCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['HGT'] = ('REAL',('AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['HST'] = ('Enumeration',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryCrv']['HST2'] = ('Enumeration',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryCrv']['HST3'] = ('Enumeration',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryCrv']['LMC'] = ('Boolean',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['LNU'] = ('REAL',('GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['LZN'] = ('REAL',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['MCC'] = ('Enumeration',('AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC']['GB050']  = (-999999,5,9,21,62,64,83,86,88,104,999)
    field_information['TDS 4.0']['MilitaryCrv']['MCC2'] = ('Enumeration',('AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC2']['GB050']  = (-999999,5,9,21,62,64,83,86,88,104,999)
    field_information['TDS 4.0']['MilitaryCrv']['MCC3'] = ('Enumeration',('AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['MCC3']['GB050']  = (-999999,5,9,21,62,64,83,86,88,104,999)
    field_information['TDS 4.0']['MilitaryCrv']['OTH'] = ('StructuredText',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['PCF'] = ('Enumeration',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryCrv']['EnumeratedIndexValues']['PCF']['GB050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryCrv']['UFI'] = ('StructuredText',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['WD3'] = ('REAL',('AH025'))
    field_information['TDS 4.0']['MilitaryCrv']['WID'] = ('REAL',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZI004_RCG'] = ('CodeList',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZI005_FNA'] = ('String',('AH025','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZI005_NFN'] = ('String',('AH025','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZI006_MEM'] = ('String',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZSAX_RS0'] = ('CodeList',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZSAX_RX3'] = ('StructuredText',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZSAX_RX4'] = ('StructuredText',('AH025','AL060','GB050'))
    field_information['TDS 4.0']['MilitaryCrv']['ZVH'] = ('REAL',('GB050'))
    field_information['TDS 4.0']['MilitaryPnt']['ADR'] = ('String',('AH055','AL375','AL376','AM060','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['AOO'] = ('REAL',('AH055','AL375'))
    field_information['TDS 4.0']['MilitaryPnt']['ARA'] = ('REAL',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ATB'] = ('Boolean',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['AWP'] = ('Boolean',('AH055','AL375'))
    field_information['TDS 4.0']['MilitaryPnt']['BNF'] = ('Integer',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['CAA'] = ('Enumeration',('AH055','AH060','AL376','AM060','FA015','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitaryPnt']['DZP'] = ('REAL',('AH060'))
    field_information['TDS 4.0']['MilitaryPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['FFN'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['FFN2'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['FFN3'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitaryPnt']['FRT'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitaryPnt']['FRT2'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitaryPnt']['FRT3'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitaryPnt']['FZR'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FZR'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitaryPnt']['HGT'] = ('REAL',('AH055','AL375','AL376','AM060','FA015','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['HST'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['HST2'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['HST3'] = ('Enumeration',('AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitaryPnt']['LEA'] = ('REAL',('AH060'))
    field_information['TDS 4.0']['MilitaryPnt']['LMC'] = ('Boolean',('AH055','AL375','AL376','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['LUN'] = ('Boolean',('AL120'))
    field_information['TDS 4.0']['MilitaryPnt']['LZN'] = ('REAL',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['MCC'] = ('Enumeration',('AH060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitaryPnt']['MCC2'] = ('Enumeration',('AH060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitaryPnt']['MCC3'] = ('Enumeration',('AH060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitaryPnt']['MST'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitaryPnt']['MST2'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitaryPnt']['MST3'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitaryPnt']['MUB'] = ('Boolean',('AH055','AL375'))
    field_information['TDS 4.0']['MilitaryPnt']['OTH'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['PCF'] = ('Enumeration',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitaryPnt']['PPO'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitaryPnt']['PPO2'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitaryPnt']['PPO3'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitaryPnt']['SSR'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitaryPnt']['SSR2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitaryPnt']['SSR3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitaryPnt']['UFI'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['VCM'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitaryPnt']['VCM2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitaryPnt']['VCM3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitaryPnt']['VOI'] = ('StructuredText',('AH055','AL375'))
    field_information['TDS 4.0']['MilitaryPnt']['WID'] = ('REAL',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['YSU'] = ('Enumeration',('AH055','AH060','AL120','FA015','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI004_RCG'] = ('CodeList',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZI005_FNA'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZI005_NFN'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZI006_MEM'] = ('String',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZI018_WIT'] = ('Enumeration',('AH055','AL376','FA165'))
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT']['AL376']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['EnumeratedIndexValues']['ZI018_WIT']['FA165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitaryPnt']['ZSAX_RS0'] = ('CodeList',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZSAX_RX3'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZSAX_RX4'] = ('StructuredText',('AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA165','SU001'))
    field_information['TDS 4.0']['MilitaryPnt']['ZVH'] = ('REAL',('AH055','AL375','AL376','AM060','FA015','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['ADR'] = ('String',('AH055','AL375','AL376','AM060','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['AOO'] = ('REAL',('AH055','AL375'))
    field_information['TDS 4.0']['MilitarySrf']['ARA'] = ('REAL',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ATB'] = ('Boolean',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['AWP'] = ('Boolean',('AH055','AL375'))
    field_information['TDS 4.0']['MilitarySrf']['BNF'] = ('Integer',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['CAA'] = ('Enumeration',('AH055','AH060','AL376','AM060','FA015','FA165','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AH055']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AH060']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AL376']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['AM060']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['FA015']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['FA165']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['CAA']['SU004']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['MilitarySrf']['DZP'] = ('REAL',('AH060'))
    field_information['TDS 4.0']['MilitarySrf']['EET'] = ('Enumeration',('AH025'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['EET'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['EET']['AH025']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['MilitarySrf']['F_CODE'] = ('CONSTRAINED_STRING',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['FFN'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitarySrf']['FFN2'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN2']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitarySrf']['FFN3'] = ('Enumeration',('AH055','AL375','AL376','FA015','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AH055']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AL375']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['AL376']  = (-999999,551,563,570,572,578,809,810,811,815,822,835,836,843,847,905,922,930,970,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['FA015']  = (-999999,835,841,921,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FFN3']['FA165']  = (-999999,811,831,832,835,839,841,845,846,847,848,857,888,912,914,954,970,999)
    field_information['TDS 4.0']['MilitarySrf']['FRT'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitarySrf']['FRT2'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT2']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitarySrf']['FRT3'] = ('Enumeration',('FA015'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FRT3']['FA015']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitarySrf']['FZR'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FZR'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['FZR']['AH055']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['MilitarySrf']['HGT'] = ('REAL',('AH055','AL060','AL375','AL376','AM060','FA015','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['HST'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['HST2'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST2']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['HST3'] = ('Enumeration',('AH025','AH055','AH060','AL375','AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH025']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH055']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AH060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AL375']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['HST3']['AM060']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['MilitarySrf']['LEA'] = ('REAL',('AH060'))
    field_information['TDS 4.0']['MilitarySrf']['LMC'] = ('Boolean',('AH025','AH055','AL375','AL376','FA165','SU001'))
    field_information['TDS 4.0']['MilitarySrf']['LUN'] = ('Boolean',('AL120'))
    field_information['TDS 4.0']['MilitarySrf']['LZN'] = ('REAL',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['MCC'] = ('Enumeration',('AH060','AL060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitarySrf']['MCC2'] = ('Enumeration',('AH060','AL060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC2']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitarySrf']['MCC3'] = ('Enumeration',('AH060','AL060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3']['AH060']  = (-999999,7,9,21,62,77,83,104,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MCC3']['AL060']  = (-999999,21,107,108,999)
    field_information['TDS 4.0']['MilitarySrf']['MST'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitarySrf']['MST2'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST2']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitarySrf']['MST3'] = ('Enumeration',('AL120'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['MST3']['AL120']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,19,20,21,22,23,24,25,26,999)
    field_information['TDS 4.0']['MilitarySrf']['MUB'] = ('Boolean',('AH055','AL375'))
    field_information['TDS 4.0']['MilitarySrf']['OTH'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['PCF'] = ('Enumeration',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH025']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AH060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL120']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL375']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AL376']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['AM060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA015']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['FA165']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['SU001']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PCF']['SU004']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['MilitarySrf']['PPO'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitarySrf']['PPO2'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO2']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitarySrf']['PPO3'] = ('Enumeration',('AM060'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['PPO3']['AM060']  = (-999999,3,16,38,46,90,120,999)
    field_information['TDS 4.0']['MilitarySrf']['SSR'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitarySrf']['SSR2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR2']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitarySrf']['SSR3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['SSR3']['AH055']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['MilitarySrf']['UFI'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['VCM'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitarySrf']['VCM2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM2']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitarySrf']['VCM3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['VCM3']['AH055']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['MilitarySrf']['VOI'] = ('StructuredText',('AH055','AL375'))
    field_information['TDS 4.0']['MilitarySrf']['WD3'] = ('REAL',('AH025'))
    field_information['TDS 4.0']['MilitarySrf']['WID'] = ('REAL',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['YSU'] = ('Enumeration',('AH055','AH060','AL120','FA015','SU001'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AH055']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AH060']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['AL120']  = (-999999,1,2,3,4,5,7,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['FA015']  = (-999999,1,2,3,4,5,7,8,9,998,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['YSU']['SU001']  = (-999999,1,2,3,4,5,7,8,9,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI004_RCG'] = ('CodeList',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZI005_FNA'] = ('String',('AH025','AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZI005_NFN'] = ('String',('AH025','AH055','AH060','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZI006_MEM'] = ('String',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PBY'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PBY2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY2']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PBY3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PBY3']['AH055']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PPO'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PPO2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO2']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PPO3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PPO3']['AH055']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PRW'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PRW2'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW2']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI014_PRW3'] = ('Enumeration',('AH055'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI014_PRW3']['AH055']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['MilitarySrf']['ZI018_WIT'] = ('Enumeration',('AH055','AL376','FA165'))
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT']['AH055']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT']['AL376']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitarySrf']['EnumeratedIndexValues']['ZI018_WIT']['FA165']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['MilitarySrf']['ZSAX_RS0'] = ('CodeList',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZSAX_RX3'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZSAX_RX4'] = ('StructuredText',('AH025','AH055','AH060','AL060','AL065','AL120','AL375','AL376','AM060','FA015','FA100','FA165','SU001','SU004'))
    field_information['TDS 4.0']['MilitarySrf']['ZVH'] = ('REAL',('AH055','AL375','AL376','AM060','FA015','FA165'))
    field_information['TDS 4.0']['PhysiographyCrv']['ARA'] = ('REAL',('BJ031','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['BA000_VDC'] = ('Enumeration',('BA010'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['BA000_VDC']['BA010']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['TDS 4.0']['PhysiographyCrv']['BA000_VDR'] = ('String',('BA010'))
    field_information['TDS 4.0']['PhysiographyCrv']['CET'] = ('Enumeration',('DB070','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET']['DB070']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['PhysiographyCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['FIC'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['FIC'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['TDS 4.0']['PhysiographyCrv']['GFT'] = ('Boolean',('DB110'))
    field_information['TDS 4.0']['PhysiographyCrv']['HGT'] = ('REAL',('BJ040','DB010','DB070','DB090','DB100','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['LMC'] = ('Boolean',('DB090','DB100'))
    field_information['TDS 4.0']['PhysiographyCrv']['LZN'] = ('REAL',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['MCC'] = ('Enumeration',('DB010','DB061','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB010']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['MCC2'] = ('Enumeration',('DB010','DB061','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB010']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['MCC3'] = ('Enumeration',('DB061','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographyCrv']['OTH'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['PCF'] = ('Enumeration',('DB070','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF']['DB070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PhysiographyCrv']['PFD'] = ('REAL',('BJ031','DB061','DB070'))
    field_information['TDS 4.0']['PhysiographyCrv']['PFH'] = ('REAL',('BJ040','DB010','DB071','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['SGCC'] = ('Enumeration',('DB010','DB070','DB071','DB090','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB070']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB071']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SGCC']['DB190']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographyCrv']['SGCL'] = ('real',('DB010','DB070','DB071','DB090','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['SGCU'] = ('real',('DB010','DB070','DB071','DB090','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['SHD'] = ('Boolean',('BA010'))
    field_information['TDS 4.0']['PhysiographyCrv']['SLT'] = ('Enumeration',('BA010'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SLT'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['SLT']['BA010']  = (-999999,6,8,10,11,12,13,14,16,17,18,998,999)
    field_information['TDS 4.0']['PhysiographyCrv']['TRS'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB070']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB071']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['TRS2'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB070']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB071']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['TRS3'] = ('Enumeration',('DB070','DB071','DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB070']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB071']  = (-999999,2,5,9,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographyCrv']['UFI'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['WID'] = ('REAL',('BJ031','DB010','DB061','DB070','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['WLE'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['PhysiographyCrv']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PhysiographyCrv']['ZI004_RCG'] = ('CodeList',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZI005_FNA'] = ('String',('BA010','BJ040','DB010','DB070','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZI005_NFN'] = ('String',('BA010','BJ040','DB010','DB070','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZI006_MEM'] = ('String',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZSAX_RS0'] = ('CodeList',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZSAX_RX3'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZSAX_RX4'] = ('StructuredText',('BA010','BJ031','BJ040','DB010','DB061','DB070','DB071','DB090','DB100','DB110','DB190'))
    field_information['TDS 4.0']['PhysiographyCrv']['ZVH'] = ('REAL',('BJ031','BJ040','DB010','DB061','DB090','DB100','DB190'))
    field_information['TDS 4.0']['PhysiographyPnt']['AOO'] = ('REAL',('DB029','DB150'))
    field_information['TDS 4.0']['PhysiographyPnt']['AQN'] = ('String',('DB115'))
    field_information['TDS 4.0']['PhysiographyPnt']['ARA'] = ('REAL',('BA030','BJ060','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['TDS 4.0']['PhysiographyPnt']['BA000_VDR'] = ('String',('BA030'))
    field_information['TDS 4.0']['PhysiographyPnt']['DOF'] = ('REAL',('DB115'))
    field_information['TDS 4.0']['PhysiographyPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['GOT'] = ('Enumeration',('DB115'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['GOT'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['PhysiographyPnt']['HGT'] = ('REAL',('BA030','BJ060','DB160','DB180'))
    field_information['TDS 4.0']['PhysiographyPnt']['LMC'] = ('Boolean',('BA030','BJ060','DB029','DB115','DB160','DB180'))
    field_information['TDS 4.0']['PhysiographyPnt']['LZN'] = ('REAL',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['MCC'] = ('Enumeration',('BJ060'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['TDS 4.0']['PhysiographyPnt']['MCC2'] = ('Enumeration',('BJ060'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC2']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['TDS 4.0']['PhysiographyPnt']['MCC3'] = ('Enumeration',('BJ060'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['MCC3']['BJ060']  = (-999999,84,88,103,104,999)
    field_information['TDS 4.0']['PhysiographyPnt']['OHC'] = ('REAL',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['OTH'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['PCF'] = ('Enumeration',('EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PhysiographyPnt']['PFH'] = ('REAL',('DB160'))
    field_information['TDS 4.0']['PhysiographyPnt']['RKF'] = ('Enumeration',('DB160'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['RKF'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['PhysiographyPnt']['SHD'] = ('Boolean',('BA030'))
    field_information['TDS 4.0']['PhysiographyPnt']['SLT'] = ('Enumeration',('BA030'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['SLT'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['TDS 4.0']['PhysiographyPnt']['UFI'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['VGT'] = ('Enumeration',('DB180'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['VGT'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['VGT']['DB180']  = (-999999,1,2,3,4,5)
    field_information['TDS 4.0']['PhysiographyPnt']['VOA'] = ('Enumeration',('DB180'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['VOA'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['VOA']['DB180']  = (-999999,1,2,3)
    field_information['TDS 4.0']['PhysiographyPnt']['WID'] = ('REAL',('BA030','BJ060','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZI004_RCG'] = ('CodeList',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZI005_FNA'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZI005_NFN'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZI006_MEM'] = ('String',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZI071_CTX'] = ('Enumeration',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_CTX'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_CTX']['DB029']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['PhysiographyPnt']['ZI071_FFN'] = ('Enumeration',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN']['DB029']  = (-999999,530,563,835,930,999)
    field_information['TDS 4.0']['PhysiographyPnt']['ZI071_FFN2'] = ('Enumeration',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN2'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN2']['DB029']  = (-999999,530,563,835,930,999)
    field_information['TDS 4.0']['PhysiographyPnt']['ZI071_FFN3'] = ('Enumeration',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN3'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_FFN3']['DB029']  = (-999999,530,563,835,930,999)
    field_information['TDS 4.0']['PhysiographyPnt']['ZI071_UAO'] = ('Enumeration',('DB029'))
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_UAO'] = {}
    field_information['TDS 4.0']['PhysiographyPnt']['EnumeratedIndexValues']['ZI071_UAO']['DB029']  = (-999999,1,2,3,4,5)
    field_information['TDS 4.0']['PhysiographyPnt']['ZSAX_RS0'] = ('CodeList',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZSAX_RX3'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZSAX_RX4'] = ('StructuredText',('BA030','BJ060','DB029','DB115','DB150','DB160','DB180','EC020'))
    field_information['TDS 4.0']['PhysiographyPnt']['ZVH'] = ('REAL',('BA030','BJ060','DB150','DB160','DB180'))
    field_information['TDS 4.0']['PhysiographySrf']['AQN'] = ('String',('DB115'))
    field_information['TDS 4.0']['PhysiographySrf']['ARA'] = ('REAL',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['BA000_VDC'] = ('Enumeration',('BA030'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['BA000_VDC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['BA000_VDC']['BA030']  = (-999999,4,7,9,10,11,13,14,15,19,20,24,28,30,90,999)
    field_information['TDS 4.0']['PhysiographySrf']['BA000_VDR'] = ('String',('BA030'))
    field_information['TDS 4.0']['PhysiographySrf']['CET'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['CET'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['CET']['DB090']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['PhysiographySrf']['DOF'] = ('REAL',('DB115'))
    field_information['TDS 4.0']['PhysiographySrf']['F_CODE'] = ('CONSTRAINED_STRING',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['FIC'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['FIC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['FIC']['DB090']  = (-999999,1,2,3,5,6,999)
    field_information['TDS 4.0']['PhysiographySrf']['GOT'] = ('Enumeration',('DB115'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['GOT'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['GOT']['DB115']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['PhysiographySrf']['HGT'] = ('REAL',('BA030','BJ080','DB090','DB160','DB170'))
    field_information['TDS 4.0']['PhysiographySrf']['LMC'] = ('Boolean',('BA030','BH160','DA005','DB090','DB115','DB160'))
    field_information['TDS 4.0']['PhysiographySrf']['LND'] = ('Enumeration',('BJ099'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['LND'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['LND']['BJ099']  = (-999999,19,41,56,999)
    field_information['TDS 4.0']['PhysiographySrf']['LZN'] = ('REAL',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['MCC'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['BH150']  = (-999999,88,104,119,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['MCC2'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['BH150']  = (-999999,88,104,119,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC2']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['MCC3'] = ('Enumeration',('BH150','DB061','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['BH150']  = (-999999,88,104,119,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['DB061']  = (-999999,84,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['MCC3']['DB090']  = (-999999,8,21,46,52,62,84,86,104,999)
    field_information['TDS 4.0']['PhysiographySrf']['OTH'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['PCF'] = ('Enumeration',('DB090','EC020'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF']['DB090']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['PCF']['EC020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PhysiographySrf']['PFD'] = ('REAL',('BJ031','DB061','DB080'))
    field_information['TDS 4.0']['PhysiographySrf']['PFH'] = ('REAL',('BJ080','DB090','DB160'))
    field_information['TDS 4.0']['PhysiographySrf']['RKF'] = ('Enumeration',('DB160'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['RKF'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['RKF']['DB160']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['PhysiographySrf']['SAD'] = ('Boolean',('DB170'))
    field_information['TDS 4.0']['PhysiographySrf']['SDCC'] = ('Enumeration',('BJ100','DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC']['BJ100']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SDCC']['DA010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographySrf']['SDCL'] = ('real',('BJ100','DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['SDCU'] = ('real',('BJ100','DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['SDO'] = ('REAL',('DB170'))
    field_information['TDS 4.0']['PhysiographySrf']['SDT'] = ('Enumeration',('DB170'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SDT'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SDT']['DB170']  = (-999999,1,2,3,4,5,6,7,8,999)
    field_information['TDS 4.0']['PhysiographySrf']['SGCC'] = ('Enumeration',('DB080','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC']['DB080']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SGCC']['DB090']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PhysiographySrf']['SGCL'] = ('real',('DB080','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['SGCU'] = ('real',('DB080','DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['SHD'] = ('Boolean',('BA030'))
    field_information['TDS 4.0']['PhysiographySrf']['SIC'] = ('Enumeration',('BJ100'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SIC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SIC']['BJ100']  = (-999999,1,2)
    field_information['TDS 4.0']['PhysiographySrf']['SLT'] = ('Enumeration',('BA030'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SLT'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SLT']['BA030']  = (-999999,6,8,10,11,12,13,14,16,17,18,999)
    field_information['TDS 4.0']['PhysiographySrf']['SRD'] = ('Enumeration',('BJ099','BJ100','DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['BJ099']  = (-999999,1,17,36,70,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['BJ100']  = (-999999,1,2,11,12,16,17,18,36,43,52,53,55,56,57,70,81,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SRD']['DA010']  = (-999999,1,2,11,12,13,14,15,16,17,18,19,20,31,32,33,34,35,36,37,43,51,52,53,54,55,56,57,58,59,60,61,63,64,65,66,67,69,70,81,86,88,89,90,91,92,93,94,95,999)
    field_information['TDS 4.0']['PhysiographySrf']['SSE'] = ('StructuredText',('BJ080'))
    field_information['TDS 4.0']['PhysiographySrf']['STP'] = ('Enumeration',('DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['STP'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['STP']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,17,18,99,999)
    field_information['TDS 4.0']['PhysiographySrf']['SWC'] = ('Enumeration',('DA010'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SWC'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['SWC']['DA010']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['PhysiographySrf']['TRS'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographySrf']['TRS2'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS2']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographySrf']['TRS3'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TRS3']['DB090']  = (-999999,2,5,8,10,12,13,999)
    field_information['TDS 4.0']['PhysiographySrf']['TSM'] = ('Enumeration',('DA010','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['TSM2'] = ('Enumeration',('DA010','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM2']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['TSM3'] = ('Enumeration',('DA010','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3']['DA010']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['TSM3']['EE030']  = (-999999,2,3,5,6,7,8,9,10,12,13,14,999)
    field_information['TDS 4.0']['PhysiographySrf']['UFI'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['WID'] = ('REAL',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['WLE'] = ('Enumeration',('DB090'))
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['PhysiographySrf']['EnumeratedIndexValues']['WLE']['DB090']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PhysiographySrf']['ZI004_RCG'] = ('CodeList',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZI005_FNA'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZI005_NFN'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZI006_MEM'] = ('String',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZSAX_RS0'] = ('CodeList',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZSAX_RX3'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZSAX_RX4'] = ('StructuredText',('BA030','BH150','BH160','BJ020','BJ030','BJ031','BJ065','BJ080','BJ099','BJ100','DA005','DA010','DB061','DB080','DB090','DB115','DB160','DB170','DB211','EC020','EE030'))
    field_information['TDS 4.0']['PhysiographySrf']['ZVH'] = ('REAL',('BA030','BJ030','BJ031','BJ080','DB061','DB090','DB160','DB170'))
    field_information['TDS 4.0']['PortHarbourCrv']['ARA'] = ('REAL',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['CAA'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourCrv']['F_CODE'] = ('CONSTRAINED_STRING',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['FAC'] = ('Boolean',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['FFN'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourCrv']['FFN2'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourCrv']['FFN3'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourCrv']['FLO'] = ('Boolean',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['HGT'] = ('REAL',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['LMC'] = ('Boolean',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['LZN'] = ('REAL',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['MCC'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourCrv']['MCC2'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourCrv']['MCC3'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourCrv']['OTH'] = ('StructuredText',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['PCF'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourCrv']['PWC'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['PWC'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['TDS 4.0']['PortHarbourCrv']['SGCC'] = ('Enumeration',('BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PortHarbourCrv']['SGCL'] = ('real',('BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['SGCU'] = ('real',('BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['SLR'] = ('Enumeration',('BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['SLR'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['PortHarbourCrv']['UFI'] = ('StructuredText',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['WID'] = ('REAL',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['WLE'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourCrv']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourCrv']['ZI004_RCG'] = ('CodeList',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZI005_FNA'] = ('String',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZI005_NFN'] = ('String',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZI006_MEM'] = ('String',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZSAX_RS0'] = ('CodeList',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZSAX_RX3'] = ('StructuredText',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZSAX_RX4'] = ('StructuredText',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourCrv']['ZVH'] = ('REAL',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourPnt']['ADR'] = ('String',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['ARA'] = ('REAL',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['CAA'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourPnt']['F_CODE'] = ('CONSTRAINED_STRING',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['FFN'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourPnt']['FFN2'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourPnt']['FFN3'] = ('Enumeration',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourPnt']['HGT'] = ('REAL',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['LMC'] = ('Boolean',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['LZN'] = ('REAL',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['MCC'] = ('Enumeration',('BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourPnt']['MCC2'] = ('Enumeration',('BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourPnt']['MCC3'] = ('Enumeration',('BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourPnt']['OTH'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['PCF'] = ('Enumeration',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourPnt']['TID'] = ('Boolean',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['UFI'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['WID'] = ('REAL',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['WPI'] = ('String',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['YSU'] = ('Enumeration',('BB241'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI004_RCG'] = ('CodeList',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZI005_FNA'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZI005_NFN'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZI006_MEM'] = ('String',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI018_WIT'] = ('Enumeration',('BB201'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI018_WIT']['BB201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['TDS 4.0']['PortHarbourPnt']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourPnt']['ZSAX_RS0'] = ('CodeList',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZSAX_RX3'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZSAX_RX4'] = ('StructuredText',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourPnt']['ZVH'] = ('REAL',('BB009','BB201','BB241','BD100'))
    field_information['TDS 4.0']['PortHarbourSrf']['ADR'] = ('String',('BB009','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['ARA'] = ('REAL',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['CAA'] = ('Enumeration',('BB009','BB081','BB090','BB199','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB009']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB081']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB090']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB199']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB201']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['CAA']['BB241']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['PortHarbourSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['FAC'] = ('Boolean',('BB081'))
    field_information['TDS 4.0']['PortHarbourSrf']['FFN'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FFN2'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN2']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FFN3'] = ('Enumeration',('BB009','BB081','BB201','BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB009']  = (-999999,301,340,484,490,497,500,505,507,508,510,511,512,513,520,530,536,537,538,539,827,829,833,835,841,842,847,888,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB081']  = (-999999,30,99,440,529,530,921,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB201']  = (-999999,340,382,466,470,476,484,505,507,508,550,570,572,612,829,847,888,921,923,955,970,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FFN3']['BB241']  = (-999999,99,257,270,280,301,331,333,334,340,505,530,835,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FHC'] = ('Enumeration',('BB005'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FHC2'] = ('Enumeration',('BB005'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC2']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FHC3'] = ('Enumeration',('BB005'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['FHC3']['BB005']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,999)
    field_information['TDS 4.0']['PortHarbourSrf']['FLO'] = ('Boolean',('BB081'))
    field_information['TDS 4.0']['PortHarbourSrf']['HGT'] = ('REAL',('BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['LCA'] = ('REAL',('BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['LMC'] = ('Boolean',('BB005','BB009','BB081','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['LNU'] = ('REAL',('BB090'))
    field_information['TDS 4.0']['PortHarbourSrf']['LZN'] = ('REAL',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['MCC'] = ('Enumeration',('BB081','BB082','BB090','BB199','BD100'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BB199']  = (-999999,107,117,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['MCC2'] = ('Enumeration',('BB081','BB082','BB090','BB199','BD100'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BB199']  = (-999999,107,117,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC2']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['MCC3'] = ('Enumeration',('BB081','BB082','BB090','BD100'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB081']  = (-999999,5,8,9,21,62,64,77,83,84,86,104,107,108,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB082']  = (-999999,5,9,21,46,88,104,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BB090']  = (-999999,8,21,62,64,77,83,84,86,104,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['MCC3']['BD100']  = (-999999,21,51,64,107,117,150,999)
    field_information['TDS 4.0']['PortHarbourSrf']['OTH'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['PCF'] = ('Enumeration',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB005']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB009']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB081']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB082']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB090']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB199']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB201']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BB241']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BD100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PCF']['BI005']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['PortHarbourSrf']['PWC'] = ('Enumeration',('BB081'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PWC'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['PWC']['BB081']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,18,999)
    field_information['TDS 4.0']['PortHarbourSrf']['SGCC'] = ('Enumeration',('BB082'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['SGCC']['BB082']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['PortHarbourSrf']['SGCL'] = ('real',('BB082'))
    field_information['TDS 4.0']['PortHarbourSrf']['SGCU'] = ('real',('BB082'))
    field_information['TDS 4.0']['PortHarbourSrf']['SLR'] = ('Enumeration',('BB082'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['SLR'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['SLR']['BB082']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['PortHarbourSrf']['TID'] = ('Boolean',('BB005','BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['UFI'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['WDU'] = ('REAL',('BB090'))
    field_information['TDS 4.0']['PortHarbourSrf']['WID'] = ('REAL',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['WLE'] = ('Enumeration',('BB081','BB082'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE']['BB081']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['WLE']['BB082']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourSrf']['WPI'] = ('String',('BB005','BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['YSU'] = ('Enumeration',('BB241'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['YSU'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['YSU']['BB241']  = (-999999,2,3,4,5,7,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI004_RCG'] = ('CodeList',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZI005_FNA'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZI005_NFN'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZI006_MEM'] = ('String',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PBY'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PBY2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY2']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PBY3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PBY3']['BB009']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PPO'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PPO2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO2']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PPO3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PPO3']['BB009']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PRW'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PRW2'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW2']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI014_PRW3'] = ('Enumeration',('BB009'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI014_PRW3']['BB009']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI018_WIT'] = ('Enumeration',('BB201'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI018_WIT']['BB201']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZI025_WLE'] = ('Enumeration',('BD100'))
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['TDS 4.0']['PortHarbourSrf']['EnumeratedIndexValues']['ZI025_WLE']['BD100']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['PortHarbourSrf']['ZSAX_RS0'] = ('CodeList',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZSAX_RX3'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZSAX_RX4'] = ('StructuredText',('BB005','BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['PortHarbourSrf']['ZVH'] = ('REAL',('BB009','BB081','BB082','BB090','BB199','BB201','BB241','BD100','BI005'))
    field_information['TDS 4.0']['RecreationCrv']['ADR'] = ('String',('AK130'))
    field_information['TDS 4.0']['RecreationCrv']['AMA'] = ('Enumeration',('AK020'))
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['AMA'] = {}
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['RecreationCrv']['AOO'] = ('REAL',('AK080'))
    field_information['TDS 4.0']['RecreationCrv']['ARA'] = ('REAL',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['AWP'] = ('Boolean',('AK020','AK080','AK150'))
    field_information['TDS 4.0']['RecreationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['HEI'] = ('REAL',('AK080'))
    field_information['TDS 4.0']['RecreationCrv']['HGT'] = ('REAL',('AK020','AK080','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['LMC'] = ('Boolean',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['LZN'] = ('REAL',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['OTH'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['PCF'] = ('Enumeration',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationCrv']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationCrv']['THI'] = ('REAL',('AK080'))
    field_information['TDS 4.0']['RecreationCrv']['UFI'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['VOI'] = ('StructuredText',('AK020','AK080','AK150'))
    field_information['TDS 4.0']['RecreationCrv']['WID'] = ('REAL',('AK020','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZI004_RCG'] = ('CodeList',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZI005_FNA'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZI005_NFN'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZI006_MEM'] = ('String',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZSAX_RS0'] = ('CodeList',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZSAX_RX3'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZSAX_RX4'] = ('StructuredText',('AK020','AK080','AK130','AK150','AK155'))
    field_information['TDS 4.0']['RecreationCrv']['ZVH'] = ('REAL',('AK020','AK080','AK150','AK155'))
    field_information['TDS 4.0']['RecreationPnt']['ADR'] = ('String',('AK030','AK160','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['AMA'] = ('Enumeration',('AK020'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['AMA'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['RecreationPnt']['AOO'] = ('REAL',('AK080','AK161'))
    field_information['TDS 4.0']['RecreationPnt']['ARA'] = ('REAL',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['AWP'] = ('Boolean',('AK020','AK080','AK110','AK150','AK160','AK161'))
    field_information['TDS 4.0']['RecreationPnt']['CCT'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['CCT'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['RecreationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['FFN'] = ('Enumeration',('AK030','AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationPnt']['FFN2'] = ('Enumeration',('AK030','AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationPnt']['FFN3'] = ('Enumeration',('AK030','AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationPnt']['HEI'] = ('REAL',('AK080','AK161'))
    field_information['TDS 4.0']['RecreationPnt']['HGT'] = ('REAL',('AK020','AK030','AK040','AK080','AK110','AK150','AK160','AK161','AK164','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['LMC'] = ('Boolean',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['LZN'] = ('REAL',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['OTH'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['PCF'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK150']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK161']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationPnt']['SSR'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationPnt']['SSR2'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationPnt']['SSR3'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['RecreationPnt']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationPnt']['THI'] = ('REAL',('AK080'))
    field_information['TDS 4.0']['RecreationPnt']['UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['VLM'] = ('REAL',('AK170'))
    field_information['TDS 4.0']['RecreationPnt']['VOI'] = ('StructuredText',('AK020','AK080','AK110','AK150','AK160','AK161'))
    field_information['TDS 4.0']['RecreationPnt']['WID'] = ('REAL',('AK020','AK030','AK040','AK060','AK110','AK150','AK160','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZI004_RCG'] = ('CodeList',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZI005_FNA'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZI005_NFN'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZI006_MEM'] = ('String',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZSAX_RS0'] = ('CodeList',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZSAX_RX3'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZSAX_RX4'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK080','AK110','AK150','AK160','AK161','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationPnt']['ZVH'] = ('REAL',('AK020','AK030','AK040','AK080','AK110','AK150','AK160','AK161','AK164','AK180'))
    field_information['TDS 4.0']['RecreationSrf']['ADR'] = ('String',('AK030','AK070','AK090','AK100','AK101','AK130','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['AMA'] = ('Enumeration',('AK020'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['AMA'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['AMA']['AK020']  = (-999999,1,2,3,4,5,6,999)
    field_information['TDS 4.0']['RecreationSrf']['ARA'] = ('REAL',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['AWP'] = ('Boolean',('AK020','AK110','AK160'))
    field_information['TDS 4.0']['RecreationSrf']['CCT'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['CCT'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['CCT']['AK160']  = (-999999,1,2,3,4)
    field_information['TDS 4.0']['RecreationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['FFN'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationSrf']['FFN2'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN2']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationSrf']['FFN3'] = ('Enumeration',('AK030','AK070','AK090','AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK030']  = (-999999,382,464,465,466,475,480,551,552,570,572,573,574,578,594,643,780,810,863,890,891,892,894,895,900,905,906,907,909,912,919,921,922,923,930,966,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK070']  = (-999999,382,466,594,847,921,922,923,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK090']  = (-999999,382,475,480,570,572,574,643,780,810,847,862,863,891,892,905,919,921,922,923,930,970,999)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['FFN3']['AK160']  = (-999999,570,900,912,921,930,999)
    field_information['TDS 4.0']['RecreationSrf']['HGT'] = ('REAL',('AK020','AK030','AK040','AK070','AK090','AK110','AK155','AK160','AK164','AK180'))
    field_information['TDS 4.0']['RecreationSrf']['LMC'] = ('Boolean',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180'))
    field_information['TDS 4.0']['RecreationSrf']['LZN'] = ('REAL',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['OTH'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['PCF'] = ('Enumeration',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK061']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK090']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK100']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK101']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK160']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK164']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AK180']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['PCF']['AL170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['RecreationSrf']['SSR'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationSrf']['SSR2'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR2']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationSrf']['SSR3'] = ('Enumeration',('AK160'))
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['RecreationSrf']['EnumeratedIndexValues']['SSR3']['AK160']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['RecreationSrf']['UFI'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['VLM'] = ('REAL',('AK170'))
    field_information['TDS 4.0']['RecreationSrf']['VOI'] = ('StructuredText',('AK020','AK110','AK160'))
    field_information['TDS 4.0']['RecreationSrf']['WID'] = ('REAL',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZI004_RCG'] = ('CodeList',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZI005_FNA'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZI005_NFN'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZI006_MEM'] = ('String',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZSAX_RS0'] = ('CodeList',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZSAX_RX3'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZSAX_RX4'] = ('StructuredText',('AK020','AK030','AK040','AK060','AK061','AK070','AK090','AK100','AK101','AK110','AK130','AK155','AK160','AK164','AK170','AK180','AL170'))
    field_information['TDS 4.0']['RecreationSrf']['ZVH'] = ('REAL',('AK020','AK030','AK040','AK070','AK090','AK110','AK155','AK160','AK164','AK180'))
    field_information['TDS 4.0']['SettlementPnt']['ADR'] = ('String',('AI030'))
    field_information['TDS 4.0']['SettlementPnt']['ARA'] = ('REAL',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['BAC'] = ('Enumeration',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['BAC'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['TDS 4.0']['SettlementPnt']['CAA'] = ('Enumeration',('AI030','AL020'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['SettlementPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['FFN'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementPnt']['FFN2'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementPnt']['FFN3'] = ('Enumeration',('AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementPnt']['HGT'] = ('REAL',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['HHD'] = ('Boolean',('AL105'))
    field_information['TDS 4.0']['SettlementPnt']['LMC'] = ('Boolean',('AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['LZN'] = ('REAL',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['OTH'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['PCF'] = ('Enumeration',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementPnt']['STL'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementPnt']['STL2'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL2'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementPnt']['STL3'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL3'] = {}
    field_information['TDS 4.0']['SettlementPnt']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementPnt']['UFI'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['WID'] = ('REAL',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['WPI'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['ZI004_RCG'] = ('CodeList',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_FNA'] = ('String',('AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_FNA1'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_NFN'] = ('String',('AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_NFN1'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementPnt']['ZI006_MEM'] = ('String',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZSAX_RS0'] = ('CodeList',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZSAX_RX3'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZSAX_RX4'] = ('StructuredText',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementPnt']['ZVH'] = ('REAL',('AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ADR'] = ('String',('AI020','AI021','AI030'))
    field_information['TDS 4.0']['SettlementSrf']['ARA'] = ('REAL',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['BAC'] = ('Enumeration',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['BAC'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['BAC']['AL020']  = (-999999,1,2,3)
    field_information['TDS 4.0']['SettlementSrf']['CAA'] = ('Enumeration',('AI030','AL020'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AI030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['CAA']['AL020']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['SettlementSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['FFN'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI020']  = (-999999,382,466,470,476,563,570,921,930,961,970,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI021']  = (-999999,382,466,470,476,563,570,921,930,961,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementSrf']['FFN2'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI020']  = (-999999,382,466,470,476,563,570,921,930,961,970,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI021']  = (-999999,382,466,470,476,563,570,921,930,961,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN2']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementSrf']['FFN3'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI020']  = (-999999,382,466,470,476,563,570,921,930,961,970,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI021']  = (-999999,382,466,470,476,563,570,921,930,961,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AI030']  = (-999999,16,20,40,60,563,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AL020']  = (-999999,99,350,440,563,835,930,999)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['FFN3']['AL105']  = (-999999,99,350,440,563,883,930,999)
    field_information['TDS 4.0']['SettlementSrf']['HGT'] = ('REAL',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['HHD'] = ('Boolean',('AL105'))
    field_information['TDS 4.0']['SettlementSrf']['LMC'] = ('Boolean',('AI020','AI021','AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['LZN'] = ('REAL',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['OTH'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['PCF'] = ('Enumeration',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI021']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AI030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL105']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['PCF']['AL208']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['SettlementSrf']['STL'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementSrf']['STL2'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL2'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL2']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementSrf']['STL3'] = ('Enumeration',('AI030'))
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL3'] = {}
    field_information['TDS 4.0']['SettlementSrf']['EnumeratedIndexValues']['STL3']['AI030']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['SettlementSrf']['UFI'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['WID'] = ('REAL',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['WPI'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['ZI004_RCG'] = ('CodeList',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_FNA'] = ('String',('AI020','AI021','AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_FNA1'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_FNA2'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_NFN'] = ('String',('AI020','AI021','AI030','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_NFN1'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['ZI005_NFN2'] = ('String',('AL020'))
    field_information['TDS 4.0']['SettlementSrf']['ZI006_MEM'] = ('String',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZSAX_RS0'] = ('CodeList',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZSAX_RX3'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZSAX_RX4'] = ('StructuredText',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['SettlementSrf']['ZVH'] = ('REAL',('AI020','AI021','AI030','AL020','AL105','AL208'))
    field_information['TDS 4.0']['StoragePnt']['ADR'] = ('String',('AM010','AM030','AM065','AM071','AM075'))
    field_information['TDS 4.0']['StoragePnt']['ARA'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['AWP'] = ('Boolean',('AM030','AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['CAA'] = ('Enumeration',('AM010','AM065','AM071','AM075'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StoragePnt']['CBP'] = ('Boolean',('AM070'))
    field_information['TDS 4.0']['StoragePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['FFN'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StoragePnt']['FFN2'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StoragePnt']['FFN3'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StoragePnt']['HGT'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['LMC'] = ('Boolean',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['LUN'] = ('Boolean',('AM010','AM065','AM070','AM075'))
    field_information['TDS 4.0']['StoragePnt']['LZN'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['OTH'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['PCF'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StoragePnt']['PPO'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StoragePnt']['PPO2'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StoragePnt']['PPO3'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StoragePnt']['SHT'] = ('Enumeration',('AM011'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SHT'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StoragePnt']['SPT'] = ('Boolean',('AM011','AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['SSC'] = ('Enumeration',('AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSC'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,999)
    field_information['TDS 4.0']['StoragePnt']['SSR'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StoragePnt']['SSR2'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StoragePnt']['SSR3'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StoragePnt']['UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['VCM'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StoragePnt']['VCM2'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StoragePnt']['VCM3'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StoragePnt']['VLM'] = ('REAL',('AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['VOI'] = ('StructuredText',('AM030','AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['WID'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['YWQ'] = ('Enumeration',('AM070','AM080'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StoragePnt']['ZI004_RCG'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZI005_FNA'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZI005_NFN'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZI006_MEM'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZI018_WIT'] = ('Enumeration',('AM071'))
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['StoragePnt']['EnumeratedIndexValues']['ZI018_WIT']['AM071']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StoragePnt']['ZSAX_RS0'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZSAX_RX3'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZSAX_RX4'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StoragePnt']['ZVH'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ADR'] = ('String',('AM010','AM030','AM065','AM071','AM075'))
    field_information['TDS 4.0']['StorageSrf']['ARA'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['AWP'] = ('Boolean',('AM030','AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['CAA'] = ('Enumeration',('AM010','AM065','AM071','AM075'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM065']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM071']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['CAA']['AM075']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StorageSrf']['CBP'] = ('Boolean',('AM070'))
    field_information['TDS 4.0']['StorageSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['FFN'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StorageSrf']['FFN2'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN2']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StorageSrf']['FFN3'] = ('Enumeration',('AM010','AM011','AM071','AM075'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM010']  = (-999999,2,40,60,99,351,385,440,459,473,480,484,490,495,497,530,835,847,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM011']  = (-999999,2,99,330,334,383,475,480,490,497,505,529,530,536,550,781,843,881,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM071']  = (-999999,60,192,195,350,351,484,497,500,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['FFN3']['AM075']  = (-999999,40,192,350,470,480,484,490,495,505,508,520,811,835,841,999)
    field_information['TDS 4.0']['StorageSrf']['HGT'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['LMC'] = ('Boolean',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['LUN'] = ('Boolean',('AM010','AM065','AM070','AM075'))
    field_information['TDS 4.0']['StorageSrf']['LZN'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['OTH'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['PCF'] = ('Enumeration',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM011']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM071']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PCF']['AM080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StorageSrf']['PPO'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StorageSrf']['PPO2'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO2']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StorageSrf']['PPO3'] = ('Enumeration',('AM010','AM070','AM071'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM010']  = (-999999,1,3,16,18,19,21,38,45,46,53,63,83,90,95,96,110,116,117,120,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM070']  = (-999999,16,45,46,61,62,83,90,101,122,214,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['PPO3']['AM071']  = (-999999,16,45,46,61,62,83,214,999)
    field_information['TDS 4.0']['StorageSrf']['SHT'] = ('Enumeration',('AM011'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SHT'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SHT']['AM011']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StorageSrf']['SPT'] = ('Boolean',('AM011','AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['SSC'] = ('Enumeration',('AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSC'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSC']['AM070']  = (-999999,2,4,12,17,59,65,66,71,87,88,89,91,92,94,99,100,101,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSC']['AM080']  = (-999999,17,65,66,71,88,89,999)
    field_information['TDS 4.0']['StorageSrf']['SSR'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StorageSrf']['SSR2'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR2']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StorageSrf']['SSR3'] = ('Enumeration',('AM030'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['SSR3']['AM030']  = (-999999,6,7,38,40,41,42,999)
    field_information['TDS 4.0']['StorageSrf']['UFI'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['VCM'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StorageSrf']['VCM2'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM2']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StorageSrf']['VCM3'] = ('Enumeration',('AM011','AM030','AM070'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM011']  = (-999999,2,4,7,8,9,12,13,15,17,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM030']  = (-999999,2,4,7,8,9,12,13,15,18,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['VCM3']['AM070']  = (-999999,2,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['StorageSrf']['VLM'] = ('REAL',('AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['VOI'] = ('StructuredText',('AM030','AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['WID'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['YWQ'] = ('Enumeration',('AM070','AM080'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['YWQ'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['YWQ']['AM070']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['YWQ']['AM080']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StorageSrf']['ZI004_RCG'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZI005_FNA'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZI005_NFN'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZI006_MEM'] = ('String',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZI018_WIT'] = ('Enumeration',('AM071'))
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['StorageSrf']['EnumeratedIndexValues']['ZI018_WIT']['AM071']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StorageSrf']['ZSAX_RS0'] = ('CodeList',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZSAX_RX3'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZSAX_RX4'] = ('StructuredText',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StorageSrf']['ZVH'] = ('REAL',('AM010','AM011','AM030','AM065','AM070','AM071','AM075','AM080'))
    field_information['TDS 4.0']['StructureCrv']['AOO'] = ('REAL',('AL018'))
    field_information['TDS 4.0']['StructureCrv']['ARA'] = ('REAL',('AL018','AL080','AL140','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['AWP'] = ('Boolean',('AL018','AL080'))
    field_information['TDS 4.0']['StructureCrv']['BAT'] = ('Enumeration',('AL070','AL260'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['BAT'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['BAT']['AL070']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['BAT']['AL260']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StructureCrv']['BSU'] = ('Enumeration',('AL018'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['BSU'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['TDS 4.0']['StructureCrv']['CRM'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['CRM'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['FFN'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructureCrv']['FFN2'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructureCrv']['FFN3'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructureCrv']['FTI'] = ('Enumeration',('AL070'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FTI'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['FTI']['AL070']  = (-999999,1,2,5,6,7,8,9,999)
    field_information['TDS 4.0']['StructureCrv']['HEI'] = ('REAL',('AL018'))
    field_information['TDS 4.0']['StructureCrv']['HGT'] = ('REAL',('AL018','AL070','AL080','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['LMC'] = ('Boolean',('AL018','AL070','AL080','AL140','AL260'))
    field_information['TDS 4.0']['StructureCrv']['LZN'] = ('REAL',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['MCC'] = ('Enumeration',('AL070','AL260'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC']['AL260']  = (-999999,9,21,62,64,77,83,107,108,117,150,999)
    field_information['TDS 4.0']['StructureCrv']['MCC2'] = ('Enumeration',('AL070','AL260'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC2']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC2']['AL260']  = (-999999,9,21,62,64,77,83,107,108,117,150,999)
    field_information['TDS 4.0']['StructureCrv']['MCC3'] = ('Enumeration',('AL070','AL260'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC3']['AL070']  = (-999999,9,21,62,64,108,117,999)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['MCC3']['AL260']  = (-999999,9,21,62,64,77,83,107,108,117,150,999)
    field_information['TDS 4.0']['StructureCrv']['OTH'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['PCF'] = ('Enumeration',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AL260']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureCrv']['THI'] = ('REAL',('AL070','AL260'))
    field_information['TDS 4.0']['StructureCrv']['UFI'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['VCM'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructureCrv']['VCM2'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructureCrv']['VCM3'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructureCrv']['VOI'] = ('StructuredText',('AL018','AL080'))
    field_information['TDS 4.0']['StructureCrv']['WID'] = ('REAL',('AL018','AL080','AL140','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['WTI'] = ('Enumeration',('AL260'))
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['WTI'] = {}
    field_information['TDS 4.0']['StructureCrv']['EnumeratedIndexValues']['WTI']['AL260']  = (-999999,1,2,999)
    field_information['TDS 4.0']['StructureCrv']['ZI004_RCG'] = ('CodeList',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZI005_FNA'] = ('String',('AL018','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZI005_NFN'] = ('String',('AL018','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZI006_MEM'] = ('String',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZSAX_RS0'] = ('CodeList',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZSAX_RX3'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZSAX_RX4'] = ('StructuredText',('AL018','AL070','AL080','AL140','AL260','AQ150'))
    field_information['TDS 4.0']['StructureCrv']['ZVH'] = ('REAL',('AL018','AL070','AL080','AL260','AQ150'))
    field_information['TDS 4.0']['StructurePnt']['ADR'] = ('String',('AL013','AL019','AL099','AL142','AL250'))
    field_information['TDS 4.0']['StructurePnt']['AOO'] = ('REAL',('AG050','AL013','AL014','AL018','AL019','AL142'))
    field_information['TDS 4.0']['StructurePnt']['ARA'] = ('REAL',('AF060','AG050','AL013','AL014','AL018','AL019','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ATB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['AWP'] = ('Boolean',('AF060','AG050','AL013','AL014','AL018','AL073','AL080','AL110','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['BNF'] = ('Integer',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['BSU'] = ('Enumeration',('AL018'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['BSU'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['TDS 4.0']['StructurePnt']['CAA'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StructurePnt']['CRM'] = ('Enumeration',('AL080'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['CRM'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['CRM']['AL080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['ETY'] = ('Enumeration',('AF060'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ETY'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StructurePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['FFN'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL110']  = (-999999,480,490,495,921,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructurePnt']['FFN2'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL110']  = (-999999,480,490,495,921,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructurePnt']['FFN3'] = ('Enumeration',('AG050','AL013','AL019','AL080','AL099','AL110','AL142'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AG050']  = (-999999,343,382,466,470,476,488,548,570,580,610,640,680,681,760,808,830,850,860,887,890,900,930,950,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL080']  = (-999999,99,480,486,490,495,505,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL110']  = (-999999,480,490,495,921,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructurePnt']['GUG'] = ('Boolean',('AL241'))
    field_information['TDS 4.0']['StructurePnt']['HEI'] = ('REAL',('AG050','AL018','AL073','AL241'))
    field_information['TDS 4.0']['StructurePnt']['HGT'] = ('REAL',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['HST'] = ('Enumeration',('AL013','AL250'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST']['AL250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['HST2'] = ('Enumeration',('AL013','AL250'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST2']['AL250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['HST3'] = ('Enumeration',('AL013','AL250'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['HST3']['AL250']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['LMC'] = ('Boolean',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['LZN'] = ('REAL',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['MFB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['MUB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['OTH'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['PCF'] = ('Enumeration',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AG050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL073']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL110']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PCF']['AL250']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructurePnt']['PYC'] = ('Enumeration',('AL110','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYC'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYC']['AL110']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StructurePnt']['PYM'] = ('Enumeration',('AL110','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYM']['AL110']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['StructurePnt']['SPT'] = ('Boolean',('AL241'))
    field_information['TDS 4.0']['StructurePnt']['SRL'] = ('Enumeration',('AF060'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['TDS 4.0']['StructurePnt']['SSR'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructurePnt']['SSR2'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructurePnt']['SSR3'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructurePnt']['TEL'] = ('Enumeration',('AL142'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TEL'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructurePnt']['TOS'] = ('Enumeration',('AL110','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TOS']['AL110']  = (-999999,6,8,12,13,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['TDS 4.0']['StructurePnt']['TTC'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructurePnt']['TTC2'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructurePnt']['TTC3'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructurePnt']['UFI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['VCM'] = ('Enumeration',('AL013','AL019','AL080'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructurePnt']['VCM2'] = ('Enumeration',('AL013','AL019','AL080'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM2']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructurePnt']['VCM3'] = ('Enumeration',('AL013','AL019','AL080'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['VCM3']['AL080']  = (-999999,2,7,9,15,999)
    field_information['TDS 4.0']['StructurePnt']['VOI'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL073','AL080','AL110','AL142','AL241'))
    field_information['TDS 4.0']['StructurePnt']['WID'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZI004_RCG'] = ('CodeList',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZI005_FNA'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZI005_NFN'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZI006_MEM'] = ('String',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZI014_PBY'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PBY2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PBY3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PPO'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PPO2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PPO3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PRW'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PRW2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['ZI014_PRW3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructurePnt']['ZI018_WIT'] = ('Enumeration',('AL013','AL241'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StructurePnt']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['StructurePnt']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['StructurePnt']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['StructurePnt']['ZSAX_RS0'] = ('CodeList',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZSAX_RX3'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZSAX_RX4'] = ('StructuredText',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241','AL250'))
    field_information['TDS 4.0']['StructurePnt']['ZVH'] = ('REAL',('AF060','AG050','AL013','AL014','AL018','AL019','AL073','AL080','AL099','AL110','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['ADR'] = ('String',('AL013','AL019','AL099','AL142'))
    field_information['TDS 4.0']['StructureSrf']['AOO'] = ('REAL',('AL013','AL014','AL018','AL019','AL142'))
    field_information['TDS 4.0']['StructureSrf']['ARA'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ATB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['AWP'] = ('Boolean',('AF060','AL013','AL014','AL018','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['BNF'] = ('Integer',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['BSU'] = ('Enumeration',('AL018'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['BSU'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['BSU']['AL018']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,999)
    field_information['TDS 4.0']['StructureSrf']['CAA'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['CAA']['AL013']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['StructureSrf']['ETY'] = ('Enumeration',('AF060'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ETY'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ETY']['AF060']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['StructureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['FFN'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructureSrf']['FFN2'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN2']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructureSrf']['FFN3'] = ('Enumeration',('AL013','AL019','AL099','AL142'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL013']  = (-999999,2,3,9,14,27,35,40,95,99,100,101,102,103,104,105,106,107,110,111,112,113,114,115,116,118,119,120,121,122,123,124,125,129,130,140,150,155,160,161,165,171,181,190,191,192,195,210,221,225,230,231,232,233,234,235,236,237,240,241,242,243,250,251,255,257,260,270,272,280,289,290,301,304,305,306,310,320,321,322,323,324,325,330,331,332,333,334,340,341,342,343,350,351,352,355,356,360,362,363,370,372,382,383,385,440,459,460,464,465,466,470,473,474,475,476,477,478,480,481,482,483,484,486,487,488,489,490,491,494,495,496,497,500,501,505,507,508,510,511,512,513,520,525,529,530,535,536,537,538,539,540,541,545,548,549,550,551,552,553,554,555,556,557,558,563,570,572,573,574,578,579,580,582,594,601,604,610,612,614,615,616,617,620,621,622,625,626,632,633,640,642,643,651,662,663,671,680,681,691,696,701,706,711,714,717,720,721,722,725,730,741,752,757,760,761,770,775,780,781,791,795,801,807,808,809,810,811,812,813,814,815,817,818,819,821,822,825,826,827,828,829,830,831,832,833,835,836,837,838,839,840,841,842,843,844,845,846,847,848,850,851,852,855,857,860,861,862,863,864,865,866,871,873,875,881,882,883,884,885,887,888,890,891,892,893,894,895,900,902,905,906,907,909,912,913,914,919,921,922,923,930,931,932,950,954,955,961,962,963,964,965,966,967,970,980,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL019']  = (-999999,2,480,490,494,495,500,505,508,520,530,722,847,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL099']  = (-999999,2,9,14,557,563,721,722,847,866,881,883,930,970,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['FFN3']['AL142']  = (-999999,720,721,850,923,999)
    field_information['TDS 4.0']['StructureSrf']['GUG'] = ('Boolean',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['HEI'] = ('REAL',('AL018','AL241'))
    field_information['TDS 4.0']['StructureSrf']['HGT'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL099','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['HST'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructureSrf']['HST2'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST2']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructureSrf']['HST3'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['HST3']['AL013']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructureSrf']['LMC'] = ('Boolean',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['LZN'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['MFB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['MUB'] = ('Boolean',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['OTH'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['PCF'] = ('Enumeration',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AF060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL013']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL014']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL018']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL019']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL099']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL140']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL142']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AL241']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PCF']['AQ150']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['StructureSrf']['PYC'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PYC'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PYC']['AL241']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['StructureSrf']['PYM'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PYM'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['PYM']['AL241']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['StructureSrf']['SPT'] = ('Boolean',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['SRL'] = ('Enumeration',('AF060'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SRL']['AF060']  = (-999999,1,2,3)
    field_information['TDS 4.0']['StructureSrf']['SSR'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructureSrf']['SSR2'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR2']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructureSrf']['SSR3'] = ('Enumeration',('AL013','AL019','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL013']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL019']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL142']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['SSR3']['AL241']  = (-999999,6,7,38,40,41,42,82,999)
    field_information['TDS 4.0']['StructureSrf']['TEL'] = ('Enumeration',('AL142'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TEL'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TEL']['AL142']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['StructureSrf']['TOS'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TOS']['AL241']  = (-999999,6,8,12,13,999)
    field_information['TDS 4.0']['StructureSrf']['TTC'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructureSrf']['TTC2'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC2']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructureSrf']['TTC3'] = ('Enumeration',('AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['TTC3']['AL241']  = (-999999,2,10,12,20,21,22,23,24,999)
    field_information['TDS 4.0']['StructureSrf']['UFI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['VCM'] = ('Enumeration',('AL013','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructureSrf']['VCM2'] = ('Enumeration',('AL013','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM2']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM2']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructureSrf']['VCM3'] = ('Enumeration',('AL013','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM3']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['VCM3']['AL019']  = (-999999,1,2,4,5,7,8,9,10,11,14,15,16,18,999)
    field_information['TDS 4.0']['StructureSrf']['VOI'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL142','AL241'))
    field_information['TDS 4.0']['StructureSrf']['WID'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZI004_RCG'] = ('CodeList',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZI005_FNA'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZI005_NFN'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZI006_MEM'] = ('String',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZI014_PBY'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PBY2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY2']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PBY3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL013']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL014']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PBY3']['AL019']  = (-999999,1,2,6,7,8,12,13,15,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PPO'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PPO2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO2']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PPO3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL013']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL014']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PPO3']['AL019']  = (-999999,1,2,3,4,5,13,15,16,18,20,21,23,25,26,28,32,37,38,39,41,43,44,45,46,47,48,57,58,59,60,61,62,63,65,69,70,73,74,80,83,84,87,90,92,94,95,101,105,106,109,111,114,117,120,121,122,123,126,136,137,146,147,148,150,154,155,156,157,160,165,192,214,279,325,435,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PRW'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PRW2'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW2']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['ZI014_PRW3'] = ('Enumeration',('AL013','AL014','AL019'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL013']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL014']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI014_PRW3']['AL019']  = (-999999,1,2,5,9,10,11,12,14,16,18,27,28,29,33,38,39,41,45,46,48,50,52,54,57,60,64,66,75,78,79,83,85,87,90,93,94,96,97,99,118,999)
    field_information['TDS 4.0']['StructureSrf']['ZI018_WIT'] = ('Enumeration',('AL013','AL241'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AL013']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AL241']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['StructureSrf']['ZI037_REL'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_REL']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['StructureSrf']['ZI037_RFA'] = ('Enumeration',('AL013'))
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['StructureSrf']['EnumeratedIndexValues']['ZI037_RFA']['AL013']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,18,19,20,21,22,23,999)
    field_information['TDS 4.0']['StructureSrf']['ZSAX_RS0'] = ('CodeList',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZSAX_RX3'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZSAX_RX4'] = ('StructuredText',('AF060','AL013','AL014','AL018','AL019','AL099','AL140','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['StructureSrf']['ZVH'] = ('REAL',('AF060','AL013','AL014','AL018','AL019','AL099','AL142','AL241','AQ150'))
    field_information['TDS 4.0']['TransportationGroundCrv']['AOO'] = ('REAL',('AL211'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ARA'] = ('REAL',('AL155','AL195','AL211','AP010','AP030','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ130','AQ151','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['AWP'] = ('Boolean',('AQ040','AQ050','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['BCC'] = ('Enumeration',('AL155','AQ040','AQ059','AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['BRN'] = ('String',('AQ040','AQ045','AQ050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['BSC'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['CAA'] = ('Enumeration',('AN010','AP030','AP040','AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AN010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['CAT'] = ('Enumeration',('AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAT'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CAT']['AT041']  = (-999999,2,3,5,6,7,8,9,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['CON'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CON'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['COS'] = ('Enumeration',('AN010','AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AN010']  = (-999999,4,6,9,13,14)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['COS']['AN050']  = (-999999,4,6,9,13,14)
    field_information['TDS 4.0']['TransportationGroundCrv']['CTC'] = ('Enumeration',('AQ065'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CTC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['CTL'] = ('REAL',('AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['CWT'] = ('Boolean',('AN010','AN050','AP010','AP030','AP050','AQ035'))
    field_information['TDS 4.0']['TransportationGroundCrv']['DEV'] = ('Integer',('AL155','AN010','AP010','AP030','AP050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['DZC'] = ('Integer',('AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EXP'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['EXP'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['FCO'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FCO'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['TDS 4.0']['TransportationGroundCrv']['FFN'] = ('Enumeration',('AP040','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN']['AT041']  = (-999999,99,480,921,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['FFN2'] = ('Enumeration',('AP040','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN2']['AT041']  = (-999999,99,480,921,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['FFN3'] = ('Enumeration',('AP040','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['FFN3']['AT041']  = (-999999,99,480,921,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['FSC'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['GTC'] = ('Enumeration',('AP040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GTC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['HCA'] = ('REAL',('AL211','AQ040','AQ059','AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['HEI'] = ('REAL',('AQ050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['HGT'] = ('REAL',('AL211','AP040','AP041','AQ040','AQ045','AQ050','AQ056','AQ063','AQ130','AQ151','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['HST'] = ('Enumeration',('AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['HST2'] = ('Enumeration',('AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['HST3'] = ('Enumeration',('AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['LC1'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LC2'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LC3'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LC4'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LMC'] = ('Boolean',('AL211','AN010','AP050','AQ035','AQ040','AQ050','AQ056','AQ063','AQ120','AQ151','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LOC'] = ('Enumeration',('AN010','AN050','AP010','AP030','AP050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AN010']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AN050']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP010']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['LOC']['AP050']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundCrv']['LOG'] = ('REAL',('AQ120'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LTN'] = ('Integer',('AN010','AN050','AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['LZN'] = ('REAL',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['MCC'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['MCC2'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['MCC3'] = ('Enumeration',('AP041','AQ063','AQ065'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['MES'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['MWG'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['NOS'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['OHC'] = ('REAL',('AL155','AL211','AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ONE'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['OOC'] = ('Enumeration',('AL155'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['OOC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['OTH'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['OWO'] = ('Boolean',('AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['PCF'] = ('Enumeration',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AN010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AN050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AP050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ035']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['AT041']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundCrv']['PFH'] = ('REAL',('AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RFD'] = ('Boolean',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RLE'] = ('Enumeration',('AN010','AN050','AP010','AP030','AP050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AN010']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AN050']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP010']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RLE']['AP050']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['RMWC'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['RMWL'] = ('real',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RMWU'] = ('real',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RRC'] = ('Enumeration',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RRC2'] = ('Enumeration',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC2']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RRC3'] = ('Enumeration',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RRC3']['AN010']  = (-999999,2,6,8,11,13,14,15,24,32,33,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RSA'] = ('Enumeration',('AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RSA'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RSA']['AN050']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RTA'] = ('Enumeration',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTA'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTA']['AN010']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN_ROI'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN_ROI2'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN_ROI3'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RTN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN2'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RTN3'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['RWC'] = ('Enumeration',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RWC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['RWC']['AN010']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['SBB'] = ('Boolean',('AN010','AN050','AP010','AP030','AP050','AQ035'))
    field_information['TDS 4.0']['TransportationGroundCrv']['SEP'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['SGCC'] = ('Enumeration',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AN010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AN050']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ035']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SGCC']['AQ120']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundCrv']['SGCL'] = ('real',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['TDS 4.0']['TransportationGroundCrv']['SGCU'] = ('real',('AN010','AN050','AP030','AQ035','AQ063','AQ120'))
    field_information['TDS 4.0']['TransportationGroundCrv']['SHC'] = ('REAL',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundCrv']['SRE'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SRE'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,4,5,8,9,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TCS'] = ('Enumeration',('AQ065'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TCS'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['THI'] = ('REAL',('AP040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['THR'] = ('Boolean',('AP010','AP030','AP050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['TRA'] = ('Boolean',('AQ130'))
    field_information['TDS 4.0']['TransportationGroundCrv']['TRP'] = ('Enumeration',('AL211'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRP'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TRS'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP010']  = (-999999,3,4,6,11,21,22,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ120']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TRS2'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP010']  = (-999999,3,4,6,11,21,22,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ120']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TRS3'] = ('Enumeration',('AL155','AL211','AP010','AP040','AP041','AQ040','AQ059','AQ063','AQ120','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP010']  = (-999999,3,4,6,11,21,22,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ120']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TST'] = ('Enumeration',('AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TST'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TST']['AT041']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['TYP'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TYP'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['TYP']['AP030']  = (-999999,1,5,9,13,17,21,25,29,33,37,41,45,47,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['UBC'] = ('REAL',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['UFI'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['VCM'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['VCM2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['VCM3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['VOI'] = ('StructuredText',('AQ040','AQ050','AT041'))
    field_information['TDS 4.0']['TransportationGroundCrv']['WD1'] = ('REAL',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundCrv']['WD2'] = ('REAL',('AP030','AP040'))
    field_information['TDS 4.0']['TransportationGroundCrv']['WID'] = ('REAL',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ065','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['WLE'] = ('Enumeration',('AQ063'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,2,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['WT2'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI004_RCG'] = ('CodeList',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI005_FNA'] = ('String',('AL195','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ056','AQ063','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI005_NFN'] = ('String',('AL195','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ056','AQ063','AQ075','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI006_MEM'] = ('String',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI016_ROC'] = ('Enumeration',('AP030','AQ035','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['AQ035']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI016_WD1'] = ('REAL',('AP010','AP030','AQ035'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI016_WTC'] = ('Enumeration',('AP010','AP030','AP050','AQ035'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AP050']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI016_WTC']['AQ035']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI017_GAW'] = ('REAL',('AN010','AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI017_RGC'] = ('Enumeration',('AN010','AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC']['AN010']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RGC']['AN050']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI017_RIR'] = ('Boolean',('AN010'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI017_RRA'] = ('Enumeration',('AN010','AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA']['AN010']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_RRA']['AN050']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['ZI017_TRT'] = ('Enumeration',('AN010','AN050'))
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT']['AN010']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['EnumeratedIndexValues']['ZI017_TRT']['AN050']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundCrv']['ZSAX_RS0'] = ('CodeList',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZSAX_RX3'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZSAX_RX4'] = ('StructuredText',('AL155','AL195','AL211','AN010','AN050','AP010','AP030','AP040','AP041','AP050','AQ035','AQ040','AQ045','AQ050','AQ056','AQ059','AQ063','AQ065','AQ075','AQ120','AQ130','AQ151','AT041','BH070'))
    field_information['TDS 4.0']['TransportationGroundCrv']['ZVH'] = ('REAL',('AL211','AP041','AQ035','AQ040','AQ045','AQ050','AQ056','AQ063','AQ151','AT041'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ADI'] = ('Enumeration',('AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ADI'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ADI']['AQ162']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['ADR'] = ('String',('AN076','AQ125','AQ135','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['AOO'] = ('REAL',('AL211','AN076','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ARA'] = ('REAL',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP041','AQ040','AQ045','AQ055','AQ056','AQ062','AQ065','AQ068','AQ125','AQ135','AQ141','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ATB'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['AWP'] = ('Boolean',('AN076','AQ040','AQ055','AQ141'))
    field_information['TDS 4.0']['TransportationGroundPnt']['BCC'] = ('Enumeration',('AL155','AQ040','AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AL155']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BCC']['AQ059']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['BRN'] = ('String',('AQ040','AQ045','AQ055'))
    field_information['TDS 4.0']['TransportationGroundPnt']['BSC'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CAA'] = ('Enumeration',('AP040','AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AP040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CON'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CON'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CON']['AQ059']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CSC'] = ('Enumeration',('AQ062'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CSC2'] = ('Enumeration',('AQ062'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC2']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CSC3'] = ('Enumeration',('AQ062'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CSC3']['AQ062']  = (-999999,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CTC'] = ('Enumeration',('AQ065'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CTC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['CTC']['AQ065']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['CWT'] = ('Boolean',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['DEV'] = ('Integer',('AL155'))
    field_information['TDS 4.0']['TransportationGroundPnt']['DGC'] = ('Enumeration',('AQ068'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['DGC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['DZC'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EXP'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['EXP'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['EXP']['AQ059']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['FFN'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['FFN2'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['FFN3'] = ('Enumeration',('AH070','AN076','AP040','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AH070']  = (-999999,537,538,539,830,831,833,842,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AP040']  = (-999999,2,480,830,831,833,842,907,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['GTC'] = ('Enumeration',('AP040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GTC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['GTC']['AP040']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['HCA'] = ('REAL',('AL211','AQ040','AQ059','AQ095'))
    field_information['TDS 4.0']['TransportationGroundPnt']['HEI'] = ('REAL',('AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['HGT'] = ('REAL',('AL211','AN076','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['HST'] = ('Enumeration',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['HST2'] = ('Enumeration',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['HST3'] = ('Enumeration',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['LC1'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LC2'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LC3'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LC4'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LMC'] = ('Boolean',('AH070','AL211','AN075','AN076','AP020','AQ040','AQ055','AQ056','AQ118','AQ125','AQ135','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LOC'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['LOC']['AP020']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundPnt']['LTN'] = ('Integer',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LUN'] = ('Boolean',('AQ125','AQ141'))
    field_information['TDS 4.0']['TransportationGroundPnt']['LZN'] = ('REAL',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['MCC'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC']['AQ162']  = (-999999,64,74,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['MCC2'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC2']['AQ162']  = (-999999,64,74,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['MCC3'] = ('Enumeration',('AP041','AQ065','AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AP041']  = (-999999,21,62,64,77,83,104,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AQ065']  = (-999999,21,62,64,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['MCC3']['AQ162']  = (-999999,64,74,117,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['MFB'] = ('Boolean',('AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['MUB'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['NOS'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['OHC'] = ('REAL',('AL155','AL211','AQ040','AQ095'))
    field_information['TDS 4.0']['TransportationGroundPnt']['OOC'] = ('Enumeration',('AL155'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['OOC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['OOC']['AL155']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['OTH'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['PCF'] = ('Enumeration',('AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ065','AQ068','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL155']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL165']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AN085']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AP041']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ065']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ095']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ160']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ161']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ162']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['AQ180']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundPnt']['PYM'] = ('Enumeration',('AQ055'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PYM'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['PYM']['AQ055']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['RAD'] = ('REAL',('AQ118'))
    field_information['TDS 4.0']['TransportationGroundPnt']['RFD'] = ('Boolean',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['RIT'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIT'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RIT']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['RLE'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RLE']['AP020']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN'] = ('String',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN_ROI'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN_ROI2'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI2']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN_ROI3'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['RTN_ROI3']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN2'] = ('String',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['RTN3'] = ('String',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SBB'] = ('Boolean',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SGCC'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SGCC']['AP020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundPnt']['SGCL'] = ('real',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SGCU'] = ('real',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SHC'] = ('REAL',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SPT'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundPnt']['SRE'] = ('Enumeration',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SRE'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SRE']['AQ059']  = (-999999,1,2,3,4,5,8,9,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['SSG'] = ('Enumeration',('AQ162'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSG'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSG']['AQ162']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['SSR'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['SSR2'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR2']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['SSR3'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['SSR3']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['TCS'] = ('Enumeration',('AQ065'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TCS'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TCS']['AQ065']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['THI'] = ('REAL',('AP040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['THR'] = ('Boolean',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['TRP'] = ('Enumeration',('AL211'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRP'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['TRS'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AQ040','AQ059','AQ062','AQ068','AQ125','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AH070']  = (-999999,1,3,4,7,8,9,12,15,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ062']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['TRS2'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AQ040','AQ059','AQ062','AQ068','AQ125','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AH070']  = (-999999,1,3,4,7,8,9,12,15,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ062']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['TRS3'] = ('Enumeration',('AH070','AL155','AL211','AP040','AP041','AQ040','AQ059','AQ062','AQ068','AQ125','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AH070']  = (-999999,1,3,4,7,8,9,12,15,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AL155']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AP040']  = (-999999,4,9,12,13,15,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AP041']  = (-999999,12,13,16,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ059']  = (-999999,5,9,12,13,17,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ062']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['TYP'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TYP'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['TYP']['AP020']  = (-999999,1,33,47,48,50,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['UBC'] = ('REAL',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['UFI'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['VCM'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['VCM2'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['VCM3'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['VOI'] = ('StructuredText',('AN076','AQ040','AQ055','AQ141'))
    field_information['TDS 4.0']['TransportationGroundPnt']['VST'] = ('Integer',('AQ180'))
    field_information['TDS 4.0']['TransportationGroundPnt']['WD1'] = ('REAL',('AQ059'))
    field_information['TDS 4.0']['TransportationGroundPnt']['WD2'] = ('REAL',('AP040'))
    field_information['TDS 4.0']['TransportationGroundPnt']['WID'] = ('REAL',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP041','AQ040','AQ045','AQ055','AQ056','AQ062','AQ065','AQ068','AQ125','AQ135','AQ141','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI004_RCG'] = ('CodeList',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI005_FNA'] = ('String',('AH070','AL165','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ056','AQ062','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI005_NFN'] = ('String',('AH070','AL165','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ056','AQ062','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI006_MEM'] = ('String',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI016_ROC'] = ('Enumeration',('AP020','AQ135','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['AP020']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI016_WD1'] = ('REAL',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI016_WTC'] = ('Enumeration',('AP020'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI016_WTC']['AP020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI017_GAW'] = ('REAL',('AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI017_RGC'] = ('Enumeration',('AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI017_RRA'] = ('Enumeration',('AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['ZI017_TRT'] = ('Enumeration',('AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundPnt']['ZSAX_RS0'] = ('CodeList',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZSAX_RX3'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZSAX_RX4'] = ('StructuredText',('AH070','AL155','AL165','AL211','AN075','AN076','AN085','AP020','AP040','AP041','AQ040','AQ045','AQ055','AQ056','AQ059','AQ062','AQ065','AQ068','AQ095','AQ118','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundPnt']['ZVH'] = ('REAL',('AL211','AN076','AP041','AQ040','AQ045','AQ055','AQ056','AQ095','AQ125','AQ135','AQ141','AQ160','AQ161','AQ162','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ADR'] = ('String',('AN060','AN076','AQ125','AQ135','AQ140','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['AOO'] = ('REAL',('AL211','AN076','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ARA'] = ('REAL',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ATB'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundSrf']['AWP'] = ('Boolean',('AN076','AQ040','AQ050','AQ141'))
    field_information['TDS 4.0']['TransportationGroundSrf']['BCC'] = ('Enumeration',('AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC']['AQ040']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BCC']['AQ130']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundSrf']['BOT'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT']['AQ040']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BOT']['AQ045']  = (-999999,4,10,11,12,14,15,16,17,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['BRN'] = ('String',('AQ040','AQ045','AQ050'))
    field_information['TDS 4.0']['TransportationGroundSrf']['BSC'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['BSC2'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC2']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['BSC3'] = ('Enumeration',('AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3']['AQ040']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,22,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['BSC3']['AQ045']  = (-999999,1,2,5,6,7,8,9,12,15,16,19,26,27,30,31,32,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['CAA'] = ('Enumeration',('AP030','AQ040','AQ140'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AP030']  = (-999999,3,4,5,6,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ040']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['CAA']['AQ140']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['COS'] = ('Enumeration',('AN060'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['COS']['AN060']  = (-999999,4,6,9,13,14)
    field_information['TDS 4.0']['TransportationGroundSrf']['CTL'] = ('REAL',('AN060'))
    field_information['TDS 4.0']['TransportationGroundSrf']['CWT'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['DEV'] = ('Integer',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['DGC'] = ('Enumeration',('AQ068'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['DGC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['DGC']['AQ068']  = (-999999,1,2,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['DZC'] = ('Integer',('AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['FCO'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FCO'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FCO']['AP030']  = (-999999,5,6,7)
    field_information['TDS 4.0']['TransportationGroundSrf']['FFN'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['FFN2'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN2']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['FFN3'] = ('Enumeration',('AN060','AN076','AQ125','AQ135','AQ141','AQ170'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AN060']  = (-999999,304,342,482,484,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AN076']  = (-999999,342,490,530,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ125']  = (-999999,382,481,482,483,484,489,490,491,494,495,500,505,507,508,520,530,535,537,538,539,540,551,570,572,573,775,833,841,842,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ135']  = (-999999,382,466,470,488,570,572,612,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ141']  = (-999999,343,470,483,495,530,535,761,847,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['FFN3']['AQ170']  = (-999999,343,382,466,470,970,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['FSC'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['HCA'] = ('REAL',('AL211','AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['HEI'] = ('REAL',('AQ050'))
    field_information['TDS 4.0']['TransportationGroundSrf']['HGT'] = ('REAL',('AL211','AN060','AN076','AQ040','AQ045','AQ050','AQ056','AQ063','AQ125','AQ130','AQ135','AQ141','AQ151','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['HST'] = ('Enumeration',('AQ125','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['HST2'] = ('Enumeration',('AQ125','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST2']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['HST3'] = ('Enumeration',('AQ125','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3']['AQ125']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['HST3']['AQ130']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['LC1'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LC2'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LC3'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LC4'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LMC'] = ('Boolean',('AL211','AN060','AN075','AN076','AQ040','AQ050','AQ056','AQ063','AQ125','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LOC'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['LOC']['AP030']  = (-999999,17,40,44)
    field_information['TDS 4.0']['TransportationGroundSrf']['LTN'] = ('Integer',('AN060','AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LUN'] = ('Boolean',('AQ125','AQ141'))
    field_information['TDS 4.0']['TransportationGroundSrf']['LZN'] = ('REAL',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['MCC'] = ('Enumeration',('AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['MCC2'] = ('Enumeration',('AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC2']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['MCC3'] = ('Enumeration',('AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['MCC3']['AQ063']  = (-999999,8,46,52,55,65,84,86,88,104,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['MES'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['MFB'] = ('Boolean',('AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['MUB'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundSrf']['MWG'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['NOS'] = ('Integer',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['OHC'] = ('REAL',('AL211','AQ040','AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ONE'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['OTH'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['PCF'] = ('Enumeration',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AL195']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AL211']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN075']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AN076']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AP030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ040']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ056']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ063']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ068']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ125']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ130']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ135']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ140']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ141']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ151']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ170']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['AQ180']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['PCF']['BH070']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationGroundSrf']['RFD'] = ('Boolean',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['RLE'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RLE']['AP030']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationGroundSrf']['RMWC'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RMWC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RMWC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundSrf']['RMWL'] = ('real',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['RMWU'] = ('real',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN_ROI'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN_ROI2'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI2']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN_ROI3'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['RTN_ROI3']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN2'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['RTN3'] = ('String',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SBB'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SEP'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SGCC'] = ('Enumeration',('AP030','AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC']['AP030']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SGCC']['AQ063']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationGroundSrf']['SGCL'] = ('real',('AP030','AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SGCU'] = ('real',('AP030','AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SPT'] = ('Boolean',('AQ125'))
    field_information['TDS 4.0']['TransportationGroundSrf']['SSR'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['SSR2'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR2']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['SSR3'] = ('Enumeration',('AN076','AQ125','AQ141','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AN076']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ125']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ141']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ170']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['SSR3']['AQ180']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['THR'] = ('Boolean',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['TRA'] = ('Boolean',('AQ130'))
    field_information['TDS 4.0']['TransportationGroundSrf']['TRP'] = ('Enumeration',('AL211'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRP'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRP']['AL211']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['TRS'] = ('Enumeration',('AL211','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['TRS2'] = ('Enumeration',('AL211','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS2']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['TRS3'] = ('Enumeration',('AL211','AQ040','AQ063','AQ068','AQ125','AQ130','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AL211']  = (-999999,5,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ040']  = (-999999,2,5,9,10,12,13,20,25,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ063']  = (-999999,2,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ068']  = (-999999,5,9,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ125']  = (-999999,1,3,4,5,9,12,13,15,16,30,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['AQ130']  = (-999999,2,5,8,9,11,12,13,17,20,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TRS3']['BH070']  = (-999999,6,9,11,13,18,21,22,23,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['TYP'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TYP'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['TYP']['AP030']  = (-999999,1,5,9,13,17,21,25,29,33,37,41,45,47,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['UBC'] = ('REAL',('AQ040'))
    field_information['TDS 4.0']['TransportationGroundSrf']['UFI'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['VCM'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['VCM2'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM2']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['VCM3'] = ('Enumeration',('AN076','AQ040','AQ045'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AN076']  = (-999999,1,4,8,12,13,15,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AQ040']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VCM3']['AQ045']  = (-999999,2,3,4,7,8,9,12,13,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['VET'] = ('Enumeration',('AQ140'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VET'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['VET']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['VOI'] = ('StructuredText',('AN076','AQ040','AQ050','AQ141'))
    field_information['TDS 4.0']['TransportationGroundSrf']['VST'] = ('Integer',('AQ180'))
    field_information['TDS 4.0']['TransportationGroundSrf']['WD2'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['WID'] = ('REAL',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['WLE'] = ('Enumeration',('AQ063'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['WLE'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['WLE']['AQ063']  = (-999999,2,4,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['WT2'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI004_RCG'] = ('CodeList',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI005_FNA'] = ('String',('AL195','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ056','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI005_NFN'] = ('String',('AL195','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ056','AQ063','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI006_MEM'] = ('String',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI016_ROC'] = ('Enumeration',('AP030','AQ135','AQ140','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AP030']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AQ135']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['AQ140']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_ROC']['BH070']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI016_WD1'] = ('REAL',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI016_WTC'] = ('Enumeration',('AP030'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_WTC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI016_WTC']['AP030']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI017_GAW'] = ('REAL',('AN060','AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI017_RGC'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN060']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN075']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RGC']['AN076']  = (-999999,1,2,3)
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI017_RRA'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN060']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN075']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_RRA']['AN076']  = (-999999,1,3,4,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['ZI017_TRT'] = ('Enumeration',('AN060','AN075','AN076'))
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT'] = {}
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN060']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN075']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['EnumeratedIndexValues']['ZI017_TRT']['AN076']  = (-999999,1,2,3,4,5,6,7,9,10,12,13,999)
    field_information['TDS 4.0']['TransportationGroundSrf']['ZSAX_RS0'] = ('CodeList',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZSAX_RX3'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZSAX_RX4'] = ('StructuredText',('AL195','AL211','AN060','AN075','AN076','AP030','AQ040','AQ045','AQ050','AQ056','AQ063','AQ068','AQ125','AQ130','AQ135','AQ140','AQ141','AQ151','AQ170','AQ180','BH070'))
    field_information['TDS 4.0']['TransportationGroundSrf']['ZVH'] = ('REAL',('AL211','AN060','AN076','AQ040','AQ045','AQ050','AQ056','AQ063','AQ125','AQ135','AQ141','AQ151','AQ170','AQ180'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ARA'] = ('REAL',('BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['AWP'] = ('Boolean',('BI006'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BGT'] = ('Enumeration',('BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BGT'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_AWBA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_AWBB'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_WBHA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BH141_WBHB'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BMC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BMC2'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BMC3'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWHBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BPWSBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['BWVCBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['CAA'] = ('Enumeration',('BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,17,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['CDA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['COS'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,4,6,9,13,14)
    field_information['TDS 4.0']['TransportationWaterCrv']['CWT'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['DEV'] = ('Integer',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['FCL'] = ('REAL',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['FER'] = ('Enumeration',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['FER'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['FER']['AQ070']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['HEI'] = ('REAL',('BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['HGT'] = ('REAL',('AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['LMC'] = ('Boolean',('AQ070','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['LNU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['LZN'] = ('REAL',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['MCC'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['MCC2'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['MCC3'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['MCX'] = ('Boolean',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['NVS'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['NVS'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['OPT'] = ('Enumeration',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['OPT'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['OPT']['AQ070']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['OTH'] = ('StructuredText',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['PCF'] = ('Enumeration',('AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['AQ111']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterCrv']['PWA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['RLE'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationWaterCrv']['SBB'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['THI'] = ('REAL',('BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['TRA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['TRS'] = ('Enumeration',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS']['AQ070']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['TRS2'] = ('Enumeration',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS2']['AQ070']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['TRS3'] = ('Enumeration',('AQ070'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['TRS3']['AQ070']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['UFI'] = ('StructuredText',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['VOI'] = ('StructuredText',('BI006'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WD3'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WDH'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WDL'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WDU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WID'] = ('REAL',('AQ111','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WVA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WVH'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['WVL'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI004_RCG'] = ('CodeList',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI005_FNA'] = ('String',('AQ070','AQ111','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI005_NFN'] = ('String',('AQ070','AQ111','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI006_MEM'] = ('String',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['TDS 4.0']['TransportationWaterCrv']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['TransportationWaterCrv']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterCrv']['ZSAX_RS0'] = ('CodeList',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZSAX_RX3'] = ('StructuredText',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZSAX_RX4'] = ('StructuredText',('AQ070','AQ111','BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterCrv']['ZVH'] = ('REAL',('BH020','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ADR'] = ('String',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ARA'] = ('REAL',('AQ080','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ATB'] = ('Boolean',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['AWP'] = ('Boolean',('AQ080','BI006'))
    field_information['TDS 4.0']['TransportationWaterPnt']['BGT'] = ('Enumeration',('BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['BGT'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['BGT']['BI045']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['CAA'] = ('Enumeration',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['FFN'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['HEI'] = ('REAL',('BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['HGT'] = ('REAL',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['HST'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['HST2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['HST3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['LMC'] = ('Boolean',('AQ080','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['LNU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['LZN'] = ('REAL',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['MCC'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['MCC2'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC2']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['MCC3'] = ('Enumeration',('BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['MCC3']['BI045']  = (-999999,21,51,64,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['MUB'] = ('Boolean',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['OTH'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['PCF'] = ('Enumeration',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['AQ111']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['PCF']['BI045']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterPnt']['SSR'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['THI'] = ('REAL',('BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['TRS'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationWaterPnt']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterPnt']['UFI'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['VOI'] = ('StructuredText',('AQ080','BI006'))
    field_information['TDS 4.0']['TransportationWaterPnt']['WDU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['WID'] = ('REAL',('AQ080','AQ111','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZI004_RCG'] = ('CodeList',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZI005_FNA'] = ('String',('AQ080','AQ111','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZI005_NFN'] = ('String',('AQ080','AQ111','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZI006_MEM'] = ('String',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZSAX_RS0'] = ('CodeList',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZSAX_RX3'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZSAX_RX4'] = ('StructuredText',('AQ080','AQ111','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterPnt']['ZVH'] = ('REAL',('AQ080','BI006','BI030','BI045'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ADR'] = ('String',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ARA'] = ('REAL',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ATB'] = ('Boolean',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['AWP'] = ('Boolean',('AQ080','BI006'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_AWBA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_AWBB'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_IBOA'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOA']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_IBOB'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_IBOB']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_SHDA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_SHDB'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_SLTA'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTA']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_SLTB'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BH141_SLTB']['BH020']  = (-999999,6,8,10,11,12,13,14,17,18,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_WBHA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BH141_WBHB'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BMC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BMC2'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC2']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BMC3'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BMC3']['BH020']  = (-999999,1,2,3,4,5,6,7,8,15,16,17,18,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWHBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWHBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BPWSBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BPWSBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCAC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCAC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCAL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCAU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCBC'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['BWVCBC']['BH020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCBL'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['BWVCBU'] = ('real',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['CAA'] = ('Enumeration',('BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BH020']  = (-999999,3,17,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BI006']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['CAA']['BI030']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['CDA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['COS'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['COS']['BH020']  = (-999999,4,6,9,13,14)
    field_information['TDS 4.0']['TransportationWaterSrf']['CWT'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['DEV'] = ('Integer',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['FFN'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['FFN2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN2']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['FFN3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['FFN3']['AQ080']  = (-999999,382,482,483,484,490,494,495,505,507,537,538,539,540,847,970,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['HGT'] = ('REAL',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['HST'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['HST2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST2']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['HST3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['HST3']['AQ080']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['LMC'] = ('Boolean',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['LNU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['LZN'] = ('REAL',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['MCC'] = ('Enumeration',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['MCC2'] = ('Enumeration',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC2']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['MCC3'] = ('Enumeration',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3']['BI006']  = (-999999,77,83,107,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['MCC3']['BI030']  = (-999999,9,21,62,77,83,104,107,108,117,150,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['MUB'] = ('Boolean',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['NVS'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['NVS'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['NVS']['BH020']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['OTH'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['PCF'] = ('Enumeration',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['AQ080']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BH020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BI006']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['PCF']['BI030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['TransportationWaterSrf']['PWA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['RLE'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['RLE']['BH020']  = (-999999,1,2,3,998)
    field_information['TDS 4.0']['TransportationWaterSrf']['SBB'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['SSR'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['SSR2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR2']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['SSR3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['SSR3']['AQ080']  = (-999999,6,7,38,40,41,42,47,50,51,55,64,77,78,79,80,81,82,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['TRA'] = ('Boolean',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['TRS'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['TRS2'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS2'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS2']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['TRS3'] = ('Enumeration',('AQ080'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS3'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['TRS3']['AQ080']  = (-999999,9,12,13,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['UFI'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['VOI'] = ('StructuredText',('AQ080','BI006'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WD3'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WDH'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WDL'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WDU'] = ('REAL',('BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WID'] = ('REAL',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WVA'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WVH'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['WVL'] = ('REAL',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI004_RCG'] = ('CodeList',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI005_FNA'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI005_NFN'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI006_MEM'] = ('String',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI024_HYP'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_HYP']['BH020']  = (-999999,1,2,4)
    field_information['TDS 4.0']['TransportationWaterSrf']['ZI024_YWQ'] = ('Enumeration',('BH020'))
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['TransportationWaterSrf']['EnumeratedIndexValues']['ZI024_YWQ']['BH020']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['TransportationWaterSrf']['ZSAX_RS0'] = ('CodeList',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZSAX_RX3'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZSAX_RX4'] = ('StructuredText',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['TransportationWaterSrf']['ZVH'] = ('REAL',('AQ080','BH020','BI006','BI030'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['AWP'] = ('Boolean',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CAA'] = ('Enumeration',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA']['AQ113']  = (-999999,5,7,16,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAA']['AT005']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CAB'] = ('Enumeration',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CAB2'] = ('Enumeration',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB2']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CAB3'] = ('Enumeration',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['CAB3']['AT005']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CST'] = ('Boolean',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['CWT'] = ('Boolean',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['DEV'] = ('Integer',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['DIM'] = ('REAL',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['F_CODE'] = ('CONSTRAINED_STRING',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['FLO'] = ('Boolean',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['HGT'] = ('REAL',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['KVA'] = ('REAL',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['LMC'] = ('Boolean',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['LOC'] = ('Enumeration',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC']['AQ113']  = (-999999,17,23,40,44,45,46)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['LOC']['AT005']  = (-999999,17,23,40,44,45,46,47)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['LZN'] = ('REAL',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['NPL'] = ('Integer',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['OHC'] = ('REAL',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['OTH'] = ('StructuredText',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['OWO'] = ('Boolean',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['PCF'] = ('Enumeration',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF']['AQ113']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PCF']['AT005']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['PFH'] = ('REAL',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['PPO'] = ('Enumeration',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO']['AQ113']  = (-999999,16,45,46,83,101,122,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['PPO2'] = ('Enumeration',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO2']['AQ113']  = (-999999,16,45,46,83,101,122,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['PPO3'] = ('Enumeration',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['PPO3']['AQ113']  = (-999999,16,45,46,83,101,122,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['RLE'] = ('Enumeration',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RLE'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RLE']['AQ113']  = (-999999,1,2,3)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['RTA'] = ('Enumeration',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RTA'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['RTA']['AQ113']  = (-999999,1,2,3,4,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['SBB'] = ('Boolean',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['SPT'] = ('Boolean',('AQ113'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['TST'] = ('Enumeration',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['TST'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['TST']['AT005']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['UFI'] = ('StructuredText',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['VOI'] = ('StructuredText',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZI004_RCG'] = ('CodeList',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZI005_FNA'] = ('String',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZI005_NFN'] = ('String',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZI006_MEM'] = ('String',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZI025_WLE'] = ('Enumeration',('AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI025_WLE'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['EnumeratedIndexValues']['ZI025_WLE']['AT005']  = (-999999,1,2,3,4,5,9,999)
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZSAX_RS0'] = ('CodeList',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZSAX_RX3'] = ('StructuredText',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZSAX_RX4'] = ('StructuredText',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructureCrv']['ZVH'] = ('REAL',('AQ113','AT005'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ADR'] = ('String',('AC507','AD010','AD025','AD030','AD050','AD055','AD060','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['AOO'] = ('REAL',('AT010','AT011'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ARA'] = ('REAL',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AQ114','AQ115','AQ116','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['AT005_CAB'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['AT005_CAB2'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB2']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['AT005_CAB3'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['AT005_CAB3']['AT042']  = (-999999,2,3,4,6,7,8,9,10,11,12,13,14,15,19,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['AWP'] = ('Boolean',('AD041','AF010','AF030','AJ051','AT011','AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['CAA'] = ('Enumeration',('AC507','AD041','AT010','AT011','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT010']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['AT011']  = (-999999,3,5,7,17,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['F_CODE'] = ('CONSTRAINED_STRING',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['FFN'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['FFN2'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['FFN3'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['GUG'] = ('Boolean',('AJ051'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['HEI'] = ('REAL',('AF010','AT010','AT011'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['HGT'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['LMC'] = ('Boolean',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['LZN'] = ('REAL',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['MCC'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC']['AT010']  = (-999999,64,152,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['MCC2'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC2']['AT010']  = (-999999,64,152,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['MCC3'] = ('Enumeration',('AQ114','AQ115','AT010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AQ114']  = (-999999,21,51,62,64,107,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AQ115']  = (-999999,2,51,64,107,117,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['MCC3']['AT010']  = (-999999,64,152,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['OTH'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['PCF'] = ('Enumeration',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AB021']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AF010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AJ051']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AL017']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AQ114']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT011']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['AT042']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['POS'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['POS2'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['POS3'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['PPO'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['PPO2'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['PPO3'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SBT'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SBT2'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SBT3'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SPT'] = ('Boolean',('AT011'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SRL'] = ('Enumeration',('AJ051'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SRL'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SRL']['AJ051']  = (-999999,1,2,3)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SSR'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SSR2'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['SSR3'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['TOS'] = ('Enumeration',('AJ051'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['TOS'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['TOS']['AJ051']  = (-999999,6,11,12,13,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['UFI'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['UTY'] = ('Enumeration',('AQ115'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['UTY2'] = ('Enumeration',('AQ115'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY2']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['UTY3'] = ('Enumeration',('AQ115'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['UTY3']['AQ115']  = (-999999,1,2,3,4,5,6,7,8,9,10,11,12,13,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['VCM'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AJ051']  = (-999999,2,4,5,7,9,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['VCM2'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AJ051']  = (-999999,2,4,5,7,9,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['VCM3'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF010','AF030','AJ051','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AF010']  = (-999999,3,4,7,8,9,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AJ051']  = (-999999,2,4,5,7,9,15,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['VOI'] = ('StructuredText',('AD041','AF010','AF030','AJ051','AT011','AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['WID'] = ('REAL',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AQ114','AQ115','AQ116','AT010','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI004_RCG'] = ('CodeList',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI005_FNA'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI005_NFN'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI006_MEM'] = ('String',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI018_WIT'] = ('Enumeration',('AC507','AT011','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['AT011']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI018_WIT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI032_GUG'] = ('Boolean',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI032_PYC'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYC'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYC']['AT042']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI032_PYM'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYM'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_PYM']['AT042']  = (-999999,1,3,4,5,7,8,9,10,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZI032_TOS'] = ('Enumeration',('AT042'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_TOS'] = {}
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['EnumeratedIndexValues']['ZI032_TOS']['AT042']  = (-999999,6,8,11,12,13,999)
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZSAX_RS0'] = ('CodeList',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZSAX_RX3'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZSAX_RX4'] = ('StructuredText',('AB021','AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ114','AQ115','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructurePnt']['ZVH'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF010','AF030','AJ051','AL017','AQ116','AT010','AT011','AT012','AT042','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ADR'] = ('String',('AC507','AD010','AD025','AD030','AD050','AD055','AD060','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ARA'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['AWP'] = ('Boolean',('AD041','AF030'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['CAA'] = ('Enumeration',('AC507','AD041','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AC507']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['AD041']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['CAA']['BH220']  = (-999999,3,5,7,16,17,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['F_CODE'] = ('CONSTRAINED_STRING',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['FFN'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['FFN2'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN2']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['FFN3'] = ('Enumeration',('AD050','AD055','AQ116','AT012'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AD050']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AD055']  = (-999999,99,440,563,811,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AQ116']  = (-999999,50,60,192,350,500,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['FFN3']['AT012']  = (-999999,486,601,604,610,614,615,620,625,720,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['HGT'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['LMC'] = ('Boolean',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['LZN'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['OTH'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['PCF'] = ('Enumeration',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AC507']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD010']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD020']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD025']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD041']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD050']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD055']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AD060']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AF030']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AQ116']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['AT012']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PCF']['BH220']  = (-999999,1,2,3,4,5,6)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['POS'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['POS2'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS2']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['POS3'] = ('Enumeration',('AD010'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['POS3']['AD010']  = (-999999,1,2,3,4,5,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['PPO'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['PPO2'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO2']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['PPO3'] = ('Enumeration',('AD020','AD025','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AD020']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AD025']  = (-999999,37,146,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['PPO3']['AQ116']  = (-999999,16,45,46,83,101,122,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SBT'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SBT2'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT2']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SBT3'] = ('Enumeration',('AD030'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SBT3']['AD030']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SSR'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SSR2'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR2']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['SSR3'] = ('Enumeration',('AD041'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['SSR3']['AD041']  = (-999999,6,38,40,41,42,47,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['UFI'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['VCM'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['VCM2'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM2']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['VCM3'] = ('Enumeration',('AD010','AD025','AD030','AD041','AD050','AF030','AQ116'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD010']  = (-999999,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD025']  = (-999999,2,3,5,7,9,15,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD030']  = (-999999,2,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD041']  = (-999999,4,12,13,15,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AD050']  = (-999999,3,4,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AF030']  = (-999999,2,3,4,7,8,9,15,16,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['VCM3']['AQ116']  = (-999999,2,3,4,7,8,9,12,13,15,16,18,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['VOI'] = ('StructuredText',('AD041','AF030'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['WID'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZI004_RCG'] = ('CodeList',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZI005_FNA'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZI005_NFN'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZI006_MEM'] = ('String',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZI018_WIT'] = ('Enumeration',('AC507','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['AC507']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['EnumeratedIndexValues']['ZI018_WIT']['BH220']  = (-999999,1,2,3,4,5,6,7,999)
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZSAX_RS0'] = ('CodeList',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZSAX_RX3'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZSAX_RX4'] = ('StructuredText',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['UtilityInfrastructureSrf']['ZVH'] = ('REAL',('AC507','AD010','AD020','AD025','AD030','AD041','AD050','AD055','AD060','AF030','AQ116','AT012','BH220'))
    field_information['TDS 4.0']['VegetationCrv']['ARA'] = ('REAL',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['DMBC'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationCrv']['DMBL'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['DMBU'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['DMT'] = ('REAL',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['F_CODE'] = ('CONSTRAINED_STRING',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['HGT'] = ('REAL',('EA020','EC015'))
    field_information['TDS 4.0']['VegetationCrv']['LMC'] = ('Boolean',('EA020','EC015'))
    field_information['TDS 4.0']['VegetationCrv']['LZN'] = ('REAL',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['OTH'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['PVH'] = ('REAL',('EA020','EC015'))
    field_information['TDS 4.0']['VegetationCrv']['SBC'] = ('Boolean',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['SDSC'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationCrv']['SDSL'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['SDSU'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['TRE'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['TRE'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['VegetationCrv']['TSCC'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationCrv']['TSCL'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['TSCU'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['UFI'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['VSP'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationCrv']['VSP2'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationCrv']['VSP3'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['TDS 4.0']['VegetationCrv']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationCrv']['WID'] = ('REAL',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZI004_RCG'] = ('CodeList',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZI005_FNA'] = ('String',('EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZI005_NFN'] = ('String',('EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZI006_MEM'] = ('String',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZSAX_RS0'] = ('CodeList',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZSAX_RX3'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZSAX_RX4'] = ('StructuredText',('EA020','EC015','EC040'))
    field_information['TDS 4.0']['VegetationCrv']['ZVH'] = ('REAL',('EC015'))
    field_information['TDS 4.0']['VegetationPnt']['F_CODE'] = ('CONSTRAINED_STRING',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['HGT'] = ('REAL',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['LMC'] = ('Boolean',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['OTH'] = ('StructuredText',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['TRE'] = ('Enumeration',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['EnumeratedIndexValues']['TRE'] = {}
    field_information['TDS 4.0']['VegetationPnt']['EnumeratedIndexValues']['TRE']['EC005']  = (-999999,1,2,999)
    field_information['TDS 4.0']['VegetationPnt']['UFI'] = ('StructuredText',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['VSP'] = ('Enumeration',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['EnumeratedIndexValues']['VSP'] = {}
    field_information['TDS 4.0']['VegetationPnt']['EnumeratedIndexValues']['VSP']['EC005']  = (-999999,4,6,8,10,11,19,22,25,999)
    field_information['TDS 4.0']['VegetationPnt']['ZI004_RCG'] = ('CodeList',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['ZI006_MEM'] = ('String',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['ZSAX_RS0'] = ('CodeList',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['ZSAX_RX3'] = ('StructuredText',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['ZSAX_RX4'] = ('StructuredText',('EC005'))
    field_information['TDS 4.0']['VegetationPnt']['ZVH'] = ('REAL',('EC005'))
    field_information['TDS 4.0']['VegetationSrf']['ARA'] = ('REAL',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['BMC'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['BMC2'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC2']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['BMC3'] = ('Enumeration',('BH015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['BH015']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['ED010']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BMC3']['ED020']  = (-999999,1,2,3,4,5,6,8,9,14,18,999)
    field_information['TDS 4.0']['VegetationSrf']['BOC'] = ('Enumeration',('BH015'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BOC'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['BOC']['BH015']  = (-999999,1,2,3,4,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,999)
    field_information['TDS 4.0']['VegetationSrf']['DMBC'] = ('Enumeration',('EB020','EC015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['EB020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['ED010']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['DMBC']['ED020']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['DMBL'] = ('real',('EB020','EC015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['DMBU'] = ('real',('EB020','EC015','ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['DMT'] = ('REAL',('EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['F_CODE'] = ('CONSTRAINED_STRING',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['FFN'] = ('Enumeration',('EB010'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN']['EB010']  = (-999999,14,907,921,999)
    field_information['TDS 4.0']['VegetationSrf']['FFN2'] = ('Enumeration',('EB010'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN2'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN2']['EB010']  = (-999999,14,907,921,999)
    field_information['TDS 4.0']['VegetationSrf']['FFN3'] = ('Enumeration',('EB010'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN3'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['FFN3']['EB010']  = (-999999,14,907,921,999)
    field_information['TDS 4.0']['VegetationSrf']['HGT'] = ('REAL',('EB020','EB070','EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['HYP'] = ('Enumeration',('ED010'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['HYP'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['HYP']['ED010']  = (-999999,1,2)
    field_information['TDS 4.0']['VegetationSrf']['LMC'] = ('Boolean',('EB070','EC015'))
    field_information['TDS 4.0']['VegetationSrf']['LZN'] = ('REAL',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['OTH'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['PVH'] = ('REAL',('EB020','EB070','EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['SBC'] = ('Boolean',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['SDSC'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['SDSC'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['SDSC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['SDSL'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['SDSU'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['TID'] = ('Boolean',('ED010','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['TRE'] = ('Enumeration',('EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['TRE'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['TRE']['EC015']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['TRE']['ED020']  = (-999999,1,2,3,999)
    field_information['TDS 4.0']['VegetationSrf']['TSCC'] = ('Enumeration',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['TSCC'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['TSCC']['EC015']  = (2,3,4,5,6,7,8,9)
    field_information['TDS 4.0']['VegetationSrf']['TSCL'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['TSCU'] = ('real',('EC015'))
    field_information['TDS 4.0']['VegetationSrf']['UFI'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['VEG'] = ('Enumeration',('EB010'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VEG'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VEG']['EB010']  = (-999999,8,9,10,56,83,999)
    field_information['TDS 4.0']['VegetationSrf']['VSP'] = ('Enumeration',('EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP']['ED020']  = (-999999,8,19,22,999)
    field_information['TDS 4.0']['VegetationSrf']['VSP2'] = ('Enumeration',('EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP2']['ED020']  = (-999999,8,19,22,999)
    field_information['TDS 4.0']['VegetationSrf']['VSP3'] = ('Enumeration',('EC015','ED020'))
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3'] = {}
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3']['EC015']  = (-999999,4,6,8,10,11,25,999)
    field_information['TDS 4.0']['VegetationSrf']['EnumeratedIndexValues']['VSP3']['ED020']  = (-999999,8,19,22,999)
    field_information['TDS 4.0']['VegetationSrf']['WID'] = ('REAL',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZI004_RCG'] = ('CodeList',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZI005_FNA'] = ('String',('BH015','BJ110','EB010','EB020','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZI005_NFN'] = ('String',('BH015','BJ110','EB010','EB020','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZI006_MEM'] = ('String',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZSAX_RS0'] = ('CodeList',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZSAX_RX3'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZSAX_RX4'] = ('StructuredText',('BH015','BH077','BJ110','EB010','EB020','EB070','EC015','EC040','EC060','ED010','ED020','EE010'))
    field_information['TDS 4.0']['VegetationSrf']['ZVH'] = ('REAL',('EB070','EC015'))


    field_information['TDS 4.0']['SummaryDomainValues'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ADR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AHA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AOO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['APY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQTL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AQTU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ARA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ATB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AWP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AYRL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AYRU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['AZC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BEL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_AWBA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_AWBB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_WBHA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_WBHB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BNF'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BRN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CBP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CDA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CET'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CID'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CNS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CON'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['COS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CPA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CPS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CTL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['CWT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DEV'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DGC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DIM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DMBL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DMBU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DMD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DMT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DOF'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DPAL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DPAU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DQS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DZC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['DZP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['EET'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['EQC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ETS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ETZ'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['EVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['F_CODE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FCL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FCO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FER'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FLO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GB052_RIDH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GB052_RIDL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GFT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['GUG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HCA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HEI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HGT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HHD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HYP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['HZD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['IC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['IKO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['KVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LC1'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LC4'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LCA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LEA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LMC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LND'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LNU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LOG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LTN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LUN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['LZN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MCX'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MDE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MEM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MES'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MFB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MNS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MUB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MWG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['NA8'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['NOS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['NPL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OHC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ONE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OTH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['OWO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PEC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PFD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PFH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['POS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PVH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PWA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RAD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RCG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RFD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RIP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RMWL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RMWU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RTN3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SAD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SBB'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDCL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDCU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDSL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDSU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SEP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SGCL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SGCU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SHC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SHD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SIC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SPT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SRL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['STL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['STP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['SWW'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['THI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['THR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TID'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSCL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSCU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UBC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UFI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['URI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VDT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VET'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VLM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VOA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VOI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['VST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WAD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WD1'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WD2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WD3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WD5'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WDH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WDL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WDU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WID'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WPI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WST'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WT2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WTI'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WVH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['WVL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_NSD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_NSN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_NSP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_SSD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_SSN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_SSY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_VSC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_VSD'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_VSN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI002_CCN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI002_CDR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI004_PRE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI004_RCG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_FNA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_FNA1'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_FNA2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_NFN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_NFN1'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI005_NFN2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI006_MEM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WD1'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_GAW'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RGC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RIR'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_HYP'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_GUG'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZSAX_RS0'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZSAX_RX3'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZSAX_RX4'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZVA'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ZVH'] = {}
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][1] = u'International or Supranational'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][2] = u'National'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][3] = u'Subnational'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][4] = u'Local'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][6] = u'Municipal'
    field_information['TDS 4.0']['SummaryDomainValues']['ADI'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][1] = u'Artificial Mountain'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][2] = u'Ferris Wheel'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][3] = u'Roller-coaster'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][4] = u'Spherical'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][5] = u'Water Attraction'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][6] = u'Vertical Ride'
    field_information['TDS 4.0']['SummaryDomainValues']['AMA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][1] = u'Passenger'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][2] = u'Cargo'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][3] = u'Remote Parking'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][4] = u'Services and/or Hangar'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][5] = u'General Aviation'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][6] = u'Military'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][7] = u'Dispersal'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][8] = u'Holding'
    field_information['TDS 4.0']['SummaryDomainValues']['APY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][1] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][2] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][3] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][4] = u'Conglomerate'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][5] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][6] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][8] = u'Igneous Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][9] = u'Karst'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][10] = u'Limestone'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][11] = u'Marl'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][12] = u'Metamorphic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][13] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][15] = u'Schist'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][16] = u'Unconsolidated'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][18] = u'Volcanic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][1] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][2] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][3] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][4] = u'Conglomerate'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][5] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][6] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][8] = u'Igneous Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][9] = u'Karst'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][10] = u'Limestone'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][11] = u'Marl'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][12] = u'Metamorphic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][13] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][15] = u'Schist'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][16] = u'Unconsolidated'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][18] = u'Volcanic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][1] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][2] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][3] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][4] = u'Conglomerate'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][5] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][6] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][8] = u'Igneous Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][9] = u'Karst'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][10] = u'Limestone'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][11] = u'Marl'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][12] = u'Metamorphic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][13] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][15] = u'Schist'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][16] = u'Unconsolidated'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][18] = u'Volcanic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQO3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][1] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][2] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][3] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][4] = u'Conglomerate'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][5] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][6] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][8] = u'Igneous Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][9] = u'Karst'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][10] = u'Limestone'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][11] = u'Marl'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][12] = u'Metamorphic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][13] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][15] = u'Schist'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][16] = u'Unconsolidated'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][17] = u'Semi-consolidated and Consolidated Volcanic Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][18] = u'Volcanic Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['AQP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AQTC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ASU3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][1] = u'A - Active Civilian'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][2] = u'B - Active Joint (Civilian/Military)'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][3] = u'C - Active Military'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][4] = u'D - Active (with less than the minimum facilities)'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][5] = u'E - Abandoned or Closed (with usable runways or landing areas)'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][6] = u'F - Highway Strip'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][7] = u'G - Unusable for landing or take-off'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][8] = u'H - Active Military Heliport'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][9] = u'J - Active Civil Heliport'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][10] = u'K - Active Military Heliport (with less than minimum facilities)'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][11] = u'L - Active Civil Heliport (with less than minimum facilities)'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][12] = u'X - Decoy'
    field_information['TDS 4.0']['SummaryDomainValues']['ASY'][13] = u'Active Joint (Civilian/Military) Heliport'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['AT005_CAB3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ATB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ATB'][1000] = u'FALSE'
    field_information['TDS 4.0']['SummaryDomainValues']['ATB'][1001] = u'TRUE'
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'][3] = u'Underground'
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'][4] = u'Underwater'
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'][5] = u'Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['ATC'][6] = u'Qanat'
    field_information['TDS 4.0']['SummaryDomainValues']['AWP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AWP'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['AWP'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'][1] = u'Closed'
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'][2] = u'Open'
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'][3] = u'Work in Progress'
    field_information['TDS 4.0']['SummaryDomainValues']['AXS'][4] = u'Parked or Disabled Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AYRC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['AZC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['AZC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['AZC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][4] = u'Indian Spring Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][7] = u'Mean High Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][9] = u'Mean High Water Springs'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][10] = u'Mean Higher High Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][11] = u'Mean Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][13] = u'Mean Low Water Springs'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][14] = u'Mean Lower Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][15] = u'Mean Sea Level'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][19] = u'Mean Lower Low Water Springs'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][20] = u'Lowest Astronomical Tide'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][24] = u'Mean Higher High Water Springs'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][28] = u'Highest High Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][30] = u'Indian Spring High Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][90] = u'Lowest Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['BA000_VDC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BAC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BAC'][1] = u'Sparse'
    field_information['TDS 4.0']['SummaryDomainValues']['BAC'][2] = u'Dense'
    field_information['TDS 4.0']['SummaryDomainValues']['BAC'][3] = u'Moderate'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][1] = u'Barbed Wire'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][2] = u'Chain-link'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][3] = u'Concertina Wire'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][4] = u'Electrified Wire'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][5] = u'Spiked'
    field_information['TDS 4.0']['SummaryDomainValues']['BAT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BCC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BCC'][1] = u'Easy'
    field_information['TDS 4.0']['SummaryDomainValues']['BCC'][2] = u'Difficult'
    field_information['TDS 4.0']['SummaryDomainValues']['BCC'][3] = u'Impossible'
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'][1] = u'Caisson'
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'][2] = u'Lock Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'][3] = u'Tide Lock'
    field_information['TDS 4.0']['SummaryDomainValues']['BGT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][1] = u'Right'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][2] = u'Left'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][3] = u'Indeterminate'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][4] = u'No Flow'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][1] = u'Right'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][2] = u'Left'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][3] = u'Indeterminate'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][4] = u'No Flow'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_IBOB'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDA'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDA'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDB'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SHDB'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][6] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][8] = u'Marshy'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][10] = u'Stony'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][11] = u'Building Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][12] = u'Erosion Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][13] = u'Sandy'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][14] = u'Shingly'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][17] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][18] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][6] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][8] = u'Marshy'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][10] = u'Stony'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][11] = u'Building Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][12] = u'Erosion Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][13] = u'Sandy'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][14] = u'Shingly'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][17] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][18] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['BH141_SLTB'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][1] = u'Clay and Silt'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][2] = u'Silty Sands'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][3] = u'Sand and Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][4] = u'Gravel and Cobble'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][5] = u'Rocks and Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][6] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][7] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][8] = u'Peat'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][9] = u'Sand over Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][15] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][16] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][17] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][18] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][1] = u'Clay and Silt'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][2] = u'Silty Sands'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][3] = u'Sand and Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][4] = u'Gravel and Cobble'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][5] = u'Rocks and Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][6] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][7] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][8] = u'Peat'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][9] = u'Sand over Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][15] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][16] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][17] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][18] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][1] = u'Clay and Silt'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][2] = u'Silty Sands'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][3] = u'Sand and Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][4] = u'Gravel and Cobble'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][5] = u'Rocks and Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][6] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][7] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][8] = u'Peat'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][9] = u'Sand over Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][14] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][15] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][16] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][17] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][18] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['BMC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][1] = u'Palsa Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][2] = u'String Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][3] = u'Atlantic Plateau Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][4] = u'Basin Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][6] = u'Blanket Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][7] = u'Cranberry Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][8] = u'Domed Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][9] = u'Fen'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][10] = u'Flat Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][11] = u'Horizontal Fen'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][12] = u'Lowland Polygon Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][13] = u'Northern Ribbed Fen'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][14] = u'Peat Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][15] = u'Peat Plateau Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][16] = u'Polygonal Peat Plateau Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][17] = u'Shore Fen'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][18] = u'Slope Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][19] = u'Slope Fen'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][20] = u'Veneer Bog'
    field_information['TDS 4.0']['SummaryDomainValues']['BOC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][4] = u'Bascule'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][10] = u'Swing-bridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][11] = u'Lift-bridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][12] = u'Retractable'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][14] = u'Submersible'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][15] = u'Drawbridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][16] = u'Opening'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][17] = u'Fixed'
    field_information['TDS 4.0']['SummaryDomainValues']['BOT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWHBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BPWSBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][1] = u'Open Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][2] = u'Cantilever'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][5] = u'Floating'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][6] = u'Girder'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][7] = u'Tower Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][8] = u'Truss'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][9] = u'Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][12] = u'Transporter'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][15] = u'Slab'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][16] = u'Stringer Beam'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][19] = u'Bowstring-bridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][22] = u'Covered'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][26] = u'Closed Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][27] = u'Cable Stayed'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][30] = u'Submersible'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][31] = u'Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][32] = u'Trestle'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][1] = u'Open Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][2] = u'Cantilever'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][5] = u'Floating'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][6] = u'Girder'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][7] = u'Tower Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][8] = u'Truss'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][9] = u'Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][12] = u'Transporter'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][15] = u'Slab'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][16] = u'Stringer Beam'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][19] = u'Bowstring-bridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][22] = u'Covered'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][26] = u'Closed Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][27] = u'Cable Stayed'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][30] = u'Submersible'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][31] = u'Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][32] = u'Trestle'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][1] = u'Open Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][2] = u'Cantilever'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][5] = u'Floating'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][6] = u'Girder'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][7] = u'Tower Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][8] = u'Truss'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][9] = u'Suspension'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][12] = u'Transporter'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][15] = u'Slab'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][16] = u'Stringer Beam'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][19] = u'Bowstring-bridge'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][22] = u'Covered'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][26] = u'Closed Spandrel Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][27] = u'Cable Stayed'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][30] = u'Submersible'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][31] = u'Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][32] = u'Trestle'
    field_information['TDS 4.0']['SummaryDomainValues']['BSC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][1] = u'Chimney'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][2] = u'Elevator Machine Room'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][3] = u'HVAC Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][4] = u'Lightning Rod'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][5] = u'Minaret'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][6] = u'Ornamental Element'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][7] = u'Parapet'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][8] = u'Roof Deck'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][9] = u'Roof Garden'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][10] = u'Signage'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][11] = u'Skylight'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][12] = u'Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][13] = u'Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][14] = u'Cupola'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][15] = u'Steeple'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][16] = u'Turret'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][17] = u'Dome'
    field_information['TDS 4.0']['SummaryDomainValues']['BSU'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['BWVCBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][3] = u'Private'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][4] = u'Tribal'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][5] = u'Military'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][6] = u'Municipal'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][7] = u'Joint Military and Civilian'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][16] = u'Civilian'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][17] = u'Public'
    field_information['TDS 4.0']['SummaryDomainValues']['CAA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][2] = u'Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][3] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][4] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][6] = u'Transmission Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][7] = u'Digital Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][8] = u'Communication Line'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][9] = u'Fibre-optic'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][10] = u'Tethering'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][11] = u'Load Bearing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][12] = u'Guide'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][13] = u'Barrier'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][14] = u'Restraining'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][15] = u'Towing'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][19] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAB3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][1] = u'Strict Nature Reserve'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][2] = u'Wilderness Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][3] = u'National Park'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][4] = u'Natural Monument'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][5] = u'Habitat and/or Species Management Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][6] = u'Habitat Management Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][7] = u'Species Management Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][8] = u'Breeding Ground'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][9] = u'Protected Landscape or Seascape'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][10] = u'Managed Resource Protected Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][11] = u'Managed Forest Protected Area'
    field_information['TDS 4.0']['SummaryDomainValues']['CAM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][2] = u'Chair-lift'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][3] = u'Ski Tow'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][5] = u'Aerial Tramway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][6] = u'Gondola Lift'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][7] = u'T-bar Lift'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][8] = u'Industrial Ropeway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][9] = u'Material Tramway'
    field_information['TDS 4.0']['SummaryDomainValues']['CAT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CBP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CBP'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['CBP'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][1] = u'Biological'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][2] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][3] = u'Nuclear and/or Radiological'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][4] = u'Thermal'
    field_information['TDS 4.0']['SummaryDomainValues']['CCG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'][1] = u'Open'
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'][2] = u'Partial'
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'][3] = u'Moveable'
    field_information['TDS 4.0']['SummaryDomainValues']['CCT'][4] = u'Complete'
    field_information['TDS 4.0']['SummaryDomainValues']['CDA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CDA'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['CDA'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][1] = u'One Side'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][2] = u'Two Sides'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][3] = u'Many Sides'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][4] = u'No Sides'
    field_information['TDS 4.0']['SummaryDomainValues']['CET'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CNS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CNS'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['CNS'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][1] = u'Dropgate'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][2] = u'Pass'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][3] = u'Building'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][4] = u'Underpass'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][5] = u'Arcade'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][6] = u'Bridge Pier'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][7] = u'Bridge Superstructure'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][8] = u'Bridge Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][9] = u'Causeway Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][10] = u'Cave'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][11] = u'Culvert'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][12] = u'Curb'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][13] = u'Cut'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][14] = u'Dam'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][15] = u'Embankment'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][16] = u'Entrance and/or Exit'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][17] = u'Fence'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][18] = u'Fire Hydrant'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][19] = u'Ford'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][20] = u'Gallery'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][21] = u'Gantry'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][22] = u'Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][23] = u'Hedgerow'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][24] = u'Memorial Monument'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][25] = u'Non-building Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][26] = u'Parking Garage'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][27] = u'Pipeline'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][28] = u'Pipeline Crossing Point'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][29] = u'Prepared Watercourse Crossing'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][30] = u'Railway Signal'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][31] = u'Railway Switch'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][32] = u'Ramp'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][33] = u'Reduced Track or Lane Count'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][34] = u'Retail Stand'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][35] = u'Road Interchange'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][36] = u'Rock Formation'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][37] = u'Route-related Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][38] = u'Stair'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][39] = u'Steep Terrain Face'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][40] = u'Transportation Block'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][41] = u'Transportation Route Protection Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][42] = u'Tunnel'
    field_information['TDS 4.0']['SummaryDomainValues']['CON'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][4] = u'Non-operational'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][6] = u'Planned'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][8] = u'Not in Operation'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][9] = u'Temporarily Non-operational'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][13] = u'Operational'
    field_information['TDS 4.0']['SummaryDomainValues']['COS'][14] = u'Partially Operational'
    field_information['TDS 4.0']['SummaryDomainValues']['CPA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CPA'][2] = u'Horizontal Position'
    field_information['TDS 4.0']['SummaryDomainValues']['CPA'][3] = u'Horizontal Position and Benchmark'
    field_information['TDS 4.0']['SummaryDomainValues']['CPA'][5] = u'Vertical Position'
    field_information['TDS 4.0']['SummaryDomainValues']['CPS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CPS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][2] = u'Bridge Crane'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][3] = u'Rotating Crane'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][7] = u'Tower Crane'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][99] = u'Container Crane'
    field_information['TDS 4.0']['SummaryDomainValues']['CRA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][1] = u'Fixed'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][2] = u'Travelling'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][3] = u'Floating'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][4] = u'Mobile'
    field_information['TDS 4.0']['SummaryDomainValues']['CRM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][2] = u'Signal Device'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][3] = u'Stop Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][4] = u'No Control'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][5] = u'Ground Marking'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][6] = u'Yield Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][7] = u'Priority Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][2] = u'Signal Device'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][3] = u'Stop Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][4] = u'No Control'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][5] = u'Ground Marking'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][6] = u'Yield Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][7] = u'Priority Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][2] = u'Signal Device'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][3] = u'Stop Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][4] = u'No Control'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][5] = u'Ground Marking'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][6] = u'Yield Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][7] = u'Priority Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['CSC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][1] = u'Dredging'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][2] = u'Factories'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][3] = u'Farm Run-off'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][4] = u'Military Operations'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][5] = u'Naturally Occurring'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][6] = u'Sewers'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][7] = u'Spoil'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][8] = u'Wrecks'
    field_information['TDS 4.0']['SummaryDomainValues']['CSO'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CST'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CST'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['CST'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'][1] = u'Regular with Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'][2] = u'Box with Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'][3] = u'Box with Load'
    field_information['TDS 4.0']['SummaryDomainValues']['CTC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][1] = u'National Identity'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][2] = u'Ethnic Group'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][3] = u'Tribe'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][4] = u'Clan'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][5] = u'Language'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][6] = u'Religion'
    field_information['TDS 4.0']['SummaryDomainValues']['CUL'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['CWT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['CWT'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['CWT'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['DGC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['DGC'][1] = u'Drop Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['DGC'][2] = u'Rolling Block'
    field_information['TDS 4.0']['SummaryDomainValues']['DGC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMBC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DMD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['DMD'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['DMD'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DPAC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][2] = u'Navigation'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][3] = u'Flood Control'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][4] = u'Hydroelectric Power Generation'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][5] = u'Weir'
    field_information['TDS 4.0']['SummaryDomainValues']['DWT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][1] = u'Battery'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][2] = u'Military Parapet'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][3] = u'Military Trench'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][4] = u'Rampart'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][5] = u'Redoubt'
    field_information['TDS 4.0']['SummaryDomainValues']['EET'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['EQC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['EQC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][1] = u'Land'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][2] = u'Snow Field and/or Ice-field'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][3] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][4] = u'Vegetation'
    field_information['TDS 4.0']['SummaryDomainValues']['ESC'][5] = u'Inland Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ETS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ETS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][1] = u'Jet Engine Dismounted'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][2] = u'Jet Engine Mounted'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][3] = u'Rocket Engine Upright'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][4] = u'Rocket Engine Horizontal'
    field_information['TDS 4.0']['SummaryDomainValues']['ETY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][1] = u'Siding'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][2] = u'Increased Track or Lane Count'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][3] = u'Railway Sidetrack'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][4] = u'Roadside Rest Area'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][5] = u'Shoulder'
    field_information['TDS 4.0']['SummaryDomainValues']['EXP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FAC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FAC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['FAC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['FCO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FCO'][5] = u'Divided Same'
    field_information['TDS 4.0']['SummaryDomainValues']['FCO'][6] = u'Divided Different'
    field_information['TDS 4.0']['SummaryDomainValues']['FCO'][7] = u'Non-divided'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][1] = u'Dyke Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][2] = u'Emergency Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][3] = u'Flood Gate'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][4] = u'Fixed Barrage'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][5] = u'Movable Barrage'
    field_information['TDS 4.0']['SummaryDomainValues']['FCS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FER'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FER'][1] = u'Cable'
    field_information['TDS 4.0']['SummaryDomainValues']['FER'][2] = u'Free-moving'
    field_information['TDS 4.0']['SummaryDomainValues']['FER'][3] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['FER'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][2] = u'Agriculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][3] = u'Growing of Crops'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][9] = u'Raising of Animals'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][14] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][15] = u'Mixed Farming'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][16] = u'Migrant Labour'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][19] = u'Hunting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][20] = u'Forestry and/or Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][21] = u'Silviculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][27] = u'Forest Warden'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][30] = u'Fishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][35] = u'Aquaculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][40] = u'Mining and Quarrying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][50] = u'Solid Mineral Fuel Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][60] = u'Petroleum and/or Gas Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][70] = u'Metal Ore Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][83] = u'Chemical Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][84] = u'Peat Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][85] = u'Salt Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][87] = u'Mineral Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][91] = u'Gas Oil Separation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][95] = u'Ore Dressing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][99] = u'Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][100] = u'Food Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][101] = u'Food Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][102] = u'Meat Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][103] = u'Seafood Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][104] = u'Fruit and/or Vegetable Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][105] = u'Oil-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][106] = u'Dairying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][107] = u'Grain Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][110] = u'Baking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][111] = u'Sugar Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][112] = u'Sugar Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][113] = u'Sugar Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][114] = u'Confection Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][115] = u'Pasta Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][116] = u'Prepared Meal Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][118] = u'Beverage Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][119] = u'Animal Feed Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][120] = u'Ice Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][121] = u'Spirit Distillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][122] = u'Winery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][123] = u'Brewing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][124] = u'Soft Drink Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][125] = u'Tobacco Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][129] = u'Textile, Apparel and Leather Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][130] = u'Textile Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][140] = u'Apparel Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][150] = u'Leather Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][155] = u'Footwear Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][160] = u'Wood-based Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][161] = u'Sawmilling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][165] = u'Wooden Construction Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][171] = u'Paper-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][181] = u'Printing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][190] = u'Petroleum and Coal Products Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][191] = u'Coke Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][192] = u'Petroleum Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][195] = u'Chemical Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][210] = u'Medicinal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][221] = u'Rubber Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][225] = u'Plastic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][230] = u'Nonmetallic Mineral Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][231] = u'Glass Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][232] = u'Refractory Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][233] = u'Clay Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][234] = u'Ceramic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][235] = u'Cement Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][236] = u'Cement Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][237] = u'Stone Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][240] = u'Primary Metal Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][241] = u'Steel Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][242] = u'Metal Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][243] = u'Foundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][250] = u'Metal Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][251] = u'Structural Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][255] = u'Munitions Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][257] = u'Fabricated Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][260] = u'Electronic Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][270] = u'Electrical Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][272] = u'Propane Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][280] = u'Machinery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][289] = u'Transportation Equipment Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][290] = u'Motor Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][301] = u'Ship Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][304] = u'Railway Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][305] = u'Aircraft Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][306] = u'Military Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][310] = u'Furniture Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][320] = u'Miscellaneous Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][321] = u'Jewellery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][322] = u'Musical Instrument Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][323] = u'Sports Goods Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][324] = u'Game and/or Toy Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][325] = u'Medical and/or Dental Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][330] = u'General Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][331] = u'Fabricated Metal Product Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][332] = u'Electronic Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][333] = u'Electrical Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][334] = u'Machinery Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][340] = u'Ship Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][341] = u'Aircraft Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][342] = u'Railway Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][343] = u'Motor Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][350] = u'Utilities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][351] = u'Power Generation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][352] = u'Climate Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][355] = u'Cooling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][356] = u'Heating'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][360] = u'Water Supply'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][361] = u'Water Collection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][362] = u'Water Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][363] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][370] = u'Sewerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][372] = u'Sewerage Screening'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][382] = u'Restroom'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][383] = u'Waste Treatment and Disposal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][385] = u'Materials Recovery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][440] = u'Commerce'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][459] = u'Wholesale Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][460] = u'Retail Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][464] = u'Specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][465] = u'Non-specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][466] = u'Convenience Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][470] = u'Petrol Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][473] = u'Sales Yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][474] = u'Precious Metal Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][475] = u'Market'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][476] = u'Grocery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][477] = u'Pharmacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][478] = u'Pet-shop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][480] = u'Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][481] = u'Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][482] = u'Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][483] = u'Stop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][484] = u'Transfer Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][486] = u'Signalling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][487] = u'Transport System Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][488] = u'Navigation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][489] = u'Transportation Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][490] = u'Railway Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][491] = u'Railway Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][494] = u'Pedestrian Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][495] = u'Road Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][496] = u'Road Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][497] = u'Road Freight Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][500] = u'Pipeline Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][501] = u'Pumping'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][505] = u'Water Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][507] = u'Inland Waters Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][508] = u'Canal Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][510] = u'Port Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][511] = u'Maritime Pilotage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][512] = u'Pilot Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][513] = u'Harbour Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][520] = u'Air Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][525] = u'Air Traffic Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][529] = u'Transportation Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][535] = u'Motor Vehicle Parking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][536] = u'Cargo Handling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][537] = u'Customs Checkpoint'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][538] = u'Inspection Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][539] = u'Inspection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][540] = u'Postal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][541] = u'Mail and Package Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][545] = u'Courier Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][548] = u'Short-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][549] = u'Long-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][550] = u'Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][551] = u'Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][552] = u'Resort Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][553] = u'Motel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][554] = u'Guest-house'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][555] = u'Hostel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][556] = u'Dormitory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][557] = u'Vacation Cottage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][558] = u'Dependents Housing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][570] = u'Food Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][572] = u'Restaurant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][573] = u'Bar'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][574] = u'Dining Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][578] = u'Banquet Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][579] = u'Convention Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][580] = u'Publishing and Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][582] = u'Print Publishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][594] = u'Cinema'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][601] = u'Radio Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][604] = u'Television Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][610] = u'Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][612] = u'Retail Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][614] = u'Wired Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][615] = u'Main Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][616] = u'Branch Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][617] = u'Wired Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][620] = u'Wireless Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][621] = u'Mobile Phone Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][622] = u'Wireless Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][625] = u'Satellite Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][626] = u'Satellite Ground Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][632] = u'Information Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][633] = u'Public Records'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][640] = u'Financial Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][642] = u'Central Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][643] = u'Retail Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][651] = u'Insurance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][662] = u'Financial Market Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][663] = u'Security Brokerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][671] = u'Fund Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][680] = u'Real Estate Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][681] = u'Professional, Scientific and Technical'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][691] = u'Legal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][696] = u'Accounting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][701] = u'Head Office'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][706] = u'Business Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][711] = u'Architecture Consulting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][714] = u'Engineering Design'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][717] = u'Surveying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][720] = u'Scientific Research and Development'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][721] = u'Observation Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][722] = u'Weather Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][725] = u'Nuclear Research Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][730] = u'Wind Tunnel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][741] = u'Advertising'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][752] = u'Photography'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][757] = u'Veterinary'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][760] = u'Business and Personal Support Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][761] = u'Motor Vehicle Rental'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][770] = u'Employment Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][775] = u'Travel Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][780] = u'Security Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][781] = u'Guard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][791] = u'Custodial Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][795] = u'Landscaping Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][801] = u'Office Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][807] = u'Call Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][808] = u'Public Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][809] = u'Headquarters'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][810] = u'Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][811] = u'Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][812] = u'Local Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][813] = u'Subnational Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][814] = u'National Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][815] = u'Palace'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][817] = u'Capitol'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][818] = u'Executive Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][819] = u'Legislative Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][821] = u'Polling Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][822] = u'Civil Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][825] = u'Diplomacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][826] = u'Diplomatic Mission'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][827] = u'Embassy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][828] = u'Consul'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][829] = u'Maritime Defense'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][830] = u'Public Order, Safety and Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][831] = u'Public Order'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][832] = u'Safety'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][833] = u'Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][836] = u'Armory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][837] = u'Military Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][838] = u'Military Recruitment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][839] = u'CBRNE Civilian Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][840] = u'Judicial Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][841] = u'Law Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][842] = u'Immigration Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][843] = u'Imprisonment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][844] = u'Juvenile Corrections'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][845] = u'Firefighting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][846] = u'Rescue and Paramedical Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][847] = u'Emergency Operations'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][848] = u'Civil Intelligence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][850] = u'Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][851] = u'Primary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][852] = u'Secondary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][855] = u'Higher Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][857] = u'Vocational Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][860] = u'Human Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][861] = u'In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][862] = u'Out-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][863] = u'Urgent Medical Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][864] = u'Human Tissue Repository'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][865] = u'Public Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][866] = u'Leprosy Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][871] = u'Intermediate Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][873] = u'Psychiatric In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][875] = u'Residential Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][881] = u'Emergency Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][882] = u'Homeless Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][883] = u'Refugee Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][884] = u'Emergency Youth Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][885] = u'Day Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][887] = u'Social Work'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][888] = u'Emergency Relief Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][890] = u'Cultural, Arts and Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][891] = u'Theatre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][892] = u'Auditorium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][893] = u'Community Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][894] = u'Opera House'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][895] = u'Night Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][900] = u'Sports, Amusement and Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][902] = u'Library'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][905] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][906] = u'Aquarium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][907] = u'Botanical and/or Zoological Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][909] = u'Gambling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][912] = u'Sports Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][913] = u'Fitness Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][914] = u'Shooting Range'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][919] = u'Animal Boarding'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][921] = u'Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][922] = u'Amusement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][923] = u'Hobbies and/or Leisure Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][931] = u'Place of Worship'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][932] = u'Islamic Prayer Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][950] = u'Membership Organization'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][954] = u'Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][955] = u'Yacht-club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][961] = u'Laundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][962] = u'Beauty Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][963] = u'Funeral Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][964] = u'Cremation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][965] = u'Mortuary Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][966] = u'Adult Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][967] = u'Storage of Human Remains'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][970] = u'Meeting Place'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][980] = u'Death Care Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][2] = u'Agriculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][3] = u'Growing of Crops'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][9] = u'Raising of Animals'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][14] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][15] = u'Mixed Farming'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][16] = u'Migrant Labour'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][19] = u'Hunting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][20] = u'Forestry and/or Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][21] = u'Silviculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][27] = u'Forest Warden'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][30] = u'Fishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][35] = u'Aquaculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][40] = u'Mining and Quarrying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][50] = u'Solid Mineral Fuel Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][60] = u'Petroleum and/or Gas Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][70] = u'Metal Ore Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][83] = u'Chemical Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][84] = u'Peat Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][85] = u'Salt Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][87] = u'Mineral Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][91] = u'Gas Oil Separation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][95] = u'Ore Dressing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][99] = u'Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][100] = u'Food Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][101] = u'Food Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][102] = u'Meat Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][103] = u'Seafood Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][104] = u'Fruit and/or Vegetable Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][105] = u'Oil-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][106] = u'Dairying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][107] = u'Grain Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][110] = u'Baking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][111] = u'Sugar Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][112] = u'Sugar Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][113] = u'Sugar Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][114] = u'Confection Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][115] = u'Pasta Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][116] = u'Prepared Meal Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][118] = u'Beverage Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][119] = u'Animal Feed Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][120] = u'Ice Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][121] = u'Spirit Distillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][122] = u'Winery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][123] = u'Brewing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][124] = u'Soft Drink Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][125] = u'Tobacco Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][129] = u'Textile, Apparel and Leather Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][130] = u'Textile Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][140] = u'Apparel Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][150] = u'Leather Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][155] = u'Footwear Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][160] = u'Wood-based Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][161] = u'Sawmilling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][165] = u'Wooden Construction Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][171] = u'Paper-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][181] = u'Printing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][190] = u'Petroleum and Coal Products Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][191] = u'Coke Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][192] = u'Petroleum Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][195] = u'Chemical Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][210] = u'Medicinal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][221] = u'Rubber Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][225] = u'Plastic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][230] = u'Nonmetallic Mineral Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][231] = u'Glass Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][232] = u'Refractory Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][233] = u'Clay Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][234] = u'Ceramic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][235] = u'Cement Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][236] = u'Cement Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][237] = u'Stone Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][240] = u'Primary Metal Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][241] = u'Steel Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][242] = u'Metal Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][243] = u'Foundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][250] = u'Metal Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][251] = u'Structural Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][255] = u'Munitions Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][257] = u'Fabricated Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][260] = u'Electronic Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][270] = u'Electrical Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][272] = u'Propane Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][280] = u'Machinery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][289] = u'Transportation Equipment Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][290] = u'Motor Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][301] = u'Ship Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][304] = u'Railway Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][305] = u'Aircraft Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][306] = u'Military Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][310] = u'Furniture Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][320] = u'Miscellaneous Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][321] = u'Jewellery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][322] = u'Musical Instrument Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][323] = u'Sports Goods Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][324] = u'Game and/or Toy Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][325] = u'Medical and/or Dental Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][330] = u'General Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][331] = u'Fabricated Metal Product Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][332] = u'Electronic Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][333] = u'Electrical Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][334] = u'Machinery Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][340] = u'Ship Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][341] = u'Aircraft Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][342] = u'Railway Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][343] = u'Motor Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][350] = u'Utilities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][351] = u'Power Generation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][352] = u'Climate Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][355] = u'Cooling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][356] = u'Heating'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][360] = u'Water Supply'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][361] = u'Water Collection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][362] = u'Water Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][363] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][370] = u'Sewerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][372] = u'Sewerage Screening'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][382] = u'Restroom'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][383] = u'Waste Treatment and Disposal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][385] = u'Materials Recovery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][440] = u'Commerce'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][459] = u'Wholesale Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][460] = u'Retail Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][464] = u'Specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][465] = u'Non-specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][466] = u'Convenience Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][470] = u'Petrol Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][473] = u'Sales Yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][474] = u'Precious Metal Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][475] = u'Market'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][476] = u'Grocery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][477] = u'Pharmacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][478] = u'Pet-shop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][480] = u'Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][481] = u'Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][482] = u'Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][483] = u'Stop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][484] = u'Transfer Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][486] = u'Signalling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][487] = u'Transport System Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][488] = u'Navigation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][489] = u'Transportation Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][490] = u'Railway Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][491] = u'Railway Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][494] = u'Pedestrian Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][495] = u'Road Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][496] = u'Road Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][497] = u'Road Freight Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][500] = u'Pipeline Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][501] = u'Pumping'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][505] = u'Water Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][507] = u'Inland Waters Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][508] = u'Canal Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][510] = u'Port Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][511] = u'Maritime Pilotage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][512] = u'Pilot Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][513] = u'Harbour Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][520] = u'Air Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][525] = u'Air Traffic Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][529] = u'Transportation Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][535] = u'Motor Vehicle Parking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][536] = u'Cargo Handling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][537] = u'Customs Checkpoint'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][538] = u'Inspection Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][539] = u'Inspection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][540] = u'Postal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][541] = u'Mail and Package Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][545] = u'Courier Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][548] = u'Short-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][549] = u'Long-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][550] = u'Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][551] = u'Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][552] = u'Resort Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][553] = u'Motel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][554] = u'Guest-house'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][555] = u'Hostel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][556] = u'Dormitory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][557] = u'Vacation Cottage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][558] = u'Dependents Housing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][570] = u'Food Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][572] = u'Restaurant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][573] = u'Bar'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][574] = u'Dining Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][578] = u'Banquet Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][579] = u'Convention Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][580] = u'Publishing and Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][582] = u'Print Publishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][594] = u'Cinema'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][601] = u'Radio Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][604] = u'Television Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][610] = u'Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][612] = u'Retail Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][614] = u'Wired Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][615] = u'Main Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][616] = u'Branch Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][617] = u'Wired Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][620] = u'Wireless Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][621] = u'Mobile Phone Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][622] = u'Wireless Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][625] = u'Satellite Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][626] = u'Satellite Ground Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][632] = u'Information Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][633] = u'Public Records'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][640] = u'Financial Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][642] = u'Central Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][643] = u'Retail Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][651] = u'Insurance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][662] = u'Financial Market Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][663] = u'Security Brokerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][671] = u'Fund Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][680] = u'Real Estate Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][681] = u'Professional, Scientific and Technical'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][691] = u'Legal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][696] = u'Accounting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][701] = u'Head Office'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][706] = u'Business Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][711] = u'Architecture Consulting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][714] = u'Engineering Design'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][717] = u'Surveying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][720] = u'Scientific Research and Development'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][721] = u'Observation Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][722] = u'Weather Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][725] = u'Nuclear Research Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][730] = u'Wind Tunnel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][741] = u'Advertising'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][752] = u'Photography'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][757] = u'Veterinary'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][760] = u'Business and Personal Support Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][761] = u'Motor Vehicle Rental'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][770] = u'Employment Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][775] = u'Travel Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][780] = u'Security Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][781] = u'Guard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][791] = u'Custodial Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][795] = u'Landscaping Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][801] = u'Office Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][807] = u'Call Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][808] = u'Public Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][809] = u'Headquarters'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][810] = u'Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][811] = u'Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][812] = u'Local Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][813] = u'Subnational Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][814] = u'National Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][815] = u'Palace'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][817] = u'Capitol'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][818] = u'Executive Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][819] = u'Legislative Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][821] = u'Polling Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][822] = u'Civil Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][825] = u'Diplomacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][826] = u'Diplomatic Mission'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][827] = u'Embassy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][828] = u'Consul'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][829] = u'Maritime Defense'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][830] = u'Public Order, Safety and Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][831] = u'Public Order'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][832] = u'Safety'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][833] = u'Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][836] = u'Armory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][837] = u'Military Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][838] = u'Military Recruitment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][839] = u'CBRNE Civilian Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][840] = u'Judicial Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][841] = u'Law Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][842] = u'Immigration Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][843] = u'Imprisonment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][844] = u'Juvenile Corrections'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][845] = u'Firefighting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][846] = u'Rescue and Paramedical Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][847] = u'Emergency Operations'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][848] = u'Civil Intelligence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][850] = u'Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][851] = u'Primary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][852] = u'Secondary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][855] = u'Higher Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][857] = u'Vocational Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][860] = u'Human Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][861] = u'In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][862] = u'Out-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][863] = u'Urgent Medical Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][864] = u'Human Tissue Repository'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][865] = u'Public Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][866] = u'Leprosy Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][871] = u'Intermediate Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][873] = u'Psychiatric In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][875] = u'Residential Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][881] = u'Emergency Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][882] = u'Homeless Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][883] = u'Refugee Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][884] = u'Emergency Youth Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][885] = u'Day Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][887] = u'Social Work'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][888] = u'Emergency Relief Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][890] = u'Cultural, Arts and Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][891] = u'Theatre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][892] = u'Auditorium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][893] = u'Community Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][894] = u'Opera House'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][895] = u'Night Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][900] = u'Sports, Amusement and Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][902] = u'Library'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][905] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][906] = u'Aquarium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][907] = u'Botanical and/or Zoological Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][909] = u'Gambling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][912] = u'Sports Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][913] = u'Fitness Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][914] = u'Shooting Range'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][919] = u'Animal Boarding'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][921] = u'Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][922] = u'Amusement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][923] = u'Hobbies and/or Leisure Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][931] = u'Place of Worship'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][932] = u'Islamic Prayer Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][950] = u'Membership Organization'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][954] = u'Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][955] = u'Yacht-club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][961] = u'Laundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][962] = u'Beauty Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][963] = u'Funeral Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][964] = u'Cremation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][965] = u'Mortuary Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][966] = u'Adult Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][967] = u'Storage of Human Remains'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][970] = u'Meeting Place'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][980] = u'Death Care Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][2] = u'Agriculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][3] = u'Growing of Crops'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][9] = u'Raising of Animals'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][14] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][15] = u'Mixed Farming'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][16] = u'Migrant Labour'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][19] = u'Hunting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][20] = u'Forestry and/or Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][21] = u'Silviculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][27] = u'Forest Warden'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][30] = u'Fishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][35] = u'Aquaculture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][40] = u'Mining and Quarrying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][50] = u'Solid Mineral Fuel Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][60] = u'Petroleum and/or Gas Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][70] = u'Metal Ore Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][83] = u'Chemical Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][84] = u'Peat Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][85] = u'Salt Extraction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][87] = u'Mineral Mining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][91] = u'Gas Oil Separation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][95] = u'Ore Dressing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][99] = u'Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][100] = u'Food Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][101] = u'Food Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][102] = u'Meat Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][103] = u'Seafood Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][104] = u'Fruit and/or Vegetable Processing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][105] = u'Oil-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][106] = u'Dairying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][107] = u'Grain Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][110] = u'Baking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][111] = u'Sugar Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][112] = u'Sugar Milling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][113] = u'Sugar Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][114] = u'Confection Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][115] = u'Pasta Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][116] = u'Prepared Meal Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][118] = u'Beverage Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][119] = u'Animal Feed Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][120] = u'Ice Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][121] = u'Spirit Distillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][122] = u'Winery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][123] = u'Brewing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][124] = u'Soft Drink Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][125] = u'Tobacco Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][129] = u'Textile, Apparel and Leather Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][130] = u'Textile Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][140] = u'Apparel Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][150] = u'Leather Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][155] = u'Footwear Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][160] = u'Wood-based Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][161] = u'Sawmilling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][165] = u'Wooden Construction Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][171] = u'Paper-mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][181] = u'Printing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][190] = u'Petroleum and Coal Products Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][191] = u'Coke Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][192] = u'Petroleum Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][195] = u'Chemical Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][210] = u'Medicinal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][221] = u'Rubber Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][225] = u'Plastic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][230] = u'Nonmetallic Mineral Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][231] = u'Glass Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][232] = u'Refractory Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][233] = u'Clay Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][234] = u'Ceramic Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][235] = u'Cement Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][236] = u'Cement Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][237] = u'Stone Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][240] = u'Primary Metal Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][241] = u'Steel Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][242] = u'Metal Refining'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][243] = u'Foundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][250] = u'Metal Product Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][251] = u'Structural Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][255] = u'Munitions Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][257] = u'Fabricated Metal Product Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][260] = u'Electronic Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][270] = u'Electrical Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][272] = u'Propane Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][280] = u'Machinery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][289] = u'Transportation Equipment Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][290] = u'Motor Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][301] = u'Ship Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][304] = u'Railway Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][305] = u'Aircraft Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][306] = u'Military Vehicle Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][310] = u'Furniture Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][320] = u'Miscellaneous Manufacturing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][321] = u'Jewellery Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][322] = u'Musical Instrument Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][323] = u'Sports Goods Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][324] = u'Game and/or Toy Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][325] = u'Medical and/or Dental Equipment Manufacture'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][330] = u'General Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][331] = u'Fabricated Metal Product Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][332] = u'Electronic Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][333] = u'Electrical Equipment Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][334] = u'Machinery Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][340] = u'Ship Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][341] = u'Aircraft Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][342] = u'Railway Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][343] = u'Motor Vehicle Repair'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][350] = u'Utilities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][351] = u'Power Generation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][352] = u'Climate Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][355] = u'Cooling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][356] = u'Heating'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][360] = u'Water Supply'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][361] = u'Water Collection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][362] = u'Water Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][363] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][370] = u'Sewerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][372] = u'Sewerage Screening'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][382] = u'Restroom'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][383] = u'Waste Treatment and Disposal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][385] = u'Materials Recovery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][440] = u'Commerce'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][459] = u'Wholesale Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][460] = u'Retail Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][464] = u'Specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][465] = u'Non-specialized Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][466] = u'Convenience Store'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][470] = u'Petrol Sale'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][473] = u'Sales Yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][474] = u'Precious Metal Merchant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][475] = u'Market'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][476] = u'Grocery'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][477] = u'Pharmacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][478] = u'Pet-shop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][480] = u'Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][481] = u'Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][482] = u'Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][483] = u'Stop'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][484] = u'Transfer Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][486] = u'Signalling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][487] = u'Transport System Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][488] = u'Navigation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][489] = u'Transportation Hub'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][490] = u'Railway Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][491] = u'Railway Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][494] = u'Pedestrian Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][495] = u'Road Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][496] = u'Road Passenger Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][497] = u'Road Freight Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][500] = u'Pipeline Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][501] = u'Pumping'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][505] = u'Water Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][507] = u'Inland Waters Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][508] = u'Canal Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][510] = u'Port Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][511] = u'Maritime Pilotage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][512] = u'Pilot Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][513] = u'Harbour Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][520] = u'Air Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][525] = u'Air Traffic Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][529] = u'Transportation Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][535] = u'Motor Vehicle Parking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][536] = u'Cargo Handling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][537] = u'Customs Checkpoint'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][538] = u'Inspection Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][539] = u'Inspection'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][540] = u'Postal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][541] = u'Mail and Package Transport'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][545] = u'Courier Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][548] = u'Short-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][549] = u'Long-term Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][550] = u'Accommodation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][551] = u'Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][552] = u'Resort Hotel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][553] = u'Motel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][554] = u'Guest-house'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][555] = u'Hostel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][556] = u'Dormitory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][557] = u'Vacation Cottage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][558] = u'Dependents Housing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][570] = u'Food Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][572] = u'Restaurant'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][573] = u'Bar'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][574] = u'Dining Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][578] = u'Banquet Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][579] = u'Convention Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][580] = u'Publishing and Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][582] = u'Print Publishing'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][594] = u'Cinema'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][601] = u'Radio Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][604] = u'Television Broadcasting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][610] = u'Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][612] = u'Retail Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][614] = u'Wired Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][615] = u'Main Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][616] = u'Branch Telephone Exchange'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][617] = u'Wired Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][620] = u'Wireless Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][621] = u'Mobile Phone Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][622] = u'Wireless Repeater'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][625] = u'Satellite Telecommunications'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][626] = u'Satellite Ground Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][632] = u'Information Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][633] = u'Public Records'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][640] = u'Financial Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][642] = u'Central Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][643] = u'Retail Banking'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][651] = u'Insurance'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][662] = u'Financial Market Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][663] = u'Security Brokerage'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][671] = u'Fund Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][680] = u'Real Estate Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][681] = u'Professional, Scientific and Technical'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][691] = u'Legal Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][696] = u'Accounting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][701] = u'Head Office'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][706] = u'Business Management'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][711] = u'Architecture Consulting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][714] = u'Engineering Design'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][717] = u'Surveying'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][720] = u'Scientific Research and Development'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][721] = u'Observation Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][722] = u'Weather Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][725] = u'Nuclear Research Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][730] = u'Wind Tunnel'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][741] = u'Advertising'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][752] = u'Photography'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][757] = u'Veterinary'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][760] = u'Business and Personal Support Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][761] = u'Motor Vehicle Rental'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][770] = u'Employment Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][775] = u'Travel Agency'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][780] = u'Security Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][781] = u'Guard'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][791] = u'Custodial Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][795] = u'Landscaping Service'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][801] = u'Office Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][807] = u'Call Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][808] = u'Public Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][809] = u'Headquarters'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][810] = u'Administration'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][811] = u'Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][812] = u'Local Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][813] = u'Subnational Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][814] = u'National Government'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][815] = u'Palace'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][817] = u'Capitol'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][818] = u'Executive Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][819] = u'Legislative Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][821] = u'Polling Station'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][822] = u'Civil Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][825] = u'Diplomacy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][826] = u'Diplomatic Mission'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][827] = u'Embassy'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][828] = u'Consul'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][829] = u'Maritime Defense'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][830] = u'Public Order, Safety and Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][831] = u'Public Order'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][832] = u'Safety'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][833] = u'Security Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][836] = u'Armory'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][837] = u'Military Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][838] = u'Military Recruitment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][839] = u'CBRNE Civilian Support'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][840] = u'Judicial Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][841] = u'Law Enforcement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][842] = u'Immigration Control'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][843] = u'Imprisonment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][844] = u'Juvenile Corrections'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][845] = u'Firefighting'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][846] = u'Rescue and Paramedical Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][847] = u'Emergency Operations'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][848] = u'Civil Intelligence'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][850] = u'Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][851] = u'Primary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][852] = u'Secondary Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][855] = u'Higher Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][857] = u'Vocational Education'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][860] = u'Human Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][861] = u'In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][862] = u'Out-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][863] = u'Urgent Medical Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][864] = u'Human Tissue Repository'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][865] = u'Public Health Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][866] = u'Leprosy Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][871] = u'Intermediate Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][873] = u'Psychiatric In-patient Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][875] = u'Residential Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][881] = u'Emergency Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][882] = u'Homeless Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][883] = u'Refugee Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][884] = u'Emergency Youth Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][885] = u'Day Care'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][887] = u'Social Work'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][888] = u'Emergency Relief Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][890] = u'Cultural, Arts and Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][891] = u'Theatre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][892] = u'Auditorium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][893] = u'Community Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][894] = u'Opera House'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][895] = u'Night Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][900] = u'Sports, Amusement and Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][902] = u'Library'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][905] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][906] = u'Aquarium'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][907] = u'Botanical and/or Zoological Reserve Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][909] = u'Gambling'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][912] = u'Sports Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][913] = u'Fitness Centre'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][914] = u'Shooting Range'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][919] = u'Animal Boarding'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][921] = u'Recreation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][922] = u'Amusement'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][923] = u'Hobbies and/or Leisure Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][931] = u'Place of Worship'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][932] = u'Islamic Prayer Hall'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][950] = u'Membership Organization'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][954] = u'Club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][955] = u'Yacht-club'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][961] = u'Laundry'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][962] = u'Beauty Treatment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][963] = u'Funeral Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][964] = u'Cremation'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][965] = u'Mortuary Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][966] = u'Adult Entertainment'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][967] = u'Storage of Human Remains'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][970] = u'Meeting Place'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][980] = u'Death Care Services'
    field_information['TDS 4.0']['SummaryDomainValues']['FFN3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][1] = u'Ro-Ro Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][2] = u'Timber-yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][3] = u'Ferry Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][4] = u'Fishing Harbour'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][5] = u'Marina'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][6] = u'Naval Base'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][7] = u'Tanker Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][8] = u'Passenger Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][9] = u'Shipyard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][10] = u'Container Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][11] = u'Bulk Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][1] = u'Ro-Ro Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][2] = u'Timber-yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][3] = u'Ferry Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][4] = u'Fishing Harbour'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][5] = u'Marina'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][6] = u'Naval Base'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][7] = u'Tanker Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][8] = u'Passenger Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][9] = u'Shipyard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][10] = u'Container Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][11] = u'Bulk Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][1] = u'Ro-Ro Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][2] = u'Timber-yard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][3] = u'Ferry Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][4] = u'Fishing Harbour'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][5] = u'Marina'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][6] = u'Naval Base'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][7] = u'Tanker Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][8] = u'Passenger Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][9] = u'Shipyard'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][10] = u'Container Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][11] = u'Bulk Terminal'
    field_information['TDS 4.0']['SummaryDomainValues']['FHC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][1] = u'Mound'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][2] = u'Fill'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][3] = u'Dyke'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][5] = u'Levee'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][6] = u'Divider'
    field_information['TDS 4.0']['SummaryDomainValues']['FIC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FLO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FLO'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['FLO'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][1] = u'Major'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][2] = u'Minor and Hard'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][3] = u'Minor and Soft'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][4] = u'Minor'
    field_information['TDS 4.0']['SummaryDomainValues']['FPT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][1] = u'Small Arms'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][2] = u'Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][3] = u'Field Artillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][4] = u'Grenade'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][5] = u'Demolition Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][6] = u'Impact Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][1] = u'Small Arms'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][2] = u'Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][3] = u'Field Artillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][4] = u'Grenade'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][5] = u'Demolition Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][6] = u'Impact Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][1] = u'Small Arms'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][2] = u'Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][3] = u'Field Artillery'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][4] = u'Grenade'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][5] = u'Demolition Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][6] = u'Impact Area'
    field_information['TDS 4.0']['SummaryDomainValues']['FRT3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FSC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FSC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['FSC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][1] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][2] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][5] = u'Barbed Wire'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][6] = u'Chain-link'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][7] = u'Electrified Wire'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][8] = u'Geotextile'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][9] = u'Netting'
    field_information['TDS 4.0']['SummaryDomainValues']['FTI'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][1] = u'Blockhouse'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][2] = u'Casement'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][3] = u'Keep'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][4] = u'Martello Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][5] = u'Non-specific Fortified'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][6] = u'Pillbox'
    field_information['TDS 4.0']['SummaryDomainValues']['FZR'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['GFT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['GFT'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['GFT'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][1] = u'Fissure'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][2] = u'Fumarole'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][3] = u'Hot Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][4] = u'Sulphur Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][5] = u'Geyser'
    field_information['TDS 4.0']['SummaryDomainValues']['GOT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCHC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GSGCLC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][1] = u'Toll-gate'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][2] = u'Crossing'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][3] = u'Entrance'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][4] = u'Border Crossing'
    field_information['TDS 4.0']['SummaryDomainValues']['GTC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['GUG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['GUG'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['GUG'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][1] = u'Heliport'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][2] = u'Land Aerodrome'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][3] = u'Hospital'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][4] = u'Non-hospital Building'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][6] = u'Rig'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][9] = u'Offshore Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][10] = u'Water Aerodrome'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][11] = u'Military Installation'
    field_information['TDS 4.0']['SummaryDomainValues']['HAF'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HHD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HHD'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['HHD'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][1] = u'Index Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][2] = u'Intermediate Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][3] = u'Half Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][4] = u'Form Line'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][5] = u'Depression Index Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][6] = u'Depression Intermediate Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][7] = u'Approximate Index Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][8] = u'Mound Index Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][9] = u'Mound Intermediate Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][12] = u'Approximate Intermediate Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][13] = u'Approximate Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][14] = u'Quarter Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][15] = u'Approximate Depression Index Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][16] = u'Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][18] = u'Approximate Depression Intermediate Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][19] = u'Intermediate Carrying Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][20] = u'Auxiliary Carrying Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][21] = u'Index Carrying Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][22] = u'Depression Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][23] = u'Approximate Depression Auxiliary Contour'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][98] = u'Transition Line'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][99] = u'Connector Line'
    field_information['TDS 4.0']['SummaryDomainValues']['HQC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][1] = u'Ancient'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][2] = u'Historic'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][3] = u'Not Significant'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][4] = u'Battlefield'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][5] = u'Military'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][6] = u'Political'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][7] = u'National'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][8] = u'Religious'
    field_information['TDS 4.0']['SummaryDomainValues']['HSS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HST'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HST'][1] = u'Bomb Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST'][2] = u'Fallout Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST'][3] = u'Storm Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'][1] = u'Bomb Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'][2] = u'Fallout Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'][3] = u'Storm Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'][1] = u'Bomb Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'][2] = u'Fallout Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'][3] = u'Storm Shelter'
    field_information['TDS 4.0']['SummaryDomainValues']['HST3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][1] = u'M - Multi-bay'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][2] = u'O - Open End'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][3] = u'N - Nose In'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][4] = u'G - Underground'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][5] = u'S - Single Bay'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][6] = u'D - Double Bay'
    field_information['TDS 4.0']['SummaryDomainValues']['HTP'][7] = u'T - T-Shaped'
    field_information['TDS 4.0']['SummaryDomainValues']['HYP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HYP'][1] = u'Perennial'
    field_information['TDS 4.0']['SummaryDomainValues']['HYP'][2] = u'Intermittent'
    field_information['TDS 4.0']['SummaryDomainValues']['HZD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['HZD'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['IC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][1] = u'Lake'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][2] = u'Pond'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][3] = u'Undifferentiated Water Body'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][4] = u'Reservoir'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][5] = u'Basin'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][6] = u'Water-hole'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][7] = u'Landlocked Sea'
    field_information['TDS 4.0']['SummaryDomainValues']['IWT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['LMC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['LMC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['LMC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['LND'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['LND'][19] = u'Dome'
    field_information['TDS 4.0']['SummaryDomainValues']['LND'][41] = u'Ridge'
    field_information['TDS 4.0']['SummaryDomainValues']['LND'][56] = u'Depression'
    field_information['TDS 4.0']['SummaryDomainValues']['LND'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][17] = u'On Waterbody Bottom'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][23] = u'Below Waterbody Bottom'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][40] = u'Below Ground Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][44] = u'On Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][45] = u'Above Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][46] = u'Above Waterbody Bottom'
    field_information['TDS 4.0']['SummaryDomainValues']['LOC'][47] = u'Below Waterbody Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['LUN'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['LUN'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['LUN'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][5] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][7] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][8] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][9] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][21] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][46] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][51] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][52] = u'Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][55] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][62] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][64] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][65] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][74] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][77] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][83] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][84] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][86] = u'Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][88] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][103] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][104] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][107] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][108] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][117] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][119] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][150] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][152] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][5] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][7] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][8] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][9] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][21] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][46] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][51] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][52] = u'Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][55] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][62] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][64] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][65] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][74] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][77] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][83] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][84] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][86] = u'Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][88] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][103] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][104] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][107] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][108] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][117] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][119] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][150] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][152] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][5] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][7] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][8] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][9] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][21] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][46] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][51] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][52] = u'Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][55] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][62] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][64] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][65] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][74] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][77] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][83] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][84] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][86] = u'Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][88] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][103] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][104] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][107] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][108] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][117] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][119] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][150] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][152] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['MCC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MCX'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MCX'][1000] = u'FALSE'
    field_information['TDS 4.0']['SummaryDomainValues']['MCX'][1001] = u'TRUE'
    field_information['TDS 4.0']['SummaryDomainValues']['MES'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MES'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['MES'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['MFB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MFB'][1000] = u'FALSE'
    field_information['TDS 4.0']['SummaryDomainValues']['MFB'][1001] = u'TRUE'
    field_information['TDS 4.0']['SummaryDomainValues']['MNS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MNS'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['MNS'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][4] = u'SA-1 Guild'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][5] = u'SA-2 Guideline'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][6] = u'SA-3 Goa'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][7] = u'SA-4 Ganef'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][8] = u'SA-5 Gammon'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][9] = u'SA-6 Gainful'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][10] = u'SA-7 Grail'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][11] = u'SA-8 Gecko'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][12] = u'SA-9 Gaskin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][15] = u'Surface-to-air Missile (SAM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][17] = u'SA-10 Grumble'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][18] = u'SA-11 Gadfly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][19] = u'SA-12 Gladiator/Giant'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][20] = u'SA-13 Gopher'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][21] = u'SA-14 Gremlin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][22] = u'SA-15 Gauntlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][23] = u'SA-16 Gimlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][24] = u'SA-17 Grizzly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][25] = u'SA-18 Grouse'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][26] = u'SA-19 Grisom'
    field_information['TDS 4.0']['SummaryDomainValues']['MST'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][4] = u'SA-1 Guild'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][5] = u'SA-2 Guideline'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][6] = u'SA-3 Goa'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][7] = u'SA-4 Ganef'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][8] = u'SA-5 Gammon'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][9] = u'SA-6 Gainful'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][10] = u'SA-7 Grail'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][11] = u'SA-8 Gecko'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][12] = u'SA-9 Gaskin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][15] = u'Surface-to-air Missile (SAM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][17] = u'SA-10 Grumble'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][18] = u'SA-11 Gadfly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][19] = u'SA-12 Gladiator/Giant'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][20] = u'SA-13 Gopher'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][21] = u'SA-14 Gremlin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][22] = u'SA-15 Gauntlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][23] = u'SA-16 Gimlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][24] = u'SA-17 Grizzly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][25] = u'SA-18 Grouse'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][26] = u'SA-19 Grisom'
    field_information['TDS 4.0']['SummaryDomainValues']['MST2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][1] = u'Anti-ballistic Missile (ABM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][2] = u'Intercontinental Ballistic Missile (ICBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][3] = u'Intermediate-range Ballistic Missile (IRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][4] = u'SA-1 Guild'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][5] = u'SA-2 Guideline'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][6] = u'SA-3 Goa'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][7] = u'SA-4 Ganef'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][8] = u'SA-5 Gammon'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][9] = u'SA-6 Gainful'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][10] = u'SA-7 Grail'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][11] = u'SA-8 Gecko'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][12] = u'SA-9 Gaskin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][13] = u'Medium-range Ballistic Missile (MRBM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][14] = u'Surface-to-surface Missile (SSM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][15] = u'Surface-to-air Missile (SAM)'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][17] = u'SA-10 Grumble'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][18] = u'SA-11 Gadfly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][19] = u'SA-12 Gladiator/Giant'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][20] = u'SA-13 Gopher'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][21] = u'SA-14 Gremlin'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][22] = u'SA-15 Gauntlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][23] = u'SA-16 Gimlet'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][24] = u'SA-17 Grizzly'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][25] = u'SA-18 Grouse'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][26] = u'SA-19 Grisom'
    field_information['TDS 4.0']['SummaryDomainValues']['MST3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['MUB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MUB'][1000] = u'FALSE'
    field_information['TDS 4.0']['SummaryDomainValues']['MUB'][1001] = u'TRUE'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][1] = u'Borrow-pit'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][3] = u'Opencast'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][4] = u'Placer'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][5] = u'Prospect'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][6] = u'Area Strip-mine'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][8] = u'Peatery'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][9] = u'Below Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][10] = u'Quarry'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][11] = u'Contour Strip-mine'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][12] = u'Strip-mine'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][13] = u'Dredge'
    field_information['TDS 4.0']['SummaryDomainValues']['MZN'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][1] = u'Area'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][2] = u'Locality'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][3] = u'Region'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][4] = u'Arctic Land'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][5] = u'Populated Locality'
    field_information['TDS 4.0']['SummaryDomainValues']['NLT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][1] = u'Navigable and Operational'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][2] = u'Navigable but Abandoned'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][3] = u'Navigable'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][4] = u'Navigable with Periodic Restrictions'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][5] = u'Not Navigable'
    field_information['TDS 4.0']['SummaryDomainValues']['NVS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][1] = u'Platform'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][2] = u'Terminal Buoy'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][3] = u'Catenary Turntable'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][4] = u'Submerged Turret'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][5] = u'Vessel'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][6] = u'Barge'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][7] = u'Submerged Platform'
    field_information['TDS 4.0']['SummaryDomainValues']['OCS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ONE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ONE'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['ONE'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][1] = u'Frame Bridge Span'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][2] = u'Arch Bridge Span'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][3] = u'Roof'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][4] = u'Railway Power Line'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][6] = u'Bridge Superstructure'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][7] = u'Building'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][8] = u'Bridge Span'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][9] = u'Gantry'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][10] = u'Scaffold'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][11] = u'Arcade'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][12] = u'Building Overhang'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][13] = u'Cable'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][14] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][15] = u'Conveyor'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][16] = u'Entrance and/or Exit'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][17] = u'Memorial Monument'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][18] = u'Non-building Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][19] = u'Overhead Walkway'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][20] = u'Parking Garage'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][21] = u'Pipeline'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][22] = u'Pipeline Crossing Point'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][23] = u'Route-related Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][24] = u'Transportation Block'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][25] = u'Transportation Route Protection Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][26] = u'Tunnel'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][27] = u'Traffic Sign'
    field_information['TDS 4.0']['SummaryDomainValues']['OOC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][1] = u'Daytime'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][2] = u'Night-time'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][3] = u'Continuously Operating'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][4] = u'Summer Season'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][5] = u'Winter Season'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][6] = u'Restricted'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][7] = u'Never Operating'
    field_information['TDS 4.0']['SummaryDomainValues']['OPT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['OWO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['OWO'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['OWO'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][16] = u'Sludge'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][17] = u'Spoil'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][16] = u'Sludge'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][17] = u'Spoil'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][16] = u'Sludge'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][17] = u'Spoil'
    field_information['TDS 4.0']['SummaryDomainValues']['PBY3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][1] = u'Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][2] = u'Intact'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][3] = u'Unmaintained'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][4] = u'Damaged'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][5] = u'Dismantled'
    field_information['TDS 4.0']['SummaryDomainValues']['PCF'][6] = u'Destroyed'
    field_information['TDS 4.0']['SummaryDomainValues']['PEC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PEC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['PEC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][1] = u'Geothermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][2] = u'Hydro-electric'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][3] = u'Nuclear'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][4] = u'Thermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][5] = u'Tidal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][1] = u'Geothermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][2] = u'Hydro-electric'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][3] = u'Nuclear'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][4] = u'Thermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][5] = u'Tidal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][1] = u'Geothermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][2] = u'Hydro-electric'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][3] = u'Nuclear'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][4] = u'Thermal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][5] = u'Tidal'
    field_information['TDS 4.0']['SummaryDomainValues']['POS3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][8] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][9] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][11] = u'Bivalve Mollusc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][17] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][19] = u'Cobbles'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][29] = u'Crustacean'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][30] = u'Cultivated Shellfish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][33] = u'Diamond'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][34] = u'Diatomaceous Earth'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][35] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][50] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][53] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][66] = u'Marble'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][72] = u'Mussels'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][77] = u'Oysters'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][85] = u'Porphyry'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][88] = u'Pumice'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][89] = u'Quartz'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][93] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][96] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][97] = u'Sandstone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][110] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][116] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][118] = u'Travertine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][130] = u'Chalk'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][149] = u'Brine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][151] = u'Chromium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][152] = u'Nickel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][153] = u'Tin'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][158] = u'Pottery'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][159] = u'Charcoal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][161] = u'Coalbed Methane'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][162] = u'Natural Gas Condensate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][163] = u'Helium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][164] = u'Hydrothermal Fluid'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][173] = u'Fluorite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][204] = u'Phosphate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][224] = u'Vanadium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][283] = u'Mica'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][339] = u'Selenium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][8] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][9] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][11] = u'Bivalve Mollusc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][17] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][19] = u'Cobbles'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][29] = u'Crustacean'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][30] = u'Cultivated Shellfish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][33] = u'Diamond'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][34] = u'Diatomaceous Earth'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][35] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][50] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][53] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][66] = u'Marble'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][72] = u'Mussels'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][77] = u'Oysters'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][85] = u'Porphyry'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][88] = u'Pumice'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][89] = u'Quartz'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][93] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][96] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][97] = u'Sandstone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][110] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][116] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][118] = u'Travertine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][130] = u'Chalk'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][149] = u'Brine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][151] = u'Chromium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][152] = u'Nickel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][153] = u'Tin'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][158] = u'Pottery'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][159] = u'Charcoal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][161] = u'Coalbed Methane'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][162] = u'Natural Gas Condensate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][163] = u'Helium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][164] = u'Hydrothermal Fluid'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][173] = u'Fluorite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][204] = u'Phosphate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][224] = u'Vanadium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][283] = u'Mica'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][339] = u'Selenium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][8] = u'Basalt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][9] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][11] = u'Bivalve Mollusc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][17] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][19] = u'Cobbles'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][29] = u'Crustacean'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][30] = u'Cultivated Shellfish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][33] = u'Diamond'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][34] = u'Diatomaceous Earth'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][35] = u'Dolomite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][50] = u'Granite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][53] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][66] = u'Marble'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][72] = u'Mussels'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][77] = u'Oysters'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][85] = u'Porphyry'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][88] = u'Pumice'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][89] = u'Quartz'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][93] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][96] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][97] = u'Sandstone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][110] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][116] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][118] = u'Travertine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][130] = u'Chalk'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][149] = u'Brine'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][151] = u'Chromium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][152] = u'Nickel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][153] = u'Tin'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][158] = u'Pottery'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][159] = u'Charcoal'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][161] = u'Coalbed Methane'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][162] = u'Natural Gas Condensate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][163] = u'Helium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][164] = u'Hydrothermal Fluid'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][173] = u'Fluorite'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][204] = u'Phosphate'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][224] = u'Vanadium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][283] = u'Mica'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][339] = u'Selenium'
    field_information['TDS 4.0']['SummaryDomainValues']['PPO3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][34] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][67] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][68] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][84] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][154] = u'Sulphur'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][34] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][67] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][68] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][84] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][154] = u'Sulphur'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][34] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][67] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][68] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][84] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][154] = u'Sulphur'
    field_information['TDS 4.0']['SummaryDomainValues']['PRW3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][1] = u'Pier'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][2] = u'Wharf'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][3] = u'Quay'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][4] = u'Breakwater'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][5] = u'Groin'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][6] = u'Mole'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][7] = u'Recreational Pier'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][8] = u'Training Wall'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][9] = u'Riprap'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][10] = u'Revetment (Marine)'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][11] = u'Seawall'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][18] = u'Promenade'
    field_information['TDS 4.0']['SummaryDomainValues']['PWC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][1] = u'\'A\''
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][2] = u'\'H\''
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][3] = u'\'I\''
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][4] = u'\'Y\''
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][5] = u'\'T\''
    field_information['TDS 4.0']['SummaryDomainValues']['PYC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][1] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][3] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][4] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][5] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][7] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][8] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][9] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][10] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['PYM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][1] = u'Dome Enclosed'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][2] = u'Mast Mounted'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][3] = u'Radome'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][4] = u'Radome on Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][5] = u'Scanner'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][6] = u'Tower Mounted'
    field_information['TDS 4.0']['SummaryDomainValues']['RAC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][1] = u'General Surveillance'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][2] = u'Coastal Radar'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][5] = u'Early Warning'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][6] = u'Weather'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][7] = u'Satellite Tracking'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][8] = u'Aircraft Flight Tracking'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][9] = u'Fire Control Tracking'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][10] = u'Launch Control Tracking'
    field_information['TDS 4.0']['SummaryDomainValues']['RAS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RCG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RCG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RFD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RFD'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['RFD'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['RIP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RIP'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['RIP'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][1] = u'Cloverleaf'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][2] = u'Diamond'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][3] = u'Fork'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][4] = u'Rotary'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][5] = u'Staggered Ramps'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][6] = u'Standard Ramps'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][7] = u'Symmetrical Ramps'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][8] = u'Trumpet'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][9] = u'Turban'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][10] = u'Wye'
    field_information['TDS 4.0']['SummaryDomainValues']['RIT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][1] = u'Columnar'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][2] = u'Needle'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][3] = u'Pinnacle'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][4] = u'Fossilized Forest'
    field_information['TDS 4.0']['SummaryDomainValues']['RKF'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'][1] = u'Raised'
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'][2] = u'Level'
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'][3] = u'Depressed'
    field_information['TDS 4.0']['SummaryDomainValues']['RLE'][998] = u'Not Applicable'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RMWC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][2] = u'Carline'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][6] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][8] = u'Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][11] = u'Rail Rapid Transit'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][13] = u'Marine Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][14] = u'Tramway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][15] = u'Funicular'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][24] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][32] = u'Automated Transit System'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][33] = u'Long-haul'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][2] = u'Carline'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][6] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][8] = u'Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][11] = u'Rail Rapid Transit'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][13] = u'Marine Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][14] = u'Tramway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][15] = u'Funicular'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][24] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][32] = u'Automated Transit System'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][33] = u'Long-haul'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][2] = u'Carline'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][6] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][8] = u'Logging'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][11] = u'Rail Rapid Transit'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][13] = u'Marine Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][14] = u'Tramway'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][15] = u'Funicular'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][24] = u'Museum'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][32] = u'Automated Transit System'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][33] = u'Long-haul'
    field_information['TDS 4.0']['SummaryDomainValues']['RRC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'][1] = u'Spur'
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'][2] = u'Siding'
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'][3] = u'Passing'
    field_information['TDS 4.0']['SummaryDomainValues']['RSA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][1] = u'Single Arrangement'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][2] = u'Double Arrangement'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][3] = u'Multiple Arrangements'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][4] = u'Juxtaposition'
    field_information['TDS 4.0']['SummaryDomainValues']['RTA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][1] = u'International'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][2] = u'National Motorway'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][3] = u'National'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][4] = u'Secondary'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][5] = u'Local'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][1] = u'International'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][2] = u'National Motorway'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][3] = u'National'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][4] = u'Secondary'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][5] = u'Local'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][1] = u'International'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][2] = u'National Motorway'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][3] = u'National'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][4] = u'Secondary'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][5] = u'Local'
    field_information['TDS 4.0']['SummaryDomainValues']['RTN_ROI3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'][1] = u'High Speed Rail'
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'][2] = u'Main Line'
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'][3] = u'Branch-line'
    field_information['TDS 4.0']['SummaryDomainValues']['RWC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SAD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SAD'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SAD'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SBB'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SBB'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SBB'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SBC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SBC'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SBC'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'][1] = u'Switched Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'][2] = u'Transformer Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'][3] = u'Converter Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'][1] = u'Switched Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'][2] = u'Transformer Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'][3] = u'Converter Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'][1] = u'Switched Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'][2] = u'Transformer Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'][3] = u'Converter Substation'
    field_information['TDS 4.0']['SummaryDomainValues']['SBT3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDSC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][1] = u'Crescent'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][2] = u'Dome'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][3] = u'Transverse'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][4] = u'Linear'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][5] = u'Parabolic'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][6] = u'Ripple'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][7] = u'Star'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][8] = u'Dome and Transverse'
    field_information['TDS 4.0']['SummaryDomainValues']['SDT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SEP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SEP'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SEP'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SGCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['SHD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SHD'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SHD'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][1] = u'Deliverable Container'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][2] = u'Dumpster'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][3] = u'ISO Container'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][4] = u'Roll-off Dumpster'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][5] = u'Tank Container'
    field_information['TDS 4.0']['SummaryDomainValues']['SHT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SIC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SIC'][1] = u'Snowfield'
    field_information['TDS 4.0']['SummaryDomainValues']['SIC'][2] = u'Ice-field'
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'][1] = u'Log Ramp'
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'][2] = u'Marine Ramp'
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'][3] = u'Slipway'
    field_information['TDS 4.0']['SummaryDomainValues']['SLR'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][6] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][8] = u'Marshy'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][10] = u'Stony'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][11] = u'Building Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][12] = u'Erosion Rubble'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][13] = u'Sandy'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][14] = u'Shingly'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][16] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][17] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][18] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][998] = u'Not Applicable'
    field_information['TDS 4.0']['SummaryDomainValues']['SLT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SPT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SPT'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['SPT'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][1] = u'No Effect'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][2] = u'Landslide Potential'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][11] = u'Numerous Cobbles and Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][12] = u'Stony Areas'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][13] = u'Stony Soil with Surface Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][14] = u'Stony Soil with scattered Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][15] = u'Stony Soil with numerous Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][16] = u'Numerous Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][17] = u'Numerous Rock Outcrops'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][18] = u'Scattered Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][19] = u'Talus'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][20] = u'Boulder Field'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][31] = u'Highly Fractured Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][32] = u'Weathered Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][33] = u'Unweathered Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][34] = u'Stony Soil with numerous Rock Outcrops'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][35] = u'Irregular with deep Foliation Fractures'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][36] = u'Rugged with numerous Rock Outcrops'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][37] = u'Rugged Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][43] = u'Highly Distorted with sharp Rocky Ridges'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][51] = u'Stony Soil with numerous Gullies'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][52] = u'Moderately Dissected'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][53] = u'Moderately Dissected with scattered Rock Outcrops'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][54] = u'Dissected Floodplain'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][55] = u'Highly Dissected'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][56] = u'Deep Erosional Gullies'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][57] = u'Steep Rugged Dissected with narrow Gullies'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][58] = u'Karst with numerous Sinkholes and Solution Valleys'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][59] = u'Karst with numerous Sinkholes'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][60] = u'Hummocky Karst with Large Hills'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][61] = u'Hummocky Karst with Low Mounds'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][63] = u'Playa'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][64] = u'Meander Scars and Lakes'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][65] = u'Solifluction Lobes and Frost Scars'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][66] = u'Hummocky with Frost Heaves'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][67] = u'Frost Polygons'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][69] = u'Numerous Small Lakes and Ponds'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][70] = u'Numerous Crevasses'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][81] = u'Numerous Terraces'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][86] = u'Mine Tailing(s)'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][88] = u'Numerous Dykes'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][89] = u'Numerous Dyked Fields'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][90] = u'Numerous Fences'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][91] = u'Numerous Stone Walls'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][92] = u'Numerous Man-made Drainage'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][93] = u'Numerous Terraced Fields'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][94] = u'Parallel Earthen Rows'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][95] = u'Numerous Hedgerows'
    field_information['TDS 4.0']['SummaryDomainValues']['SRD'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][1] = u'Railway Switch'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][2] = u'Reduced Track or Lane Count'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][3] = u'Road Interchange'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][4] = u'Sharp Curve'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][5] = u'Steep Grade'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][8] = u'Sharp Curves'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][9] = u'Steep Curves'
    field_information['TDS 4.0']['SummaryDomainValues']['SRE'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SRL'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SRL'][1] = u'Offshore'
    field_information['TDS 4.0']['SummaryDomainValues']['SRL'][2] = u'Inland'
    field_information['TDS 4.0']['SummaryDomainValues']['SRL'][3] = u'At Shoreline'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][2] = u'Horizontal Capped Cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][4] = u'Vertical Capped Cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][12] = u'Pyramidal'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][17] = u'Spherical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][59] = u'Cylindrical with Framework'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][65] = u'Cylindrical with Flat Top'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][66] = u'Cylindrical with Domed Top'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][71] = u'Cylindrical with Conical Top'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][77] = u'Arched'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][78] = u'Multiple Arched'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][87] = u'Domed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][88] = u'Spherical on Column'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][89] = u'Cylindrical on Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][91] = u'Vertical Cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][92] = u'Cubic'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][94] = u'Board-like Prism'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][95] = u'Columnar'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][96] = u'Plaque'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][97] = u'Statue'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][98] = u'Cross'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][99] = u'Horizontal Cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][100] = u'Rectangular Prism'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][101] = u'Square Prism'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][109] = u'Obelisk'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][112] = u'Statue on Pedestal'
    field_information['TDS 4.0']['SummaryDomainValues']['SSC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][1] = u'Direction'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][2] = u'Electronic Message'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][3] = u'General Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][4] = u'Mandatory Regulation'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][5] = u'Place Identification'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][6] = u'Prohibited or Restricted Activity'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][7] = u'Road Identification'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][8] = u'Route Marker'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][9] = u'Traffic Control'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][10] = u'Warning'
    field_information['TDS 4.0']['SummaryDomainValues']['SSG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][6] = u'Conical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][7] = u'Pyramidal'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][38] = u'Semi-cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][40] = u'Domed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][41] = u'Flat'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][42] = u'Pitched'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][47] = u'Sawtoothed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][50] = u'With Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][51] = u'With Steeple'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][55] = u'Flat with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][64] = u'Pitched with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][77] = u'With Cupola'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][78] = u'With Turret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][79] = u'With Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][80] = u'With Minaret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][81] = u'With Smokestack'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][82] = u'Flat with Parapet'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][6] = u'Conical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][7] = u'Pyramidal'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][38] = u'Semi-cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][40] = u'Domed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][41] = u'Flat'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][42] = u'Pitched'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][47] = u'Sawtoothed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][50] = u'With Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][51] = u'With Steeple'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][55] = u'Flat with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][64] = u'Pitched with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][77] = u'With Cupola'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][78] = u'With Turret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][79] = u'With Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][80] = u'With Minaret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][81] = u'With Smokestack'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][82] = u'Flat with Parapet'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][6] = u'Conical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][7] = u'Pyramidal'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][38] = u'Semi-cylindrical'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][40] = u'Domed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][41] = u'Flat'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][42] = u'Pitched'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][47] = u'Sawtoothed'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][50] = u'With Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][51] = u'With Steeple'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][55] = u'Flat with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][64] = u'Pitched with Clerestory'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][77] = u'With Cupola'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][78] = u'With Turret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][79] = u'With Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][80] = u'With Minaret'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][81] = u'With Smokestack'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][82] = u'Flat with Parapet'
    field_information['TDS 4.0']['SummaryDomainValues']['SSR3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][1] = u'Winter'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][2] = u'Summer'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][3] = u'Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][4] = u'Autumn'
    field_information['TDS 4.0']['SummaryDomainValues']['STL'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][1] = u'Winter'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][2] = u'Summer'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][3] = u'Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][4] = u'Autumn'
    field_information['TDS 4.0']['SummaryDomainValues']['STL2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][1] = u'Winter'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][2] = u'Summer'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][3] = u'Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][4] = u'Autumn'
    field_information['TDS 4.0']['SummaryDomainValues']['STL3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][1] = u'GW: Well-graded Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][2] = u'GP: Poorly-graded Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][3] = u'GM: Silty Gravel Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][4] = u'GC: Clayey Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][5] = u'SW: Well-graded Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][6] = u'SP: Poorly-graded Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][7] = u'SM: Silty Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][8] = u'SC: Clayey Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][9] = u'ML: Silt and Fine Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][10] = u'CL: Lean Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][11] = u'OL: Organic Silt and Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][12] = u'CH: Fat Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][13] = u'MH: Micraceous'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][14] = u'OH: Organic Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][15] = u'PT: Peat'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][17] = u'ML-CL: Silt, Fine Sand and Lean Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][18] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][99] = u'Not Evaluated'
    field_information['TDS 4.0']['SummaryDomainValues']['STP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'][1] = u'Normally Dry'
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'][2] = u'Normally Moist'
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'][3] = u'Normally Wet'
    field_information['TDS 4.0']['SummaryDomainValues']['SWC'][4] = u'Normally Frozen'
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'][4] = u'Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'][6] = u'Walled-in Spring'
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'][7] = u'Resurgence'
    field_information['TDS 4.0']['SummaryDomainValues']['SWT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'][1] = u'Arch'
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'][2] = u'Box'
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'][3] = u'Semicircular'
    field_information['TDS 4.0']['SummaryDomainValues']['TCS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'][1] = u'Optical'
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'][2] = u'Parabolic Radio Aerial'
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'][3] = u'Radio Aerial Array'
    field_information['TDS 4.0']['SummaryDomainValues']['TEL'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['THR'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['THR'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['THR'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['TID'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TID'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['TID'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][1] = u'\'A\' Frame'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][2] = u'\'H\' Frame'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][3] = u'\'I\' Frame'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][5] = u'\'Y\' Frame'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][6] = u'Mast'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][8] = u'Pole'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][11] = u'Tripod'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][12] = u'Truss'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][13] = u'Tubular'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][14] = u'Tower Mill'
    field_information['TDS 4.0']['SummaryDomainValues']['TOS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TRA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRA'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['TRA'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'][1] = u'Deciduous'
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'][2] = u'Evergreen'
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'][3] = u'Mixed'
    field_information['TDS 4.0']['SummaryDomainValues']['TRE'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][1] = u'Gallery'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][2] = u'Rock Protection Shed'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][3] = u'Snow Protection Shed'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][4] = u'Protection Shed'
    field_information['TDS 4.0']['SummaryDomainValues']['TRP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][1] = u'Aeronautical'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][2] = u'Aqueduct'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][3] = u'Automotive'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][4] = u'Bus'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][5] = u'Canal'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][6] = u'Caravan Route'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][7] = u'Maritime'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][8] = u'No Transportation System'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][9] = u'Pedestrian'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][10] = u'Pipeline'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][11] = u'Portage'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][12] = u'Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][13] = u'Road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][15] = u'Truck'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][16] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][17] = u'Inland Waterway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][18] = u'Pack-road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][20] = u'Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][21] = u'Pipeline Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][22] = u'Power Line Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][23] = u'Drove'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][25] = u'Runway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][30] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][1] = u'Aeronautical'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][2] = u'Aqueduct'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][3] = u'Automotive'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][4] = u'Bus'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][5] = u'Canal'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][6] = u'Caravan Route'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][7] = u'Maritime'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][8] = u'No Transportation System'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][9] = u'Pedestrian'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][10] = u'Pipeline'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][11] = u'Portage'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][12] = u'Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][13] = u'Road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][15] = u'Truck'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][16] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][17] = u'Inland Waterway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][18] = u'Pack-road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][20] = u'Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][21] = u'Pipeline Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][22] = u'Power Line Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][23] = u'Drove'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][25] = u'Runway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][30] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][1] = u'Aeronautical'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][2] = u'Aqueduct'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][3] = u'Automotive'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][4] = u'Bus'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][5] = u'Canal'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][6] = u'Caravan Route'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][7] = u'Maritime'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][8] = u'No Transportation System'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][9] = u'Pedestrian'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][10] = u'Pipeline'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][11] = u'Portage'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][12] = u'Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][13] = u'Road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][15] = u'Truck'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][16] = u'Underground Railway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][17] = u'Inland Waterway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][18] = u'Pack-road'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][20] = u'Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][21] = u'Pipeline Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][22] = u'Power Line Maintenance'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][23] = u'Drove'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][25] = u'Runway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][30] = u'Cableway'
    field_information['TDS 4.0']['SummaryDomainValues']['TRS3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][2] = u'Open Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][3] = u'Greater-than-or-equal to Less-than Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][4] = u'Greater-than to Less-than-or-equal Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][5] = u'Closed Interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][6] = u'Greater-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][7] = u'Greater-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][8] = u'Less-than Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSCC'][9] = u'Less-than or Equal Semi-interval'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][2] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][3] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][5] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][6] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][8] = u'Lava Flow'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][9] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][10] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][11] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][12] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][13] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][14] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][2] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][3] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][5] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][6] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][8] = u'Lava Flow'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][9] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][10] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][11] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][12] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][13] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][14] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][2] = u'Bedrock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][3] = u'Boulders'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][5] = u'Evaporite'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][6] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][7] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][8] = u'Lava Flow'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][9] = u'Loess'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][10] = u'Mud'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][11] = u'Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][12] = u'Rock'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][13] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][14] = u'Soil'
    field_information['TDS 4.0']['SummaryDomainValues']['TSM3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TST'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TST'][1] = u'Symmetric Catenary'
    field_information['TDS 4.0']['SummaryDomainValues']['TST'][2] = u'Mountain Catenary'
    field_information['TDS 4.0']['SummaryDomainValues']['TST'][3] = u'Overwater Catenary'
    field_information['TDS 4.0']['SummaryDomainValues']['TST'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][2] = u'Observation Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][10] = u'Lookout Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][12] = u'Fire Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][20] = u'Telecommunication Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][21] = u'Guard Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][22] = u'Industrial Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][23] = u'Drop Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][24] = u'Solar Power Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][2] = u'Observation Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][10] = u'Lookout Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][12] = u'Fire Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][20] = u'Telecommunication Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][21] = u'Guard Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][22] = u'Industrial Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][23] = u'Drop Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][24] = u'Solar Power Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][2] = u'Observation Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][10] = u'Lookout Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][12] = u'Fire Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][20] = u'Telecommunication Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][21] = u'Guard Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][22] = u'Industrial Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][23] = u'Drop Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][24] = u'Solar Power Tower'
    field_information['TDS 4.0']['SummaryDomainValues']['TTC3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][1] = u'Cave'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][2] = u'Catacomb'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][3] = u'Crypt'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][4] = u'Surface Vault'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][5] = u'Mausoleum'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][6] = u'Burial Mound'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][7] = u'Columbarium'
    field_information['TDS 4.0']['SummaryDomainValues']['TTY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][1] = u'Parallel Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][2] = u'Stub Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][3] = u'Rapid Exit and/or Turnoff Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][4] = u'Turnaround Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][5] = u'Dispersal'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][6] = u'Loop'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][7] = u'Perimeter'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][8] = u'Apron Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][9] = u'Aircraft Stand Taxilane'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][10] = u'Lead-in Taxilane'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][11] = u'Lead-out Taxilane'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][12] = u'Air Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][13] = u'Helicopter Ground Taxiway'
    field_information['TDS 4.0']['SummaryDomainValues']['TXP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][1] = u'Road'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][5] = u'Boulevard'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][9] = u'Avenue'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][13] = u'Drive'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][17] = u'Circle'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][21] = u'Close'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][25] = u'Parkway'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][29] = u'Lane'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][33] = u'Street'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][37] = u'Terrace'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][41] = u'Motorway'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][45] = u'Place'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][47] = u'Limited Access Motorway'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][48] = u'Roundabout'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][50] = u'Ramp'
    field_information['TDS 4.0']['SummaryDomainValues']['TYP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'][1] = u'Drift'
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'][2] = u'Slope'
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'][3] = u'Shaft'
    field_information['TDS 4.0']['SummaryDomainValues']['UMA'][998] = u'Not Applicable'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][1] = u'Cable Television'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][2] = u'Cooling Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][3] = u'Digital Fibre-optic System'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][4] = u'Electric Power Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][5] = u'Heating Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][6] = u'Natural Gas Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][7] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][8] = u'Storm Sewer'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][9] = u'Street Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][10] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][11] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][12] = u'Traffic Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][13] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][1] = u'Cable Television'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][2] = u'Cooling Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][3] = u'Digital Fibre-optic System'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][4] = u'Electric Power Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][5] = u'Heating Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][6] = u'Natural Gas Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][7] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][8] = u'Storm Sewer'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][9] = u'Street Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][10] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][11] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][12] = u'Traffic Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][13] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][1] = u'Cable Television'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][2] = u'Cooling Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][3] = u'Digital Fibre-optic System'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][4] = u'Electric Power Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][5] = u'Heating Fluid Circulation'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][6] = u'Natural Gas Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][7] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][8] = u'Storm Sewer'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][9] = u'Street Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][10] = u'Telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][11] = u'Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][12] = u'Traffic Light'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][13] = u'Water Distribution'
    field_information['TDS 4.0']['SummaryDomainValues']['UTY3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][1] = u'Not Requested'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][2] = u'Inaccessible'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][3] = u'No Available Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][6] = u'No Available Map Source'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][7] = u'No Suitable Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][8] = u'Not Required'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][9] = u'Cloud Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][10] = u'Snow Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][11] = u'Dark Shade'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][12] = u'Vegetation Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][13] = u'Flooded'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][16] = u'No Available Survey'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][1] = u'Not Requested'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][2] = u'Inaccessible'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][3] = u'No Available Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][6] = u'No Available Map Source'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][7] = u'No Suitable Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][8] = u'Not Required'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][9] = u'Cloud Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][10] = u'Snow Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][11] = u'Dark Shade'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][12] = u'Vegetation Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][13] = u'Flooded'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][16] = u'No Available Survey'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][1] = u'Not Requested'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][2] = u'Inaccessible'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][3] = u'No Available Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][6] = u'No Available Map Source'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][7] = u'No Suitable Imagery'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][8] = u'Not Required'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][9] = u'Cloud Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][10] = u'Snow Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][11] = u'Dark Shade'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][12] = u'Vegetation Cover'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][13] = u'Flooded'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][16] = u'No Available Survey'
    field_information['TDS 4.0']['SummaryDomainValues']['VCA3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][1] = u'Adobe Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][5] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][6] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][7] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][8] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][9] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][10] = u'Mud-based Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][11] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][12] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][13] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][14] = u'Sod'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][15] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][16] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][17] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][18] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][1] = u'Adobe Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][5] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][6] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][7] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][8] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][9] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][10] = u'Mud-based Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][11] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][12] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][13] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][14] = u'Sod'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][15] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][16] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][17] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][18] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][1] = u'Adobe Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][4] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][5] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][6] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][7] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][8] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][9] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][10] = u'Mud-based Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][11] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][12] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][13] = u'Reinforced Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][14] = u'Sod'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][15] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][16] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][17] = u'Treated Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][18] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['VCM3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'][1] = u'Hypsography'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'][3] = u'Bathymetry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'][4] = u'Waterbody Bottom Composition'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'][1] = u'Hypsography'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'][3] = u'Bathymetry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'][4] = u'Waterbody Bottom Composition'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'][1] = u'Hypsography'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'][3] = u'Bathymetry'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'][4] = u'Waterbody Bottom Composition'
    field_information['TDS 4.0']['SummaryDomainValues']['VCT3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VDT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VDT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][8] = u'Grassland'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][9] = u'Grassland with Trees'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][10] = u'Tropical Grass'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][56] = u'Without Trees'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][83] = u'Meadow'
    field_information['TDS 4.0']['SummaryDomainValues']['VEG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][2] = u'Automobile'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][3] = u'Barge'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][4] = u'Bicycle'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][5] = u'Boat'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][6] = u'Bus'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][7] = u'Caravanette'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][8] = u'Caravan'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][9] = u'Motorcycle'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][10] = u'Ship'
    field_information['TDS 4.0']['SummaryDomainValues']['VET'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][1] = u'Cone'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][2] = u'Cinder Cone'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][3] = u'Shield'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][4] = u'Caldera'
    field_information['TDS 4.0']['SummaryDomainValues']['VGT'][5] = u'Composite'
    field_information['TDS 4.0']['SummaryDomainValues']['VOA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VOA'][1] = u'Active'
    field_information['TDS 4.0']['SummaryDomainValues']['VOA'][2] = u'Dormant'
    field_information['TDS 4.0']['SummaryDomainValues']['VOA'][3] = u'Inactive or Extinct'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][4] = u'Casuarina'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][6] = u'Conifer'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][8] = u'Cypress'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][10] = u'Eucalyptus'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][11] = u'Filao'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][19] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][22] = u'Nipa'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][25] = u'Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][34] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][4] = u'Casuarina'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][6] = u'Conifer'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][8] = u'Cypress'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][10] = u'Eucalyptus'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][11] = u'Filao'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][19] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][22] = u'Nipa'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][25] = u'Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][34] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][4] = u'Casuarina'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][6] = u'Conifer'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][8] = u'Cypress'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][10] = u'Eucalyptus'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][11] = u'Filao'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][19] = u'Mangrove'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][22] = u'Nipa'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][25] = u'Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][34] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['VSP3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][1] = u'Channelized Stream'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][2] = u'Braided Stream'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][3] = u'Gorge'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][4] = u'Wadi'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][6] = u'Split Stream'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][7] = u'Normal Channel'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][8] = u'Lost Watercourse'
    field_information['TDS 4.0']['SummaryDomainValues']['WCC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][1] = u'Wellhead'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][2] = u'Christmas Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][3] = u'Manifold'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][4] = u'Protective Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][5] = u'Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][6] = u'Rod Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][7] = u'Separator'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][8] = u'Stock Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][9] = u'Treater'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][10] = u'Capped'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][1] = u'Wellhead'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][2] = u'Christmas Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][3] = u'Manifold'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][4] = u'Protective Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][5] = u'Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][6] = u'Rod Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][7] = u'Separator'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][8] = u'Stock Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][9] = u'Treater'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][10] = u'Capped'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][1] = u'Wellhead'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][2] = u'Christmas Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][3] = u'Manifold'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][4] = u'Protective Structure'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][5] = u'Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][6] = u'Rod Pump'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][7] = u'Separator'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][8] = u'Stock Tank'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][9] = u'Treater'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][10] = u'Capped'
    field_information['TDS 4.0']['SummaryDomainValues']['WEQ3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][2] = u'Walled-in'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][3] = u'Artesian'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][5] = u'Dug or Drilled'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][6] = u'Dug'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][7] = u'Drilled'
    field_information['TDS 4.0']['SummaryDomainValues']['WFT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][1] = u'Partly Submerged'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][2] = u'Always Dry'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][3] = u'Always Submerged'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][4] = u'Covers and Uncovers'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][5] = u'Awash at Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][9] = u'Awash at Chart Datum'
    field_information['TDS 4.0']['SummaryDomainValues']['WLE'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][1] = u'Mouth'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][2] = u'Pool'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][3] = u'Bend'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][4] = u'Confluence'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][5] = u'Cut-off'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][6] = u'Reach'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][7] = u'Anabranch'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][8] = u'Canalized'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][9] = u'Distributary'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][10] = u'Headwaters'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][11] = u'Abandoned'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][12] = u'Meander'
    field_information['TDS 4.0']['SummaryDomainValues']['WMT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'][1] = u'Sluice'
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'][2] = u'Flume'
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'][3] = u'Headrace'
    field_information['TDS 4.0']['SummaryDomainValues']['WRT'][4] = u'Tailrace'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][1] = u'Dissipating'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][2] = u'Disappearing'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][3] = u'Sinkhole'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][4] = u'Hole'
    field_information['TDS 4.0']['SummaryDomainValues']['WST'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['WTI'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['WTI'][1] = u'Free-standing'
    field_information['TDS 4.0']['SummaryDomainValues']['WTI'][2] = u'Retaining'
    field_information['TDS 4.0']['SummaryDomainValues']['WTI'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][1] = u'Air Force'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][2] = u'Army'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][3] = u'Coastguard'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][4] = u'Marines'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][5] = u'Navy'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][7] = u'Joint'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][8] = u'Air National Guard'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][9] = u'Army National Guard'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][998] = u'Not Applicable'
    field_information['TDS 4.0']['SummaryDomainValues']['YSU'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][1] = u'Potable'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][2] = u'Treatable'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][3] = u'Contaminated'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][4] = u'Nonpotable'
    field_information['TDS 4.0']['SummaryDomainValues']['YWQ'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_NSP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_NSP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_SSY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_SSY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_VSC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI001_VSC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI004_RCG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI004_RCG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][1] = u'Almond'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][2] = u'Apple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][3] = u'Barley'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][4] = u'Berry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][5] = u'Carob'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][6] = u'Chestnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][7] = u'Citrus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][8] = u'Cork-Oak'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][9] = u'Cacao'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][10] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][11] = u'Maize'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][13] = u'Dry Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][14] = u'Fibre Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][15] = u'Fruit Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][16] = u'Grape'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][17] = u'Hazelnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][18] = u'Hop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][19] = u'Maple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][20] = u'Millet'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][21] = u'Oat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][22] = u'Oil Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][23] = u'Olive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][24] = u'Peach'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][25] = u'Peanut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][26] = u'Potato'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][27] = u'Pulse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][28] = u'Rice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][29] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][30] = u'Rye'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][31] = u'Sisal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][32] = u'Sorghum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][33] = u'Sugar Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][34] = u'Tea'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][35] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][36] = u'Tuber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][37] = u'Vegetable Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][38] = u'Walnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][39] = u'Wheat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][40] = u'Date'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][41] = u'Banana'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][42] = u'Oil Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][43] = u'Coconut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][44] = u'Sugar Cane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][45] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][46] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][47] = u'Palmetto'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][48] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][117] = u'Opium Poppy'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][152] = u'Cannabis'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][159] = u'Ornamental Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][1] = u'Almond'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][2] = u'Apple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][3] = u'Barley'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][4] = u'Berry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][5] = u'Carob'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][6] = u'Chestnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][7] = u'Citrus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][8] = u'Cork-Oak'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][9] = u'Cacao'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][10] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][11] = u'Maize'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][13] = u'Dry Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][14] = u'Fibre Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][15] = u'Fruit Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][17] = u'Hazelnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][19] = u'Maple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][20] = u'Millet'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][21] = u'Oat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][22] = u'Oil Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][23] = u'Olive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][24] = u'Peach'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][25] = u'Peanut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][26] = u'Potato'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][27] = u'Pulse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][29] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][30] = u'Rye'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][31] = u'Sisal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][32] = u'Sorghum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][33] = u'Sugar Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][34] = u'Tea'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][35] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][36] = u'Tuber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][37] = u'Vegetable Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][38] = u'Walnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][39] = u'Wheat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][40] = u'Date'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][41] = u'Banana'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][42] = u'Oil Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][43] = u'Coconut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][44] = u'Sugar Cane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][45] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][46] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][47] = u'Palmetto'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][48] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][117] = u'Opium Poppy'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][152] = u'Cannabis'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][159] = u'Ornamental Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][1] = u'Almond'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][2] = u'Apple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][3] = u'Barley'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][4] = u'Berry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][5] = u'Carob'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][6] = u'Chestnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][7] = u'Citrus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][8] = u'Cork-Oak'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][9] = u'Cacao'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][10] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][11] = u'Maize'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][13] = u'Dry Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][14] = u'Fibre Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][15] = u'Fruit Tree'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][17] = u'Hazelnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][19] = u'Maple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][20] = u'Millet'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][21] = u'Oat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][22] = u'Oil Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][23] = u'Olive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][24] = u'Peach'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][25] = u'Peanut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][26] = u'Potato'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][27] = u'Pulse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][29] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][30] = u'Rye'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][31] = u'Sisal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][32] = u'Sorghum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][33] = u'Sugar Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][34] = u'Tea'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][35] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][36] = u'Tuber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][37] = u'Vegetable Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][38] = u'Walnut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][39] = u'Wheat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][40] = u'Date'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][41] = u'Banana'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][42] = u'Oil Palm'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][43] = u'Coconut'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][44] = u'Sugar Cane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][45] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][46] = u'Bamboo'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][47] = u'Palmetto'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][48] = u'Timber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][117] = u'Opium Poppy'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][152] = u'Cannabis'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][159] = u'Ornamental Crop'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_CSP3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][1] = u'Linear'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][2] = u'Regular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][3] = u'Terraced'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][4] = u'Intermingled Woods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][5] = u'Intermingled Trees'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][6] = u'Treeless'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][7] = u'Trellised'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][8] = u'Irregular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][1] = u'Linear'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][2] = u'Regular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][3] = u'Terraced'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][4] = u'Intermingled Woods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][5] = u'Intermingled Trees'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][6] = u'Treeless'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][7] = u'Trellised'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][8] = u'Irregular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][1] = u'Linear'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][2] = u'Regular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][3] = u'Terraced'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][4] = u'Intermingled Woods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][5] = u'Intermingled Trees'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][6] = u'Treeless'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][7] = u'Trellised'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][8] = u'Irregular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FFP3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][1] = u'Fallow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][2] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][3] = u'Permanent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][4] = u'Slash and Burn'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][5] = u'Permanent Irrigation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][1] = u'Fallow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][2] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][3] = u'Permanent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][4] = u'Slash and Burn'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][5] = u'Permanent Irrigation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][1] = u'Fallow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][2] = u'Grazing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][3] = u'Permanent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][4] = u'Slash and Burn'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][5] = u'Permanent Irrigation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_FMM3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][1] = u'Furrow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][2] = u'Overhead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][3] = u'Center Pivot'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][4] = u'Linear Move'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI013_IRG'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][1] = u'Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][2] = u'Cinders'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][6] = u'No Byproduct'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][7] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][12] = u'Scrap-metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][13] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][1] = u'Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][2] = u'Cinders'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][6] = u'No Byproduct'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][7] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][12] = u'Scrap-metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][13] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][1] = u'Ash'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][2] = u'Cinders'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][6] = u'No Byproduct'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][7] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][8] = u'Refuse'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][12] = u'Scrap-metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][13] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][15] = u'Slag'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PBY3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][4] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][5] = u'Motor Vehicle'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][20] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][23] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][25] = u'Consumer Goods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][28] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][32] = u'Desalinated Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][41] = u'Food'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][43] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][44] = u'Fruit'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][47] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][57] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][69] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][70] = u'Milk'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][73] = u'No Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][80] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][84] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][87] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][92] = u'Rice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][94] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][106] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][109] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][111] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][114] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][121] = u'Vegetation Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][123] = u'Wine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][136] = u'Biochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][137] = u'Petrochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][147] = u'Electronic Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][148] = u'Electrical Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][150] = u'Fertilizer'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][154] = u'Munitions'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][155] = u'Olive Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][156] = u'Whale Products'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][157] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][165] = u'Clothing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][192] = u'Petroleum Lubricant'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][279] = u'Fluorine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][325] = u'Phosphorus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][435] = u'Nuclear Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][4] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][5] = u'Motor Vehicle'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][20] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][23] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][25] = u'Consumer Goods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][28] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][32] = u'Desalinated Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][41] = u'Food'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][43] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][44] = u'Fruit'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][47] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][57] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][69] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][70] = u'Milk'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][73] = u'No Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][80] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][84] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][87] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][92] = u'Rice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][94] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][106] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][109] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][111] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][114] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][121] = u'Vegetation Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][123] = u'Wine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][136] = u'Biochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][137] = u'Petrochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][147] = u'Electronic Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][148] = u'Electrical Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][150] = u'Fertilizer'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][154] = u'Munitions'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][155] = u'Olive Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][156] = u'Whale Products'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][157] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][165] = u'Clothing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][192] = u'Petroleum Lubricant'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][279] = u'Fluorine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][325] = u'Phosphorus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][435] = u'Nuclear Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][1] = u'Aircraft'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][2] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][3] = u'Ammunition'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][4] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][5] = u'Motor Vehicle'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][13] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][15] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][16] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][18] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][20] = u'Coffee'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][21] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][23] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][25] = u'Consumer Goods'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][26] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][28] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][32] = u'Desalinated Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][37] = u'Electric Power'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][38] = u'Explosive'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][39] = u'Fish'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][41] = u'Food'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][43] = u'Frozen Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][44] = u'Fruit'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][45] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][46] = u'Petrol'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][47] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][48] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][57] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][58] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][59] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][60] = u'Lime'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][61] = u'Liquefied Natural Gas (LNG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][62] = u'Liquefied Petroleum Gas (LPG)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][63] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][65] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][69] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][70] = u'Milk'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][73] = u'No Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][74] = u'Non-solid Hydrocarbon Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][80] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][83] = u'Petroleum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][84] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][87] = u'Prestressed Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][90] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][92] = u'Rice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][94] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][95] = u'Salt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][101] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][105] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][106] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][109] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][111] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][114] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][117] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][120] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][121] = u'Vegetation Product'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][122] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][123] = u'Wine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][126] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][136] = u'Biochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][137] = u'Petrochemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][146] = u'Heating Steam and/or Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][147] = u'Electronic Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][148] = u'Electrical Equipment'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][150] = u'Fertilizer'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][154] = u'Munitions'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][155] = u'Olive Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][156] = u'Whale Products'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][157] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][160] = u'Milled Grain'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][165] = u'Clothing'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][192] = u'Petroleum Lubricant'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][214] = u'Biodiesel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][279] = u'Fluorine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][325] = u'Phosphorus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][435] = u'Nuclear Fuel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PPO3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][1] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][2] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][5] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][9] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][10] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][11] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][16] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][18] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][27] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][28] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][29] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][33] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][38] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][39] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][41] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][45] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][46] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][48] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][50] = u'No Raw Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][52] = u'Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][57] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][60] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][64] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][66] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][75] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][78] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][79] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][83] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][85] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][87] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][90] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][93] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][94] = u'Vegetation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][96] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][97] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][99] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][118] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][1] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][2] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][5] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][9] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][10] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][11] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][16] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][18] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][27] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][28] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][29] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][33] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][38] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][39] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][41] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][45] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][46] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][48] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][50] = u'No Raw Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][52] = u'Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][57] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][60] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][64] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][66] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][75] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][78] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][79] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][83] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][85] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][87] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][90] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][93] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][94] = u'Vegetation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][96] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][97] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][99] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][118] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][1] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][2] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][5] = u'Bauxite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][9] = u'Cement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][10] = u'Chemical'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][11] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][12] = u'Coal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][14] = u'Coke'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][16] = u'Copper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][18] = u'Cotton'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][27] = u'Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][28] = u'Glass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][29] = u'Gold'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][33] = u'Plant Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][38] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][39] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][41] = u'Lead'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][45] = u'Lumber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][46] = u'Manganese'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][48] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][50] = u'No Raw Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][52] = u'Oil'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][54] = u'Ore'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][57] = u'Paper'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][60] = u'Plastic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][64] = u'Radioactive Material'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][66] = u'Rubber'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][75] = u'Sewage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][78] = u'Silver'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][79] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][83] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][85] = u'Sugar'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][87] = u'Textile'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][90] = u'Tobacco'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][93] = u'Uranium'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][94] = u'Vegetation'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][96] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][97] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][99] = u'Zinc'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][118] = u'Petroleum and/or Natural Gas'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI014_PRW3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][1] = u'Unimproved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][2] = u'Stabilized Earth'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][3] = u'Flexible Pavement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][4] = u'Aggregate'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][5] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][6] = u'Bound Surface'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][7] = u'Rigid Pavement'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][8] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][9] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][10] = u'Asphalt over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][11] = u'Cobble-stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][12] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][13] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][14] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][15] = u'Corduroy'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][16] = u'Wood Plank'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][17] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][18] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_ROC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][1] = u'All-weather'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][2] = u'Fair-weather'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][3] = u'Winter Only'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][4] = u'Limited All-weather'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][5] = u'Closed in Winter'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI016_WTC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RGC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RGC'][1] = u'Broad'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RGC'][2] = u'Narrow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RGC'][3] = u'Standard'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RIR'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RIR'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RIR'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'][1] = u'Electrified Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'][3] = u'Overhead Electrified'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'][4] = u'Non-electrified'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_RRA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][1] = u'Crane Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][2] = u'Drill Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][3] = u'House Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][4] = u'Joint Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][5] = u'Ladder Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][6] = u'Paired Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][7] = u'Rip Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][9] = u'Stub Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][10] = u'Team Track'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][12] = u'Monorail'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][13] = u'Maglev'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI017_TRT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][1] = u'Cellular Phone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][2] = u'Microwave Radio Relay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][3] = u'Mobile Phone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][4] = u'Radio Broadcast'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][5] = u'Radio Telephone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][6] = u'Radio-telegraph'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][7] = u'Television (TV)'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI018_WIT'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][1] = u'Aggregate Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][2] = u'Graded'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][3] = u'Grass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][4] = u'Grooved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][5] = u'Oiled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][6] = u'Porous Friction Course'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][7] = u'Rolled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][8] = u'Rubberized Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][1] = u'Aggregate Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][2] = u'Graded'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][3] = u'Grass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][4] = u'Grooved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][5] = u'Oiled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][6] = u'Porous Friction Course'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][7] = u'Rolled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][8] = u'Rubberized Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][1] = u'Aggregate Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][2] = u'Graded'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][3] = u'Grass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][4] = u'Grooved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][5] = u'Oiled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][6] = u'Porous Friction Course'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][7] = u'Rolled'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][8] = u'Rubberized Seal Coat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASP3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][1] = u'Asphalt'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][2] = u'Bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][3] = u'Brick'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][4] = u'Clay'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][5] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][6] = u'Coral'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][7] = u'Earthen'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][8] = u'Gravel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][9] = u'Ice'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][10] = u'Landing Mat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][11] = u'Laterite'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][12] = u'Macadam'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][13] = u'Membrane'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][14] = u'Non-bituminous Mix'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][15] = u'Pierced Steel Planking'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][16] = u'Sand'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][17] = u'Snow'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][18] = u'Stone'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][19] = u'Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][20] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][21] = u'Asphalt Over Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASU3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][1] = u'Completely Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][2] = u'Mostly Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][3] = u'Unprepared'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][4] = u'Partially Paved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][5] = u'Unpaved'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_ASX'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][1] = u'Fair'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][2] = u'Fair Estimated'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][3] = u'Good'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][4] = u'Good Estimated'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][5] = u'Poor'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][6] = u'Poor Estimated'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][7] = u'Under Construction'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][8] = u'Unserviceable'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI019_SFS'][9] = u'Excellent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_HYP'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_HYP'][1] = u'Perennial'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_HYP'][2] = u'Intermittent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_HYP'][4] = u'Dry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][1] = u'Alkaline'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][4] = u'Mineral'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][10] = u'Saline'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][11] = u'Fresh'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][12] = u'Brackish'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][13] = u'Seawater'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][14] = u'Brine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_SCC'][998] = u'Not Applicable'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][1] = u'Potable'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][2] = u'Treatable'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][3] = u'Contaminated'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][4] = u'Nonpotable'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI024_YWQ'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][1] = u'Partly Submerged'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][2] = u'Always Dry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][3] = u'Always Submerged'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][4] = u'Covers and Uncovers'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][5] = u'Awash at Low Water'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][9] = u'Awash at Chart Datum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI025_WLE'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_GUG'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_GUG'][1000] = u'False'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_GUG'][1001] = u'True'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][1] = u'\'A\''
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][2] = u'\'H\''
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][3] = u'\'I\''
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][4] = u'\'Y\''
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][5] = u'\'T\''
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYC'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][1] = u'Aluminum'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][3] = u'Concrete'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][4] = u'Masonry'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][5] = u'Metal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][7] = u'Wood'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][8] = u'Steel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][9] = u'Fibreglass'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][10] = u'Iron'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_PYM'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][6] = u'Mast'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][8] = u'Pole'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][11] = u'Tripod'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][12] = u'Truss'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][13] = u'Tubular'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI032_TOS'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][1] = u'Buddhism'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][2] = u'Islam'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][3] = u'Roman Catholic'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][4] = u'Christian'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][5] = u'Judaism'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][6] = u'Orthodox'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][7] = u'Protestant'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][8] = u'Shinto'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][9] = u'Hinduism'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][10] = u'Shia'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][11] = u'Sunni'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][12] = u'Nestorian'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][13] = u'Chaldean'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_REL'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][1] = u'Cathedral'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][2] = u'Chapel'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][3] = u'Church'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][4] = u'Marabout'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][5] = u'Minaret'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][6] = u'Mission'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][7] = u'Mosque'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][8] = u'Pagoda'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][9] = u'Religious Community'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][10] = u'Seminary'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][11] = u'Shrine'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][12] = u'Stupa'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][13] = u'Synagogue'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][14] = u'Tabernacle'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][15] = u'Temple'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][18] = u'Convent'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][19] = u'Monastery'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][20] = u'Noviciate'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][21] = u'Hermitage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][22] = u'Retreat'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][23] = u'Burial Site'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI037_RFA'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][1] = u'Solution'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][2] = u'Erosional'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][3] = u'Aeolian'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][4] = u'Waterbody'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][5] = u'Glacier'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][6] = u'Lava'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][7] = u'Talus'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_CTX'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN2'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][530] = u'Warehousing and Storage'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][563] = u'Residence'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][835] = u'Defence Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][930] = u'Religious Activities'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_FFN3'][999] = u'Other'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][-999999] = u'No Information'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][1] = u'Horizontal'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][2] = u'Slopes Downward'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][3] = u'Vertical Down'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][4] = u'Slopes Upward'
    field_information['TDS 4.0']['SummaryDomainValues']['ZI071_UAO'][5] = u'Vertical Up'
    field_information['TDS 4.0']['SummaryDomainValues']['ZSAX_RS0'][5] = u'UNCLASSIFIED'


    field_information['TDS 4.0']['DefaultValues'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['DZP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['F_CODE'] = 'AA010'
    field_information['TDS 4.0']['DefaultValues']['AA010']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['LEA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['MZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA010']['UMA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA011'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA011']['F_CODE'] = 'AA011'
    field_information['TDS 4.0']['DefaultValues']['AA011']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA011']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA011']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA011']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA011']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA011']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['F_CODE'] = 'AA020'
    field_information['TDS 4.0']['DefaultValues']['AA020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['F_CODE'] = 'AA040'
    field_information['TDS 4.0']['DefaultValues']['AA040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA040']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA045'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA045']['F_CODE'] = 'AA045'
    field_information['TDS 4.0']['DefaultValues']['AA045']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA045']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA045']['RIP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA045']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA052']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['F_CODE'] = 'AA052'
    field_information['TDS 4.0']['DefaultValues']['AA052']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA052']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA052']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA052']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA054'] = {}
    field_information['TDS 4.0']['DefaultValues']['AA054']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['F_CODE'] = 'AA054'
    field_information['TDS 4.0']['DefaultValues']['AA054']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA054']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['RIP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA054']['WEQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['WEQ2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['WEQ3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AA054']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000'] = {}
    field_information['TDS 4.0']['DefaultValues']['AB000']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['F_CODE'] = 'AB000'
    field_information['TDS 4.0']['DefaultValues']['AB000']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB000']['PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB000']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB000']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB000']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AB010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['F_CODE'] = 'AB010'
    field_information['TDS 4.0']['DefaultValues']['AB010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021'] = {}
    field_information['TDS 4.0']['DefaultValues']['AB021']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['F_CODE'] = 'AB021'
    field_information['TDS 4.0']['DefaultValues']['AB021']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB021']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB021']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB021']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AB040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['F_CODE'] = 'AB040'
    field_information['TDS 4.0']['DefaultValues']['AB040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB040']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AB040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['F_CODE'] = 'AC010'
    field_information['TDS 4.0']['DefaultValues']['AC010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['F_CODE'] = 'AC020'
    field_information['TDS 4.0']['DefaultValues']['AC020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC020']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['F_CODE'] = 'AC030'
    field_information['TDS 4.0']['DefaultValues']['AC030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC030']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC040']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['F_CODE'] = 'AC040'
    field_information['TDS 4.0']['DefaultValues']['AC040']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['F_CODE'] = 'AC060'
    field_information['TDS 4.0']['DefaultValues']['AC060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507'] = {}
    field_information['TDS 4.0']['DefaultValues']['AC507']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['F_CODE'] = 'AC507'
    field_information['TDS 4.0']['DefaultValues']['AC507']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC507']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC507']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AC507']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD010']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['F_CODE'] = 'AD010'
    field_information['TDS 4.0']['DefaultValues']['AD010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['POS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['POS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['POS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD010']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['F_CODE'] = 'AD020'
    field_information['TDS 4.0']['DefaultValues']['AD020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD025']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['F_CODE'] = 'AD025'
    field_information['TDS 4.0']['DefaultValues']['AD025']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD025']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD025']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD025']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['F_CODE'] = 'AD030'
    field_information['TDS 4.0']['DefaultValues']['AD030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['SBT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['SBT2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['SBT3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD030']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD041']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['F_CODE'] = 'AD041'
    field_information['TDS 4.0']['DefaultValues']['AD041']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD041']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD041']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD041']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD041']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD050']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['F_CODE'] = 'AD050'
    field_information['TDS 4.0']['DefaultValues']['AD050']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD050']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD055']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['F_CODE'] = 'AD055'
    field_information['TDS 4.0']['DefaultValues']['AD055']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD055']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AD060']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['F_CODE'] = 'AD060'
    field_information['TDS 4.0']['DefaultValues']['AD060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AD060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['F_CODE'] = 'AF010'
    field_information['TDS 4.0']['DefaultValues']['AF010']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF010']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['F_CODE'] = 'AF020'
    field_information['TDS 4.0']['DefaultValues']['AF020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF020']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF021']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['F_CODE'] = 'AF021'
    field_information['TDS 4.0']['DefaultValues']['AF021']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF021']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF021']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF021']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF021']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['F_CODE'] = 'AF030'
    field_information['TDS 4.0']['DefaultValues']['AF030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF030']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['CRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['CRM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['F_CODE'] = 'AF040'
    field_information['TDS 4.0']['DefaultValues']['AF040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['LCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF040']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['F_CODE'] = 'AF050'
    field_information['TDS 4.0']['DefaultValues']['AF050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['ETY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['F_CODE'] = 'AF060'
    field_information['TDS 4.0']['DefaultValues']['AF060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF060']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['F_CODE'] = 'AF070'
    field_information['TDS 4.0']['DefaultValues']['AF070']['GUG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF070']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AF080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['F_CODE'] = 'AF080'
    field_information['TDS 4.0']['DefaultValues']['AF080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF080']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AF080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AG030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['F_CODE'] = 'AG030'
    field_information['TDS 4.0']['DefaultValues']['AG030']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AG040']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['F_CODE'] = 'AG040'
    field_information['TDS 4.0']['DefaultValues']['AG040']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZI037_RFA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AG050']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['F_CODE'] = 'AG050'
    field_information['TDS 4.0']['DefaultValues']['AG050']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AG050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025'] = {}
    field_information['TDS 4.0']['DefaultValues']['AH025']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['EET'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['F_CODE'] = 'AH025'
    field_information['TDS 4.0']['DefaultValues']['AH025']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH025']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH025']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH025']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055'] = {}
    field_information['TDS 4.0']['DefaultValues']['AH055']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH055']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['BNF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['F_CODE'] = 'AH055'
    field_information['TDS 4.0']['DefaultValues']['AH055']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['FZR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AH060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['DZP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['F_CODE'] = 'AH060'
    field_information['TDS 4.0']['DefaultValues']['AH060']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['LEA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AH070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['F_CODE'] = 'AH070'
    field_information['TDS 4.0']['DefaultValues']['AH070']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH070']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AH070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AI020']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['F_CODE'] = 'AI020'
    field_information['TDS 4.0']['DefaultValues']['AI020']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021'] = {}
    field_information['TDS 4.0']['DefaultValues']['AI021']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['F_CODE'] = 'AI021'
    field_information['TDS 4.0']['DefaultValues']['AI021']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI021']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI021']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI021']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AI030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['F_CODE'] = 'AI030'
    field_information['TDS 4.0']['DefaultValues']['AI030']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['STL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['STL2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['STL3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AI030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['F_CODE'] = 'AJ030'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['F_CODE'] = 'AJ050'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['F_CODE'] = 'AJ051'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['GUG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ051']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['F_CODE'] = 'AJ055'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['F_CODE'] = 'AJ080'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['F_CODE'] = 'AJ085'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ085']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110'] = {}
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['F_CODE'] = 'AJ110'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AJ110']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK020']['AMA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['F_CODE'] = 'AK020'
    field_information['TDS 4.0']['DefaultValues']['AK020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['F_CODE'] = 'AK030'
    field_information['TDS 4.0']['DefaultValues']['AK030']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['F_CODE'] = 'AK040'
    field_information['TDS 4.0']['DefaultValues']['AK040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['F_CODE'] = 'AK060'
    field_information['TDS 4.0']['DefaultValues']['AK060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK061'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK061']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['F_CODE'] = 'AK061'
    field_information['TDS 4.0']['DefaultValues']['AK061']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK061']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK061']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK061']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK070']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['F_CODE'] = 'AK070'
    field_information['TDS 4.0']['DefaultValues']['AK070']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK080']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['F_CODE'] = 'AK080'
    field_information['TDS 4.0']['DefaultValues']['AK080']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK080']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK090']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['F_CODE'] = 'AK090'
    field_information['TDS 4.0']['DefaultValues']['AK090']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK090']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK090']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK090']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK100']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['F_CODE'] = 'AK100'
    field_information['TDS 4.0']['DefaultValues']['AK100']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK100']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK101'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK101']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK101']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['F_CODE'] = 'AK101'
    field_information['TDS 4.0']['DefaultValues']['AK101']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK101']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK101']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK101']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['F_CODE'] = 'AK110'
    field_information['TDS 4.0']['DefaultValues']['AK110']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK110']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK120']['ADI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK120']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['F_CODE'] = 'AK120'
    field_information['TDS 4.0']['DefaultValues']['AK120']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK120']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK120']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK120']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK121'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK121']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['F_CODE'] = 'AK121'
    field_information['TDS 4.0']['DefaultValues']['AK121']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK121']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK121']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK121']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK130'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK130']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK130']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['F_CODE'] = 'AK130'
    field_information['TDS 4.0']['DefaultValues']['AK130']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK130']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK130']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK130']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK150']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['F_CODE'] = 'AK150'
    field_information['TDS 4.0']['DefaultValues']['AK150']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK150']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK155']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['F_CODE'] = 'AK155'
    field_information['TDS 4.0']['DefaultValues']['AK155']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK155']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK155']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK155']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK160']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['CCT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['F_CODE'] = 'AK160'
    field_information['TDS 4.0']['DefaultValues']['AK160']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK160']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK160']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK160']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK160']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK161']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['F_CODE'] = 'AK161'
    field_information['TDS 4.0']['DefaultValues']['AK161']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK161']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK161']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK161']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK164']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['F_CODE'] = 'AK164'
    field_information['TDS 4.0']['DefaultValues']['AK164']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK164']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK164']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK164']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK170']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK170']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['F_CODE'] = 'AK170'
    field_information['TDS 4.0']['DefaultValues']['AK170']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK170']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK170']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK170']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK180'] = {}
    field_information['TDS 4.0']['DefaultValues']['AK180']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['F_CODE'] = 'AK180'
    field_information['TDS 4.0']['DefaultValues']['AK180']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK180']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK180']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AK180']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL010']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL010']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['F_CODE'] = 'AL010'
    field_information['TDS 4.0']['DefaultValues']['AL010']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL010']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZI037_RFA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL011']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL011']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['F_CODE'] = 'AL011'
    field_information['TDS 4.0']['DefaultValues']['AL011']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL011']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL011']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL011']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL012']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['F_CODE'] = 'AL012'
    field_information['TDS 4.0']['DefaultValues']['AL012']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL012']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL013']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL013']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['BNF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['F_CODE'] = 'AL013'
    field_information['TDS 4.0']['DefaultValues']['AL013']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['MFB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL013']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL013']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL013']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZI037_RFA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL013']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL014']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['F_CODE'] = 'AL014'
    field_information['TDS 4.0']['DefaultValues']['AL014']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL014']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL014']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL014']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL014']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL017']['F_CODE'] = 'AL017'
    field_information['TDS 4.0']['DefaultValues']['AL017']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL017']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL017']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL018']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['BSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['F_CODE'] = 'AL018'
    field_information['TDS 4.0']['DefaultValues']['AL018']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL018']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL018']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL018']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL018']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL019']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL019']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['F_CODE'] = 'AL019'
    field_information['TDS 4.0']['DefaultValues']['AL019']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL019']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL019']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL019']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['BAC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['F_CODE'] = 'AL020'
    field_information['TDS 4.0']['DefaultValues']['AL020']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['WPI'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI005_FNA1'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI005_FNA2'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI005_NFN1'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI005_NFN2'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL025']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['F_CODE'] = 'AL025'
    field_information['TDS 4.0']['DefaultValues']['AL025']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL025']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL025']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL025']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['F_CODE'] = 'AL030'
    field_information['TDS 4.0']['DefaultValues']['AL030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL036']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['F_CODE'] = 'AL036'
    field_information['TDS 4.0']['DefaultValues']['AL036']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL036']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['SSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['TTY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL036']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL036']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['F_CODE'] = 'AL060'
    field_information['TDS 4.0']['DefaultValues']['AL060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL065'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL065']['F_CODE'] = 'AL065'
    field_information['TDS 4.0']['DefaultValues']['AL065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL065']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL070']['BAT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['F_CODE'] = 'AL070'
    field_information['TDS 4.0']['DefaultValues']['AL070']['FTI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL073']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['F_CODE'] = 'AL073'
    field_information['TDS 4.0']['DefaultValues']['AL073']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL073']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL073']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL073']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['CRM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['F_CODE'] = 'AL080'
    field_information['TDS 4.0']['DefaultValues']['AL080']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL080']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL099']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['F_CODE'] = 'AL099'
    field_information['TDS 4.0']['DefaultValues']['AL099']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL099']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL099']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL099']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL105']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['F_CODE'] = 'AL105'
    field_information['TDS 4.0']['DefaultValues']['AL105']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['HHD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL105']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL105']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL105']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['F_CODE'] = 'AL110'
    field_information['TDS 4.0']['DefaultValues']['AL110']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['PYC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['PYM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL110']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL110']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL120']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['F_CODE'] = 'AL120'
    field_information['TDS 4.0']['DefaultValues']['AL120']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['MST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['MST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['MST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL120']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL120']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL120']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL130']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['F_CODE'] = 'AL130'
    field_information['TDS 4.0']['DefaultValues']['AL130']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['SSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL130']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL140']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['F_CODE'] = 'AL140'
    field_information['TDS 4.0']['DefaultValues']['AL140']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL140']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL140']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL140']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL142']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL142']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['F_CODE'] = 'AL142'
    field_information['TDS 4.0']['DefaultValues']['AL142']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['TEL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL142']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL155']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['BCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['F_CODE'] = 'AL155'
    field_information['TDS 4.0']['DefaultValues']['AL155']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['OOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL155']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL155']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL155']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL155']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL155']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL155']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL165'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL165']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL165']['F_CODE'] = 'AL165'
    field_information['TDS 4.0']['DefaultValues']['AL165']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL165']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL165']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL165']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL165']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL165']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL170'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL170']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL170']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL170']['F_CODE'] = 'AL170'
    field_information['TDS 4.0']['DefaultValues']['AL170']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL170']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL170']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL170']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL170']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL170']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL175'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL175']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['F_CODE'] = 'AL175'
    field_information['TDS 4.0']['DefaultValues']['AL175']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL175']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL175']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZI037_RFA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL175']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL180'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL180']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['F_CODE'] = 'AL180'
    field_information['TDS 4.0']['DefaultValues']['AL180']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL180']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL180']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL180']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL195']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195']['F_CODE'] = 'AL195'
    field_information['TDS 4.0']['DefaultValues']['AL195']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL195']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL195']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL195']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL200'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL200']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['F_CODE'] = 'AL200'
    field_information['TDS 4.0']['DefaultValues']['AL200']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL200']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL200']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL200']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL201']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['F_CODE'] = 'AL201'
    field_information['TDS 4.0']['DefaultValues']['AL201']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['HSS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL201']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL201']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZI037_RFA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL201']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL208']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['F_CODE'] = 'AL208'
    field_information['TDS 4.0']['DefaultValues']['AL208']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL208']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL208']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL208']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL211']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['F_CODE'] = 'AL211'
    field_information['TDS 4.0']['DefaultValues']['AL211']['HCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL211']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['TRP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL211']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL211']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL241']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['F_CODE'] = 'AL241'
    field_information['TDS 4.0']['DefaultValues']['AL241']['GUG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL241']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['PYC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['PYM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['TTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['TTC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['TTC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL241']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL241']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL241']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL250']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL250']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['F_CODE'] = 'AL250'
    field_information['TDS 4.0']['DefaultValues']['AL250']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL250']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL250']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL250']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL260'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL260']['BAT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['F_CODE'] = 'AL260'
    field_information['TDS 4.0']['DefaultValues']['AL260']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL260']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL260']['WTI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL260']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL270']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['DMBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL270']['DMBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['DMBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['DMT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['F_CODE'] = 'AL270'
    field_information['TDS 4.0']['DefaultValues']['AL270']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL270']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['SDSC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL270']['SDSL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['SDSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['TRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['TSCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL270']['TSCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['TSCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL270']['VSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['VSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['VSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_CSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_CSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_CSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FMM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FMM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI013_FMM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL270']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL351']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['F_CODE'] = 'AL351'
    field_information['TDS 4.0']['DefaultValues']['AL351']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL351']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL351']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL351']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL375']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL375']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['F_CODE'] = 'AL375'
    field_information['TDS 4.0']['DefaultValues']['AL375']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL375']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL375']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL375']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL375']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL376']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['F_CODE'] = 'AL376'
    field_information['TDS 4.0']['DefaultValues']['AL376']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL376']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL376']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL376']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL510'] = {}
    field_information['TDS 4.0']['DefaultValues']['AL510']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL510']['F_CODE'] = 'AL510'
    field_information['TDS 4.0']['DefaultValues']['AL510']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL510']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL510']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL510']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL510']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AL510']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM010']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['F_CODE'] = 'AM010'
    field_information['TDS 4.0']['DefaultValues']['AM010']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM011']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['F_CODE'] = 'AM011'
    field_information['TDS 4.0']['DefaultValues']['AM011']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM011']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['SHT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM011']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM011']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['F_CODE'] = 'AM020'
    field_information['TDS 4.0']['DefaultValues']['AM020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM020']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['F_CODE'] = 'AM030'
    field_information['TDS 4.0']['DefaultValues']['AM030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM030']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['F_CODE'] = 'AM040'
    field_information['TDS 4.0']['DefaultValues']['AM040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM040']['PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM040']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM060']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['F_CODE'] = 'AM060'
    field_information['TDS 4.0']['DefaultValues']['AM060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM065']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['F_CODE'] = 'AM065'
    field_information['TDS 4.0']['DefaultValues']['AM065']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM065']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM065']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['CBP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['F_CODE'] = 'AM070'
    field_information['TDS 4.0']['DefaultValues']['AM070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['SSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM070']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM071']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['F_CODE'] = 'AM071'
    field_information['TDS 4.0']['DefaultValues']['AM071']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM071']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM071']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM071']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM075']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['F_CODE'] = 'AM075'
    field_information['TDS 4.0']['DefaultValues']['AM075']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM075']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM075']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM075']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AM080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['F_CODE'] = 'AM080'
    field_information['TDS 4.0']['DefaultValues']['AM080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['SSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM080']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AM080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['F_CODE'] = 'AN010'
    field_information['TDS 4.0']['DefaultValues']['AN010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['LTN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RRC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RRC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RRC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['RWC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN010']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI017_GAW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI017_RGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI017_RIR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI017_RRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZI017_TRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN050']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['CTL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['F_CODE'] = 'AN050'
    field_information['TDS 4.0']['DefaultValues']['AN050']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['LTN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['RSA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN050']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI017_GAW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI017_RGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI017_RRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZI017_TRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN060']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['CTL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['F_CODE'] = 'AN060'
    field_information['TDS 4.0']['DefaultValues']['AN060']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['LTN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI017_GAW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI017_RGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI017_RRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZI017_TRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN075']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['F_CODE'] = 'AN075'
    field_information['TDS 4.0']['DefaultValues']['AN075']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN075']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN075']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI017_GAW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI017_RGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI017_RRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZI017_TRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN075']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN076']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN076']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['F_CODE'] = 'AN076'
    field_information['TDS 4.0']['DefaultValues']['AN076']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI017_GAW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI017_RGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI017_RRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZI017_TRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN076']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085'] = {}
    field_information['TDS 4.0']['DefaultValues']['AN085']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085']['F_CODE'] = 'AN085'
    field_information['TDS 4.0']['DefaultValues']['AN085']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN085']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN085']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AN085']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['F_CODE'] = 'AP010'
    field_information['TDS 4.0']['DefaultValues']['AP010']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['THR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI016_WD1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZI016_WTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP020'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP020']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['F_CODE'] = 'AP020'
    field_information['TDS 4.0']['DefaultValues']['AP020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['LTN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN_ROI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN_ROI2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN_ROI3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN2'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['RTN3'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP020']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['THR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['TYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI016_WD1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZI016_WTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP030'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['F_CODE'] = 'AP030'
    field_information['TDS 4.0']['DefaultValues']['AP030']['FCO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['FSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['LTN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['MES'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['MWG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ONE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RMWC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP030']['RMWL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RMWU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN_ROI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN_ROI2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN_ROI3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN2'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['RTN3'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['SEP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP030']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['THR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['TYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP030']['WD2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['WT2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI016_WD1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZI016_WTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP040']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['F_CODE'] = 'AP040'
    field_information['TDS 4.0']['DefaultValues']['AP040']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['GTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP040']['WD2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP041'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP041']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['F_CODE'] = 'AP041'
    field_information['TDS 4.0']['DefaultValues']['AP041']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP041']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP041']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP041']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AP050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['F_CODE'] = 'AP050'
    field_information['TDS 4.0']['DefaultValues']['AP050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['THR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZI016_WTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AP050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ035'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['F_CODE'] = 'AQ035'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ035']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI016_WD1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZI016_WTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ035']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BOT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BRN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BSC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['BSC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['DZC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['F_CODE'] = 'AQ040'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['HCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LC1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LC4'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['NOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['RFD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['UBC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['BOT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['BRN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['BSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['BSC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['BSC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['F_CODE'] = 'AQ045'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ045']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['BRN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['F_CODE'] = 'AQ050'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['BRN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['F_CODE'] = 'AQ055'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['PYM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['F_CODE'] = 'AQ056'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ056']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ059']['BCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['CON'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['EXP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['F_CODE'] = 'AQ059'
    field_information['TDS 4.0']['DefaultValues']['AQ059']['HCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ059']['SHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['SRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ059']['WD1'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ059']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ059']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ059']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ059']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['F_CODE'] = 'AQ060'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['CSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['CSC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['CSC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['F_CODE'] = 'AQ062'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ062']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ063'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['F_CODE'] = 'AQ063'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ063']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ063']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['CTC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['F_CODE'] = 'AQ065'
    field_information['TDS 4.0']['DefaultValues']['AQ065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ065']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['TCS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ068'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['DGC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['F_CODE'] = 'AQ068'
    field_information['TDS 4.0']['DefaultValues']['AQ068']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ068']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ068']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ068']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ070'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ070']['F_CODE'] = 'AQ070'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['FCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['FER'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['MCX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['OPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ075'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ075']['F_CODE'] = 'AQ075'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ075']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ075']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ075']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['F_CODE'] = 'AQ080'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ095']['F_CODE'] = 'AQ095'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['HCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ095']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['F_CODE'] = 'AQ110'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['GUG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['PYM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ110']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ111']['F_CODE'] = 'AQ111'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ111']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ113'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ113']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['DIM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['F_CODE'] = 'AQ113'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['FLO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['NPL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['OWO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['RTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ113']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['F_CODE'] = 'AQ114'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ114']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ115'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['F_CODE'] = 'AQ115'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['UTY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['UTY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['UTY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ115']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ116'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['F_CODE'] = 'AQ116'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ116']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ118'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ118']['F_CODE'] = 'AQ118'
    field_information['TDS 4.0']['DefaultValues']['AQ118']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ118']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ118']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ118']['RAD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ118']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ118']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ118']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ118']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ118']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ118']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ120'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ120']['F_CODE'] = 'AQ120'
    field_information['TDS 4.0']['DefaultValues']['AQ120']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['LOG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ120']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ120']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ120']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ120']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ120']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ120']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ120']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ125'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['F_CODE'] = 'AQ125'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ125']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['BCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['DZC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['F_CODE'] = 'AQ130'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['HCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['TRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ130']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ135'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['F_CODE'] = 'AQ135'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ135']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['F_CODE'] = 'AQ140'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['VET'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ140']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['F_CODE'] = 'AQ141'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['LUN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ141']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['F_CODE'] = 'AQ150'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ150']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['F_CODE'] = 'AQ151'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ151']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ160'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ160']['F_CODE'] = 'AQ160'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ160']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ160']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ160']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ160']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ161'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ161']['F_CODE'] = 'AQ161'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ161']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ161']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ161']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ161']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ADI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['F_CODE'] = 'AQ162'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['SSG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ162']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['F_CODE'] = 'AQ170'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ170']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180'] = {}
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['F_CODE'] = 'AQ180'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['MFB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['VST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AQ180']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT005']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['CAB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['CAB2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['CAB3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['CST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['F_CODE'] = 'AT005'
    field_information['TDS 4.0']['DefaultValues']['AT005']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['KVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['NPL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT005']['OWO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['TST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT005']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZI025_WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT005']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT010']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['F_CODE'] = 'AT010'
    field_information['TDS 4.0']['DefaultValues']['AT010']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT011']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['F_CODE'] = 'AT011'
    field_information['TDS 4.0']['DefaultValues']['AT011']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT011']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT011']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT011']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT012']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['F_CODE'] = 'AT012'
    field_information['TDS 4.0']['DefaultValues']['AT012']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT012']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT012']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT012']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT041']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['CAT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['F_CODE'] = 'AT041'
    field_information['TDS 4.0']['DefaultValues']['AT041']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT041']['OWO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['TST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT041']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT041']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT041']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT042']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['AT005_CAB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['AT005_CAB2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['AT005_CAB3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['F_CODE'] = 'AT042'
    field_information['TDS 4.0']['DefaultValues']['AT042']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT042']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT042']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT042']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI032_GUG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI032_PYC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI032_PYM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZI032_TOS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT042']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045'] = {}
    field_information['TDS 4.0']['DefaultValues']['AT045']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['F_CODE'] = 'AT045'
    field_information['TDS 4.0']['DefaultValues']['AT045']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT045']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['RAC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['RAS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT045']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['AT045']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010'] = {}
    field_information['TDS 4.0']['DefaultValues']['BA010']['BA000_VDC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010']['BA000_VDR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA010']['F_CODE'] = 'BA010'
    field_information['TDS 4.0']['DefaultValues']['BA010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA010']['SHD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010']['SLT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA030'] = {}
    field_information['TDS 4.0']['DefaultValues']['BA030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['BA000_VDC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['BA000_VDR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA030']['F_CODE'] = 'BA030'
    field_information['TDS 4.0']['DefaultValues']['BA030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA030']['SHD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['SLT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040'] = {}
    field_information['TDS 4.0']['DefaultValues']['BA040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['F_CODE'] = 'BA040'
    field_information['TDS 4.0']['DefaultValues']['BA040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BA040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB005'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB005']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['F_CODE'] = 'BB005'
    field_information['TDS 4.0']['DefaultValues']['BB005']['FHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['FHC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['FHC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB005']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB005']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['WPI'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB009'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB009']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['F_CODE'] = 'BB009'
    field_information['TDS 4.0']['DefaultValues']['BB009']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB009']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB009']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['WPI'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PBY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PBY2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PBY3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PRW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PRW2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZI014_PRW3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB009']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB081']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['F_CODE'] = 'BB081'
    field_information['TDS 4.0']['DefaultValues']['BB081']['FAC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['FLO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB081']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['PWC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB081']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB081']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB082']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['F_CODE'] = 'BB082'
    field_information['TDS 4.0']['DefaultValues']['BB082']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB082']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB082']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['SLR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB082']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB082']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB090']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['F_CODE'] = 'BB090'
    field_information['TDS 4.0']['DefaultValues']['BB090']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['LNU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB090']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB090']['WDU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB090']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB110'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB110']['F_CODE'] = 'BB110'
    field_information['TDS 4.0']['DefaultValues']['BB110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB199'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB199']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['F_CODE'] = 'BB199'
    field_information['TDS 4.0']['DefaultValues']['BB199']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB199']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB199']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB199']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB201']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['F_CODE'] = 'BB201'
    field_information['TDS 4.0']['DefaultValues']['BB201']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB201']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB201']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB201']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241'] = {}
    field_information['TDS 4.0']['DefaultValues']['BB241']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['F_CODE'] = 'BB241'
    field_information['TDS 4.0']['DefaultValues']['BB241']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB241']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB241']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BB241']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050'] = {}
    field_information['TDS 4.0']['DefaultValues']['BC050']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC050']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['F_CODE'] = 'BC050'
    field_information['TDS 4.0']['DefaultValues']['BC050']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC050']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070'] = {}
    field_information['TDS 4.0']['DefaultValues']['BC070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['F_CODE'] = 'BC070'
    field_information['TDS 4.0']['DefaultValues']['BC070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC070']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BC070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100'] = {}
    field_information['TDS 4.0']['DefaultValues']['BD100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['F_CODE'] = 'BD100'
    field_information['TDS 4.0']['DefaultValues']['BD100']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD100']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZI025_WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD100']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115'] = {}
    field_information['TDS 4.0']['DefaultValues']['BD115']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['F_CODE'] = 'BD115'
    field_information['TDS 4.0']['DefaultValues']['BD115']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['OCS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD115']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD115']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD115']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD115']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD140'] = {}
    field_information['TDS 4.0']['DefaultValues']['BD140']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD140']['F_CODE'] = 'BD140'
    field_information['TDS 4.0']['DefaultValues']['BD140']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD140']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD140']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD140']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD140']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181'] = {}
    field_information['TDS 4.0']['DefaultValues']['BD181']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['F_CODE'] = 'BD181'
    field_information['TDS 4.0']['DefaultValues']['BD181']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BD181']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ATC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_AWBA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_AWBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_IBOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_IBOB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_SHDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_SHDB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_SLTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_SLTB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_WBHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BH141_WBHB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWHBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BPWSBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['BWVCBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['CDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['F_CODE'] = 'BH010'
    field_information['TDS 4.0']['DefaultValues']['BH010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['TRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH010']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH012']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['F_CODE'] = 'BH012'
    field_information['TDS 4.0']['DefaultValues']['BH012']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH012']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH012']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH012']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH015']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['BOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['F_CODE'] = 'BH015'
    field_information['TDS 4.0']['DefaultValues']['BH015']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH015']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH015']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH015']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH020'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_AWBA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_AWBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_IBOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_IBOB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_SHDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_SHDB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_SLTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_SLTB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_WBHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BH141_WBHB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWHBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BPWSBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['BWVCBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['CDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['CWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['F_CODE'] = 'BH020'
    field_information['TDS 4.0']['DefaultValues']['BH020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['NVS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['PWA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['RLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['SBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['TRA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH020']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WDH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WDL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['WVL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_AWBA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_AWBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_IBOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_IBOB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_SHDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_SHDB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_SLTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_SLTB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_WBHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BH141_WBHB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWHBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BPWSBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['BWVCBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['CDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['F_CODE'] = 'BH030'
    field_information['TDS 4.0']['DefaultValues']['BH030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH030']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['F_CODE'] = 'BH040'
    field_information['TDS 4.0']['DefaultValues']['BH040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH040']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH051'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH051']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['F_CODE'] = 'BH051'
    field_information['TDS 4.0']['DefaultValues']['BH051']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH051']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['PPO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['PPO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['PPO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH051']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH051']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH065'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['F_CODE'] = 'BH065'
    field_information['TDS 4.0']['DefaultValues']['BH065']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH065']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['WRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH070'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['F_CODE'] = 'BH070'
    field_information['TDS 4.0']['DefaultValues']['BH070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZI016_ROC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH075'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH075']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['F_CODE'] = 'BH075'
    field_information['TDS 4.0']['DefaultValues']['BH075']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH075']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH075']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH075']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH077'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH077']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH077']['F_CODE'] = 'BH077'
    field_information['TDS 4.0']['DefaultValues']['BH077']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH077']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH077']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH077']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH077']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH077']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH077']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH077']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH077']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH082'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH082']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['AZC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_AWBA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_AWBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_IBOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_IBOB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_SHDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_SHDB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_SLTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_SLTB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_WBHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BH141_WBHB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWHBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BPWSBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['BWVCBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['DMD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['F_CODE'] = 'BH082'
    field_information['TDS 4.0']['DefaultValues']['BH082']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['IWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['MNS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH082']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH082']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH082']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH090']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090']['CNS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090']['F_CODE'] = 'BH090'
    field_information['TDS 4.0']['DefaultValues']['BH090']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH090']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH090']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH090']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH090']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH090']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH090']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH100'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['F_CODE'] = 'BH100'
    field_information['TDS 4.0']['DefaultValues']['BH100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH100']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH100']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH100']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['DIM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['F_CODE'] = 'BH110'
    field_information['TDS 4.0']['DefaultValues']['BH110']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['LOC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH110']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['SPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH110']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQO2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQO3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQTC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQTL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AQTU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AYRC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH116']['AYRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['AYRU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['DPAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH116']['DPAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['DPAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['F_CODE'] = 'BH116'
    field_information['TDS 4.0']['DefaultValues']['BH116']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH116']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH116']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH116']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH120'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH120']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH120']['F_CODE'] = 'BH120'
    field_information['TDS 4.0']['DefaultValues']['BH120']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH120']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH120']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH120']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH120']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH120']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH135'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH135']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['F_CODE'] = 'BH135'
    field_information['TDS 4.0']['DefaultValues']['BH135']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH135']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH135']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI013_CSP'] = 28
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH135']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH140'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH140']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_AWBA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_AWBB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_IBOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_IBOB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_SHDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_SHDB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_SLTA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_SLTB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_WBHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BH141_WBHB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWHBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BPWSBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCAC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCAL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCAU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['BWVCBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['CDA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['F_CODE'] = 'BH140'
    field_information['TDS 4.0']['DefaultValues']['BH140']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['NVS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH140']['PWA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH140']['WCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WD3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WDH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WDL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WMT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['WVL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH140']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH145'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH145']['DOF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH145']['F_CODE'] = 'BH145'
    field_information['TDS 4.0']['DefaultValues']['BH145']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH145']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH145']['WST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH145']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH150'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH150']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['F_CODE'] = 'BH150'
    field_information['TDS 4.0']['DefaultValues']['BH150']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH150']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH150']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH150']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH155'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH155']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['AZC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['F_CODE'] = 'BH155'
    field_information['TDS 4.0']['DefaultValues']['BH155']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH155']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH155']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH155']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH160'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH160']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH160']['F_CODE'] = 'BH160'
    field_information['TDS 4.0']['DefaultValues']['BH160']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH160']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH160']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH160']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH160']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH160']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH165'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH165']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['F_CODE'] = 'BH165'
    field_information['TDS 4.0']['DefaultValues']['BH165']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH165']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH165']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH165']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH170'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH170']['AQN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH170']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['DOF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['F_CODE'] = 'BH170'
    field_information['TDS 4.0']['DefaultValues']['BH170']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH170']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['SWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH170']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH170']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH180'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH180']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['F_CODE'] = 'BH180'
    field_information['TDS 4.0']['DefaultValues']['BH180']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH180']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH180']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH180']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH220']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['F_CODE'] = 'BH220'
    field_information['TDS 4.0']['DefaultValues']['BH220']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH220']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH220']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH220']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230'] = {}
    field_information['TDS 4.0']['DefaultValues']['BH230']['AQN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['F_CODE'] = 'BH230'
    field_information['TDS 4.0']['DefaultValues']['BH230']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH230']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['SWW'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH230']['WAD'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH230']['WFT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI024_HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI024_SCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZI024_YWQ'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BH230']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI005']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['F_CODE'] = 'BI005'
    field_information['TDS 4.0']['DefaultValues']['BI005']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['LCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI005']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI005']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI005']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI006']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['F_CODE'] = 'BI006'
    field_information['TDS 4.0']['DefaultValues']['BI006']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['LNU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI006']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI006']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI006']['WDU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI006']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['F_CODE'] = 'BI010'
    field_information['TDS 4.0']['DefaultValues']['BI010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI010']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI010']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['VLM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI020']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['DWT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['F_CODE'] = 'BI020'
    field_information['TDS 4.0']['DefaultValues']['BI020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI020']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI020']['WD5'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI020']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['F_CODE'] = 'BI030'
    field_information['TDS 4.0']['DefaultValues']['BI030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['LNU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI030']['WDU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI040']['F_CODE'] = 'BI040'
    field_information['TDS 4.0']['DefaultValues']['BI040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI044'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI044']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['F_CODE'] = 'BI044'
    field_information['TDS 4.0']['DefaultValues']['BI044']['FCS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI044']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI044']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI044']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI045']['BGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['F_CODE'] = 'BI045'
    field_information['TDS 4.0']['DefaultValues']['BI045']['HEI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI045']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['THI'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI045']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['F_CODE'] = 'BI050'
    field_information['TDS 4.0']['DefaultValues']['BI050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI050']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060']['F_CODE'] = 'BI060'
    field_information['TDS 4.0']['DefaultValues']['BI060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI060']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI070'] = {}
    field_information['TDS 4.0']['DefaultValues']['BI070']['F_CODE'] = 'BI070'
    field_information['TDS 4.0']['DefaultValues']['BI070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BI070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ020'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ020']['F_CODE'] = 'BJ020'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ030'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ030']['F_CODE'] = 'BJ030'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031']['F_CODE'] = 'BJ031'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['PFD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ031']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ040'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ040']['F_CODE'] = 'BJ040'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['F_CODE'] = 'BJ060'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ060']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ065'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ065']['F_CODE'] = 'BJ065'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['F_CODE'] = 'BJ080'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['SSE'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ080']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['F_CODE'] = 'BJ099'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['LND'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['SRD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ099']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ100'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['F_CODE'] = 'BJ100'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['SDCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ100']['SDCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['SDCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['SIC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['SRD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ110'] = {}
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ110']['F_CODE'] = 'BJ110'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['BJ110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA010'] = {}
    field_information['TDS 4.0']['DefaultValues']['CA010']['ESC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA010']['F_CODE'] = 'CA010'
    field_information['TDS 4.0']['DefaultValues']['CA010']['HQC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA030'] = {}
    field_information['TDS 4.0']['DefaultValues']['CA030']['ESC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA030']['F_CODE'] = 'CA030'
    field_information['TDS 4.0']['DefaultValues']['CA030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['CA030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005'] = {}
    field_information['TDS 4.0']['DefaultValues']['DA005']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005']['F_CODE'] = 'DA005'
    field_information['TDS 4.0']['DefaultValues']['DA005']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA005']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA010'] = {}
    field_information['TDS 4.0']['DefaultValues']['DA010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['F_CODE'] = 'DA010'
    field_information['TDS 4.0']['DefaultValues']['DA010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA010']['SDCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DA010']['SDCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['SDCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['SRD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['STP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['SWC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['TSM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['TSM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['TSM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DA010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB010'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['F_CODE'] = 'DB010'
    field_information['TDS 4.0']['DefaultValues']['DB010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB010']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB010']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB010']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB029']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['F_CODE'] = 'DB029'
    field_information['TDS 4.0']['DefaultValues']['DB029']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['OHC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB029']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI071_CTX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI071_FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI071_FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI071_FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZI071_UAO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB029']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB061'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB061']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['F_CODE'] = 'DB061'
    field_information['TDS 4.0']['DefaultValues']['DB061']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB061']['PFD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB061']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB061']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['CET'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['F_CODE'] = 'DB070'
    field_information['TDS 4.0']['DefaultValues']['DB070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['PFD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB070']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB071'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB071']['F_CODE'] = 'DB071'
    field_information['TDS 4.0']['DefaultValues']['DB071']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB071']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB071']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB071']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB071']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB071']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB071']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB071']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB080'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB080']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['F_CODE'] = 'DB080'
    field_information['TDS 4.0']['DefaultValues']['DB080']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB080']['PFD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB080']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB080']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB080']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB080']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB080']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB080']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB090'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB090']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['CET'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['F_CODE'] = 'DB090'
    field_information['TDS 4.0']['DefaultValues']['DB090']['FIC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB090']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB090']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['TRS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['TRS2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['TRS3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB090']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['WLE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB090']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['F_CODE'] = 'DB100'
    field_information['TDS 4.0']['DefaultValues']['DB100']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB100']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB110']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110']['F_CODE'] = 'DB110'
    field_information['TDS 4.0']['DefaultValues']['DB110']['GFT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB110']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB115'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB115']['AQN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB115']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['DOF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['F_CODE'] = 'DB115'
    field_information['TDS 4.0']['DefaultValues']['DB115']['GOT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB115']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB115']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB115']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB150'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB150']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB150']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB150']['F_CODE'] = 'DB150'
    field_information['TDS 4.0']['DefaultValues']['DB150']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB150']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB150']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB150']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB150']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB160']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['F_CODE'] = 'DB160'
    field_information['TDS 4.0']['DefaultValues']['DB160']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB160']['PFH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['RKF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB160']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB160']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB170']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['F_CODE'] = 'DB170'
    field_information['TDS 4.0']['DefaultValues']['DB170']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB170']['SAD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['SDO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['SDT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB170']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB170']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB180']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['F_CODE'] = 'DB180'
    field_information['TDS 4.0']['DefaultValues']['DB180']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB180']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB180']['VGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['VOA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB180']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB190']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['F_CODE'] = 'DB190'
    field_information['TDS 4.0']['DefaultValues']['DB190']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB190']['SGCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB190']['SGCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['SGCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB190']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB190']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB211'] = {}
    field_information['TDS 4.0']['DefaultValues']['DB211']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB211']['F_CODE'] = 'DB211'
    field_information['TDS 4.0']['DefaultValues']['DB211']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB211']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB211']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB211']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['DB211']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA010'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['F_CODE'] = 'EA010'
    field_information['TDS 4.0']['DefaultValues']['EA010']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_CSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_CSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_CSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FMM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FMM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_FMM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZI013_IRG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA020'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['F_CODE'] = 'EA020'
    field_information['TDS 4.0']['DefaultValues']['EA020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA020']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA030'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA030']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['F_CODE'] = 'EA030'
    field_information['TDS 4.0']['DefaultValues']['EA030']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA031'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA031']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA031']['F_CODE'] = 'EA031'
    field_information['TDS 4.0']['DefaultValues']['EA031']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA031']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA031']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA031']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA031']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA031']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['DMT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['F_CODE'] = 'EA040'
    field_information['TDS 4.0']['DefaultValues']['EA040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA040']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['SDSC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA040']['SDSL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['SDSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['TRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['TSCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA040']['TSCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['TSCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_CSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_CSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_CSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZI013_IRG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['F_CODE'] = 'EA050'
    field_information['TDS 4.0']['DefaultValues']['EA050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI013_CSP'] = 16
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZI013_IRG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055'] = {}
    field_information['TDS 4.0']['DefaultValues']['EA055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['F_CODE'] = 'EA055'
    field_information['TDS 4.0']['DefaultValues']['EA055']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI013_CSP'] = 18
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI013_FFP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI013_FFP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI013_FFP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZI013_IRG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EA055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010'] = {}
    field_information['TDS 4.0']['DefaultValues']['EB010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['F_CODE'] = 'EB010'
    field_information['TDS 4.0']['DefaultValues']['EB010']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB010']['VEG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB020'] = {}
    field_information['TDS 4.0']['DefaultValues']['EB020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['DMBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EB020']['DMBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['DMBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['F_CODE'] = 'EB020'
    field_information['TDS 4.0']['DefaultValues']['EB020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB020']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB070'] = {}
    field_information['TDS 4.0']['DefaultValues']['EB070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['F_CODE'] = 'EB070'
    field_information['TDS 4.0']['DefaultValues']['EB070']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB070']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EB070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC005']['F_CODE'] = 'EC005'
    field_information['TDS 4.0']['DefaultValues']['EC005']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC005']['TRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC005']['VSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC005']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010']['F_CODE'] = 'EC010'
    field_information['TDS 4.0']['DefaultValues']['EC010']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC015'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC015']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['DMBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC015']['DMBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['DMBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['DMT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['F_CODE'] = 'EC015'
    field_information['TDS 4.0']['DefaultValues']['EC015']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC015']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['SBC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['SDSC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC015']['SDSL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['SDSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['TRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['TSCC'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC015']['TSCL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['TSCU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC015']['VSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['VSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['VSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC015']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020']['F_CODE'] = 'EC020'
    field_information['TDS 4.0']['DefaultValues']['EC020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC020']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC040'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC040']['F_CODE'] = 'EC040'
    field_information['TDS 4.0']['DefaultValues']['EC040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC060'] = {}
    field_information['TDS 4.0']['DefaultValues']['EC060']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC060']['F_CODE'] = 'EC060'
    field_information['TDS 4.0']['DefaultValues']['EC060']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC060']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC060']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC060']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EC060']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED010'] = {}
    field_information['TDS 4.0']['DefaultValues']['ED010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['DMBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['ED010']['DMBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['DMBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['F_CODE'] = 'ED010'
    field_information['TDS 4.0']['DefaultValues']['ED010']['HYP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED010']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED020'] = {}
    field_information['TDS 4.0']['DefaultValues']['ED020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['BMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['BMC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['BMC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['DMBC'] = 5
    field_information['TDS 4.0']['DefaultValues']['ED020']['DMBL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['DMBU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['DMT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['F_CODE'] = 'ED020'
    field_information['TDS 4.0']['DefaultValues']['ED020']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED020']['PVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['TID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['TRE'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED020']['VSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['VSP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['VSP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ED020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE010'] = {}
    field_information['TDS 4.0']['DefaultValues']['EE010']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE010']['F_CODE'] = 'EE010'
    field_information['TDS 4.0']['DefaultValues']['EE010']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE010']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE010']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE010']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE010']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE030'] = {}
    field_information['TDS 4.0']['DefaultValues']['EE030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['F_CODE'] = 'EE030'
    field_information['TDS 4.0']['DefaultValues']['EE030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE030']['TSM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['TSM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['TSM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['EE030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA012'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA012']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['CCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['CSO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['F_CODE'] = 'FA012'
    field_information['TDS 4.0']['DefaultValues']['FA012']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA012']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA012']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA012']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA015'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA015']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['F_CODE'] = 'FA015'
    field_information['TDS 4.0']['DefaultValues']['FA015']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['FRT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['FRT2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['FRT3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA015']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA015']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA015']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA100']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100']['F_CODE'] = 'FA100'
    field_information['TDS 4.0']['DefaultValues']['FA100']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA100']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA100']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA100']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA110'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA110']['F_CODE'] = 'FA110'
    field_information['TDS 4.0']['DefaultValues']['FA110']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA110']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA110']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA110']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA110']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA110']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA110']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA165'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA165']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['F_CODE'] = 'FA165'
    field_information['TDS 4.0']['DefaultValues']['FA165']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA165']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA165']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZI018_WIT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA165']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210'] = {}
    field_information['TDS 4.0']['DefaultValues']['FA210']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['CAM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['F_CODE'] = 'FA210'
    field_information['TDS 4.0']['DefaultValues']['FA210']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA210']['SRL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA210']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['FA210']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB005']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['ASY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['F_CODE'] = 'GB005'
    field_information['TDS 4.0']['DefaultValues']['GB005']['FPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['IKO'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['NA8'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB005']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['PEC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB005']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB015']['APY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['AXS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['F_CODE'] = 'GB015'
    field_information['TDS 4.0']['DefaultValues']['GB015']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB015']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB015']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASU2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASU3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_ASX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZI019_SFS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB015']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['AXS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['F_CODE'] = 'GB030'
    field_information['TDS 4.0']['DefaultValues']['GB030']['HAF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASU2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASU3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_ASX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZI019_SFS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB030']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB035']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['ASY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['F_CODE'] = 'GB035'
    field_information['TDS 4.0']['DefaultValues']['GB035']['FPT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['IKO'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB035']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['NA8'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB035']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB035']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['PEC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB035']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB035']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB040']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['F_CODE'] = 'GB040'
    field_information['TDS 4.0']['DefaultValues']['GB040']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB040']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB040']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB040']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB045']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['ASU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['ASU2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['ASU3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['F_CODE'] = 'GB045'
    field_information['TDS 4.0']['DefaultValues']['GB045']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB045']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB045']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB045']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB050']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['F_CODE'] = 'GB050'
    field_information['TDS 4.0']['DefaultValues']['GB050']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['LNU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB050']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB050']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB050']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB055']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['AXS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['F_CODE'] = 'GB055'
    field_information['TDS 4.0']['DefaultValues']['GB055']['GB052_RIDH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['GB052_RIDL'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCHC'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCHL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCHU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCLC'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCLL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['GSGCLU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASU2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASU3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_ASX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZI019_SFS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB055']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB065']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['ASY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['F_CODE'] = 'GB065'
    field_information['TDS 4.0']['DefaultValues']['GB065']['IKO'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB065']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['NA8'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB065']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB065']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['PEC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB065']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB065']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB070']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['COS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['F_CODE'] = 'GB070'
    field_information['TDS 4.0']['DefaultValues']['GB070']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB070']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB070']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB070']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB075']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['AXS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['DEV'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['F_CODE'] = 'GB075'
    field_information['TDS 4.0']['DefaultValues']['GB075']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB075']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['TXP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB075']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASP2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASP3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASU2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASU3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_ASX'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZI019_SFS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB075']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB230']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB230']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['ATB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['F_CODE'] = 'GB230'
    field_information['TDS 4.0']['DefaultValues']['GB230']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['HTP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB230']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB230']['VCM'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['VCM2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['VCM3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB230']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB230']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250'] = {}
    field_information['TDS 4.0']['DefaultValues']['GB250']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB250']['AOO'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['AWP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['F_CODE'] = 'GB250'
    field_information['TDS 4.0']['DefaultValues']['GB250']['FFN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['FFN2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['FFN3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['HGT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['HST'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['HST2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['HST3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['MUB'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB250']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['SSR'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['SSR2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['SSR3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB250']['VOI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB250']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['GB250']['ZVH'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001'] = {}
    field_information['TDS 4.0']['DefaultValues']['SU001']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU001']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['F_CODE'] = 'SU001'
    field_information['TDS 4.0']['DefaultValues']['SU001']['LMC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU001']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU001']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['YSU'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU001']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU004'] = {}
    field_information['TDS 4.0']['DefaultValues']['SU004']['ADR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU004']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['CAA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['F_CODE'] = 'SU004'
    field_information['TDS 4.0']['DefaultValues']['SU004']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU004']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU004']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['SU004']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB030'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['F_CODE'] = 'ZB030'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['MCC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['MCC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['MCC3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB035'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZB035']['BEL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB035']['CPA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB035']['F_CODE'] = 'ZB035'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['PCF'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB035']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZB035']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD020'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['F_CODE'] = 'ZD020'
    field_information['TDS 4.0']['DefaultValues']['ZD020']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD020']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCA2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCA3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCT2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['VCT3'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD020']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD030'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ARA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['CUL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['F_CODE'] = 'ZD030'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['LZN'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['WID'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZI037_REL'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD030']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD040'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZD040']['F_CODE'] = 'ZD040'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['NLT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZI005_FNA'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZI005_NFN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD040']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD045'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZD045']['F_CODE'] = 'ZD045'
    field_information['TDS 4.0']['DefaultValues']['ZD045']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD045']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD045']['ZI004_RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZD045']['ZI006_MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZD045']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZD045']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZD045']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI031'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZI031']['AHA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['AVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['CID'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['CPS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['DQS'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['EQC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ETS'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ETZ'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['EVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['F_CODE'] = 'ZI031'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['HVA'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['HZD'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['IC2'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['MDE'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['MEM'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['RCG'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['URI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['VDT'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ZI002_CCN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ZI002_CDR'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ZSAX_RS0'] = 5
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ZSAX_RX3'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI031']['ZSAX_RX4'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI040'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZI040']['F_CODE'] = 'ZI040'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_SSD'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_SSN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_SSY'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_VSC'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_VSD'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI001_VSN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI040']['ZI004_PRE'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI041'] = {}
    field_information['TDS 4.0']['DefaultValues']['ZI041']['F_CODE'] = 'ZI041'
    field_information['TDS 4.0']['DefaultValues']['ZI041']['OTH'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI041']['UFI'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI041']['ZI001_NSD'] = 'noInformation'
    field_information['TDS 4.0']['DefaultValues']['ZI041']['ZI001_NSN'] = 'No Information'
    field_information['TDS 4.0']['DefaultValues']['ZI041']['ZI001_NSP'] = -999999
    field_information['TDS 4.0']['DefaultValues']['ZI041']['ZI004_PRE'] = 'No Information'


    field_information['TDS 4.0']['Levels'] = {}
    field_information['TDS 4.0']['Levels']['Global'] = {}
    field_information['TDS 4.0']['Levels']['Regional'] = {}
    field_information['TDS 4.0']['Levels']['Local'] = {}
    field_information['TDS 4.0']['Levels']['Specialized'] = {}
    field_information['TDS 4.0']['Levels']['Global']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['EXTRACTION_MINE_P'] = ('AA010', '100001', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['EXTRACTION_MINE_S'] = ('AA010', '100001', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHEAR_WALL_C'] = ('AA011', '100002', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Global']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MINE_SHAFT_SUPERSTRUCTURE_P'] = ('AA020', '100003', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MINE_SHAFT_SUPERSTRUCTURE_S'] = ('AA020', '100003', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RIG_P'] = ('AA040', '100004', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RIG_S'] = ('AA040', '100004', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BOREHOLE_P'] = ('AA045', '100696', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HYDROCARBONS_FIELD_S'] = ('AA052', '100006', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NON_WATER_WELL_P'] = ('AA054', '155023', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['DISPOSAL_SITE_P'] = ('AB000', '100007', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['DISPOSAL_SITE_P'] = ('AB000', '100007', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DISPOSAL_SITE_S'] = ('AB000', '100007', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RECYCLING_SITE_S'] = ('AB010', '100008', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LIQUID_DIFFUSER_P'] = ('AB021', '100009', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AERATION_BASIN_S'] = ('AB040', '100010', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BLAST_FURNACE_P'] = ('AC010', '100012', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BLAST_FURNACE_S'] = ('AC010', '100012', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CATALYTIC_CRACKER_P'] = ('AC020', '100013', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CATALYTIC_CRACKER_S'] = ('AC020', '100013', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['SETTLING_POND_S'] = ('AC030', '100014', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SETTLING_POND_S'] = ('AC030', '100014', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HYDROCARBON_PROD_FACILITY_P'] = ('AC040', '100015', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HYDROCARBON_PROD_FACILITY_S'] = ('AC040', '100015', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['INDUSTRIAL_FURNACE_P'] = ('AC060', '100016', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['INDUSTRIAL_FURNACE_P'] = ('AC060', '100016', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['INDUSTRIAL_FURNACE_S'] = ('AC060', '100016', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['INDUSTRIAL_FURNACE_S'] = ('AC060', '100016', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SEWAGE_TREATMENT_PLANT_P'] = ('AC507', '134665', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SEWAGE_TREATMENT_PLANT_S'] = ('AC507', '134665', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ELECTRIC_POWER_STATION_P'] = ('AD010', '100018', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ELECTRIC_POWER_STATION_S'] = ('AD010', '100018', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SOLAR_PANEL_P'] = ('AD020', '100019', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SOLAR_PANEL_S'] = ('AD020', '100019', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['SOLAR_FARM_P'] = ('AD025', '100020', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SOLAR_FARM_S'] = ('AD025', '100020', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['POWER_SUBSTATION_P'] = ('AD030', '100021', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['POWER_SUBSTATION_S'] = ('AD030', '100021', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['POWER_SUBSTATION_S'] = ('AD030', '100021', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NUCLEAR_REACTOR_CONTAINMENT_P'] = ('AD041', '100022', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['NUCLEAR_REACTOR_CONTAINMENT_S'] = ('AD041', '100022', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HEATING_FACILITY_P'] = ('AD050', '100023', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HEATING_FACILITY_S'] = ('AD050', '100023', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['COOLING_FACILITY_P'] = ('AD055', '100697', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['COOLING_FACILITY_S'] = ('AD055', '100697', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['WIND_FARM_P'] = ('AD060', '100687', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WIND_FARM_S'] = ('AD060', '100687', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SMOKESTACK_P'] = ('AF010', '100025', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Local']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CONVEYOR_C'] = ('AF020', '100026', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Local']['BUCKET_ELEVATOR_C'] = ('AF021', '100027', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BUCKET_ELEVATOR_C'] = ('AF021', '100027', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Local']['BUCKET_ELEVATOR_P'] = ('AF021', '100027', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BUCKET_ELEVATOR_P'] = ('AF021', '100027', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['COOLING_TOWER_P'] = ('AF030', '100028', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['COOLING_TOWER_S'] = ('AF030', '100028', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CRANE_P'] = ('AF040', '100029', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CRANE_S'] = ('AF040', '100029', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['EXCAVATING_MACHINE_C'] = ('AF050', '100030', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['EXCAVATING_MACHINE_C'] = ('AF050', '100030', 'IndustryCrv')
    field_information['TDS 4.0']['Levels']['Global']['EXCAVATING_MACHINE_P'] = ('AF050', '100030', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['EXCAVATING_MACHINE_P'] = ('AF050', '100030', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ENGINE_TEST_CELL_P'] = ('AF060', '100031', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['ENGINE_TEST_CELL_S'] = ('AF060', '100031', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ENGINE_TEST_CELL_S'] = ('AF060', '100031', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FLARE_PIPE_P'] = ('AF070', '100032', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HOPPER_P'] = ('AF080', '100033', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['SHOPPING_COMPLEX_S'] = ('AG030', '100034', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHOPPING_COMPLEX_S'] = ('AG030', '100034', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['OFFICE_PARK_S'] = ('AG040', '100035', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Global']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BILLBOARD_P'] = ('AG050', '121638', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Local']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ENGINEERED_EARTHWORK_C'] = ('AH025', '132596', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Local']['ENGINEERED_EARTHWORK_S'] = ('AH025', '132596', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ENGINEERED_EARTHWORK_S'] = ('AH025', '132596', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FORTIFIED_BUILDING_P'] = ('AH055', '132626', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FORTIFIED_BUILDING_S'] = ('AH055', '132626', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['UNDERGROUND_BUNKER_P'] = ('AH060', '100038', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['UNDERGROUND_BUNKER_S'] = ('AH060', '100038', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CHECKPOINT_P'] = ('AH070', '100039', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Regional']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CARAVAN_PARK_S'] = ('AI020', '100040', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Global']['MOBILE_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['MOBILE_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Regional']['MOBILE_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MOBILE_HOME_PARK_S'] = ('AI021', '133168', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['CAMP_P'] = ('AI030', '100041', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CAMP_P'] = ('AI030', '100041', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Local']['CAMP_S'] = ('AI030', '100041', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CAMP_S'] = ('AI030', '100041', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['HOLDING_PEN_P'] = ('AJ030', '100043', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HOLDING_PEN_P'] = ('AJ030', '100043', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['HOLDING_PEN_S'] = ('AJ030', '100043', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HOLDING_PEN_S'] = ('AJ030', '100043', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WINDMILL_P'] = ('AJ050', '100044', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WINDMILL_S'] = ('AJ050', '100044', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WIND_TURBINE_P'] = ('AJ051', '100045', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_MILL_P'] = ('AJ055', '100046', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_MILL_S'] = ('AJ055', '100046', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STABLE_P'] = ('AJ080', '100049', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STABLE_S'] = ('AJ080', '100049', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BARN_P'] = ('AJ085', '100691', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BARN_S'] = ('AJ085', '100691', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GREENHOUSE_P'] = ('AJ110', '100052', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Global']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GREENHOUSE_S'] = ('AJ110', '100052', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_C'] = ('AK020', '100053', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Global']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_P'] = ('AK020', '100053', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AMUSEMENT_PARK_ATTRACTION_S'] = ('AK020', '100053', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['AMUSEMENT_PARK_P'] = ('AK030', '100054', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['AMUSEMENT_PARK_P'] = ('AK030', '100054', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AMUSEMENT_PARK_S'] = ('AK030', '100054', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['SPORTS_GROUND_P'] = ('AK040', '100055', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SPORTS_GROUND_P'] = ('AK040', '100055', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SPORTS_GROUND_S'] = ('AK040', '100055', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['CAMP_SITE_P'] = ('AK060', '100057', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CAMP_SITE_P'] = ('AK060', '100057', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['CAMP_SITE_S'] = ('AK060', '100057', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CAMP_SITE_S'] = ('AK060', '100057', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PICNIC_SITE_S'] = ('AK061', '100058', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['DRIVE_IN_THEATRE_S'] = ('AK070', '100059', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DRIVE_IN_THEATRE_S'] = ('AK070', '100059', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['OUTDOOR_THEATRE_SCREEN_C'] = ('AK080', '100060', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Global']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['OUTDOOR_THEATRE_SCREEN_P'] = ('AK080', '100060', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FAIRGROUND_S'] = ('AK090', '100061', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GOLF_COURSE_S'] = ('AK100', '100062', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['GOLF_DRIVING_RANGE_S'] = ('AK101', '100063', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GOLF_DRIVING_RANGE_S'] = ('AK101', '100063', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GRANDSTAND_P'] = ('AK110', '100064', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['GRANDSTAND_S'] = ('AK110', '100064', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GRANDSTAND_S'] = ('AK110', '100064', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PARK_S'] = ('AK120', '100065', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LOOKOUT_P'] = ('AK121', '100066', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LOOKOUT_S'] = ('AK121', '100066', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Local']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Regional']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RACETRACK_C'] = ('AK130', '100069', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RACETRACK_S'] = ('AK130', '100069', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['SKI_JUMP_C'] = ('AK150', '100072', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SKI_JUMP_C'] = ('AK150', '100072', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Global']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SKI_JUMP_P'] = ('AK150', '100072', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SKI_RUN_C'] = ('AK155', '100073', 'RecreationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SKI_RUN_S'] = ('AK155', '100073', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STADIUM_P'] = ('AK160', '154703', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STADIUM_S'] = ('AK160', '154703', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SCOREBOARD_P'] = ('AK161', '121747', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AMPHITHEATRE_P'] = ('AK164', '100074', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['AMPHITHEATRE_S'] = ('AK164', '100074', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AMPHITHEATRE_S'] = ('AK164', '100074', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SWIMMING_POOL_P'] = ('AK170', '100077', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Local']['SWIMMING_POOL_S'] = ('AK170', '100077', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SWIMMING_POOL_S'] = ('AK170', '100077', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['ZOO_P'] = ('AK180', '100078', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ZOO_P'] = ('AK180', '100078', 'RecreationPnt')
    field_information['TDS 4.0']['Levels']['Global']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Local']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ZOO_S'] = ('AK180', '100078', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Global']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Local']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FACILITY_P'] = ('AL010', '100080', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Global']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Local']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Regional']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FACILITY_S'] = ('AL010', '100080', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Global']['INSTALLATION_P'] = ('AL011', '100081', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Regional']['INSTALLATION_P'] = ('AL011', '100081', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Global']['INSTALLATION_S'] = ('AL011', '100081', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Regional']['INSTALLATION_S'] = ('AL011', '100081', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Global']['ARCHEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['ARCHEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['ARCHEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ARCHEOLOGICAL_SITE_P'] = ('AL012', '100082', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Global']['ARCHEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['ARCHEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ARCHEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ARCHEOLOGICAL_SITE_S'] = ('AL012', '100082', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILDING_P'] = ('AL013', '100083', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILDING_S'] = ('AL013', '100083', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NON_BUILDING_STRUCTURE_P'] = ('AL014', '100084', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['NON_BUILDING_STRUCTURE_S'] = ('AL014', '100084', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FIRE_HYDRANT_P'] = ('AL017', '100086', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_C'] = ('AL018', '100087', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Global']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_P'] = ('AL018', '100087', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['BUILDING_SUPERSTRUCTURE_S'] = ('AL018', '100087', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILDING_SUPERSTRUCTURE_S'] = ('AL018', '100087', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SHED_P'] = ('AL019', '100088', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['SHED_S'] = ('AL019', '100088', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHED_S'] = ('AL019', '100088', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Local']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Regional']['BUILT_UP_AREA_P'] = ('AL020', '100089', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Global']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Regional']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BUILT_UP_AREA_S'] = ('AL020', '100089', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CAIRN_P'] = ('AL025', '100091', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Global']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CEMETERY_P'] = ('AL030', '100092', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Global']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CEMETERY_S'] = ('AL030', '100092', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TOMB_P'] = ('AL036', '100094', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['TOMB_S'] = ('AL036', '100094', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TOMB_S'] = ('AL036', '100094', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['DRAGONS_TEETH_C'] = ('AL060', '100096', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['DRAGONS_TEETH_C'] = ('AL060', '100096', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Local']['DRAGONS_TEETH_S'] = ('AL060', '100096', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DRAGONS_TEETH_S'] = ('AL060', '100096', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['MINEFIELD_S'] = ('AL065', '100097', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MINEFIELD_S'] = ('AL065', '100097', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Regional']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['FENCE_C'] = ('AL070', '100098', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Global']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FLAGPOLE_P'] = ('AL073', '100099', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GANTRY_C'] = ('AL080', '100101', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Global']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GANTRY_P'] = ('AL080', '100101', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['HUT_P'] = ('AL099', '100103', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HUT_P'] = ('AL099', '100103', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HUT_S'] = ('AL099', '100103', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Local']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SETTLEMENT_P'] = ('AL105', '100104', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Global']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SETTLEMENT_S'] = ('AL105', '100104', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Global']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LIGHT_SUPPORT_STRUCTURE_P'] = ('AL110', '100105', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['MISSILE_SITE_P'] = ('AL120', '100106', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MISSILE_SITE_P'] = ('AL120', '100106', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['MISSILE_SITE_S'] = ('AL120', '100106', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MISSILE_SITE_S'] = ('AL120', '100106', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_C'] = ('AL130', '100108', 'CultureCrv')
    field_information['TDS 4.0']['Levels']['Global']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_P'] = ('AL130', '100108', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['MEMORIAL_MONUMENT_S'] = ('AL130', '100108', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MEMORIAL_MONUMENT_S'] = ('AL130', '100108', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Regional']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['PARTICLE_ACCELERATOR_C'] = ('AL140', '100110', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['PARTICLE_ACCELERATOR_S'] = ('AL140', '100110', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PARTICLE_ACCELERATOR_S'] = ('AL140', '100110', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ASTRONOMICAL_OBSERVATORY_P'] = ('AL142', '100111', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ASTRONOMICAL_OBSERVATORY_S'] = ('AL142', '100111', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['OVERHEAD_OBSTRUCTION_C'] = ('AL155', '100112', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['OVERHEAD_OBSTRUCTION_C'] = ('AL155', '100112', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['OVERHEAD_OBSTRUCTION_P'] = ('AL155', '100112', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['OVERHEAD_OBSTRUCTION_P'] = ('AL155', '100112', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['PIPELINE_CROSSING_POINT_P'] = ('AL165', '100113', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['PUBLIC_SQUARE_S'] = ('AL170', '100114', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PUBLIC_SQUARE_S'] = ('AL170', '100114', 'RecreationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['COURTYARD_S'] = ('AL175', '100688', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RETAIL_STAND_S'] = ('AL180', '100689', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RAMP_C'] = ('AL195', '100115', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RAMP_S'] = ('AL195', '100115', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Local']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RUINS_P'] = ('AL200', '100116', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Global']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RUINS_S'] = ('AL200', '100116', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['INTEREST_SITE_P'] = ('AL201', '100117', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['INTEREST_SITE_S'] = ('AL201', '100117', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SHANTY_TOWN_P'] = ('AL208', '100118', 'SettlementPnt')
    field_information['TDS 4.0']['Levels']['Global']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Local']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHANTY_TOWN_S'] = ('AL208', '100118', 'SettlementSrf')
    field_information['TDS 4.0']['Levels']['Global']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_C'] = ('AL211', '130921', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_P'] = ('AL211', '130921', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRANS_ROUTE_PROTECT_STRUCT_S'] = ('AL211', '130921', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANS_ROUTE_PROTECT_STRUCT_S'] = ('AL211', '130921', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TOWER_P'] = ('AL241', '100122', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TOWER_S'] = ('AL241', '100122', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['UNDERGROUND_DWELLING_P'] = ('AL250', '100123', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['UNDERGROUND_DWELLING_P'] = ('AL250', '100123', 'StructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Regional']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['WALL_C'] = ('AL260', '100124', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Global']['INDUSTRIAL_FARM_P'] = ('AL270', '100129', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['INDUSTRIAL_FARM_P'] = ('AL270', '100129', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Global']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['INDUSTRIAL_FARM_S'] = ('AL270', '100129', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SPACE_FACILITY_P'] = ('AL351', '100126', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SPACE_FACILITY_P'] = ('AL351', '100126', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SPACE_FACILITY_S'] = ('AL351', '100126', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CASTLE_P'] = ('AL375', '100128', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CASTLE_S'] = ('AL375', '100128', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CASTLE_COMPLEX_P'] = ('AL376', '132642', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CASTLE_COMPLEX_S'] = ('AL376', '132642', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TETHERED_BALLOON_P'] = ('AL510', '100130', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['STORAGE_DEPOT_P'] = ('AM010', '100131', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Global']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Local']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Regional']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STORAGE_DEPOT_S'] = ('AM010', '100131', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHIPPING_CONTAINER_P'] = ('AM011', '100132', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SHIPPING_CONTAINER_S'] = ('AM011', '100132', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GRAIN_STORAGE_STRUCTURE_P'] = ('AM020', '100133', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['GRAIN_STORAGE_STRUCTURE_S'] = ('AM020', '100133', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GRAIN_STORAGE_STRUCTURE_S'] = ('AM020', '100133', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GRAIN_ELEVATOR_P'] = ('AM030', '100134', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['GRAIN_ELEVATOR_S'] = ('AM030', '100134', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GRAIN_ELEVATOR_S'] = ('AM030', '100134', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MINERAL_PILE_P'] = ('AM040', '100136', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Local']['MINERAL_PILE_S'] = ('AM040', '100136', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MINERAL_PILE_S'] = ('AM040', '100136', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SURFACE_BUNKER_P'] = ('AM060', '100137', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SURFACE_BUNKER_S'] = ('AM060', '100137', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MUNITION_STORAGE_FACILITY_P'] = ('AM065', '100138', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Global']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Local']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Regional']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MUNITION_STORAGE_FACILITY_S'] = ('AM065', '100138', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STORAGE_TANK_P'] = ('AM070', '100139', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['STORAGE_TANK_S'] = ('AM070', '100139', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STORAGE_TANK_S'] = ('AM070', '100139', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TANK_FARM_P'] = ('AM071', '100140', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Global']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Local']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Regional']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TANK_FARM_S'] = ('AM071', '100140', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FUEL_STORAGE_FACILITY_P'] = ('AM075', '100141', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Global']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Local']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Regional']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FUEL_STORAGE_FACILITY_S'] = ('AM075', '100141', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_TOWER_P'] = ('AM080', '100142', 'StoragePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_TOWER_S'] = ('AM080', '100142', 'StorageSrf')
    field_information['TDS 4.0']['Levels']['Global']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_C'] = ('AN010', '100143', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_SIDETRACK_C'] = ('AN050', '100144', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Regional']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_YARD_S'] = ('AN060', '100145', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['RAILWAY_TURNTABLE_P'] = ('AN075', '100146', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_TURNTABLE_P'] = ('AN075', '100146', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_TURNTABLE_S'] = ('AN075', '100146', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ROUNDHOUSE_P'] = ('AN076', '100147', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROUNDHOUSE_S'] = ('AN076', '100147', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ROUNDHOUSE_S'] = ('AN076', '100147', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RAILWAY_SIGNAL_P'] = ('AN085', '100149', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CART_TRACK_C'] = ('AP010', '100150', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ROAD_INTERCHANGE_P'] = ('AP020', '100151', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ROAD_C'] = ('AP030', '100152', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ROAD_S'] = ('AP030', '100152', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['GATE_C'] = ('AP040', '100154', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['GATE_C'] = ('AP040', '100154', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GATE_P'] = ('AP040', '100154', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['VEHICLE_BARRIER_C'] = ('AP041', '100155', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['VEHICLE_BARRIER_C'] = ('AP041', '100155', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['VEHICLE_BARRIER_P'] = ('AP041', '100155', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['TRAIL_C'] = ('AP050', '100156', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SIDEWALK_C'] = ('AQ035', '100159', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_C'] = ('AQ040', '100161', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_P'] = ('AQ040', '100161', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_S'] = ('AQ040', '100161', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_SPAN_C'] = ('AQ045', '100162', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_SPAN_C'] = ('AQ045', '100162', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_SPAN_P'] = ('AQ045', '100162', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_SPAN_P'] = ('AQ045', '100162', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_SPAN_S'] = ('AQ045', '100162', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_SUPERSTRUCTURE_C'] = ('AQ050', '100163', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_SUPERSTRUCTURE_S'] = ('AQ050', '100163', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_TOWER_P'] = ('AQ055', '100164', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_PIER_C'] = ('AQ056', '100165', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_PIER_P'] = ('AQ056', '100165', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BRIDGE_PIER_S'] = ('AQ056', '100165', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANS_ROUTE_CHARACTER_CHANGE_C'] = ('AQ059', '131083', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANS_ROUTE_CHARACTER_CHANGE_P'] = ('AQ059', '131083', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CONTROL_TOWER_P'] = ('AQ060', '100167', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['CONTROL_TOWER_S'] = ('AQ060', '100167', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CONTROL_TOWER_S'] = ('AQ060', '100167', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CROSSING_P'] = ('AQ062', '100168', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CAUSEWAY_STRUCTURE_C'] = ('AQ063', '130381', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['CAUSEWAY_STRUCTURE_S'] = ('AQ063', '130381', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CAUSEWAY_STRUCTURE_S'] = ('AQ063', '130381', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['CULVERT_C'] = ('AQ065', '100170', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CULVERT_C'] = ('AQ065', '100170', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['CULVERT_P'] = ('AQ065', '100170', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CULVERT_P'] = ('AQ065', '100170', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANSPORTATION_BLOCK_P'] = ('AQ068', '100171', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANSPORTATION_BLOCK_S'] = ('AQ068', '100171', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Regional']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['FERRY_CROSSING_C'] = ('AQ070', '100172', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Global']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ICE_ROUTE_C'] = ('AQ075', '100173', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Local']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FERRY_STATION_P'] = ('AQ080', '100174', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Global']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Local']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Regional']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FERRY_STATION_S'] = ('AQ080', '100174', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Global']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TUNNEL_MOUTH_P'] = ('AQ095', '100176', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MOORING_MAST_P'] = ('AQ110', '100177', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['PREPARED_WATERCOURSE_CROSS_C'] = ('AQ111', '100178', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['PREPARED_WATERCOURSE_CROSS_C'] = ('AQ111', '100178', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Regional']['PREPARED_WATERCOURSE_CROSS_C'] = ('AQ111', '100178', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['PREPARED_WATERCOURSE_CROSS_C'] = ('AQ111', '100178', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Global']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Local']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Regional']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['PREPARED_WATERCOURSE_CROSS_P'] = ('AQ111', '100178', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Global']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Regional']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['PIPELINE_C'] = ('AQ113', '100179', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['STORM_DRAIN_P'] = ('AQ114', '100180', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['UTILITY_COVER_P'] = ('AQ115', '100181', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['PUMPING_STATION_P'] = ('AQ116', '100182', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PUMPING_STATION_S'] = ('AQ116', '100182', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SHARP_CURVE_P'] = ('AQ118', '100183', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['STEEP_GRADE_C'] = ('AQ120', '100185', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANSPORTATION_STATION_P'] = ('AQ125', '100186', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Regional']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TRANSPORTATION_STATION_S'] = ('AQ125', '100186', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['TUNNEL_C'] = ('AQ130', '100187', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['TUNNEL_S'] = ('AQ130', '100187', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['ROADSIDE_REST_AREA_P'] = ('AQ135', '100188', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ROADSIDE_REST_AREA_P'] = ('AQ135', '100188', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROADSIDE_REST_AREA_S'] = ('AQ135', '100188', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ROADSIDE_REST_AREA_S'] = ('AQ135', '100188', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['VEHICLE_LOT_S'] = ('AQ140', '100189', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['VEHICLE_LOT_S'] = ('AQ140', '100189', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['PARKING_GARAGE_P'] = ('AQ141', '100190', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['PARKING_GARAGE_S'] = ('AQ141', '100190', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PARKING_GARAGE_S'] = ('AQ141', '100190', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STAIR_C'] = ('AQ150', '100191', 'StructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['STAIR_S'] = ('AQ150', '100191', 'StructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ARCADE_C'] = ('AQ151', '100192', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ARCADE_S'] = ('AQ151', '100192', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TRAFFIC_LIGHT_P'] = ('AQ160', '100194', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STREET_LAMP_P'] = ('AQ161', '100195', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STREET_SIGN_P'] = ('AQ162', '100196', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Global']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MOTOR_VEHICLE_STATION_P'] = ('AQ170', '100197', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['MOTOR_VEHICLE_STATION_S'] = ('AQ170', '100197', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MOTOR_VEHICLE_STATION_S'] = ('AQ170', '100197', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['WEIGH_STATION_P'] = ('AQ180', '100198', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['WEIGH_STATION_P'] = ('AQ180', '100198', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WEIGH_STATION_P'] = ('AQ180', '100198', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WEIGH_STATION_P'] = ('AQ180', '100198', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['WEIGH_STATION_S'] = ('AQ180', '100198', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WEIGH_STATION_S'] = ('AQ180', '100198', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Global']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CABLE_C'] = ('AT005', '100199', 'UtilityInfrastructureCrv')
    field_information['TDS 4.0']['Levels']['Local']['DISH_AERIAL_P'] = ('AT010', '100200', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['DISH_AERIAL_P'] = ('AT010', '100200', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AERIAL_P'] = ('AT011', '100201', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['AERIAL_FARM_P'] = ('AT012', '100202', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AERIAL_FARM_S'] = ('AT012', '100202', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CABLEWAY_C'] = ('AT041', '100206', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['PYLON_P'] = ('AT042', '100558', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Local']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Regional']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RADAR_STATION_P'] = ('AT045', '100207', 'FacilityPnt')
    field_information['TDS 4.0']['Levels']['Global']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Local']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Regional']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RADAR_STATION_S'] = ('AT045', '100207', 'FacilitySrf')
    field_information['TDS 4.0']['Levels']['Global']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['LAND_WATER_BOUNDARY_C'] = ('BA010', '100212', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['ISLAND_P'] = ('BA030', '100217', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ISLAND_P'] = ('BA030', '100217', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ISLAND_S'] = ('BA030', '100217', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TIDAL_WATER_S'] = ('BA040', '100218', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HARBOUR_S'] = ('BB005', '100222', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Local']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Regional']['PORT_P'] = ('BB009', '100223', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Global']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Local']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Regional']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PORT_S'] = ('BB009', '100223', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Local']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Regional']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SHORELINE_CONSTRUCTION_C'] = ('BB081', '100231', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Global']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Local']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHORELINE_CONSTRUCTION_S'] = ('BB081', '100231', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Local']['SHORELINE_RAMP_C'] = ('BB082', '100232', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SHORELINE_RAMP_C'] = ('BB082', '100232', 'PortHarbourCrv')
    field_information['TDS 4.0']['Levels']['Local']['SHORELINE_RAMP_S'] = ('BB082', '100232', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHORELINE_RAMP_S'] = ('BB082', '100232', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Local']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Regional']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DRY_DOCK_S'] = ('BB090', '100233', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FISH_WEIR_P'] = ('BB110', '100236', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['FLOATING_DRY_DOCK_S'] = ('BB199', '100243', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FLOATING_DRY_DOCK_S'] = ('BB199', '100243', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SMALL_CRAFT_FACILITY_P'] = ('BB201', '100244', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SMALL_CRAFT_FACILITY_S'] = ('BB201', '100244', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Local']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SHIPYARD_P'] = ('BB241', '100245', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Global']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Local']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SHIPYARD_S'] = ('BB241', '100245', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Local']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LIGHTHOUSE_P'] = ('BC050', '100253', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LIGHTHOUSE_S'] = ('BC050', '100253', 'HydroAidNavigationSrf')
    field_information['TDS 4.0']['Levels']['Global']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Local']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LIGHT_VESSEL_P'] = ('BC070', '100256', 'HydroAidNavigationPnt')
    field_information['TDS 4.0']['Levels']['Local']['STRUCTURAL_PILE_P'] = ('BD100', '100271', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['STRUCTURAL_PILE_P'] = ('BD100', '100271', 'PortHarbourPnt')
    field_information['TDS 4.0']['Levels']['Local']['STRUCTURAL_PILE_S'] = ('BD100', '100271', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STRUCTURAL_PILE_S'] = ('BD100', '100271', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['OFFSHORE_CONSTRUCTION_P'] = ('BD115', '100272', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['OFFSHORE_CONSTRUCTION_S'] = ('BD115', '100272', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['OFFSHORE_CONSTRUCTION_S'] = ('BD115', '100272', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SNAG_P'] = ('BD140', '100277', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SNAG_P'] = ('BD140', '100277', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HULK_P'] = ('BD181', '100279', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['AQUEDUCT_C'] = ('BH010', '100295', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['AQUEDUCT_S'] = ('BH010', '100295', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AQUEDUCT_S'] = ('BH010', '100295', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['QANAT_SHAFT_P'] = ('BH012', '131749', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['QANAT_SHAFT_P'] = ('BH012', '131749', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BOG_S'] = ('BH015', '100296', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CANAL_C'] = ('BH020', '100297', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['CANAL_S'] = ('BH020', '100297', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CANAL_S'] = ('BH020', '100297', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Global']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['DITCH_C'] = ('BH030', '100298', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['DITCH_S'] = ('BH030', '100298', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DITCH_S'] = ('BH030', '100298', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['WATER_TREATMENT_BED_S'] = ('BH040', '100299', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_TREATMENT_BED_S'] = ('BH040', '100299', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Local']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Regional']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FISH_FARM_FACILITY_P'] = ('BH051', '191951', 'AgriculturePnt')
    field_information['TDS 4.0']['Levels']['Global']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FISH_FARM_FACILITY_S'] = ('BH051', '191951', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['WATER_RACE_C'] = ('BH065', '131810', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_RACE_C'] = ('BH065', '131810', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Local']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Regional']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['FORD_C'] = ('BH070', '100302', 'TransportationGroundCrv')
    field_information['TDS 4.0']['Levels']['Global']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Local']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FORD_P'] = ('BH070', '100302', 'TransportationGroundPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FORD_S'] = ('BH070', '100302', 'TransportationGroundSrf')
    field_information['TDS 4.0']['Levels']['Local']['FOUNTAIN_P'] = ('BH075', '100303', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FOUNTAIN_P'] = ('BH075', '100303', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FOUNTAIN_S'] = ('BH075', '100303', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['HUMMOCK_S'] = ('BH077', '100304', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HUMMOCK_S'] = ('BH077', '100304', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['INLAND_WATERBODY_P'] = ('BH082', '130384', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['INLAND_WATERBODY_S'] = ('BH082', '130384', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LAND_SUBJECT_TO_INUNDATION_S'] = ('BH090', '100307', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['MOAT_C'] = ('BH100', '100309', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['MOAT_C'] = ('BH100', '100309', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['MOAT_S'] = ('BH100', '100309', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MOAT_S'] = ('BH100', '100309', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['PENSTOCK_C'] = ('BH110', '100310', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['AQUIFER_S'] = ('BH116', '154640', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['AQUIFER_S'] = ('BH116', '154640', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['AQUIFER_S'] = ('BH116', '154640', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AQUIFER_S'] = ('BH116', '154640', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RAPIDS_C'] = ('BH120', '100311', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['RAPIDS_P'] = ('BH120', '100311', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RAPIDS_S'] = ('BH120', '100311', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RICE_FIELD_S'] = ('BH135', '100313', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['RIVER_C'] = ('BH140', '100314', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RIVER_S'] = ('BH140', '100314', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['VANISHING_POINT_P'] = ('BH145', '100315', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SALT_FLAT_S'] = ('BH150', '100316', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['SALT_EVAPORATOR_P'] = ('BH155', '100317', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SALT_EVAPORATOR_P'] = ('BH155', '100317', 'IndustryPnt')
    field_information['TDS 4.0']['Levels']['Global']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Local']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SALT_EVAPORATOR_S'] = ('BH155', '100317', 'IndustrySrf')
    field_information['TDS 4.0']['Levels']['Global']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SABKHA_S'] = ('BH160', '100318', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SPILLWAY_C'] = ('BH165', '100319', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SPILLWAY_C'] = ('BH165', '100319', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['SPILLWAY_S'] = ('BH165', '100319', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SPILLWAY_S'] = ('BH165', '100319', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NATURAL_POOL_P'] = ('BH170', '100320', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NATURAL_POOL_S'] = ('BH170', '100320', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Global']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['WATERFALL_C'] = ('BH180', '100321', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATERFALL_P'] = ('BH180', '100321', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Local']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATERWORK_P'] = ('BH220', '100325', 'UtilityInfrastructurePnt')
    field_information['TDS 4.0']['Levels']['Global']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Local']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WATERWORK_S'] = ('BH220', '100325', 'UtilityInfrastructureSrf')
    field_information['TDS 4.0']['Levels']['Global']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_WELL_P'] = ('BH230', '100326', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_WELL_S'] = ('BH230', '100326', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['VESSEL_LIFT_S'] = ('BI005', '100328', 'PortHarbourSrf')
    field_information['TDS 4.0']['Levels']['Global']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Regional']['SHIP_ELEVATOR_C'] = ('BI006', '132749', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Global']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Local']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SHIP_ELEVATOR_P'] = ('BI006', '132749', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SHIP_ELEVATOR_S'] = ('BI006', '132749', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Global']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CISTERN_P'] = ('BI010', '100329', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['DAM_C'] = ('BI020', '100330', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['DAM_P'] = ('BI020', '100330', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DAM_S'] = ('BI020', '100330', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['LOCK_C'] = ('BI030', '100331', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['LOCK_C'] = ('BI030', '100331', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Global']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Local']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Regional']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LOCK_P'] = ('BI030', '100331', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Local']['LOCK_S'] = ('BI030', '100331', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LOCK_S'] = ('BI030', '100331', 'TransportationWaterSrf')
    field_information['TDS 4.0']['Levels']['Local']['SLUICE_GATE_C'] = ('BI040', '100334', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['SLUICE_GATE_C'] = ('BI040', '100334', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SLUICE_GATE_P'] = ('BI040', '100334', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['FLOOD_CONTROL_STRUCTURE_C'] = ('BI044', '131207', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['FLOOD_CONTROL_STRUCTURE_P'] = ('BI044', '131207', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['FLOOD_CONTROL_STRUCTURE_P'] = ('BI044', '131207', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['FLOOD_CONTROL_STRUCTURE_S'] = ('BI044', '131207', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FLOOD_CONTROL_STRUCTURE_S'] = ('BI044', '131207', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Local']['BASIN_GATE_C'] = ('BI045', '131206', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['BASIN_GATE_C'] = ('BI045', '131206', 'TransportationWaterCrv')
    field_information['TDS 4.0']['Levels']['Local']['BASIN_GATE_P'] = ('BI045', '131206', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BASIN_GATE_P'] = ('BI045', '131206', 'TransportationWaterPnt')
    field_information['TDS 4.0']['Levels']['Global']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_INTAKE_TOWER_P'] = ('BI050', '100337', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_INTAKE_TOWER_S'] = ('BI050', '100337', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_INTAKE_TOWER_S'] = ('BI050', '100337', 'HydrographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FISH_LADDER_C'] = ('BI060', '100338', 'HydrographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['GAUGING_STATION_P'] = ('BI070', '100339', 'HydrographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MORAINE_S'] = ('BJ020', '100340', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GLACIER_S'] = ('BJ030', '100341', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CREVASSE_C'] = ('BJ031', '100342', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CREVASSE_S'] = ('BJ031', '100342', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ICE_CLIFF_C'] = ('BJ040', '100343', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ICE_PEAK_P'] = ('BJ060', '100344', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ICE_SHELF_S'] = ('BJ065', '100345', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['POLAR_ICE_S'] = ('BJ080', '100347', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['ICE_CAP_S'] = ('BJ099', '100348', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['ICE_CAP_S'] = ('BJ099', '100348', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SNOW_ICE_FIELD_S'] = ('BJ100', '100349', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TUNDRA_S'] = ('BJ110', '100350', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ELEVATION_CONTOUR_C'] = ('CA010', '100353', 'HypsographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['SPOT_ELEVATION_P'] = ('CA030', '100355', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['ASPHALT_LAKE_S'] = ('DA005', '100356', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ASPHALT_LAKE_S'] = ('DA005', '100356', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SOIL_SURFACE_REGION_S'] = ('DA010', '100358', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['STEEP_TERRAIN_FACE_C'] = ('DB010', '100362', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CAVE_MOUTH_P'] = ('DB029', '154961', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CREVICE_C'] = ('DB061', '100365', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CREVICE_S'] = ('DB061', '100365', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CUT_C'] = ('DB070', '100366', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['CUT_LINE_C'] = ('DB071', '192101', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DEPRESSION_S'] = ('DB080', '100367', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['EMBANKMENT_C'] = ('DB090', '100368', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['EMBANKMENT_S'] = ('DB090', '100368', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['EMBANKMENT_S'] = ('DB090', '100368', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['ESKER_C'] = ('DB100', '100369', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ESKER_C'] = ('DB100', '100369', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Global']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Regional']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['GEOLOGIC_FAULT_C'] = ('DB110', '100370', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Local']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['GEOTHERMAL_OUTLET_P'] = ('DB115', '100371', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['GEOTHERMAL_OUTLET_S'] = ('DB115', '100371', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GEOTHERMAL_OUTLET_S'] = ('DB115', '100371', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MOUNTAIN_PASS_P'] = ('DB150', '100372', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ROCK_FORMATION_P'] = ('DB160', '100373', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ROCK_FORMATION_S'] = ('DB160', '100373', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SAND_DUNES_S'] = ('DB170', '100374', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['VOLCANO_P'] = ('DB180', '100375', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['VOLCANIC_DYKE_C'] = ('DB190', '100377', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['VOLCANIC_DYKE_C'] = ('DB190', '100377', 'PhysiographyCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['LANDSLIDE_MASS_S'] = ('DB211', '100379', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Global']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CROP_LAND_S'] = ('EA010', '100380', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['HEDGEROW_C'] = ('EA020', '100381', 'VegetationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['HEDGEROW_C'] = ('EA020', '100381', 'VegetationCrv')
    field_information['TDS 4.0']['Levels']['Local']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['PLANT_NURSERY_S'] = ('EA030', '100382', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BOTANIC_GARDEN_S'] = ('EA031', '100383', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ORCHARD_S'] = ('EA040', '100384', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['VINEYARD_S'] = ('EA050', '100385', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HOP_FIELD_S'] = ('EA055', '100386', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['GRASSLAND_S'] = ('EB010', '100387', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['THICKET_S'] = ('EB020', '100388', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['BRUSH_S'] = ('EB070', '100390', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['BRUSH_S'] = ('EB070', '100390', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['TREE_P'] = ('EC005', '100392', 'VegetationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TREE_P'] = ('EC005', '100392', 'VegetationPnt')
    field_information['TDS 4.0']['Levels']['Local']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CANE_S'] = ('EC010', '100393', 'AgricultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['FOREST_C'] = ('EC015', '130380', 'VegetationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['FOREST_C'] = ('EC015', '130380', 'VegetationCrv')
    field_information['TDS 4.0']['Levels']['Global']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FOREST_S'] = ('EC015', '130380', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['OASIS_P'] = ('EC020', '100394', 'PhysiographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['OASIS_S'] = ('EC020', '100394', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Local']['CLEARED_WAY_C'] = ('EC040', '100396', 'VegetationCrv')
    field_information['TDS 4.0']['Levels']['Local']['CLEARED_WAY_S'] = ('EC040', '100396', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['FOREST_CLEARING_S'] = ('EC060', '100398', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MARSH_S'] = ('ED010', '100399', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Local']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SWAMP_S'] = ('ED020', '100400', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LOGGING_SITE_S'] = ('EE010', '100401', 'VegetationSrf')
    field_information['TDS 4.0']['Levels']['Global']['DESERT_S'] = ('EE030', '100403', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Regional']['DESERT_S'] = ('EE030', '100403', 'PhysiographySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CONTAMINATED_REGION_P'] = ('FA012', '100409', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CONTAMINATED_REGION_S'] = ('FA012', '100409', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['FIRING_RANGE_P'] = ('FA015', '100410', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['FIRING_RANGE_P'] = ('FA015', '100410', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['FIRING_RANGE_S'] = ('FA015', '100410', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['FIRING_RANGE_S'] = ('FA015', '100410', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['TEST_SITE_S'] = ('FA100', '100414', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TEST_SITE_S'] = ('FA100', '100414', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrv')
    field_information['TDS 4.0']['Levels']['Regional']['INTERNATIONAL_DATE_LINE_C'] = ('FA110', '100415', 'BoundaryCrv')
    field_information['TDS 4.0']['Levels']['Global']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['TRAINING_SITE_P'] = ('FA165', '100416', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TRAINING_SITE_S'] = ('FA165', '100416', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Global']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Local']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Regional']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CONSERVATION_AREA_S'] = ('FA210', '100417', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['LAND_AERODROME_P'] = ('GB005', '100436', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['LAND_AERODROME_P'] = ('GB005', '100436', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['LAND_AERODROME_S'] = ('GB005', '100436', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['APRON_S'] = ('GB015', '100438', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['APRON_S'] = ('GB015', '100438', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HELIPAD_P'] = ('GB030', '100441', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['HELIPAD_S'] = ('GB030', '100441', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HELIPORT_P'] = ('GB035', '100442', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HELIPORT_S'] = ('GB035', '100442', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LAUNCH_PAD_P'] = ('GB040', '100443', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['LAUNCH_PAD_S'] = ('GB040', '100443', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['STOPWAY_S'] = ('GB045', '100444', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['AIRCRAFT_REVETMENT_C'] = ('GB050', '100446', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['AIRCRAFT_REVETMENT_C'] = ('GB050', '100446', 'MilitaryCrv')
    field_information['TDS 4.0']['Levels']['Global']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['RUNWAY_S'] = ('GB055', '100448', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_AERODROME_P'] = ('GB065', '100452', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['WATER_AERODROME_S'] = ('GB065', '100452', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['SEAPLANE_RUN_S'] = ('GB070', '100453', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SEAPLANE_RUN_S'] = ('GB070', '100453', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TAXIWAY_C'] = ('GB075', '100454', 'AeronauticCrv')
    field_information['TDS 4.0']['Levels']['Local']['TAXIWAY_S'] = ('GB075', '100454', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['TAXIWAY_S'] = ('GB075', '100454', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['AIRCRAFT_HANGAR_P'] = ('GB230', '100456', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['AIRCRAFT_HANGAR_S'] = ('GB230', '100456', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Local']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Regional']['HARDENED_AIRCRAFT_SHELTER_P'] = ('GB250', '100457', 'AeronauticPnt')
    field_information['TDS 4.0']['Levels']['Global']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Local']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Regional']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['HARDENED_AIRCRAFT_SHELTER_S'] = ('GB250', '100457', 'AeronauticSrf')
    field_information['TDS 4.0']['Levels']['Global']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Local']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Regional']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['MILITARY_INSTALLATION_P'] = ('SU001', '100462', 'MilitaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Regional']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['MILITARY_INSTALLATION_S'] = ('SU001', '100462', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['CANTONMENT_AREA_S'] = ('SU004', '170162', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CANTONMENT_AREA_S'] = ('SU004', '170162', 'MilitarySrf')
    field_information['TDS 4.0']['Levels']['Local']['BOUNDARY_MONUMENT_P'] = ('ZB030', '100465', 'BoundaryPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['BOUNDARY_MONUMENT_P'] = ('ZB030', '100465', 'BoundaryPnt')
    field_information['TDS 4.0']['Levels']['Global']['CONTROL_POINT_P'] = ('ZB035', '100466', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Local']['CONTROL_POINT_P'] = ('ZB035', '100466', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Regional']['CONTROL_POINT_P'] = ('ZB035', '100466', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CONTROL_POINT_P'] = ('ZB035', '100466', 'HypsographyPnt')
    field_information['TDS 4.0']['Levels']['Global']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Local']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['VOID_COLLECTION_AREA_S'] = ('ZD020', '100473', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['CULTURAL_CONTEXT_LOCATION_P'] = ('ZD030', '100474', 'CulturePnt')
    field_information['TDS 4.0']['Levels']['Specialized']['CULTURAL_CONTEXT_LOCATION_S'] = ('ZD030', '100474', 'CultureSrf')
    field_information['TDS 4.0']['Levels']['Global']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Local']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Regional']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['NAMED_LOCATION_C'] = ('ZD040', '100475', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Global']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Local']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['NAMED_LOCATION_P'] = ('ZD040', '100475', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Global']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Local']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['NAMED_LOCATION_S'] = ('ZD040', '100475', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Global']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Local']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Regional']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Specialized']['ANNOTATED_LOCATION_C'] = ('ZD045', '100476', 'InformationCrv')
    field_information['TDS 4.0']['Levels']['Global']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Local']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Regional']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Specialized']['ANNOTATED_LOCATION_P'] = ('ZD045', '100476', 'InformationPnt')
    field_information['TDS 4.0']['Levels']['Global']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Local']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Regional']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['ANNOTATED_LOCATION_S'] = ('ZD045', '100476', 'InformationSrf')
    field_information['TDS 4.0']['Levels']['Global']['DATASET_S'] = ('ZI031', '121591', 'DatasetSrf')
    field_information['TDS 4.0']['Levels']['Local']['DATASET_S'] = ('ZI031', '121591', 'DatasetSrf')
    field_information['TDS 4.0']['Levels']['Regional']['DATASET_S'] = ('ZI031', '121591', 'DatasetSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['DATASET_S'] = ('ZI031', '121591', 'DatasetSrf')
    field_information['TDS 4.0']['Levels']['Global']['SPATIAL_MD_ENT_COLLECT_S'] = ('ZI040', '133101', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Local']['SPATIAL_MD_ENT_COLLECT_S'] = ('ZI040', '133101', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Regional']['SPATIAL_MD_ENT_COLLECT_S'] = ('ZI040', '133101', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['SPATIAL_MD_ENT_COLLECT_S'] = ('ZI040', '133101', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Global']['NON_SPATIAL_MD_ENT_COLLECT_S'] = ('ZI041', '133102', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Local']['NON_SPATIAL_MD_ENT_COLLECT_S'] = ('ZI041', '133102', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Regional']['NON_SPATIAL_MD_ENT_COLLECT_S'] = ('ZI041', '133102', 'CollectionSrf')
    field_information['TDS 4.0']['Levels']['Specialized']['NON_SPATIAL_MD_ENT_COLLECT_S'] = ('ZI041', '133102', 'CollectionSrf')


