﻿
""" 
 ************************************************************************************************
 **                                                                                            **
 **  File: TDS70_2_GGDM30_TranslateFeaturesandFields.py
 **  Copyright (c) December 2020 by Leidos                                                     **
 **  Produced under U.S. Government contract W5J9CQ-12-D-0004  Task Order: 053.                **
 **  As per DFARS, the U.S. Government is granted unlimited rights to use this work            **
 **  in any manner and for any purpose.                                                        **
 **                                                                                            **
 **  Summary:   This file provides the feature class / feature / and field specific            **
 **             mappings and where a translation is involved, that is listed as well.          **
 **             The information in this file is specific to translations from:                 **
 **                 TDS 7.0 Composite to GGDM 3.0 Composite                                    **
 **             Notes:                                                                         **
 **                 Be sure MEM and OTH transforms are done last in each feature class.        **
 **                                                                                            **
 **  Developed by Leidos, Inc., High Resolution ISR Systems Division, Geospatial Programs                                   **
 **                                                                                            **
 **  Development History:                                                                      **
 **  December 2015 / Annette Janett Filer                                                      **
 **  January 2015 / Revised definitions based on latest translation database                   **
 **  April 2020 / Copied from TDS 6.1 to form basis for TDS 7.0
 **                                                                                            **
 **                                                                                            **
 ************************************************************************************************
"""


import sys
import os
import copy


current_include_source = "TDS 7.0"
current_include_target = "GGDM 3.0"

common_fields = [
    ('FCSubType', 'FCSubType', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None)  
]

common_geom_fields =  [
    ('FCSubType', 'FCSubType', 'transform_FCSubtype'),
    ('ObjectID', None, None), 
    ('GLOBALID', None, None), 
    ('SHAPE@', 'SHAPE@', None)
    ]

common_Pnt_fields = []

common_Crv_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None)
    ]

common_Srf_fields = [
    ('SHAPE@Length', 'SHAPE@Length', None),
    ('SHAPE@Area', 'SHAPE@Area', None)
    ]

# ('GLOBALID', 'GLOBALID', None)
common_fields_ignore = ['shape@', 'shape@length', 'shape@area', 'fcsubtype', 'objectid', 'globalid']




# A dictionary of fields and values for default restriction information item
RestrictionInfoTargetDefaultFieldValues = {
    'CCN':'No Information',
    'CDR':'No Information',
    'F_CODE':'ZI002',
    'SAX_RY2':'noInformation',
    'SAX_RS1':'No Information',
    'SAX_RS2':'No Information',
    'SAX_RX9':'No Information',
    'SAX_RS4':'noInformation',
    'SAX_RS5':'No Information',
    'SAX_RS6':'noInformation',
    'SAX_RS8':'No Information',
    'SAX_RS9':'No Information',
    'SAX_RY0':'No Information',
    'SAX_RX1':'noInformation',
    'SAX_RX2':'noInformation',
    'SAX_RY1':'noInformation',
    'SAX_RX5':'noInformation',
    'SAX_RX7':'noInformation',
    'SAX_RX6':'noInformation',
    'UFI':'A9593791-4AE9-4180-8E1E-9CB3D239DEE5'
}

RestrictionInfoTblFields = [
    ('CCN','CCN',None),
    ('CDR','CDR',None),
    ('SAX_RS1','SAX_RS1',None),
    ('SAX_RS2','SAX_RS2',None),
    ('SAX_RS4','SAX_RS4',None),
    ('SAX_RS5','SAX_RS5',None),
    ('SAX_RS6','SAX_RS6',None),
    ('SAX_RS8','SAX_RS8',None),
    ('SAX_RS9','SAX_RS9',None),
    ('SAX_RX1','SAX_RX1',None),
    ('SAX_RX2','SAX_RX2',None),
    ('SAX_RX5','SAX_RX5',None),
    ('SAX_RX6','SAX_RX6',None),
    ('SAX_RX7','SAX_RX7',None),
    ('SAX_RX9','SAX_RX9',None),
    ('SAX_RY0','SAX_RY0',None),
    ('SAX_RY1','SAX_RY1',None),
    ('SAX_RY2','SAX_RY2',None),
    (None,'UFI','transform_placeholder_return_None'),
    (None,'F_CODE','transform_placeholder_return_None'),
    ('SAX_RX8',None,None),
    ('SAX_RS3',None,None)
]



# These fields when found in the source will be saved to GGDM 3.0 Restriction Info Table
# They will be processed, feature by feature and then stored into memory and output as as 
# set of unique Restriction info records.
RestrictionInfoMetaConvertSubsetFields = [
    ('CCN','CCN',None),
    ('CDR','CDR',None),
    ('SAX_RS1','SAX_RS1',None),
    ('SAX_RS2','SAX_RS2',None),
    ('SAX_RS4','SAX_RS4',None),
    ('SAX_RS5','SAX_RS5',None),
    ('SAX_RS6','SAX_RS6',None),
    ('SAX_RS8','SAX_RS8',None),
    ('SAX_RS9','SAX_RS9',None),
    ('SAX_RX1','SAX_RX1',None),
    ('SAX_RX2','SAX_RX2',None),
    ('SAX_RX5','SAX_RX5',None),
    ('SAX_RX6','SAX_RX6',None),
    ('SAX_RX7','SAX_RX7',None),
    ('SAX_RX9','SAX_RX9',None),
    ('SAX_RY0','SAX_RY0',None),
    ('SAX_RY1','SAX_RY1',None),
    ('SAX_RY2','SAX_RY2',None)
    ]


# These are included with each feature class on step 4 translations
RestrictionInfoFCSubsetFields = [
    ('CCN',None,None),
    ('CDR',None,None),
    ('SAX_RS1',None,None),
    ('SAX_RS2',None,None),
    ('SAX_RS4',None,None),
    ('SAX_RS5',None,None),
    ('SAX_RS6',None,None),
    ('SAX_RS8',None,None),
    ('SAX_RS9',None,None),
    ('SAX_RX1',None,None),
    ('SAX_RX2',None,None),
    ('SAX_RX5',None,None),
    ('SAX_RX6',None,None),
    ('SAX_RX7',None,None),
    ('SAX_RX9',None,None),
    ('SAX_RY0',None,None),
    ('SAX_RY1',None,None),
    ('SAX_RY2',None,None)
    ]

EntityCollectionTargetDefaultFieldValues = {
    'FCSubType':132721,
    'AHA':-999999,
    'AVA':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'EVA':-999999,
    'F_CODE':'ZI039',
    'HVA':-999999,
    'MDE':'noInformation',
    'OTH':'noInformation',
    'RCG':-999999,
    'SCVN':'No Information',
    'UFI':'noInformation',
    'ZI001_SDP':'No Information',
    'ZI001_SPS':-999999,
    'ZI001_VSC':-999999,
    'ZI001_VSD':'noInformation',
    'ZI001_VSN':'No Information',
    'ZI004_PRE':'No Information'
    }

# It is critical that the target fields match the destination AND if
# the source is not actually present, the default value is set. We must
# have a value or the metadata processing code will fail. This can be very
# subtle. For instance ZI004_PRE is only in the MetadataSrf feature class.
# but we need to operate based on each feature and ZI004_PRE is not
# on individual features. The source should then be the source fields
# that are present on each feature, not the metadata entity itself.
# To process the metadata entity directly, use MetadataSrfFields.
EntityCollectionFields = [
    (None,'AHA',None),
    (None,'AVA','transform_set_EntityCollection_field_to_default'),
    (None,'DQS','transform_set_EntityCollection_field_to_default'),
    (None,'EQS','transform_set_EntityCollection_field_to_default'),
    (None,'EVA','transform_set_EntityCollection_field_to_default'),
    ('F_CODE','F_CODE',None),
    (None,'HVA','transform_set_EntityCollection_field_to_default'),
    (None,'MDE','transform_set_EntityCollection_field_to_default'),
    (None,'RCG','transform_set_EntityCollection_field_to_default'),
    (None,'SCVN','transform_set_schemaversion'),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI001_SDP','ZI001_SDP',None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromcodelisttoenum'),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    (None,'ZI004_PRE','transform_set_to_default'),
    ('OTH','OTH','transformMoveOTHOnlyIfMetaAttribute')
    ]


# These fields are examined in each source feature instance
# and they are used to extend the information in the
# Entity Collection Metadata records found in MetadataSrf
EntityCollectionMetaConvertSubsetFields = [
    ('ZI001_SDP','ZI001_SDP',None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromcodelisttoenum'),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('OTH','OTH','transformMoveOTHOnlyIfMetaAttribute'),
    ('AHA','AHA',None)
    ]

# These fields may be in each feature class instance and should
# be matched to a record in Entity Collection Metadata (MetadataSrf)
# if possible. Where there is no destination in each feature class
# in GGDM, the target is none.
EntityCollectionFCSubsetFields = [
    ('ZI001_SDP',None,None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS',None,None),
    ('ZI001_VSC',None,'transformZI001_VSCfromcodelisttoenum'),
    ('ZI001_VSD',None,None),
    ('ZI001_VSN',None,None)
    ]


DatasetSrfFields = [
    ('SHAPE@','SHAPE@', None),
    ('SHAPE@Length','SHAPE@Length',None),
    ('SHAPE@Area','SHAPE@Area',None),
    ('FCSubType','FCSubType',None),
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('CPS','CPS','transformCPScodelist2CPSenumvalue'),
    ('DQS','DQS',None),
    ('EQC',None,None),
    (None,'EQS','transformEQCtoEQS'),
    ('ETS','ETS','transformETScodelist2ETSenumvalue'),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    (None,'FURL','transform_default_value_string'),
    ('HVA','HVA',None),
    ('HZD','HZD','transformHZDcodelist2HZDenumvalue'),
    ('MDE','MDE',None),
    ('RCG','RCG','transformRCGcodelist2RCGenumvalue'),
    ('RTL',None,None),
    (None,'SCVN','transform_set_schemaversion'),
    ('URI','URI',None),
    ('VDT','VDT','transformVDTcodelist2VDTenumvalue'),
    (None,'ZI002_UFI','transform_find_restriction_info_id'),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('ZSAX_RS0','ZSAX_RS0',None),
    ('ZSAX_RX0','ZSAX_RX0',None),
    ('ZSAX_RX3','ZSAX_RX3',None),
    ('ZSAX_RX4','ZSAX_RX4',None),
    ('SAX_RY2',None, None),
    ('SAX_RS1',None, None),
    ('SAX_RS2',None, None),
    ('SAX_RX9',None, None),
    ('SAX_RS3',None, None),
    ('SAX_RS4',None, None),
    ('SAX_RS5',None, None),
    ('SAX_RS6',None, None),
    ('SAX_RS8',None, None),
    ('SAX_RS9',None, None),
    ('SAX_RY0',None, None),
    ('SAX_RX1',None, None),
    ('SAX_RX2',None, None),
    ('SAX_RY1',None, None),
    ('SAX_RX5',None, None),
    ('SAX_RX7',None, None),
    ('SAX_RX6',None, None),
    ('SAX_RX8',None, None),
    ('CCN',None, None),
    ('CDR',None, None),
    ('MEM','MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH')
    ]

DatasetSrfResourceInfoFields = [
    ('SAX_RY2',None, None),
    ('SAX_RS1',None, None),
    ('SAX_RS2',None, None),
    ('SAX_RX9',None, None),
    ('SAX_RS3',None, None),
    ('SAX_RS4',None, None),
    ('SAX_RS5',None, None),
    ('SAX_RS6',None, None),
    ('SAX_RS8',None, None),
    ('SAX_RS9',None, None),
    ('SAX_RY0',None, None),
    ('SAX_RX1',None, None),
    ('SAX_RX2',None, None),
    ('SAX_RY1',None, None),
    ('SAX_RX5',None, None),
    ('SAX_RX7',None, None),
    ('SAX_RX6',None, None),
    ('SAX_RX8',None, None),
    ('CCN',None, None),
    ('CDR',None, None)
    ]

DatasetTargetDefaultFieldValues = {
    'FCSubType':121591,
    'AHA':-999999,
    'AVA':-999999,
    'CID':'No Information',
    'CPS':-999999,
    'DQS':'No Information',
    'EQS':-999999,
    'ETS':-999999,
    'ETZ':'No Information',
    'EVA':-999999,
    'F_CODE':'ZI031',
    'FURL':'noInformation',
    'HVA':-999999,
    'HZD':-999999,
    'MDE':'noInformation',
    'MEM':'No Information',
    'OTH':'noInformation',
    'RCG':-999999,
    'RTL':'No Information',
    'SCVN':'noInformation',
    'URI':'noInformation',
    'VDT':-999999,
    'ZI002_UFI':'noInformation',
    'ZI020_GE4':'noInformation',
    'ZI020_GE42':'noInformation',
    'ZI020_GE43':'noInformation',
    'ZI020_GE44':'noInformation',
    'ZSAX_RS0':'U',
    'ZSAX_RX0':'noInformation',
    'ZSAX_RX3':'noInformation',
    'ZSAX_RX4':'noInformation'
    }


# These are the common metadata fields that are on all geometric features. we group them
# to ensure all translations are done in the same way. OTH and MEM are included so that
# they are also processed consistently.
# (except some of these are not on Dataset (ResourceSrf), which is processed separately.
common_metadata_translate_fields = [
    ('ZI004_RCG', 'ZI004_RCG', 'transformZI004_RCGfromcodelisttoenum'),
    ('ZI001_SDV','ZI001_SDV',None),
    ('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZSAX_RS0','ZSAX_RS0',None),
    ('ZSAX_RX0','ZSAX_RX0',None),
    ('ZSAX_RX3','ZSAX_RX3',None),
    ('ZSAX_RX4','ZSAX_RX4',None),
    (None,'ZI002_UFI','transform_find_restriction_info_id'),
    (None,'ZI039S_UFI','transform_find_entity_collection_id'),
    (None,'ZI031S_URI','transform_find_dataset_id'),
    ('OTH','OTH','transform_OTH'),
    ('ZI006_MEM','ZI006_MEM','transform_MEM')
    ]



############# Feature Classes specific to Metadata defined here ######################
# While these are based on the output from translation db, they customized
# Generally, they include all relevant metadata fields rather than copying them
# from the associated common lists above.
# 


# ResourceSrf field translations
ResourceSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AHA','AHA',None),
    ('AVA','AVA',None),
    ('CID','CID',None),
    ('DQS','DQS',None),
    ('ETZ','ETZ',None),
    ('EVA','EVA',None),
    ('F_CODE','F_CODE',None),
    ('HVA','HVA',None),
    ('MDE','MDE',None),
    ('URI','URI',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI020_GE42','ZI020_GE42',None),
    ('ZI020_GE43','ZI020_GE43',None),
    ('ZI020_GE44','ZI020_GE44',None),
    ('ZSAX_RS0','ZSAX_RS0',None),
    ('ZSAX_RX0','ZSAX_RX0',None),
    ('ZSAX_RX3','ZSAX_RX3',None),
    ('ZSAX_RX4','ZSAX_RX4',None),
    ('CPS','CPS','transformCPScodelist2CPSenumvalue'),
    ('EQC',None,'transform_no_target_save_to_oth'),
    ('ETS','ETS','transformETScodelist2ETSenumvalue'),
    ('HZD','HZD','transformHZDcodelist2HZDenumvalue'),
    (None,'EQS','transformEQCtoEQS'),
    (None,'FURL','transform_set_to_default'),
    (None,'RTL','transform_set_to_default'),
    (None,'SCVN','transform_set_schemaversion'),
    ('RCG','RCG','transformRCGcodelist2RCGenumvalue'),
    ('VDT','VDT','transformVDTcodelist2VDTenumvalue'),
    (None,'ZI002_UFI','transform_find_restriction_info_id'),
    ('MEM','MEM','transform_MEM'),
    ('OTH','OTH','transform_OTH') \
     ]


# MetadataSrf field translations
MetadataSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('F_CODE','F_CODE',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI001_SDP','ZI001_SDP',None),
    #('ZI001_SDV','ZI001_SDV',None),
    #('ZI001_SRT','ZI001_SRT','transformZI001_SRTfromcodelisttoenum'),
    ('ZI001_SPS','ZI001_SPS',None),
    ('ZI001_VSD','ZI001_VSD',None),
    ('ZI001_VSN','ZI001_VSN',None),
    ('ZI004_PRE','ZI004_PRE',None),
    (None,'AHA','transform_set_to_default'),
    (None,'AVA','transform_set_to_default'),
    (None,'DQS','transform_set_to_default'),
    (None,'EQS','transform_report_issue'),
    (None,'EVA','transform_set_to_default'),
    (None,'HVA','transform_set_to_default'),
    (None,'MDE','transform_set_to_default'),
    (None,'RCG','transform_set_to_default'),
    (None,'SCVN','transform_set_schemaversion'),
    ('ZI001_VSC','ZI001_VSC','transformZI001_VSCfromcodelisttoenum'),
    ('OTH','OTH','transform_OTH') \
    ]


#################### Begin non-metadata feature transform definitions ###################
### Caution: Remove the metadata feature classes from below, and put them above, customizing them
### as needed.  [MetadataSrf and ResourceSrf]
###

# AeronauticCrv field translations
AeronauticCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SBB','SBB',None),
    ('TXP','TXP',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticPnt field translations
AeronauticPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FPT','FPT',None),
    ('GUG','GUG',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('PYM','PYM',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('COS','COS','transform_COS'),
    (None,'CNCP','transform_set_to_default'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LASZ','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI103_MVD','transform_set_to_default'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AeronauticSrf field translations
AeronauticSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('APT','APT',None),
    ('APT2','APT2',None),
    ('APT3','APT3',None),
    ('APU','APU',None),
    ('APU2','APU2',None),
    ('APU3','APU3',None),
    ('APY','APY',None),
    ('ARA','ARA',None),
    ('ASY','ASY',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('AXS','AXS',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FPT','FPT',None),
    ('GB052_RIDH','GB052_RIDH',None),
    ('GB052_RIDL','GB052_RIDL',None),
    ('GSGCHC','GSGCHC',None),
    ('GSGCHL','GSGCHL',None),
    ('GSGCHU','GSGCHU',None),
    ('GSGCLC','GSGCLC',None),
    ('GSGCLL','GSGCLL',None),
    ('GSGCLU','GSGCLU',None),
    ('HAF','HAF',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('HTP','HTP',None),
    ('IKO','IKO',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAG','MAG',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('NA8','NA8',None),
    ('NAO','NAO',None),
    ('PCF','PCF',None),
    ('PEC','PEC',None),
    ('SBB','SBB',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TXP','TXP',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI019_ASP','ZI019_ASP',None),
    ('ZI019_ASP2','ZI019_ASP2',None),
    ('ZI019_ASP3','ZI019_ASP3',None),
    ('ZI019_ASX','ZI019_ASX',None),
    ('ZI019_SFS','ZI019_SFS',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVA','ZVA',None),
    ('ZVH','ZVH',None),
    ('ASU','ASU','transform_ASU'),
    ('ASU2','ASU2','transform_ASU'),
    ('ASU3','ASU3','transform_ASU'),
    ('COS','COS','transform_COS'),
    (None,'CNCP','transform_set_to_default'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GB052_TRHH','transform_set_to_default'),
    (None,'GB052_TRHL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LASZ','transform_set_to_default'),
    (None,'SERP','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI103_MVD','transform_set_to_default'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI019_ASU','ZI019_ASU','transform_ASU'),
    ('ZI019_ASU2','ZI019_ASU2','transform_ASU'),
    ('ZI019_ASU3','ZI019_ASU3','transform_ASU') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgriculturePnt field translations
AgriculturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LUN','transform_set_to_default'),
    (None,'PVH','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# AgricultureSrf field translations
AgricultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PVH','PVH',None),
    ('SDSC','SDSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI013_CSP','ZI013_CSP',None),
    ('ZI013_CSP2','ZI013_CSP2',None),
    ('ZI013_CSP3','ZI013_CSP3',None),
    ('ZI013_FFP','ZI013_FFP',None),
    ('ZI013_FFP2','ZI013_FFP2',None),
    ('ZI013_FFP3','ZI013_FFP3',None),
    ('ZI013_FMM','ZI013_FMM',None),
    ('ZI013_FMM2','ZI013_FMM2',None),
    ('ZI013_FMM3','ZI013_FMM3',None),
    ('ZI013_IRG','ZI013_IRG',None),
    ('ZI013_PIG','ZI013_PIG',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LUN','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundaryPnt field translations
BoundaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    (None,'BEN','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZVH','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# BoundarySrf field translations
BoundarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('CAA','CAA',None),
    ('CDM','CDM',None),
    ('CDY','CDY',None),
    ('CSI','CSI',None),
    ('CSY','CSY',None),
    ('F_CODE','F_CODE',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureCrv field translations
CultureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CulturePnt field translations
CulturePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCG','CCG',None),
    ('CSO','CSO',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_REL','ZI037_REL',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LEA','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# CultureSrf field translations
CultureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAM','CAM',None),
    ('CCG','CCG',None),
    ('CSO','CSO',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HSS','HSS',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('SDQ','SDQ',None),
    ('SRL','SRL',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('TTY','TTY',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LEA','transform_set_to_default'),
    (None,'TRE','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilityPnt field translations
FacilityPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'ADUR','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'WLSS','transform_set_to_default'),
    (None,'WSRC','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# FacilitySrf field translations
FacilitySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PRM','PRM',None),
    ('RAS','RAS',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'ADUR','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'WLSS','transform_set_to_default'),
    (None,'WSRC','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationPnt field translations
HydroAidNavigationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC040_EOL','BC040_EOL',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_LVN','BC040_LVN',None),
    ('BC040_PER','BC040_PER',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BC034_BRF','transform_set_to_default'),
    (None,'BC034_BRF2','transform_set_to_default'),
    (None,'BC034_MRT2','transform_set_to_default'),
    (None,'BC034_MRT3','transform_set_to_default'),
    (None,'BC040_COL','transform_set_to_default'),
    (None,'BC040_MLR','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'REF','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydroAidNavigationSrf field translations
HydroAidNavigationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BC040_LCN','BC040_LCN',None),
    ('BC040_PER','BC040_PER',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('COS','COS',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MAN','MAN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyCrv field translations
HydrographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DIM','DIM',None),
    ('DWT',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('LDC','LDC',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WRT','WRT',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BBMCA','transform_set_to_default'),
    (None,'BBMCA2','transform_set_to_default'),
    (None,'BBMCA3','transform_set_to_default'),
    (None,'BBMCB','transform_set_to_default'),
    (None,'BBMCB2','transform_set_to_default'),
    (None,'BBMCB3','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DFU','transformDWT_to_DFU'),
    (None,'DFU2','transformDWT_to_DFU'),
    (None,'DFU3','transformDWT_to_DFU'),
    (None,'DIT','transform_set_to_default'),
    (None,'DOXY','transform_set_to_default'),
    (None,'DSD','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FRZ','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'LUN','transform_set_to_default'),
    (None,'PWAC','transform_set_to_default'),
    (None,'PWAL','transform_set_to_default'),
    (None,'PWAU','transform_set_to_default'),
    (None,'STNB','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SQN','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WPAC','transform_set_to_default'),
    (None,'ZI024_WSG','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographyPnt field translations
HydrographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('DFT','DFT',None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DWT',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('THI','THI',None),
    ('TID','TID',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WFT','WFT',None),
    ('WID','WID',None),
    ('WOC','WOC',None),
    ('WST','WST',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BC034_MRT2','transform_set_to_default'),
    (None,'BC034_MRT3','transform_set_to_default'),
    (None,'BH010_CAA','transform_set_to_default'),
    (None,'CDI','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DFU','transformDWT_to_DFU'),
    (None,'DFU2','transformDWT_to_DFU'),
    (None,'DFU3','transformDWT_to_DFU'),
    (None,'DOXY','transform_set_to_default'),
    (None,'DSD','transform_set_to_default'),
    (None,'DWL','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FRZ','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'LUN','transform_set_to_default'),
    (None,'PMPR','transform_set_to_default'),
    (None,'PUD','transform_set_to_default'),
    (None,'SCOG','transform_set_to_default'),
    (None,'TSSM','transform_set_to_default'),
    (None,'TSSM2','transform_set_to_default'),
    (None,'TSSM3','transform_set_to_default'),
    (None,'TSTE','transform_set_to_default'),
    (None,'WCAC','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'WHCO','transform_set_to_default'),
    (None,'WODR','transform_set_to_default'),
    (None,'WTBB','transform_set_to_default'),
    (None,'WTCA','transform_set_to_default'),
    (None,'WTCL','transform_set_to_default'),
    (None,'WTFE','transform_set_to_default'),
    (None,'WTKK','transform_set_to_default'),
    (None,'WTMN','transform_set_to_default'),
    (None,'WTNA','transform_set_to_default'),
    (None,'WTNO','transform_set_to_default'),
    (None,'WTPO','transform_set_to_default'),
    (None,'WTSI','transform_set_to_default'),
    (None,'WTST','transform_set_to_default'),
    (None,'WWM','transform_set_to_default'),
    (None,'WWM2','transform_set_to_default'),
    (None,'WWM3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_DRL','transform_set_to_default'),
    (None,'ZI024_DVPT','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_PMP','transform_set_to_default'),
    (None,'ZI024_RTP','transform_set_to_default'),
    (None,'ZI024_WPAC','transform_set_to_default'),
    (None,'ZI024_WTBB','transform_set_to_default'),
    (None,'ZI024_WTCA','transform_set_to_default'),
    (None,'ZI024_WTFE','transform_set_to_default'),
    (None,'ZI024_WTKK','transform_set_to_default'),
    (None,'ZI024_WTMN','transform_set_to_default'),
    (None,'ZI024_WTNA','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WTPO','transform_set_to_default'),
    (None,'ZI024_WTSI','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI024_ASE','ZI024_ASE','transform_gramspercm_to_mgperlitre'),
    ('ZI024_CLO','ZI024_CLO','transform_gramspercm_to_mgperlitre'),
    ('ZI024_CYN','ZI024_CYN','transform_gramspercm_to_mgperlitre'),
    ('ZI024_HAR','ZI024_HAR','transform_gramspercm_to_mgperlitre'),
    ('ZI024_MGN','ZI024_MGN','transform_gramspercm_to_mgperlitre'),
    ('ZI024_SUL','ZI024_SUL','transform_gramspercm_to_mgperlitre'),
    ('ZI024_TDS','ZI024_TDS','transform_gramspercm_to_mgperlitre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HydrographySrf field translations
HydrographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('ATC','ATC',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BC034_MRT','BC034_MRT',None),
    ('BC101_SST','BC101_SST',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DFT','DFT',None),
    ('DMD','DMD',None),
    ('DOF','DOF',None),
    ('DWT',None,None),
    ('F_CODE','F_CODE',None),
    ('FCS','FCS',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGS','HGS',None),
    ('HGT','HGT',None),
    ('INU','INU',None),
    ('IWT','IWT',None),
    ('LDC','LDC',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MNS','MNS',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OCS','OCS',None),
    ('PCF','PCF',None),
    ('PSE','PSE',None),
    ('PWA','PWA',None),
    ('PWAC','PWAC',None),
    ('PWAL','PWAL',None),
    ('PWAU','PWAU',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SWT','SWT',None),
    ('SWW','SWW',None),
    ('TID','TID',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WAD','WAD',None),
    ('WCC','WCC',None),
    ('WD3','WD3',None),
    ('WDAC','WDAC',None),
    ('WDAL','WDAL',None),
    ('WDAU','WDAU',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WFT','WFT',None),
    ('WID','WID',None),
    ('WMT','WMT',None),
    ('WOC','WOC',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_FNA3','ZI005_FNA3',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI005_NFN3','ZI005_NFN3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_CFR','ZI024_CFR',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_PHW','ZI024_PHW',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_TEP','ZI024_TEP',None),
    ('ZI024_TUR','ZI024_TUR',None),
    ('ZI024_WAC','ZI024_WAC',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI025_MAN','ZI025_MAN',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BBMCA','transform_set_to_default'),
    (None,'BBMCA2','transform_set_to_default'),
    (None,'BBMCA3','transform_set_to_default'),
    (None,'BBMCB','transform_set_to_default'),
    (None,'BBMCB2','transform_set_to_default'),
    (None,'BBMCB3','transform_set_to_default'),
    (None,'BC034_MRT2','transform_set_to_default'),
    (None,'BC034_MRT3','transform_set_to_default'),
    (None,'CDI','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DFU','transformDWT_to_DFU'),
    (None,'DFU2','transformDWT_to_DFU'),
    (None,'DFU3','transformDWT_to_DFU'),
    (None,'DIT','transform_set_to_default'),
    (None,'DOXY','transform_set_to_default'),
    (None,'DSD','transform_set_to_default'),
    (None,'DWL','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FRZ','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'LUN','transform_set_to_default'),
    (None,'PUD','transform_set_to_default'),
    (None,'SCOG','transform_set_to_default'),
    (None,'STNB','transform_set_to_default'),
    (None,'TSSM','transform_set_to_default'),
    (None,'TSSM2','transform_set_to_default'),
    (None,'TSSM3','transform_set_to_default'),
    (None,'TSTE','transform_set_to_default'),
    (None,'WCAC','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'WHCO','transform_set_to_default'),
    (None,'WODR','transform_set_to_default'),
    (None,'WTBB','transform_set_to_default'),
    (None,'WTCA','transform_set_to_default'),
    (None,'WTCL','transform_set_to_default'),
    (None,'WTFE','transform_set_to_default'),
    (None,'WTKK','transform_set_to_default'),
    (None,'WTMN','transform_set_to_default'),
    (None,'WTNA','transform_set_to_default'),
    (None,'WTNO','transform_set_to_default'),
    (None,'WTPO','transform_set_to_default'),
    (None,'WTSI','transform_set_to_default'),
    (None,'WTST','transform_set_to_default'),
    (None,'WWM','transform_set_to_default'),
    (None,'WWM2','transform_set_to_default'),
    (None,'WWM3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_DRL','transform_set_to_default'),
    (None,'ZI024_DVPT','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_PMP','transform_set_to_default'),
    (None,'ZI024_RTP','transform_set_to_default'),
    (None,'ZI024_SQN','transform_set_to_default'),
    (None,'ZI024_WPAC','transform_set_to_default'),
    (None,'ZI024_WSG','transform_set_to_default'),
    (None,'ZI024_WTBB','transform_set_to_default'),
    (None,'ZI024_WTCA','transform_set_to_default'),
    (None,'ZI024_WTFE','transform_set_to_default'),
    (None,'ZI024_WTKK','transform_set_to_default'),
    (None,'ZI024_WTMN','transform_set_to_default'),
    (None,'ZI024_WTNA','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WTPO','transform_set_to_default'),
    (None,'ZI024_WTSI','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI024_ASE','ZI024_ASE','transform_gramspercm_to_mgperlitre'),
    ('ZI024_CLO','ZI024_CLO','transform_gramspercm_to_mgperlitre'),
    ('ZI024_CYN','ZI024_CYN','transform_gramspercm_to_mgperlitre'),
    ('ZI024_HAR','ZI024_HAR','transform_gramspercm_to_mgperlitre'),
    ('ZI024_MGN','ZI024_MGN','transform_gramspercm_to_mgperlitre'),
    ('ZI024_SUL','ZI024_SUL','transform_gramspercm_to_mgperlitre'),
    ('ZI024_TDS','ZI024_TDS','transform_gramspercm_to_mgperlitre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyCrv field translations
HypsographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('HQC','HQC',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# HypsographyPnt field translations
HypsographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEL','BEL',None),
    ('ESC','ESC',None),
    ('F_CODE','F_CODE',None),
    ('PCF','PCF',None),
    ('SUY','SUY',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    ('ZVH_AVA','ZVH_AVA',None),
    (None,'BEN','transform_set_to_default'),
    (None,'CAA','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    ('ZVH_VDT','ZVH_VDT','transformVDTcodelist2VDTenumvalue') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryCrv field translations
IndustryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustryPnt field translations
IndustryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('CVT','CVT',None),
    ('CVT2','CVT2',None),
    ('CVT3','CVT3',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('GUG','GUG',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('RIP','RIP',None),
    ('SRL','SRL',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WEQ','WEQ',None),
    ('WEQ2','WEQ2',None),
    ('WEQ3','WEQ3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# IndustrySrf field translations
IndustrySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('AZC','AZC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CRA','CRA',None),
    ('CRM','CRM',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LCA','LCA',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MZN','MZN',None),
    ('PBY','PBY',None),
    ('PBY2','PBY2',None),
    ('PBY3','PBY3',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRW','PRW',None),
    ('PRW2','PRW2',None),
    ('PRW3','PRW3',None),
    ('SRL','SRL',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('UMA','UMA',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PPO','ZI014_PPO',None),
    ('ZI014_PPO2','ZI014_PPO2',None),
    ('ZI014_PPO3','ZI014_PPO3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationCrv field translations
InformationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('F_CODE','F_CODE',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_FNA','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNR','transform_set_to_default'),
    (None,'ZI005_GNR2','transform_set_to_default'),
    (None,'ZI005_GNR3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI015_GCUC','transform_set_to_default'),
    (None,'ZI015_GCUL','transform_set_to_default'),
    (None,'ZI015_GCUU','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationPnt field translations
InformationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('F_CODE','F_CODE',None),
    ('NLT','NLT',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNR','transform_set_to_default'),
    (None,'ZI005_GNR2','transform_set_to_default'),
    (None,'ZI005_GNR3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI015_GCUC','transform_set_to_default'),
    (None,'ZI015_GCUL','transform_set_to_default'),
    (None,'ZI015_GCUU','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# InformationSrf field translations
InformationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ARA','ARA',None),
    ('F_CODE','F_CODE',None),
    ('LZN','LZN',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCA','VCA',None),
    ('VCA2','VCA2',None),
    ('VCA3','VCA3',None),
    ('VCT','VCT',None),
    ('VCT2','VCT2',None),
    ('VCT3','VCT3',None),
    ('WID','WID',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_FNA','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNR','transform_set_to_default'),
    (None,'ZI005_GNR2','transform_set_to_default'),
    (None,'ZI005_GNR3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI015_GCUC','transform_set_to_default'),
    (None,'ZI015_GCUL','transform_set_to_default'),
    (None,'ZI015_GCUU','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)


# MilitaryCrv field translations
MilitaryCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PFHC','transform_set_to_default'),
    (None,'PFHL','transform_set_to_default'),
    (None,'PFHU','transform_set_to_default'),
    (None,'YSU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitaryPnt field translations
MilitaryPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FZR','FZR',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'MLOP','transform_set_to_default'),
    (None,'MLUS','transform_set_to_default'),
    (None,'WPST','transform_set_to_default'),
    (None,'WTYP','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# MilitarySrf field translations
MilitarySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('CAA','CAA',None),
    ('DZP','DZP',None),
    ('EET','EET',None),
    ('F_CODE','F_CODE',None),
    ('FRT','FRT',None),
    ('FRT2','FRT2',None),
    ('FRT3','FRT3',None),
    ('FZR','FZR',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LEA','LEA',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MST','MST',None),
    ('MST2','MST2',None),
    ('MST3','MST3',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('PRM','PRM',None),
    ('RLE','RLE',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WID','WID',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'MLOP','transform_set_to_default'),
    (None,'MLUS','transform_set_to_default'),
    (None,'PFHC','transform_set_to_default'),
    (None,'PFHL','transform_set_to_default'),
    (None,'PFHU','transform_set_to_default'),
    (None,'WPST','transform_set_to_default'),
    (None,'WTYP','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyCrv field translations
PhysiographyCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ARA','ARA',None),
    ('AZC','AZC',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('GFT','GFT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    ('CET','CET',None),
    ('MCC','MCC','transform_placeholder_return_source'),
    ('MCC2','MCC2','transform_placeholder_return_source'),
    ('MCC3','MCC3','transform_placeholder_return_source'),
    (None,'BEN','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FDI','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'GFY','transform_set_to_default'),
    (None,'HDP','transform_set_to_default'),
    (None,'SDI','transform_set_to_default'),
    (None,'SHO','transform_set_to_default'),
    (None,'SNDC','transform_set_to_default'),
    (None,'SNDL','transform_set_to_default'),
    (None,'SNDU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographyPnt field translations
PhysiographyPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DOF','DOF',None),
    ('F_CODE','F_CODE',None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('OHC','OHC',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SHD','SHD',None),
    ('SLT','SLT',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    ('ZVH','ZVH',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'SNDC','transform_set_to_default'),
    (None,'SNDL','transform_set_to_default'),
    (None,'SNDU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PhysiographySrf field translations
PhysiographySrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('AQN','AQN',None),
    ('ARA','ARA',None),
    ('BA000_VDC','BA000_VDC',None),
    ('BA000_VDR','BA000_VDR',None),
    ('CAA','CAA',None),
    ('DOF','DOF',None),
    ('F_CODE','F_CODE',None),
    ('FIC','FIC',None),
    ('GOT','GOT',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LND','LND',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PFD','PFD',None),
    ('PFH','PFH',None),
    ('RKF','RKF',None),
    ('SAD','SAD',None),
    ('SDCC','SDCC',None),
    ('SDCL','SDCL',None),
    ('SDCU','SDCU',None),
    ('SDO','SDO',None),
    ('SDT','SDT',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHD','SHD',None),
    ('SIC','SIC',None),
    ('SLT','SLT',None),
    ('SRD','SRD',None),
    ('SSE','SSE',None),
    ('STP','STP',None),
    ('SWC','SWC',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('TSM','TSM',None),
    ('TSM2','TSM2',None),
    ('TSM3','TSM3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VGT','VGT',None),
    ('VOA','VOA',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    ('CET','CET',None),
    ('MCC','MCC','transform_placeholder_return_source'),
    ('MCC2','MCC2','transform_placeholder_return_source'),
    ('MCC3','MCC3','transform_placeholder_return_source'),
    (None,'BEN','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'SNDC','transform_set_to_default'),
    (None,'SNDL','transform_set_to_default'),
    (None,'SNDU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourCrv field translations
PortHarbourCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourPnt field translations
PortHarbourPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('TID','TID',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PLC','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# PortHarbourSrf field translations
PortHarbourSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FAC','FAC',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FHC','FHC',None),
    ('FHC2','FHC2',None),
    ('FHC3','FHC3',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('LCA','LCA',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('PWC','PWC',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SLR','SLR',None),
    ('TID','TID',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('WPI','WPI',None),
    ('YSU','YSU',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PLC','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationCrv field translations
RecreationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('THI','THI',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'RAY','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationPnt field translations
RecreationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# RecreationSrf field translations
RecreationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AMA','AMA',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CCT','CCT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_set_to_default'),
    (None,'RAY','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementPnt field translations
SettlementPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DNE','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SettlementSrf field translations
SettlementSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BAC','BAC',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('HHD','HHD',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('STL','STL',None),
    ('STL2','STL2',None),
    ('STL3','STL3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('WPI','WPI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_FNA2','ZI005_FNA2',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI005_NFN2','ZI005_NFN2',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BNF','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DNE','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StoragePnt field translations
StoragePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_set_to_default'),
    (None,'PMPR','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StorageSrf field translations
StorageSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CBP','CBP',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LUN','LUN',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SHT','SHT',None),
    ('SPT','SPT',None),
    ('SSC','SSC',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VLM','VLM',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('YWQ','YWQ',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LOC','transform_set_to_default'),
    (None,'PMPR','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_HYP','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureCrv field translations
StructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BAT','BAT',None),
    ('BEN','BEN',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('CRM','CRM',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('FTI','FTI',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('THI','THI',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('WTI','WTI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FEF','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'PFHC','transform_set_to_default'),
    (None,'PFHL','transform_set_to_default'),
    (None,'PFHU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructurePnt field translations
StructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('COS','COS',None),
    ('CRM','CRM',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MFB','MFB',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'CNCP','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HSC','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'MEL','transform_set_to_default'),
    (None,'MFY','transform_set_to_default'),
    (None,'MKSZ','transform_set_to_default'),
    (None,'NOR','transform_set_to_default'),
    (None,'STAF','transform_set_to_default'),
    (None,'VEC','transform_set_to_default'),
    (None,'WPST','transform_set_to_default'),
    (None,'WTYP','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# StructureSrf field translations
StructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BNF','BNF',None),
    ('BSU','BSU',None),
    ('CAA','CAA',None),
    ('COS','COS',None),
    ('ETY','ETY',None),
    ('F_CODE','F_CODE',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MFB','MFB',None),
    ('MUB','MUB',None),
    ('PCF','PCF',None),
    ('PYC','PYC',None),
    ('PYM','PYM',None),
    ('RLE','RLE',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TEL','TEL',None),
    ('TOS','TOS',None),
    ('TTC','TTC',None),
    ('TTC2','TTC2',None),
    ('TTC3','TTC3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI014_PBY','ZI014_PBY',None),
    ('ZI014_PBY2','ZI014_PBY2',None),
    ('ZI014_PBY3','ZI014_PBY3',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI037_RFA','ZI037_RFA',None),
    ('ZVH','ZVH',None),
    ('ZI037_REL','ZI037_REL','transform_ZI037_REL'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'CNCP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HSC','transform_set_to_default'),
    (None,'MEL','transform_set_to_default'),
    (None,'MFY','transform_set_to_default'),
    (None,'MKSZ','transform_set_to_default'),
    (None,'NOR','transform_set_to_default'),
    (None,'STAF','transform_set_to_default'),
    (None,'VEC','transform_set_to_default'),
    (None,'WPST','transform_set_to_default'),
    (None,'WTYP','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    ('ZI014_PPO','ZI014_PPO','transform_placeholder_return_source'),
    ('ZI014_PPO2','ZI014_PPO2','transform_placeholder_return_source'),
    ('ZI014_PPO3','ZI014_PPO3','transform_placeholder_return_source'),
    ('ZI014_PRW','ZI014_PRW','transform_placeholder_return_source'),
    ('ZI014_PRW2','ZI014_PRW2','transform_placeholder_return_source'),
    ('ZI014_PRW3','ZI014_PRW3','transform_placeholder_return_source') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# SubterraneanSrf field translations
SubterraneanSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AQN','AQN',None),
    ('AQO','AQO',None),
    ('AQO2','AQO2',None),
    ('AQO3','AQO3',None),
    ('AQP','AQP',None),
    ('AQP2','AQP2',None),
    ('AQP3','AQP3',None),
    ('AQTC','AQTC',None),
    ('AQTL','AQTL',None),
    ('AQTU','AQTU',None),
    ('ARA','ARA',None),
    ('AYRC','AYRC',None),
    ('AYRL','AYRL',None),
    ('AYRU','AYRU',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CNF','CNF',None),
    ('COS','COS',None),
    ('DPAC','DPAC',None),
    ('DPAL','DPAL',None),
    ('DPAU','DPAU',None),
    ('DZP','DZP',None),
    ('F_CODE','F_CODE',None),
    ('LEA','LEA',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('UFI','UFI','transform_set_UFI'),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_SCC','ZI024_SCC',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI071_CTX','ZI071_CTX',None),
    ('ZI071_FFN','ZI071_FFN',None),
    ('ZI071_FFN2','ZI071_FFN2',None),
    ('ZI071_FFN3','ZI071_FFN3',None),
    ('ZI071_UAO','ZI071_UAO',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'GWS','transform_set_to_default'),
    (None,'GWTR','transform_set_to_default'),
    (None,'HYCD','transform_set_to_default'),
    (None,'SWCP','transform_set_to_default'),
    (None,'WRCC','transform_set_to_default'),
    (None,'WRCL','transform_set_to_default'),
    (None,'WRCU','transform_set_to_default'),
    (None,'WWRC','transform_set_to_default'),
    (None,'WWRL','transform_set_to_default'),
    (None,'WWRU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundCrv field translations
TransportationGroundCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ACC', None, None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CAT','CAT',None),
    ('CON','CON',None),
    ('COS','COS',None),
    ('CTC','CTC',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DZC','DZC',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FSC','FSC',None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LOG','LOG',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MES','MES',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('OOC','OOC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RRC','RRC',None),
    ('RRC2','RRC2',None),
    ('RRC3','RRC3',None),
    ('RSA','RSA',None),
    ('RTA','RTA',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('RWC','RWC',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SHC','SHC',None),
    ('SPM','SPM',None),
    ('SRE','SRE',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('TST','TST',None),
    ('UBC','UBC',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI016_WT2','WT2',None),
    ('ZI016_WD2','WD2',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RIR','ZI017_RIR',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZVH','ZVH',None),
    ('MCC','MCC','transform_placeholder_return_source'),
    ('MCC2','MCC2','transform_placeholder_return_source'),
    ('MCC3','MCC3','transform_placeholder_return_source'),
    (None,'BMC','transform_set_to_default'),
    (None,'BMC2','transform_set_to_default'),
    (None,'BMC3','transform_set_to_default'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'CNCP','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LEA','transform_set_to_default'),
    (None,'PSN','transform_set_to_default'),
    (None,'PTG','transform_TRS_to_PTG'),
    (None,'SPD','transform_set_to_default'),
    (None,'VCO','transform_set_to_default'),
    (None,'WVA','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundPnt field translations
TransportationGroundPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADI','ADI',None),
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('CON','CON',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTC','CTC',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('EXP','EXP',None),
    ('F_CODE','F_CODE',None),
    ('GTC','GTC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('OOC','OOC',None),
    ('PCF','PCF',None),
    ('PYM','PYM',None),
    ('RAD','RAD',None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RIT','RIT',None),
    ('SHC','SHC',None),
    ('SPT','SPT',None),
    ('SRE','SRE',None),
    ('SSG','SSG',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TCS','TCS',None),
    ('THI','THI',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WD1','WD1',None),
    ('ZI016_WD2','WD2',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BMC','transform_set_to_default'),
    (None,'BMC2','transform_set_to_default'),
    (None,'BMC3','transform_set_to_default'),
    (None,'BNF','transform_set_to_default'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VCO','transform_set_to_default'),
    (None,'WVA','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationGroundSrf field translations
TransportationGroundSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BCC','BCC',None),
    ('BEN','BEN',None),
    ('BOT','BOT',None),
    ('BRN','BRN',None),
    ('BSC','BSC',None),
    ('BSC2','BSC2',None),
    ('BSC3','BSC3',None),
    ('BSM','BSM',None),
    ('CAA','CAA',None),
    ('COS','COS',None),
    ('CSC','CSC',None),
    ('CSC2','CSC2',None),
    ('CSC3','CSC3',None),
    ('CTL','CTL',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DGC','DGC',None),
    ('DZC','DZC',None),
    ('F_CODE','F_CODE',None),
    ('FCO','FCO',None),
    ('FSC','FSC',None),
    ('HCA','HCA',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LC1','LC1',None),
    ('LC2','LC2',None),
    ('LC3','LC3',None),
    ('LC4','LC4',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LTN','LTN',None),
    ('LZN','LZN',None),
    ('MES','MES',None),
    ('MUB','MUB',None),
    ('MWG','MWG',None),
    ('NOS','NOS',None),
    ('OHC','OHC',None),
    ('ONE','ONE',None),
    ('PCF','PCF',None),
    ('RFD','RFD',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('RMWC','RMWC',None),
    ('RMWL','RMWL',None),
    ('RMWU','RMWU',None),
    ('ROR','ROR',None),
    ('RTN','RTN',None),
    ('RTN2','RTN2',None),
    ('RTN3','RTN3',None),
    ('RTY','RTY',None),
    ('SBB','SBB',None),
    ('SEP','SEP',None),
    ('SGCC','SGCC',None),
    ('SGCL','SGCL',None),
    ('SGCU','SGCU',None),
    ('SPM','SPM',None),
    ('SPT','SPT',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THR','THR',None),
    ('TRA','TRA',None),
    ('TRP','TRP',None),
    ('UBC','UBC',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VCS','VCS',None),
    ('VCS_VCD','VCS_VCD',None),
    ('VCS_VCR','VCS_VCR',None),
    ('VET','VET',None),
    ('VOI','VOI',None),
    ('WBD','WBD',None),
    ('WID','WID',None),
    ('WLE','WLE',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI016_ROC','ZI016_ROC',None),
    ('ZI016_WD1','ZI016_WD1',None),
    ('ZI017_GAW','ZI017_GAW',None),
    ('ZI017_RGC','ZI017_RGC',None),
    ('ZI017_RRA','ZI017_RRA',None),
    ('ZI017_TRT','ZI017_TRT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI026_SUR','ZI026_SUR',None),
    ('ZVH','ZVH',None),
    ('MCC','MCC','transform_placeholder_return_source'),
    ('MCC2','MCC2','transform_placeholder_return_source'),
    ('MCC3','MCC3','transform_placeholder_return_source'),
    (None,'BMC','transform_set_to_default'),
    (None,'BMC2','transform_set_to_default'),
    (None,'BMC3','transform_set_to_default'),
    (None,'BNF','transform_set_to_default'),
    (None,'CIW','transformZI016_WTC_CIW'),
    (None,'CNCP','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LEA','transform_set_to_default'),
    (None,'PSN','transform_set_to_default'),
    (None,'PTG','transform_TRS_to_PTG'),
    (None,'SPD','transform_set_to_default'),
    (None,'VCO','transform_set_to_default'),
    (None,'WVA','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default'),
    ('LUN','LUN','transform_TRS_to_LUN'),
    ('FFN','FFN','transform_FFN_932_and_TRS'),
    ('FFN2','FFN2','transform_FFN_932_and_TRS'),
    ('FFN3','FFN3','transform_FFN_932_and_TRS'),
    ('TRS','TRS','transform_TRS'),
    ('TRS2','TRS2','transform_TRS'),
    ('TRS3','TRS3','transform_TRS'),
    ('ZI016_WTC','ZI016_WTC','transformZI016_WTC') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterCrv field translations
TransportationWaterCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FCL','FCL',None),
    ('FER','FER',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MCX','MCX',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('OPT','OPT',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RIN_ROI','RIN_ROI',None),
    ('RIN_ROI2','RIN_ROI2',None),
    ('RIN_ROI3','RIN_ROI3',None),
    ('RIN_RTN','RIN_RTN',None),
    ('RIN_RTN2','RIN_RTN2',None),
    ('RIN_RTN3','RIN_RTN3',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('THI','THI',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BBMCA','transform_set_to_default'),
    (None,'BBMCA2','transform_set_to_default'),
    (None,'BBMCA3','transform_set_to_default'),
    (None,'BBMCB','transform_set_to_default'),
    (None,'BBMCB2','transform_set_to_default'),
    (None,'BBMCB3','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'DOXY','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FRZ','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'PSN','transform_set_to_default'),
    (None,'SPD','transform_set_to_default'),
    (None,'SPM','transform_set_to_default'),
    (None,'TID','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SQN','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WPAC','transform_set_to_default'),
    (None,'ZI024_WSG','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterPnt field translations
TransportationWaterPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BGT','BGT',None),
    ('CAA','CAA',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('PCF','PCF',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('THI','THI',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# TransportationWaterSrf field translations
TransportationWaterSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('ATB','ATB',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('BH141_AWBA','BH141_AWBA',None),
    ('BH141_AWBB','BH141_AWBB',None),
    ('BH141_IBOA','BH141_IBOA',None),
    ('BH141_IBOB','BH141_IBOB',None),
    ('BH141_SHDA','BH141_SHDA',None),
    ('BH141_SHDB','BH141_SHDB',None),
    ('BH141_SLTA','BH141_SLTA',None),
    ('BH141_SLTB','BH141_SLTB',None),
    ('BH141_WBHA','BH141_WBHA',None),
    ('BH141_WBHB','BH141_WBHB',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BPWHAC','BPWHAC',None),
    ('BPWHAL','BPWHAL',None),
    ('BPWHAU','BPWHAU',None),
    ('BPWHBC','BPWHBC',None),
    ('BPWHBL','BPWHBL',None),
    ('BPWHBU','BPWHBU',None),
    ('BPWSAC','BPWSAC',None),
    ('BPWSAL','BPWSAL',None),
    ('BPWSAU','BPWSAU',None),
    ('BPWSBC','BPWSBC',None),
    ('BPWSBL','BPWSBL',None),
    ('BPWSBU','BPWSBU',None),
    ('BWVCAC','BWVCAC',None),
    ('BWVCAL','BWVCAL',None),
    ('BWVCAU','BWVCAU',None),
    ('BWVCBC','BWVCBC',None),
    ('BWVCBL','BWVCBL',None),
    ('BWVCBU','BWVCBU',None),
    ('CAA','CAA',None),
    ('CDA','CDA',None),
    ('CDL','CDL',None),
    ('COS','COS',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('HST','HST',None),
    ('HST2','HST2',None),
    ('HST3','HST3',None),
    ('LMC','LMC',None),
    ('LNU','LNU',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('MUB','MUB',None),
    ('MWD','MWD',None),
    ('NVS','NVS',None),
    ('PCF','PCF',None),
    ('PWA','PWA',None),
    ('RLE','RLE',None),
    ('SBB','SBB',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TRS','TRS',None),
    ('TRS2','TRS2',None),
    ('TRS3','TRS3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('WD3','WD3',None),
    ('WDH','WDH',None),
    ('WDL','WDL',None),
    ('WDU','WDU',None),
    ('WID','WID',None),
    ('WVA','WVA',None),
    ('WVH','WVH',None),
    ('WVL','WVL',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI024_YWQ','ZI024_YWQ',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BBMCA','transform_set_to_default'),
    (None,'BBMCA2','transform_set_to_default'),
    (None,'BBMCA3','transform_set_to_default'),
    (None,'BBMCB','transform_set_to_default'),
    (None,'BBMCB2','transform_set_to_default'),
    (None,'BBMCB3','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'DOXY','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FRZ','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'TID','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SQN','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WPAC','transform_set_to_default'),
    (None,'ZI024_WSG','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureCrv field translations
UtilityInfrastructureCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('CAB','CAB',None),
    ('CAB2','CAB2',None),
    ('CAB3','CAB3',None),
    ('CST','CST',None),
    ('CWT','CWT',None),
    ('DEV','DEV',None),
    ('DIM','DIM',None),
    ('F_CODE','F_CODE',None),
    ('FLO','FLO',None),
    ('HGT','HGT',None),
    ('KVA','KVA',None),
    ('LMC','LMC',None),
    ('LOC','LOC',None),
    ('LZN','LZN',None),
    ('NPL','NPL',None),
    ('OHC','OHC',None),
    ('OWO','OWO',None),
    ('PCF','PCF',None),
    ('PFH','PFH',None),
    ('PLT','PLT',None),
    ('PLT2','PLT2',None),
    ('PLT3','PLT3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RLE','RLE',None),
    ('RTA','RTA',None),
    ('SBB','SBB',None),
    ('SPT','SPT',None),
    ('TST','TST',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VOI','VOI',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI025_WLE','ZI025_WLE',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'LEA','transform_set_to_default'),
    (None,'MCC','transform_set_to_default'),
    (None,'MCC2','transform_set_to_default'),
    (None,'MCC3','transform_set_to_default'),
    (None,'PMPR','transform_set_to_default'),
    (None,'VCO','transform_set_to_default'),
    (None,'WVA','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    (None,'ZI025_HDP','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructurePnt field translations
UtilityInfrastructurePntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AT005_CAB','AT005_CAB',None),
    ('AT005_CAB2','AT005_CAB2',None),
    ('AT005_CAB3','AT005_CAB3',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('DIM','DIM',None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('GUG','GUG',None),
    ('HEI','HEI',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('MCC','MCC',None),
    ('MCC2','MCC2',None),
    ('MCC3','MCC3',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('RAC','RAC',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SPT','SPT',None),
    ('SRL','SRL',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('TOS','TOS',None),
    ('UFI','UFI','transform_set_UFI'),
    ('UTY','UTY',None),
    ('UTY2','UTY2',None),
    ('UTY3','UTY3',None),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI018_WIT','ZI018_WIT',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZI032_GUG','ZI032_GUG',None),
    ('ZI032_PYC','ZI032_PYC',None),
    ('ZI032_PYM','ZI032_PYM',None),
    ('ZI032_TOS','ZI032_TOS',None),
    ('ZVH','ZVH',None),
    (None,'ADUR','transform_set_to_default'),
    (None,'ANFL','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DCAP','transform_set_to_default'),
    (None,'DINF','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'GRD','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'LUN','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'WDH','transform_set_to_default'),
    (None,'WDL','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'WLSS','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI014_PBY','transform_set_to_default'),
    (None,'ZI014_PBY2','transform_set_to_default'),
    (None,'ZI014_PBY3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_DRL','transform_set_to_default'),
    (None,'ZI024_DVPT','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_PMP','transform_set_to_default'),
    (None,'ZI024_PUR','transform_set_to_default'),
    (None,'ZI024_PUR2','transform_set_to_default'),
    (None,'ZI024_PUR3','transform_set_to_default'),
    (None,'ZI024_PUR4','transform_set_to_default'),
    (None,'ZI024_PUR5','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# UtilityInfrastructureSrf field translations
UtilityInfrastructureSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('ADR','ADR',None),
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('AWP','AWP',None),
    ('BEN','BEN',None),
    ('CAA','CAA',None),
    ('EPW','EPW',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PCF','PCF',None),
    ('POS','POS',None),
    ('POS2','POS2',None),
    ('POS3','POS3',None),
    ('PPO','PPO',None),
    ('PPO2','PPO2',None),
    ('PPO3','PPO3',None),
    ('SBT','SBT',None),
    ('SBT2','SBT2',None),
    ('SBT3','SBT3',None),
    ('SSR','SSR',None),
    ('SSR2','SSR2',None),
    ('SSR3','SSR3',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VCM','VCM',None),
    ('VCM2','VCM2',None),
    ('VCM3','VCM3',None),
    ('VOI','VOI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'ADUR','transform_set_to_default'),
    (None,'ANFL','transform_set_to_default'),
    (None,'CNCP','transform_set_to_default'),
    (None,'COS','transform_set_to_default'),
    (None,'DCAP','transform_set_to_default'),
    (None,'DINF','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'GRD','transform_set_to_default'),
    (None,'LEA','transform_set_to_default'),
    (None,'LUN','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'WDH','transform_set_to_default'),
    (None,'WDL','transform_set_to_default'),
    (None,'WDST','transform_set_to_default'),
    (None,'WLSS','transform_set_to_default'),
    (None,'ZI005_FNA2','transform_set_to_default'),
    (None,'ZI005_FNA3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_GNT2','transform_set_to_default'),
    (None,'ZI005_GNT3','transform_set_to_default'),
    (None,'ZI005_NFN2','transform_set_to_default'),
    (None,'ZI005_NFN3','transform_set_to_default'),
    (None,'ZI014_PBY','transform_set_to_default'),
    (None,'ZI014_PBY2','transform_set_to_default'),
    (None,'ZI014_PBY3','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_AWO','transform_set_to_default'),
    (None,'ZI024_AWOI','transform_set_to_default'),
    (None,'ZI024_AWOX','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_DRL','transform_set_to_default'),
    (None,'ZI024_DVPT','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_PMP','transform_set_to_default'),
    (None,'ZI024_PUR','transform_set_to_default'),
    (None,'ZI024_PUR2','transform_set_to_default'),
    (None,'ZI024_PUR3','transform_set_to_default'),
    (None,'ZI024_PUR4','transform_set_to_default'),
    (None,'ZI024_PUR5','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_WUR2','transform_set_to_default'),
    (None,'ZI024_WUR3','transform_set_to_default'),
    (None,'ZI024_WUR4','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationCrv field translations
VegetationCrvFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Crv_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BEN','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'VSP','transform_set_to_default'),
    (None,'VSP2','transform_set_to_default'),
    (None,'VSP3','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationPnt field translations
VegetationPntFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Pnt_fields) + [ \
    ('BEN','BEN',None),
    ('F_CODE','F_CODE',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('TRE','TRE',None),
    ('UFI','UFI','transform_set_UFI'),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'SDSC','transform_set_to_default'),
    (None,'SDSL','transform_set_to_default'),
    (None,'SDSU','transform_set_to_default'),
    (None,'VSP','transform_set_to_default'),
    (None,'ZI005_FNA','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI005_NFN','transform_set_to_default') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)

# VegetationSrf field translations
VegetationSrfFields = copy.deepcopy(common_geom_fields) + copy.deepcopy(common_Srf_fields) + [ \
    ('AOO','AOO',None),
    ('ARA','ARA',None),
    ('BMC','BMC',None),
    ('BMC2','BMC2',None),
    ('BMC3','BMC3',None),
    ('BOC','BOC',None),
    ('DMBC','DMBC',None),
    ('DMBL','DMBL',None),
    ('DMBU','DMBU',None),
    ('DMT','DMT',None),
    ('F_CODE','F_CODE',None),
    ('FFN','FFN',None),
    ('FFN2','FFN2',None),
    ('FFN3','FFN3',None),
    ('HGT','HGT',None),
    ('LMC','LMC',None),
    ('LZN','LZN',None),
    ('PVH','PVH',None),
    ('SBC','SBC',None),
    ('SDSC','SDSC',None),
    ('TID','TID',None),
    ('TRE','TRE',None),
    ('TSCC','TSCC',None),
    ('TSCL','TSCL',None),
    ('TSCU','TSCU',None),
    ('UFI','UFI','transform_set_UFI'),
    ('VSP','VSP',None),
    ('VSP2','VSP2',None),
    ('VSP3','VSP3',None),
    ('VTI','VTI',None),
    ('WID','WID',None),
    ('ZI005_FNA','ZI005_FNA',None),
    ('ZI005_NFN','ZI005_NFN',None),
    ('ZI020_GE4','ZI020_GE4',None),
    ('ZI024_HYP','ZI024_HYP',None),
    ('ZI026_CTUC','ZI026_CTUC',None),
    ('ZI026_CTUL','ZI026_CTUL',None),
    ('ZI026_CTUU','ZI026_CTUU',None),
    ('ZVH','ZVH',None),
    (None,'BEN','transform_set_to_default'),
    (None,'CAA','transform_set_to_default'),
    (None,'DZP','transform_set_to_default'),
    (None,'FUFI','transform_set_FUFI_to_UFI_when_needed'),
    (None,'FURL','transform_set_to_default'),
    (None,'GDBV','transform_set_geodbversion'),
    (None,'HDP','transform_set_to_default'),
    (None,'SNDC','transform_set_to_default'),
    (None,'SNDL','transform_set_to_default'),
    (None,'SNDU','transform_set_to_default'),
    (None,'WDAC','transform_set_to_default'),
    (None,'WDAL','transform_set_to_default'),
    (None,'WDAU','transform_set_to_default'),
    (None,'ZI005_GNT','transform_set_to_default'),
    (None,'ZI024_ASE','transform_set_to_default'),
    (None,'ZI024_CFR','transform_set_to_default'),
    (None,'ZI024_CLO','transform_set_to_default'),
    (None,'ZI024_CYN','transform_set_to_default'),
    (None,'ZI024_FMR','transform_set_to_default'),
    (None,'ZI024_FRR','transform_set_to_default'),
    (None,'ZI024_HAR','transform_set_to_default'),
    (None,'ZI024_MGN','transform_set_to_default'),
    (None,'ZI024_PHW','transform_set_to_default'),
    (None,'ZI024_SCC','transform_set_to_default'),
    (None,'ZI024_SUL','transform_set_to_default'),
    (None,'ZI024_TDS','transform_set_to_default'),
    (None,'ZI024_TEP','transform_set_to_default'),
    (None,'ZI024_TUR','transform_set_to_default'),
    (None,'ZI024_WAC','transform_set_to_default'),
    (None,'ZI024_WTNO','transform_set_to_default'),
    (None,'ZI024_WUR','transform_set_to_default'),
    (None,'ZI024_YWQ','transform_set_to_default'),
    (None,'TWS','transform_TWS'),
    ('SDSL','SDSL','transform_metre_to_decimetre'),
    ('SDSU','SDSU','transform_metre_to_decimetre'),
    ('VEG','VEG','transform_VEG') \
     ] + copy.deepcopy(EntityCollectionFCSubsetFields) + copy.deepcopy(RestrictionInfoFCSubsetFields) + copy.deepcopy(common_metadata_translate_fields)



